'''
NETPYNE simulator compliant export for:

Components:
    null (Type: notes)
    CorticalCell (Type: IF_curr_exp:  tau_refrac=2.0 (dimensionless) v_thresh=-50.0 (dimensionless) tau_m=10.0 (dimensionless) v_rest=-65.0 (dimensionless) v_reset=-65.0 (dimensionless) cm=0.25 (dimensionless) i_offset=0.0 (dimensionless) tau_syn_E=0.5 (dimensionless) tau_syn_I=0.5 (dimensionless) v_init=-65.0 (dimensionless) MSEC=0.001 (SI time) MVOLT=0.001 (SI voltage) NFARAD=1.0E-9 (SI capacitance))
    ampa (Type: expCurrSynapse:  tau_syn=0.5 (dimensionless) MSEC=0.001 (SI time) MVOLT=0.001 (SI voltage) NAMP=1.0E-9 (SI current))
    gaba (Type: expCurrSynapse:  tau_syn=0.5 (dimensionless) MSEC=0.001 (SI time) MVOLT=0.001 (SI voltage) NAMP=1.0E-9 (SI current))
    InputCell (Type: SpikeSourcePoisson:  start=0.0 (SI time) duration=1.0E7 (SI time) rate=150.0 (SI per_time) end=1.0E7 (SI time) LONG_TIME=3.6E12 (SI time))
    Example6_PyNN (Type: network)
    SimExample6_PyNN (Type: Simulation:  length=0.1 (SI time) step=2.5E-5 (SI time))


    This NETPYNE file has been generated by org.neuroml.export (see https://github.com/NeuroML/org.neuroml.export)
         org.neuroml.export  v1.5.4
         org.neuroml.model   v1.5.4
         jLEMS               v0.9.9.1

'''
# Main NetPyNE script for: Example6_PyNN

# See https://github.com/Neurosim-lab/netpyne

from netpyne import specs  # import netpyne specs module
from netpyne import sim    # import netpyne sim module
from netpyne import __version__ as version

from neuron import h

import sys
import time
import datetime

setup_start = time.time()
report_file = open('report.SimExample6_PyNN.txt','w')
report_file.write('# Report of running simulation with NetPyNE v%s\n'%version)
report_file.write('Simulator=NetPyNE\n')
report_file.write('SimulatorVersion=%s\n'%version)
report_file.write('SimulationFile=%s\n'%__file__)
report_file.write('PythonVersion=%s\n'%sys.version.replace('\n',' '))
report_file.write('NeuronVersion=%s\n'%h.nrnversion())
report_file.write('NeuroMLExportVersion=1.5.4\n')


###############################################################################
# NETWORK PARAMETERS
###############################################################################

nml2_file_name = 'Example6_PyNN.net.nml'

###############################################################################
# SIMULATION PARAMETERS
###############################################################################

simConfig = specs.SimConfig()   # object of class SimConfig to store the simulation configuration

# Simulation parameters
simConfig.duration = simConfig.tstop = 100.0 # Duration of the simulation, in ms
simConfig.dt = 0.025 # Internal integration timestep to use

# Seeds for randomizers (connectivity, input stimulation and cell locations)
# Note: locations and connections should be fully specified by the structure of the NeuroML,
# so seeds for conn & loc shouldn't affect networks structure/behaviour
simConfig.seeds = {'conn': 0, 'stim': 123442, 'loc': 0} 

simConfig.createNEURONObj = 1  # create HOC objects when instantiating network
simConfig.createPyStruct = 1  # create Python structure (simulator-independent) when instantiating network
simConfig.verbose = False  # show detailed messages 

# Recording 
simConfig.recordCells = ['all']  
simConfig.recordTraces = {}
simConfig.saveCellSecs=False
simConfig.saveCellConns=False
simConfig.gatherOnlySimData=True 

# For saving to file: SimExample6_PyNN.L23_E.v.dat (ref: SimExample6_PyNN_L23_E_v_dat)
# Column: L23_E_0_CorticalCell_v: Pop: L23_E; cell: 0; segment id: $oc.segment_id; segment name: soma; Neuron loc: soma(0.5); value: v (v)
simConfig.recordTraces['SimExample6_PyNN_L23_E_v_dat_L23_E_0_soma_v'] = {'sec':'soma','loc':0.5,'var':'v','conds':{'pop':'L23_E','cellLabel':0}}
# Column: L23_E_1_CorticalCell_v: Pop: L23_E; cell: 1; segment id: $oc.segment_id; segment name: soma; Neuron loc: soma(0.5); value: v (v)
simConfig.recordTraces['SimExample6_PyNN_L23_E_v_dat_L23_E_1_soma_v'] = {'sec':'soma','loc':0.5,'var':'v','conds':{'pop':'L23_E','cellLabel':1}}

# For saving to file: SimExample6_PyNN.L23_I.v.dat (ref: SimExample6_PyNN_L23_I_v_dat)
# Column: L23_I_0_CorticalCell_v: Pop: L23_I; cell: 0; segment id: $oc.segment_id; segment name: soma; Neuron loc: soma(0.5); value: v (v)
simConfig.recordTraces['SimExample6_PyNN_L23_I_v_dat_L23_I_0_soma_v'] = {'sec':'soma','loc':0.5,'var':'v','conds':{'pop':'L23_I','cellLabel':0}}
# Column: L23_I_1_CorticalCell_v: Pop: L23_I; cell: 1; segment id: $oc.segment_id; segment name: soma; Neuron loc: soma(0.5); value: v (v)
simConfig.recordTraces['SimExample6_PyNN_L23_I_v_dat_L23_I_1_soma_v'] = {'sec':'soma','loc':0.5,'var':'v','conds':{'pop':'L23_I','cellLabel':1}}

# For saving to file: SimExample6_PyNN.L4_E.v.dat (ref: SimExample6_PyNN_L4_E_v_dat)
# Column: L4_E_0_CorticalCell_v: Pop: L4_E; cell: 0; segment id: $oc.segment_id; segment name: soma; Neuron loc: soma(0.5); value: v (v)
simConfig.recordTraces['SimExample6_PyNN_L4_E_v_dat_L4_E_0_soma_v'] = {'sec':'soma','loc':0.5,'var':'v','conds':{'pop':'L4_E','cellLabel':0}}
# Column: L4_E_1_CorticalCell_v: Pop: L4_E; cell: 1; segment id: $oc.segment_id; segment name: soma; Neuron loc: soma(0.5); value: v (v)
simConfig.recordTraces['SimExample6_PyNN_L4_E_v_dat_L4_E_1_soma_v'] = {'sec':'soma','loc':0.5,'var':'v','conds':{'pop':'L4_E','cellLabel':1}}

# For saving to file: SimExample6_PyNN.L4_I.v.dat (ref: SimExample6_PyNN_L4_I_v_dat)
# Column: L4_I_0_CorticalCell_v: Pop: L4_I; cell: 0; segment id: $oc.segment_id; segment name: soma; Neuron loc: soma(0.5); value: v (v)
simConfig.recordTraces['SimExample6_PyNN_L4_I_v_dat_L4_I_0_soma_v'] = {'sec':'soma','loc':0.5,'var':'v','conds':{'pop':'L4_I','cellLabel':0}}
# Column: L4_I_1_CorticalCell_v: Pop: L4_I; cell: 1; segment id: $oc.segment_id; segment name: soma; Neuron loc: soma(0.5); value: v (v)
simConfig.recordTraces['SimExample6_PyNN_L4_I_v_dat_L4_I_1_soma_v'] = {'sec':'soma','loc':0.5,'var':'v','conds':{'pop':'L4_I','cellLabel':1}}

# For saving to file: SimExample6_PyNN.L5_E.v.dat (ref: SimExample6_PyNN_L5_E_v_dat)
# Column: L5_E_0_CorticalCell_v: Pop: L5_E; cell: 0; segment id: $oc.segment_id; segment name: soma; Neuron loc: soma(0.5); value: v (v)
simConfig.recordTraces['SimExample6_PyNN_L5_E_v_dat_L5_E_0_soma_v'] = {'sec':'soma','loc':0.5,'var':'v','conds':{'pop':'L5_E','cellLabel':0}}
# Column: L5_E_1_CorticalCell_v: Pop: L5_E; cell: 1; segment id: $oc.segment_id; segment name: soma; Neuron loc: soma(0.5); value: v (v)
simConfig.recordTraces['SimExample6_PyNN_L5_E_v_dat_L5_E_1_soma_v'] = {'sec':'soma','loc':0.5,'var':'v','conds':{'pop':'L5_E','cellLabel':1}}

# For saving to file: SimExample6_PyNN.L5_I.v.dat (ref: SimExample6_PyNN_L5_I_v_dat)
# Column: L5_I_0_CorticalCell_v: Pop: L5_I; cell: 0; segment id: $oc.segment_id; segment name: soma; Neuron loc: soma(0.5); value: v (v)
simConfig.recordTraces['SimExample6_PyNN_L5_I_v_dat_L5_I_0_soma_v'] = {'sec':'soma','loc':0.5,'var':'v','conds':{'pop':'L5_I','cellLabel':0}}
# Column: L5_I_1_CorticalCell_v: Pop: L5_I; cell: 1; segment id: $oc.segment_id; segment name: soma; Neuron loc: soma(0.5); value: v (v)
simConfig.recordTraces['SimExample6_PyNN_L5_I_v_dat_L5_I_1_soma_v'] = {'sec':'soma','loc':0.5,'var':'v','conds':{'pop':'L5_I','cellLabel':1}}

# For saving to file: SimExample6_PyNN.L6_E.v.dat (ref: SimExample6_PyNN_L6_E_v_dat)
# Column: L6_E_0_CorticalCell_v: Pop: L6_E; cell: 0; segment id: $oc.segment_id; segment name: soma; Neuron loc: soma(0.5); value: v (v)
simConfig.recordTraces['SimExample6_PyNN_L6_E_v_dat_L6_E_0_soma_v'] = {'sec':'soma','loc':0.5,'var':'v','conds':{'pop':'L6_E','cellLabel':0}}
# Column: L6_E_1_CorticalCell_v: Pop: L6_E; cell: 1; segment id: $oc.segment_id; segment name: soma; Neuron loc: soma(0.5); value: v (v)
simConfig.recordTraces['SimExample6_PyNN_L6_E_v_dat_L6_E_1_soma_v'] = {'sec':'soma','loc':0.5,'var':'v','conds':{'pop':'L6_E','cellLabel':1}}

# For saving to file: SimExample6_PyNN.L6_I.v.dat (ref: SimExample6_PyNN_L6_I_v_dat)
# Column: L6_I_0_CorticalCell_v: Pop: L6_I; cell: 0; segment id: $oc.segment_id; segment name: soma; Neuron loc: soma(0.5); value: v (v)
simConfig.recordTraces['SimExample6_PyNN_L6_I_v_dat_L6_I_0_soma_v'] = {'sec':'soma','loc':0.5,'var':'v','conds':{'pop':'L6_I','cellLabel':0}}
# Column: L6_I_1_CorticalCell_v: Pop: L6_I; cell: 1; segment id: $oc.segment_id; segment name: soma; Neuron loc: soma(0.5); value: v (v)
simConfig.recordTraces['SimExample6_PyNN_L6_I_v_dat_L6_I_1_soma_v'] = {'sec':'soma','loc':0.5,'var':'v','conds':{'pop':'L6_I','cellLabel':1}}



simConfig.plotCells = ['all']


simConfig.recordStim = True  # record spikes of cell stims
simConfig.recordStep = simConfig.dt # Step size in ms to save data (eg. V traces, LFP, etc)



# Analysis and plotting, see http://neurosimlab.org/netpyne/reference.html#analysis-related-functions
simConfig.analysis['plotRaster'] = False  # Plot raster
simConfig.analysis['plot2Dnet'] = False  # Plot 2D net cells and connections
simConfig.analysis['plotSpikeHist'] = False # plot spike histogram
simConfig.analysis['plotConn'] = False # plot network connectivity
simConfig.analysis['plotSpikePSD'] = False # plot 3d architecture

# Saving
simConfig.filename = 'Example6_PyNN.txt'  # Set file output name
simConfig.saveFileStep = simConfig.dt # step size in ms to save data to disk
# simConfig.saveDat = True # save to dat file


###############################################################################
# IMPORT & RUN
###############################################################################

print("Running a NetPyNE based simulation for %sms (dt: %sms) at %s degC"%(simConfig.duration, simConfig.dt, simConfig.hParams['celsius']))

setup_sim_start = time.time()
gids = sim.importNeuroML2SimulateAnalyze(nml2_file_name,simConfig)

sim_end = time.time()
setup_sim_time = sim_end - setup_sim_start
print("Finished NetPyNE simulation in %f seconds (%f mins)..."%(setup_sim_time, setup_sim_time/60.0))


###############################################################################
#   Saving data (this ensures the data gets saved in the format/files 
#   as specified in the LEMS <Simulation> element)
###############################################################################


if sim.rank==0: 
    print("Saving traces to file: SimExample6_PyNN.L23_E.v.dat (ref: SimExample6_PyNN_L23_E_v_dat)")

 
    # Column: t
    col_SimExample6_PyNN_L23_E_v_dat_t = [i*simConfig.dt for i in range(int(simConfig.duration/simConfig.dt))]

    # Column: L23_E_0_CorticalCell_v: Pop: L23_E; cell: 0; segment id: $oc.segment_id; segment name: soma; value: v
    col_SimExample6_PyNN_L23_E_v_dat_L23_E_0_CorticalCell_v = sim.allSimData['SimExample6_PyNN_L23_E_v_dat_L23_E_0_soma_v']['cell_%s'%gids['L23_E'][0]]

    # Column: L23_E_1_CorticalCell_v: Pop: L23_E; cell: 1; segment id: $oc.segment_id; segment name: soma; value: v
    col_SimExample6_PyNN_L23_E_v_dat_L23_E_1_CorticalCell_v = sim.allSimData['SimExample6_PyNN_L23_E_v_dat_L23_E_1_soma_v']['cell_%s'%gids['L23_E'][1]]

    dat_file_SimExample6_PyNN_L23_E_v_dat = open('SimExample6_PyNN.L23_E.v.dat', 'w')
    for i in range(len(col_SimExample6_PyNN_L23_E_v_dat_t)):
        dat_file_SimExample6_PyNN_L23_E_v_dat.write( '%s\t'%(col_SimExample6_PyNN_L23_E_v_dat_t[i]/1000.0) +  '%s\t'%(col_SimExample6_PyNN_L23_E_v_dat_L23_E_0_CorticalCell_v[i]/1000.0) +  '%s\t'%(col_SimExample6_PyNN_L23_E_v_dat_L23_E_1_CorticalCell_v[i]/1000.0) +  '\n')
    dat_file_SimExample6_PyNN_L23_E_v_dat.close()

    print("Saving traces to file: SimExample6_PyNN.L23_I.v.dat (ref: SimExample6_PyNN_L23_I_v_dat)")

 
    # Column: t
    col_SimExample6_PyNN_L23_I_v_dat_t = [i*simConfig.dt for i in range(int(simConfig.duration/simConfig.dt))]

    # Column: L23_I_0_CorticalCell_v: Pop: L23_I; cell: 0; segment id: $oc.segment_id; segment name: soma; value: v
    col_SimExample6_PyNN_L23_I_v_dat_L23_I_0_CorticalCell_v = sim.allSimData['SimExample6_PyNN_L23_I_v_dat_L23_I_0_soma_v']['cell_%s'%gids['L23_I'][0]]

    # Column: L23_I_1_CorticalCell_v: Pop: L23_I; cell: 1; segment id: $oc.segment_id; segment name: soma; value: v
    col_SimExample6_PyNN_L23_I_v_dat_L23_I_1_CorticalCell_v = sim.allSimData['SimExample6_PyNN_L23_I_v_dat_L23_I_1_soma_v']['cell_%s'%gids['L23_I'][1]]

    dat_file_SimExample6_PyNN_L23_I_v_dat = open('SimExample6_PyNN.L23_I.v.dat', 'w')
    for i in range(len(col_SimExample6_PyNN_L23_I_v_dat_t)):
        dat_file_SimExample6_PyNN_L23_I_v_dat.write( '%s\t'%(col_SimExample6_PyNN_L23_I_v_dat_t[i]/1000.0) +  '%s\t'%(col_SimExample6_PyNN_L23_I_v_dat_L23_I_0_CorticalCell_v[i]/1000.0) +  '%s\t'%(col_SimExample6_PyNN_L23_I_v_dat_L23_I_1_CorticalCell_v[i]/1000.0) +  '\n')
    dat_file_SimExample6_PyNN_L23_I_v_dat.close()

    print("Saving traces to file: SimExample6_PyNN.L4_E.v.dat (ref: SimExample6_PyNN_L4_E_v_dat)")

 
    # Column: t
    col_SimExample6_PyNN_L4_E_v_dat_t = [i*simConfig.dt for i in range(int(simConfig.duration/simConfig.dt))]

    # Column: L4_E_0_CorticalCell_v: Pop: L4_E; cell: 0; segment id: $oc.segment_id; segment name: soma; value: v
    col_SimExample6_PyNN_L4_E_v_dat_L4_E_0_CorticalCell_v = sim.allSimData['SimExample6_PyNN_L4_E_v_dat_L4_E_0_soma_v']['cell_%s'%gids['L4_E'][0]]

    # Column: L4_E_1_CorticalCell_v: Pop: L4_E; cell: 1; segment id: $oc.segment_id; segment name: soma; value: v
    col_SimExample6_PyNN_L4_E_v_dat_L4_E_1_CorticalCell_v = sim.allSimData['SimExample6_PyNN_L4_E_v_dat_L4_E_1_soma_v']['cell_%s'%gids['L4_E'][1]]

    dat_file_SimExample6_PyNN_L4_E_v_dat = open('SimExample6_PyNN.L4_E.v.dat', 'w')
    for i in range(len(col_SimExample6_PyNN_L4_E_v_dat_t)):
        dat_file_SimExample6_PyNN_L4_E_v_dat.write( '%s\t'%(col_SimExample6_PyNN_L4_E_v_dat_t[i]/1000.0) +  '%s\t'%(col_SimExample6_PyNN_L4_E_v_dat_L4_E_0_CorticalCell_v[i]/1000.0) +  '%s\t'%(col_SimExample6_PyNN_L4_E_v_dat_L4_E_1_CorticalCell_v[i]/1000.0) +  '\n')
    dat_file_SimExample6_PyNN_L4_E_v_dat.close()

    print("Saving traces to file: SimExample6_PyNN.L4_I.v.dat (ref: SimExample6_PyNN_L4_I_v_dat)")

 
    # Column: t
    col_SimExample6_PyNN_L4_I_v_dat_t = [i*simConfig.dt for i in range(int(simConfig.duration/simConfig.dt))]

    # Column: L4_I_0_CorticalCell_v: Pop: L4_I; cell: 0; segment id: $oc.segment_id; segment name: soma; value: v
    col_SimExample6_PyNN_L4_I_v_dat_L4_I_0_CorticalCell_v = sim.allSimData['SimExample6_PyNN_L4_I_v_dat_L4_I_0_soma_v']['cell_%s'%gids['L4_I'][0]]

    # Column: L4_I_1_CorticalCell_v: Pop: L4_I; cell: 1; segment id: $oc.segment_id; segment name: soma; value: v
    col_SimExample6_PyNN_L4_I_v_dat_L4_I_1_CorticalCell_v = sim.allSimData['SimExample6_PyNN_L4_I_v_dat_L4_I_1_soma_v']['cell_%s'%gids['L4_I'][1]]

    dat_file_SimExample6_PyNN_L4_I_v_dat = open('SimExample6_PyNN.L4_I.v.dat', 'w')
    for i in range(len(col_SimExample6_PyNN_L4_I_v_dat_t)):
        dat_file_SimExample6_PyNN_L4_I_v_dat.write( '%s\t'%(col_SimExample6_PyNN_L4_I_v_dat_t[i]/1000.0) +  '%s\t'%(col_SimExample6_PyNN_L4_I_v_dat_L4_I_0_CorticalCell_v[i]/1000.0) +  '%s\t'%(col_SimExample6_PyNN_L4_I_v_dat_L4_I_1_CorticalCell_v[i]/1000.0) +  '\n')
    dat_file_SimExample6_PyNN_L4_I_v_dat.close()

    print("Saving traces to file: SimExample6_PyNN.L5_E.v.dat (ref: SimExample6_PyNN_L5_E_v_dat)")

 
    # Column: t
    col_SimExample6_PyNN_L5_E_v_dat_t = [i*simConfig.dt for i in range(int(simConfig.duration/simConfig.dt))]

    # Column: L5_E_0_CorticalCell_v: Pop: L5_E; cell: 0; segment id: $oc.segment_id; segment name: soma; value: v
    col_SimExample6_PyNN_L5_E_v_dat_L5_E_0_CorticalCell_v = sim.allSimData['SimExample6_PyNN_L5_E_v_dat_L5_E_0_soma_v']['cell_%s'%gids['L5_E'][0]]

    # Column: L5_E_1_CorticalCell_v: Pop: L5_E; cell: 1; segment id: $oc.segment_id; segment name: soma; value: v
    col_SimExample6_PyNN_L5_E_v_dat_L5_E_1_CorticalCell_v = sim.allSimData['SimExample6_PyNN_L5_E_v_dat_L5_E_1_soma_v']['cell_%s'%gids['L5_E'][1]]

    dat_file_SimExample6_PyNN_L5_E_v_dat = open('SimExample6_PyNN.L5_E.v.dat', 'w')
    for i in range(len(col_SimExample6_PyNN_L5_E_v_dat_t)):
        dat_file_SimExample6_PyNN_L5_E_v_dat.write( '%s\t'%(col_SimExample6_PyNN_L5_E_v_dat_t[i]/1000.0) +  '%s\t'%(col_SimExample6_PyNN_L5_E_v_dat_L5_E_0_CorticalCell_v[i]/1000.0) +  '%s\t'%(col_SimExample6_PyNN_L5_E_v_dat_L5_E_1_CorticalCell_v[i]/1000.0) +  '\n')
    dat_file_SimExample6_PyNN_L5_E_v_dat.close()

    print("Saving traces to file: SimExample6_PyNN.L5_I.v.dat (ref: SimExample6_PyNN_L5_I_v_dat)")

 
    # Column: t
    col_SimExample6_PyNN_L5_I_v_dat_t = [i*simConfig.dt for i in range(int(simConfig.duration/simConfig.dt))]

    # Column: L5_I_0_CorticalCell_v: Pop: L5_I; cell: 0; segment id: $oc.segment_id; segment name: soma; value: v
    col_SimExample6_PyNN_L5_I_v_dat_L5_I_0_CorticalCell_v = sim.allSimData['SimExample6_PyNN_L5_I_v_dat_L5_I_0_soma_v']['cell_%s'%gids['L5_I'][0]]

    # Column: L5_I_1_CorticalCell_v: Pop: L5_I; cell: 1; segment id: $oc.segment_id; segment name: soma; value: v
    col_SimExample6_PyNN_L5_I_v_dat_L5_I_1_CorticalCell_v = sim.allSimData['SimExample6_PyNN_L5_I_v_dat_L5_I_1_soma_v']['cell_%s'%gids['L5_I'][1]]

    dat_file_SimExample6_PyNN_L5_I_v_dat = open('SimExample6_PyNN.L5_I.v.dat', 'w')
    for i in range(len(col_SimExample6_PyNN_L5_I_v_dat_t)):
        dat_file_SimExample6_PyNN_L5_I_v_dat.write( '%s\t'%(col_SimExample6_PyNN_L5_I_v_dat_t[i]/1000.0) +  '%s\t'%(col_SimExample6_PyNN_L5_I_v_dat_L5_I_0_CorticalCell_v[i]/1000.0) +  '%s\t'%(col_SimExample6_PyNN_L5_I_v_dat_L5_I_1_CorticalCell_v[i]/1000.0) +  '\n')
    dat_file_SimExample6_PyNN_L5_I_v_dat.close()

    print("Saving traces to file: SimExample6_PyNN.L6_E.v.dat (ref: SimExample6_PyNN_L6_E_v_dat)")

 
    # Column: t
    col_SimExample6_PyNN_L6_E_v_dat_t = [i*simConfig.dt for i in range(int(simConfig.duration/simConfig.dt))]

    # Column: L6_E_0_CorticalCell_v: Pop: L6_E; cell: 0; segment id: $oc.segment_id; segment name: soma; value: v
    col_SimExample6_PyNN_L6_E_v_dat_L6_E_0_CorticalCell_v = sim.allSimData['SimExample6_PyNN_L6_E_v_dat_L6_E_0_soma_v']['cell_%s'%gids['L6_E'][0]]

    # Column: L6_E_1_CorticalCell_v: Pop: L6_E; cell: 1; segment id: $oc.segment_id; segment name: soma; value: v
    col_SimExample6_PyNN_L6_E_v_dat_L6_E_1_CorticalCell_v = sim.allSimData['SimExample6_PyNN_L6_E_v_dat_L6_E_1_soma_v']['cell_%s'%gids['L6_E'][1]]

    dat_file_SimExample6_PyNN_L6_E_v_dat = open('SimExample6_PyNN.L6_E.v.dat', 'w')
    for i in range(len(col_SimExample6_PyNN_L6_E_v_dat_t)):
        dat_file_SimExample6_PyNN_L6_E_v_dat.write( '%s\t'%(col_SimExample6_PyNN_L6_E_v_dat_t[i]/1000.0) +  '%s\t'%(col_SimExample6_PyNN_L6_E_v_dat_L6_E_0_CorticalCell_v[i]/1000.0) +  '%s\t'%(col_SimExample6_PyNN_L6_E_v_dat_L6_E_1_CorticalCell_v[i]/1000.0) +  '\n')
    dat_file_SimExample6_PyNN_L6_E_v_dat.close()

    print("Saving traces to file: SimExample6_PyNN.L6_I.v.dat (ref: SimExample6_PyNN_L6_I_v_dat)")

 
    # Column: t
    col_SimExample6_PyNN_L6_I_v_dat_t = [i*simConfig.dt for i in range(int(simConfig.duration/simConfig.dt))]

    # Column: L6_I_0_CorticalCell_v: Pop: L6_I; cell: 0; segment id: $oc.segment_id; segment name: soma; value: v
    col_SimExample6_PyNN_L6_I_v_dat_L6_I_0_CorticalCell_v = sim.allSimData['SimExample6_PyNN_L6_I_v_dat_L6_I_0_soma_v']['cell_%s'%gids['L6_I'][0]]

    # Column: L6_I_1_CorticalCell_v: Pop: L6_I; cell: 1; segment id: $oc.segment_id; segment name: soma; value: v
    col_SimExample6_PyNN_L6_I_v_dat_L6_I_1_CorticalCell_v = sim.allSimData['SimExample6_PyNN_L6_I_v_dat_L6_I_1_soma_v']['cell_%s'%gids['L6_I'][1]]

    dat_file_SimExample6_PyNN_L6_I_v_dat = open('SimExample6_PyNN.L6_I.v.dat', 'w')
    for i in range(len(col_SimExample6_PyNN_L6_I_v_dat_t)):
        dat_file_SimExample6_PyNN_L6_I_v_dat.write( '%s\t'%(col_SimExample6_PyNN_L6_I_v_dat_t[i]/1000.0) +  '%s\t'%(col_SimExample6_PyNN_L6_I_v_dat_L6_I_0_CorticalCell_v[i]/1000.0) +  '%s\t'%(col_SimExample6_PyNN_L6_I_v_dat_L6_I_1_CorticalCell_v[i]/1000.0) +  '\n')
    dat_file_SimExample6_PyNN_L6_I_v_dat.close()


    print("Saving spikes to file: SimExample6_PyNN.L23_E.spikes (ref: Spikes_file__L23_E)")
    to_record = {}
    # 0: Pop: L23_E; cell: 0; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][0]] = 0
    # 1: Pop: L23_E; cell: 1; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][1]] = 1
    # 2: Pop: L23_E; cell: 2; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][2]] = 2
    # 3: Pop: L23_E; cell: 3; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][3]] = 3
    # 4: Pop: L23_E; cell: 4; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][4]] = 4
    # 5: Pop: L23_E; cell: 5; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][5]] = 5
    # 6: Pop: L23_E; cell: 6; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][6]] = 6
    # 7: Pop: L23_E; cell: 7; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][7]] = 7
    # 8: Pop: L23_E; cell: 8; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][8]] = 8
    # 9: Pop: L23_E; cell: 9; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][9]] = 9
    # 10: Pop: L23_E; cell: 10; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][10]] = 10
    # 11: Pop: L23_E; cell: 11; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][11]] = 11
    # 12: Pop: L23_E; cell: 12; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][12]] = 12
    # 13: Pop: L23_E; cell: 13; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][13]] = 13
    # 14: Pop: L23_E; cell: 14; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][14]] = 14
    # 15: Pop: L23_E; cell: 15; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][15]] = 15
    # 16: Pop: L23_E; cell: 16; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][16]] = 16
    # 17: Pop: L23_E; cell: 17; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][17]] = 17
    # 18: Pop: L23_E; cell: 18; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][18]] = 18
    # 19: Pop: L23_E; cell: 19; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][19]] = 19
    # 20: Pop: L23_E; cell: 20; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][20]] = 20
    # 21: Pop: L23_E; cell: 21; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][21]] = 21
    # 22: Pop: L23_E; cell: 22; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][22]] = 22
    # 23: Pop: L23_E; cell: 23; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][23]] = 23
    # 24: Pop: L23_E; cell: 24; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][24]] = 24
    # 25: Pop: L23_E; cell: 25; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][25]] = 25
    # 26: Pop: L23_E; cell: 26; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][26]] = 26
    # 27: Pop: L23_E; cell: 27; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][27]] = 27
    # 28: Pop: L23_E; cell: 28; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][28]] = 28
    # 29: Pop: L23_E; cell: 29; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][29]] = 29
    # 30: Pop: L23_E; cell: 30; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][30]] = 30
    # 31: Pop: L23_E; cell: 31; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][31]] = 31
    # 32: Pop: L23_E; cell: 32; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][32]] = 32
    # 33: Pop: L23_E; cell: 33; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][33]] = 33
    # 34: Pop: L23_E; cell: 34; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][34]] = 34
    # 35: Pop: L23_E; cell: 35; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][35]] = 35
    # 36: Pop: L23_E; cell: 36; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][36]] = 36
    # 37: Pop: L23_E; cell: 37; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][37]] = 37
    # 38: Pop: L23_E; cell: 38; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][38]] = 38
    # 39: Pop: L23_E; cell: 39; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][39]] = 39
    # 40: Pop: L23_E; cell: 40; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][40]] = 40
    # 41: Pop: L23_E; cell: 41; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][41]] = 41
    # 42: Pop: L23_E; cell: 42; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][42]] = 42
    # 43: Pop: L23_E; cell: 43; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][43]] = 43
    # 44: Pop: L23_E; cell: 44; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][44]] = 44
    # 45: Pop: L23_E; cell: 45; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][45]] = 45
    # 46: Pop: L23_E; cell: 46; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][46]] = 46
    # 47: Pop: L23_E; cell: 47; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][47]] = 47
    # 48: Pop: L23_E; cell: 48; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][48]] = 48
    # 49: Pop: L23_E; cell: 49; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][49]] = 49
    # 50: Pop: L23_E; cell: 50; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][50]] = 50
    # 51: Pop: L23_E; cell: 51; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][51]] = 51
    # 52: Pop: L23_E; cell: 52; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][52]] = 52
    # 53: Pop: L23_E; cell: 53; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][53]] = 53
    # 54: Pop: L23_E; cell: 54; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][54]] = 54
    # 55: Pop: L23_E; cell: 55; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][55]] = 55
    # 56: Pop: L23_E; cell: 56; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][56]] = 56
    # 57: Pop: L23_E; cell: 57; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][57]] = 57
    # 58: Pop: L23_E; cell: 58; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][58]] = 58
    # 59: Pop: L23_E; cell: 59; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][59]] = 59
    # 60: Pop: L23_E; cell: 60; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][60]] = 60
    # 61: Pop: L23_E; cell: 61; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][61]] = 61
    # 62: Pop: L23_E; cell: 62; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][62]] = 62
    # 63: Pop: L23_E; cell: 63; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][63]] = 63
    # 64: Pop: L23_E; cell: 64; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][64]] = 64
    # 65: Pop: L23_E; cell: 65; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][65]] = 65
    # 66: Pop: L23_E; cell: 66; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][66]] = 66
    # 67: Pop: L23_E; cell: 67; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][67]] = 67
    # 68: Pop: L23_E; cell: 68; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][68]] = 68
    # 69: Pop: L23_E; cell: 69; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][69]] = 69
    # 70: Pop: L23_E; cell: 70; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][70]] = 70
    # 71: Pop: L23_E; cell: 71; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][71]] = 71
    # 72: Pop: L23_E; cell: 72; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][72]] = 72
    # 73: Pop: L23_E; cell: 73; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][73]] = 73
    # 74: Pop: L23_E; cell: 74; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][74]] = 74
    # 75: Pop: L23_E; cell: 75; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][75]] = 75
    # 76: Pop: L23_E; cell: 76; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][76]] = 76
    # 77: Pop: L23_E; cell: 77; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][77]] = 77
    # 78: Pop: L23_E; cell: 78; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][78]] = 78
    # 79: Pop: L23_E; cell: 79; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][79]] = 79
    # 80: Pop: L23_E; cell: 80; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][80]] = 80
    # 81: Pop: L23_E; cell: 81; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][81]] = 81
    # 82: Pop: L23_E; cell: 82; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][82]] = 82
    # 83: Pop: L23_E; cell: 83; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][83]] = 83
    # 84: Pop: L23_E; cell: 84; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][84]] = 84
    # 85: Pop: L23_E; cell: 85; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][85]] = 85
    # 86: Pop: L23_E; cell: 86; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][86]] = 86
    # 87: Pop: L23_E; cell: 87; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][87]] = 87
    # 88: Pop: L23_E; cell: 88; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][88]] = 88
    # 89: Pop: L23_E; cell: 89; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][89]] = 89
    # 90: Pop: L23_E; cell: 90; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][90]] = 90
    # 91: Pop: L23_E; cell: 91; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][91]] = 91
    # 92: Pop: L23_E; cell: 92; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][92]] = 92
    # 93: Pop: L23_E; cell: 93; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][93]] = 93
    # 94: Pop: L23_E; cell: 94; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][94]] = 94
    # 95: Pop: L23_E; cell: 95; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][95]] = 95
    # 96: Pop: L23_E; cell: 96; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][96]] = 96
    # 97: Pop: L23_E; cell: 97; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][97]] = 97
    # 98: Pop: L23_E; cell: 98; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][98]] = 98
    # 99: Pop: L23_E; cell: 99; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][99]] = 99
    # 100: Pop: L23_E; cell: 100; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][100]] = 100
    # 101: Pop: L23_E; cell: 101; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][101]] = 101
    # 102: Pop: L23_E; cell: 102; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][102]] = 102
    # 103: Pop: L23_E; cell: 103; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][103]] = 103
    # 104: Pop: L23_E; cell: 104; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][104]] = 104
    # 105: Pop: L23_E; cell: 105; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][105]] = 105
    # 106: Pop: L23_E; cell: 106; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][106]] = 106
    # 107: Pop: L23_E; cell: 107; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][107]] = 107
    # 108: Pop: L23_E; cell: 108; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][108]] = 108
    # 109: Pop: L23_E; cell: 109; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][109]] = 109
    # 110: Pop: L23_E; cell: 110; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][110]] = 110
    # 111: Pop: L23_E; cell: 111; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][111]] = 111
    # 112: Pop: L23_E; cell: 112; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][112]] = 112
    # 113: Pop: L23_E; cell: 113; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][113]] = 113
    # 114: Pop: L23_E; cell: 114; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][114]] = 114
    # 115: Pop: L23_E; cell: 115; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][115]] = 115
    # 116: Pop: L23_E; cell: 116; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][116]] = 116
    # 117: Pop: L23_E; cell: 117; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][117]] = 117
    # 118: Pop: L23_E; cell: 118; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][118]] = 118
    # 119: Pop: L23_E; cell: 119; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][119]] = 119
    # 120: Pop: L23_E; cell: 120; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][120]] = 120
    # 121: Pop: L23_E; cell: 121; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][121]] = 121
    # 122: Pop: L23_E; cell: 122; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][122]] = 122
    # 123: Pop: L23_E; cell: 123; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][123]] = 123
    # 124: Pop: L23_E; cell: 124; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][124]] = 124
    # 125: Pop: L23_E; cell: 125; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][125]] = 125
    # 126: Pop: L23_E; cell: 126; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][126]] = 126
    # 127: Pop: L23_E; cell: 127; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][127]] = 127
    # 128: Pop: L23_E; cell: 128; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][128]] = 128
    # 129: Pop: L23_E; cell: 129; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][129]] = 129
    # 130: Pop: L23_E; cell: 130; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][130]] = 130
    # 131: Pop: L23_E; cell: 131; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][131]] = 131
    # 132: Pop: L23_E; cell: 132; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][132]] = 132
    # 133: Pop: L23_E; cell: 133; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][133]] = 133
    # 134: Pop: L23_E; cell: 134; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][134]] = 134
    # 135: Pop: L23_E; cell: 135; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][135]] = 135
    # 136: Pop: L23_E; cell: 136; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][136]] = 136
    # 137: Pop: L23_E; cell: 137; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][137]] = 137
    # 138: Pop: L23_E; cell: 138; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][138]] = 138
    # 139: Pop: L23_E; cell: 139; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][139]] = 139
    # 140: Pop: L23_E; cell: 140; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][140]] = 140
    # 141: Pop: L23_E; cell: 141; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][141]] = 141
    # 142: Pop: L23_E; cell: 142; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][142]] = 142
    # 143: Pop: L23_E; cell: 143; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][143]] = 143
    # 144: Pop: L23_E; cell: 144; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][144]] = 144
    # 145: Pop: L23_E; cell: 145; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][145]] = 145
    # 146: Pop: L23_E; cell: 146; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][146]] = 146
    # 147: Pop: L23_E; cell: 147; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][147]] = 147
    # 148: Pop: L23_E; cell: 148; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][148]] = 148
    # 149: Pop: L23_E; cell: 149; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][149]] = 149
    # 150: Pop: L23_E; cell: 150; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][150]] = 150
    # 151: Pop: L23_E; cell: 151; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][151]] = 151
    # 152: Pop: L23_E; cell: 152; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][152]] = 152
    # 153: Pop: L23_E; cell: 153; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][153]] = 153
    # 154: Pop: L23_E; cell: 154; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][154]] = 154
    # 155: Pop: L23_E; cell: 155; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][155]] = 155
    # 156: Pop: L23_E; cell: 156; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][156]] = 156
    # 157: Pop: L23_E; cell: 157; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][157]] = 157
    # 158: Pop: L23_E; cell: 158; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][158]] = 158
    # 159: Pop: L23_E; cell: 159; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][159]] = 159
    # 160: Pop: L23_E; cell: 160; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][160]] = 160
    # 161: Pop: L23_E; cell: 161; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][161]] = 161
    # 162: Pop: L23_E; cell: 162; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][162]] = 162
    # 163: Pop: L23_E; cell: 163; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][163]] = 163
    # 164: Pop: L23_E; cell: 164; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][164]] = 164
    # 165: Pop: L23_E; cell: 165; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][165]] = 165
    # 166: Pop: L23_E; cell: 166; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][166]] = 166
    # 167: Pop: L23_E; cell: 167; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][167]] = 167
    # 168: Pop: L23_E; cell: 168; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][168]] = 168
    # 169: Pop: L23_E; cell: 169; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][169]] = 169
    # 170: Pop: L23_E; cell: 170; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][170]] = 170
    # 171: Pop: L23_E; cell: 171; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][171]] = 171
    # 172: Pop: L23_E; cell: 172; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][172]] = 172
    # 173: Pop: L23_E; cell: 173; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][173]] = 173
    # 174: Pop: L23_E; cell: 174; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][174]] = 174
    # 175: Pop: L23_E; cell: 175; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][175]] = 175
    # 176: Pop: L23_E; cell: 176; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][176]] = 176
    # 177: Pop: L23_E; cell: 177; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][177]] = 177
    # 178: Pop: L23_E; cell: 178; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][178]] = 178
    # 179: Pop: L23_E; cell: 179; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][179]] = 179
    # 180: Pop: L23_E; cell: 180; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][180]] = 180
    # 181: Pop: L23_E; cell: 181; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][181]] = 181
    # 182: Pop: L23_E; cell: 182; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][182]] = 182
    # 183: Pop: L23_E; cell: 183; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][183]] = 183
    # 184: Pop: L23_E; cell: 184; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][184]] = 184
    # 185: Pop: L23_E; cell: 185; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][185]] = 185
    # 186: Pop: L23_E; cell: 186; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][186]] = 186
    # 187: Pop: L23_E; cell: 187; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][187]] = 187
    # 188: Pop: L23_E; cell: 188; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][188]] = 188
    # 189: Pop: L23_E; cell: 189; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][189]] = 189
    # 190: Pop: L23_E; cell: 190; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][190]] = 190
    # 191: Pop: L23_E; cell: 191; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][191]] = 191
    # 192: Pop: L23_E; cell: 192; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][192]] = 192
    # 193: Pop: L23_E; cell: 193; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][193]] = 193
    # 194: Pop: L23_E; cell: 194; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][194]] = 194
    # 195: Pop: L23_E; cell: 195; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][195]] = 195
    # 196: Pop: L23_E; cell: 196; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][196]] = 196
    # 197: Pop: L23_E; cell: 197; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][197]] = 197
    # 198: Pop: L23_E; cell: 198; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][198]] = 198
    # 199: Pop: L23_E; cell: 199; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][199]] = 199
    # 200: Pop: L23_E; cell: 200; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][200]] = 200
    # 201: Pop: L23_E; cell: 201; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][201]] = 201
    # 202: Pop: L23_E; cell: 202; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][202]] = 202
    # 203: Pop: L23_E; cell: 203; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][203]] = 203
    # 204: Pop: L23_E; cell: 204; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][204]] = 204
    # 205: Pop: L23_E; cell: 205; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_E'][205]] = 205

    spike_file_Spikes_file__L23_E = open('SimExample6_PyNN.L23_E.spikes', 'w')
    to_record_keys = to_record.keys()
    for t, id in zip(sim.allSimData['spkt'],sim.allSimData['spkid']):
        if id in to_record_keys:
            spike_file_Spikes_file__L23_E.write('%i\t%s\n'%(to_record[id],t/1000.))   # format: ID_TIME
    spike_file_Spikes_file__L23_E.close()


    print("Saving spikes to file: SimExample6_PyNN.L23_I.spikes (ref: Spikes_file__L23_I)")
    to_record = {}
    # 0: Pop: L23_I; cell: 0; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_I'][0]] = 0
    # 1: Pop: L23_I; cell: 1; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_I'][1]] = 1
    # 2: Pop: L23_I; cell: 2; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_I'][2]] = 2
    # 3: Pop: L23_I; cell: 3; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_I'][3]] = 3
    # 4: Pop: L23_I; cell: 4; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_I'][4]] = 4
    # 5: Pop: L23_I; cell: 5; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_I'][5]] = 5
    # 6: Pop: L23_I; cell: 6; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_I'][6]] = 6
    # 7: Pop: L23_I; cell: 7; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_I'][7]] = 7
    # 8: Pop: L23_I; cell: 8; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_I'][8]] = 8
    # 9: Pop: L23_I; cell: 9; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_I'][9]] = 9
    # 10: Pop: L23_I; cell: 10; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_I'][10]] = 10
    # 11: Pop: L23_I; cell: 11; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_I'][11]] = 11
    # 12: Pop: L23_I; cell: 12; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_I'][12]] = 12
    # 13: Pop: L23_I; cell: 13; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_I'][13]] = 13
    # 14: Pop: L23_I; cell: 14; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_I'][14]] = 14
    # 15: Pop: L23_I; cell: 15; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_I'][15]] = 15
    # 16: Pop: L23_I; cell: 16; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_I'][16]] = 16
    # 17: Pop: L23_I; cell: 17; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_I'][17]] = 17
    # 18: Pop: L23_I; cell: 18; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_I'][18]] = 18
    # 19: Pop: L23_I; cell: 19; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_I'][19]] = 19
    # 20: Pop: L23_I; cell: 20; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_I'][20]] = 20
    # 21: Pop: L23_I; cell: 21; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_I'][21]] = 21
    # 22: Pop: L23_I; cell: 22; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_I'][22]] = 22
    # 23: Pop: L23_I; cell: 23; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_I'][23]] = 23
    # 24: Pop: L23_I; cell: 24; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_I'][24]] = 24
    # 25: Pop: L23_I; cell: 25; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_I'][25]] = 25
    # 26: Pop: L23_I; cell: 26; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_I'][26]] = 26
    # 27: Pop: L23_I; cell: 27; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_I'][27]] = 27
    # 28: Pop: L23_I; cell: 28; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_I'][28]] = 28
    # 29: Pop: L23_I; cell: 29; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_I'][29]] = 29
    # 30: Pop: L23_I; cell: 30; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_I'][30]] = 30
    # 31: Pop: L23_I; cell: 31; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_I'][31]] = 31
    # 32: Pop: L23_I; cell: 32; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_I'][32]] = 32
    # 33: Pop: L23_I; cell: 33; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_I'][33]] = 33
    # 34: Pop: L23_I; cell: 34; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_I'][34]] = 34
    # 35: Pop: L23_I; cell: 35; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_I'][35]] = 35
    # 36: Pop: L23_I; cell: 36; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_I'][36]] = 36
    # 37: Pop: L23_I; cell: 37; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_I'][37]] = 37
    # 38: Pop: L23_I; cell: 38; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_I'][38]] = 38
    # 39: Pop: L23_I; cell: 39; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_I'][39]] = 39
    # 40: Pop: L23_I; cell: 40; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_I'][40]] = 40
    # 41: Pop: L23_I; cell: 41; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_I'][41]] = 41
    # 42: Pop: L23_I; cell: 42; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_I'][42]] = 42
    # 43: Pop: L23_I; cell: 43; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_I'][43]] = 43
    # 44: Pop: L23_I; cell: 44; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_I'][44]] = 44
    # 45: Pop: L23_I; cell: 45; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_I'][45]] = 45
    # 46: Pop: L23_I; cell: 46; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_I'][46]] = 46
    # 47: Pop: L23_I; cell: 47; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_I'][47]] = 47
    # 48: Pop: L23_I; cell: 48; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_I'][48]] = 48
    # 49: Pop: L23_I; cell: 49; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_I'][49]] = 49
    # 50: Pop: L23_I; cell: 50; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_I'][50]] = 50
    # 51: Pop: L23_I; cell: 51; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_I'][51]] = 51
    # 52: Pop: L23_I; cell: 52; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_I'][52]] = 52
    # 53: Pop: L23_I; cell: 53; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_I'][53]] = 53
    # 54: Pop: L23_I; cell: 54; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_I'][54]] = 54
    # 55: Pop: L23_I; cell: 55; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_I'][55]] = 55
    # 56: Pop: L23_I; cell: 56; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_I'][56]] = 56
    # 57: Pop: L23_I; cell: 57; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L23_I'][57]] = 57

    spike_file_Spikes_file__L23_I = open('SimExample6_PyNN.L23_I.spikes', 'w')
    to_record_keys = to_record.keys()
    for t, id in zip(sim.allSimData['spkt'],sim.allSimData['spkid']):
        if id in to_record_keys:
            spike_file_Spikes_file__L23_I.write('%i\t%s\n'%(to_record[id],t/1000.))   # format: ID_TIME
    spike_file_Spikes_file__L23_I.close()


    print("Saving spikes to file: SimExample6_PyNN.L4_E.spikes (ref: Spikes_file__L4_E)")
    to_record = {}
    # 0: Pop: L4_E; cell: 0; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][0]] = 0
    # 1: Pop: L4_E; cell: 1; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][1]] = 1
    # 2: Pop: L4_E; cell: 2; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][2]] = 2
    # 3: Pop: L4_E; cell: 3; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][3]] = 3
    # 4: Pop: L4_E; cell: 4; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][4]] = 4
    # 5: Pop: L4_E; cell: 5; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][5]] = 5
    # 6: Pop: L4_E; cell: 6; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][6]] = 6
    # 7: Pop: L4_E; cell: 7; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][7]] = 7
    # 8: Pop: L4_E; cell: 8; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][8]] = 8
    # 9: Pop: L4_E; cell: 9; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][9]] = 9
    # 10: Pop: L4_E; cell: 10; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][10]] = 10
    # 11: Pop: L4_E; cell: 11; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][11]] = 11
    # 12: Pop: L4_E; cell: 12; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][12]] = 12
    # 13: Pop: L4_E; cell: 13; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][13]] = 13
    # 14: Pop: L4_E; cell: 14; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][14]] = 14
    # 15: Pop: L4_E; cell: 15; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][15]] = 15
    # 16: Pop: L4_E; cell: 16; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][16]] = 16
    # 17: Pop: L4_E; cell: 17; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][17]] = 17
    # 18: Pop: L4_E; cell: 18; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][18]] = 18
    # 19: Pop: L4_E; cell: 19; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][19]] = 19
    # 20: Pop: L4_E; cell: 20; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][20]] = 20
    # 21: Pop: L4_E; cell: 21; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][21]] = 21
    # 22: Pop: L4_E; cell: 22; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][22]] = 22
    # 23: Pop: L4_E; cell: 23; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][23]] = 23
    # 24: Pop: L4_E; cell: 24; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][24]] = 24
    # 25: Pop: L4_E; cell: 25; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][25]] = 25
    # 26: Pop: L4_E; cell: 26; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][26]] = 26
    # 27: Pop: L4_E; cell: 27; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][27]] = 27
    # 28: Pop: L4_E; cell: 28; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][28]] = 28
    # 29: Pop: L4_E; cell: 29; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][29]] = 29
    # 30: Pop: L4_E; cell: 30; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][30]] = 30
    # 31: Pop: L4_E; cell: 31; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][31]] = 31
    # 32: Pop: L4_E; cell: 32; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][32]] = 32
    # 33: Pop: L4_E; cell: 33; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][33]] = 33
    # 34: Pop: L4_E; cell: 34; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][34]] = 34
    # 35: Pop: L4_E; cell: 35; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][35]] = 35
    # 36: Pop: L4_E; cell: 36; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][36]] = 36
    # 37: Pop: L4_E; cell: 37; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][37]] = 37
    # 38: Pop: L4_E; cell: 38; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][38]] = 38
    # 39: Pop: L4_E; cell: 39; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][39]] = 39
    # 40: Pop: L4_E; cell: 40; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][40]] = 40
    # 41: Pop: L4_E; cell: 41; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][41]] = 41
    # 42: Pop: L4_E; cell: 42; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][42]] = 42
    # 43: Pop: L4_E; cell: 43; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][43]] = 43
    # 44: Pop: L4_E; cell: 44; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][44]] = 44
    # 45: Pop: L4_E; cell: 45; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][45]] = 45
    # 46: Pop: L4_E; cell: 46; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][46]] = 46
    # 47: Pop: L4_E; cell: 47; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][47]] = 47
    # 48: Pop: L4_E; cell: 48; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][48]] = 48
    # 49: Pop: L4_E; cell: 49; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][49]] = 49
    # 50: Pop: L4_E; cell: 50; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][50]] = 50
    # 51: Pop: L4_E; cell: 51; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][51]] = 51
    # 52: Pop: L4_E; cell: 52; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][52]] = 52
    # 53: Pop: L4_E; cell: 53; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][53]] = 53
    # 54: Pop: L4_E; cell: 54; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][54]] = 54
    # 55: Pop: L4_E; cell: 55; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][55]] = 55
    # 56: Pop: L4_E; cell: 56; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][56]] = 56
    # 57: Pop: L4_E; cell: 57; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][57]] = 57
    # 58: Pop: L4_E; cell: 58; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][58]] = 58
    # 59: Pop: L4_E; cell: 59; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][59]] = 59
    # 60: Pop: L4_E; cell: 60; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][60]] = 60
    # 61: Pop: L4_E; cell: 61; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][61]] = 61
    # 62: Pop: L4_E; cell: 62; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][62]] = 62
    # 63: Pop: L4_E; cell: 63; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][63]] = 63
    # 64: Pop: L4_E; cell: 64; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][64]] = 64
    # 65: Pop: L4_E; cell: 65; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][65]] = 65
    # 66: Pop: L4_E; cell: 66; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][66]] = 66
    # 67: Pop: L4_E; cell: 67; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][67]] = 67
    # 68: Pop: L4_E; cell: 68; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][68]] = 68
    # 69: Pop: L4_E; cell: 69; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][69]] = 69
    # 70: Pop: L4_E; cell: 70; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][70]] = 70
    # 71: Pop: L4_E; cell: 71; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][71]] = 71
    # 72: Pop: L4_E; cell: 72; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][72]] = 72
    # 73: Pop: L4_E; cell: 73; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][73]] = 73
    # 74: Pop: L4_E; cell: 74; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][74]] = 74
    # 75: Pop: L4_E; cell: 75; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][75]] = 75
    # 76: Pop: L4_E; cell: 76; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][76]] = 76
    # 77: Pop: L4_E; cell: 77; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][77]] = 77
    # 78: Pop: L4_E; cell: 78; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][78]] = 78
    # 79: Pop: L4_E; cell: 79; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][79]] = 79
    # 80: Pop: L4_E; cell: 80; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][80]] = 80
    # 81: Pop: L4_E; cell: 81; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][81]] = 81
    # 82: Pop: L4_E; cell: 82; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][82]] = 82
    # 83: Pop: L4_E; cell: 83; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][83]] = 83
    # 84: Pop: L4_E; cell: 84; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][84]] = 84
    # 85: Pop: L4_E; cell: 85; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][85]] = 85
    # 86: Pop: L4_E; cell: 86; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][86]] = 86
    # 87: Pop: L4_E; cell: 87; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][87]] = 87
    # 88: Pop: L4_E; cell: 88; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][88]] = 88
    # 89: Pop: L4_E; cell: 89; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][89]] = 89
    # 90: Pop: L4_E; cell: 90; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][90]] = 90
    # 91: Pop: L4_E; cell: 91; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][91]] = 91
    # 92: Pop: L4_E; cell: 92; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][92]] = 92
    # 93: Pop: L4_E; cell: 93; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][93]] = 93
    # 94: Pop: L4_E; cell: 94; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][94]] = 94
    # 95: Pop: L4_E; cell: 95; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][95]] = 95
    # 96: Pop: L4_E; cell: 96; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][96]] = 96
    # 97: Pop: L4_E; cell: 97; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][97]] = 97
    # 98: Pop: L4_E; cell: 98; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][98]] = 98
    # 99: Pop: L4_E; cell: 99; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][99]] = 99
    # 100: Pop: L4_E; cell: 100; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][100]] = 100
    # 101: Pop: L4_E; cell: 101; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][101]] = 101
    # 102: Pop: L4_E; cell: 102; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][102]] = 102
    # 103: Pop: L4_E; cell: 103; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][103]] = 103
    # 104: Pop: L4_E; cell: 104; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][104]] = 104
    # 105: Pop: L4_E; cell: 105; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][105]] = 105
    # 106: Pop: L4_E; cell: 106; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][106]] = 106
    # 107: Pop: L4_E; cell: 107; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][107]] = 107
    # 108: Pop: L4_E; cell: 108; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][108]] = 108
    # 109: Pop: L4_E; cell: 109; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][109]] = 109
    # 110: Pop: L4_E; cell: 110; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][110]] = 110
    # 111: Pop: L4_E; cell: 111; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][111]] = 111
    # 112: Pop: L4_E; cell: 112; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][112]] = 112
    # 113: Pop: L4_E; cell: 113; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][113]] = 113
    # 114: Pop: L4_E; cell: 114; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][114]] = 114
    # 115: Pop: L4_E; cell: 115; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][115]] = 115
    # 116: Pop: L4_E; cell: 116; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][116]] = 116
    # 117: Pop: L4_E; cell: 117; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][117]] = 117
    # 118: Pop: L4_E; cell: 118; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][118]] = 118
    # 119: Pop: L4_E; cell: 119; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][119]] = 119
    # 120: Pop: L4_E; cell: 120; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][120]] = 120
    # 121: Pop: L4_E; cell: 121; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][121]] = 121
    # 122: Pop: L4_E; cell: 122; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][122]] = 122
    # 123: Pop: L4_E; cell: 123; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][123]] = 123
    # 124: Pop: L4_E; cell: 124; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][124]] = 124
    # 125: Pop: L4_E; cell: 125; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][125]] = 125
    # 126: Pop: L4_E; cell: 126; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][126]] = 126
    # 127: Pop: L4_E; cell: 127; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][127]] = 127
    # 128: Pop: L4_E; cell: 128; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][128]] = 128
    # 129: Pop: L4_E; cell: 129; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][129]] = 129
    # 130: Pop: L4_E; cell: 130; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][130]] = 130
    # 131: Pop: L4_E; cell: 131; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][131]] = 131
    # 132: Pop: L4_E; cell: 132; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][132]] = 132
    # 133: Pop: L4_E; cell: 133; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][133]] = 133
    # 134: Pop: L4_E; cell: 134; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][134]] = 134
    # 135: Pop: L4_E; cell: 135; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][135]] = 135
    # 136: Pop: L4_E; cell: 136; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][136]] = 136
    # 137: Pop: L4_E; cell: 137; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][137]] = 137
    # 138: Pop: L4_E; cell: 138; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][138]] = 138
    # 139: Pop: L4_E; cell: 139; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][139]] = 139
    # 140: Pop: L4_E; cell: 140; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][140]] = 140
    # 141: Pop: L4_E; cell: 141; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][141]] = 141
    # 142: Pop: L4_E; cell: 142; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][142]] = 142
    # 143: Pop: L4_E; cell: 143; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][143]] = 143
    # 144: Pop: L4_E; cell: 144; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][144]] = 144
    # 145: Pop: L4_E; cell: 145; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][145]] = 145
    # 146: Pop: L4_E; cell: 146; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][146]] = 146
    # 147: Pop: L4_E; cell: 147; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][147]] = 147
    # 148: Pop: L4_E; cell: 148; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][148]] = 148
    # 149: Pop: L4_E; cell: 149; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][149]] = 149
    # 150: Pop: L4_E; cell: 150; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][150]] = 150
    # 151: Pop: L4_E; cell: 151; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][151]] = 151
    # 152: Pop: L4_E; cell: 152; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][152]] = 152
    # 153: Pop: L4_E; cell: 153; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][153]] = 153
    # 154: Pop: L4_E; cell: 154; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][154]] = 154
    # 155: Pop: L4_E; cell: 155; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][155]] = 155
    # 156: Pop: L4_E; cell: 156; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][156]] = 156
    # 157: Pop: L4_E; cell: 157; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][157]] = 157
    # 158: Pop: L4_E; cell: 158; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][158]] = 158
    # 159: Pop: L4_E; cell: 159; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][159]] = 159
    # 160: Pop: L4_E; cell: 160; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][160]] = 160
    # 161: Pop: L4_E; cell: 161; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][161]] = 161
    # 162: Pop: L4_E; cell: 162; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][162]] = 162
    # 163: Pop: L4_E; cell: 163; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][163]] = 163
    # 164: Pop: L4_E; cell: 164; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][164]] = 164
    # 165: Pop: L4_E; cell: 165; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][165]] = 165
    # 166: Pop: L4_E; cell: 166; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][166]] = 166
    # 167: Pop: L4_E; cell: 167; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][167]] = 167
    # 168: Pop: L4_E; cell: 168; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][168]] = 168
    # 169: Pop: L4_E; cell: 169; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][169]] = 169
    # 170: Pop: L4_E; cell: 170; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][170]] = 170
    # 171: Pop: L4_E; cell: 171; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][171]] = 171
    # 172: Pop: L4_E; cell: 172; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][172]] = 172
    # 173: Pop: L4_E; cell: 173; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][173]] = 173
    # 174: Pop: L4_E; cell: 174; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][174]] = 174
    # 175: Pop: L4_E; cell: 175; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][175]] = 175
    # 176: Pop: L4_E; cell: 176; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][176]] = 176
    # 177: Pop: L4_E; cell: 177; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][177]] = 177
    # 178: Pop: L4_E; cell: 178; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][178]] = 178
    # 179: Pop: L4_E; cell: 179; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][179]] = 179
    # 180: Pop: L4_E; cell: 180; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][180]] = 180
    # 181: Pop: L4_E; cell: 181; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][181]] = 181
    # 182: Pop: L4_E; cell: 182; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][182]] = 182
    # 183: Pop: L4_E; cell: 183; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][183]] = 183
    # 184: Pop: L4_E; cell: 184; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][184]] = 184
    # 185: Pop: L4_E; cell: 185; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][185]] = 185
    # 186: Pop: L4_E; cell: 186; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][186]] = 186
    # 187: Pop: L4_E; cell: 187; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][187]] = 187
    # 188: Pop: L4_E; cell: 188; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][188]] = 188
    # 189: Pop: L4_E; cell: 189; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][189]] = 189
    # 190: Pop: L4_E; cell: 190; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][190]] = 190
    # 191: Pop: L4_E; cell: 191; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][191]] = 191
    # 192: Pop: L4_E; cell: 192; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][192]] = 192
    # 193: Pop: L4_E; cell: 193; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][193]] = 193
    # 194: Pop: L4_E; cell: 194; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][194]] = 194
    # 195: Pop: L4_E; cell: 195; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][195]] = 195
    # 196: Pop: L4_E; cell: 196; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][196]] = 196
    # 197: Pop: L4_E; cell: 197; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][197]] = 197
    # 198: Pop: L4_E; cell: 198; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][198]] = 198
    # 199: Pop: L4_E; cell: 199; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][199]] = 199
    # 200: Pop: L4_E; cell: 200; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][200]] = 200
    # 201: Pop: L4_E; cell: 201; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][201]] = 201
    # 202: Pop: L4_E; cell: 202; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][202]] = 202
    # 203: Pop: L4_E; cell: 203; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][203]] = 203
    # 204: Pop: L4_E; cell: 204; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][204]] = 204
    # 205: Pop: L4_E; cell: 205; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][205]] = 205
    # 206: Pop: L4_E; cell: 206; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][206]] = 206
    # 207: Pop: L4_E; cell: 207; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][207]] = 207
    # 208: Pop: L4_E; cell: 208; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][208]] = 208
    # 209: Pop: L4_E; cell: 209; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][209]] = 209
    # 210: Pop: L4_E; cell: 210; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][210]] = 210
    # 211: Pop: L4_E; cell: 211; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][211]] = 211
    # 212: Pop: L4_E; cell: 212; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][212]] = 212
    # 213: Pop: L4_E; cell: 213; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][213]] = 213
    # 214: Pop: L4_E; cell: 214; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][214]] = 214
    # 215: Pop: L4_E; cell: 215; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][215]] = 215
    # 216: Pop: L4_E; cell: 216; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][216]] = 216
    # 217: Pop: L4_E; cell: 217; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][217]] = 217
    # 218: Pop: L4_E; cell: 218; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_E'][218]] = 218

    spike_file_Spikes_file__L4_E = open('SimExample6_PyNN.L4_E.spikes', 'w')
    to_record_keys = to_record.keys()
    for t, id in zip(sim.allSimData['spkt'],sim.allSimData['spkid']):
        if id in to_record_keys:
            spike_file_Spikes_file__L4_E.write('%i\t%s\n'%(to_record[id],t/1000.))   # format: ID_TIME
    spike_file_Spikes_file__L4_E.close()


    print("Saving spikes to file: SimExample6_PyNN.L4_I.spikes (ref: Spikes_file__L4_I)")
    to_record = {}
    # 0: Pop: L4_I; cell: 0; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_I'][0]] = 0
    # 1: Pop: L4_I; cell: 1; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_I'][1]] = 1
    # 2: Pop: L4_I; cell: 2; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_I'][2]] = 2
    # 3: Pop: L4_I; cell: 3; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_I'][3]] = 3
    # 4: Pop: L4_I; cell: 4; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_I'][4]] = 4
    # 5: Pop: L4_I; cell: 5; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_I'][5]] = 5
    # 6: Pop: L4_I; cell: 6; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_I'][6]] = 6
    # 7: Pop: L4_I; cell: 7; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_I'][7]] = 7
    # 8: Pop: L4_I; cell: 8; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_I'][8]] = 8
    # 9: Pop: L4_I; cell: 9; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_I'][9]] = 9
    # 10: Pop: L4_I; cell: 10; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_I'][10]] = 10
    # 11: Pop: L4_I; cell: 11; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_I'][11]] = 11
    # 12: Pop: L4_I; cell: 12; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_I'][12]] = 12
    # 13: Pop: L4_I; cell: 13; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_I'][13]] = 13
    # 14: Pop: L4_I; cell: 14; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_I'][14]] = 14
    # 15: Pop: L4_I; cell: 15; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_I'][15]] = 15
    # 16: Pop: L4_I; cell: 16; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_I'][16]] = 16
    # 17: Pop: L4_I; cell: 17; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_I'][17]] = 17
    # 18: Pop: L4_I; cell: 18; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_I'][18]] = 18
    # 19: Pop: L4_I; cell: 19; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_I'][19]] = 19
    # 20: Pop: L4_I; cell: 20; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_I'][20]] = 20
    # 21: Pop: L4_I; cell: 21; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_I'][21]] = 21
    # 22: Pop: L4_I; cell: 22; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_I'][22]] = 22
    # 23: Pop: L4_I; cell: 23; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_I'][23]] = 23
    # 24: Pop: L4_I; cell: 24; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_I'][24]] = 24
    # 25: Pop: L4_I; cell: 25; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_I'][25]] = 25
    # 26: Pop: L4_I; cell: 26; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_I'][26]] = 26
    # 27: Pop: L4_I; cell: 27; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_I'][27]] = 27
    # 28: Pop: L4_I; cell: 28; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_I'][28]] = 28
    # 29: Pop: L4_I; cell: 29; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_I'][29]] = 29
    # 30: Pop: L4_I; cell: 30; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_I'][30]] = 30
    # 31: Pop: L4_I; cell: 31; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_I'][31]] = 31
    # 32: Pop: L4_I; cell: 32; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_I'][32]] = 32
    # 33: Pop: L4_I; cell: 33; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_I'][33]] = 33
    # 34: Pop: L4_I; cell: 34; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_I'][34]] = 34
    # 35: Pop: L4_I; cell: 35; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_I'][35]] = 35
    # 36: Pop: L4_I; cell: 36; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_I'][36]] = 36
    # 37: Pop: L4_I; cell: 37; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_I'][37]] = 37
    # 38: Pop: L4_I; cell: 38; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_I'][38]] = 38
    # 39: Pop: L4_I; cell: 39; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_I'][39]] = 39
    # 40: Pop: L4_I; cell: 40; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_I'][40]] = 40
    # 41: Pop: L4_I; cell: 41; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_I'][41]] = 41
    # 42: Pop: L4_I; cell: 42; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_I'][42]] = 42
    # 43: Pop: L4_I; cell: 43; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_I'][43]] = 43
    # 44: Pop: L4_I; cell: 44; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_I'][44]] = 44
    # 45: Pop: L4_I; cell: 45; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_I'][45]] = 45
    # 46: Pop: L4_I; cell: 46; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_I'][46]] = 46
    # 47: Pop: L4_I; cell: 47; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_I'][47]] = 47
    # 48: Pop: L4_I; cell: 48; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_I'][48]] = 48
    # 49: Pop: L4_I; cell: 49; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_I'][49]] = 49
    # 50: Pop: L4_I; cell: 50; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_I'][50]] = 50
    # 51: Pop: L4_I; cell: 51; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_I'][51]] = 51
    # 52: Pop: L4_I; cell: 52; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_I'][52]] = 52
    # 53: Pop: L4_I; cell: 53; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L4_I'][53]] = 53

    spike_file_Spikes_file__L4_I = open('SimExample6_PyNN.L4_I.spikes', 'w')
    to_record_keys = to_record.keys()
    for t, id in zip(sim.allSimData['spkt'],sim.allSimData['spkid']):
        if id in to_record_keys:
            spike_file_Spikes_file__L4_I.write('%i\t%s\n'%(to_record[id],t/1000.))   # format: ID_TIME
    spike_file_Spikes_file__L4_I.close()


    print("Saving spikes to file: SimExample6_PyNN.L5_E.spikes (ref: Spikes_file__L5_E)")
    to_record = {}
    # 0: Pop: L5_E; cell: 0; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L5_E'][0]] = 0
    # 1: Pop: L5_E; cell: 1; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L5_E'][1]] = 1
    # 2: Pop: L5_E; cell: 2; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L5_E'][2]] = 2
    # 3: Pop: L5_E; cell: 3; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L5_E'][3]] = 3
    # 4: Pop: L5_E; cell: 4; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L5_E'][4]] = 4
    # 5: Pop: L5_E; cell: 5; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L5_E'][5]] = 5
    # 6: Pop: L5_E; cell: 6; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L5_E'][6]] = 6
    # 7: Pop: L5_E; cell: 7; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L5_E'][7]] = 7
    # 8: Pop: L5_E; cell: 8; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L5_E'][8]] = 8
    # 9: Pop: L5_E; cell: 9; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L5_E'][9]] = 9
    # 10: Pop: L5_E; cell: 10; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L5_E'][10]] = 10
    # 11: Pop: L5_E; cell: 11; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L5_E'][11]] = 11
    # 12: Pop: L5_E; cell: 12; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L5_E'][12]] = 12
    # 13: Pop: L5_E; cell: 13; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L5_E'][13]] = 13
    # 14: Pop: L5_E; cell: 14; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L5_E'][14]] = 14
    # 15: Pop: L5_E; cell: 15; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L5_E'][15]] = 15
    # 16: Pop: L5_E; cell: 16; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L5_E'][16]] = 16
    # 17: Pop: L5_E; cell: 17; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L5_E'][17]] = 17
    # 18: Pop: L5_E; cell: 18; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L5_E'][18]] = 18
    # 19: Pop: L5_E; cell: 19; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L5_E'][19]] = 19
    # 20: Pop: L5_E; cell: 20; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L5_E'][20]] = 20
    # 21: Pop: L5_E; cell: 21; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L5_E'][21]] = 21
    # 22: Pop: L5_E; cell: 22; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L5_E'][22]] = 22
    # 23: Pop: L5_E; cell: 23; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L5_E'][23]] = 23
    # 24: Pop: L5_E; cell: 24; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L5_E'][24]] = 24
    # 25: Pop: L5_E; cell: 25; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L5_E'][25]] = 25
    # 26: Pop: L5_E; cell: 26; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L5_E'][26]] = 26
    # 27: Pop: L5_E; cell: 27; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L5_E'][27]] = 27
    # 28: Pop: L5_E; cell: 28; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L5_E'][28]] = 28
    # 29: Pop: L5_E; cell: 29; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L5_E'][29]] = 29
    # 30: Pop: L5_E; cell: 30; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L5_E'][30]] = 30
    # 31: Pop: L5_E; cell: 31; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L5_E'][31]] = 31
    # 32: Pop: L5_E; cell: 32; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L5_E'][32]] = 32
    # 33: Pop: L5_E; cell: 33; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L5_E'][33]] = 33
    # 34: Pop: L5_E; cell: 34; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L5_E'][34]] = 34
    # 35: Pop: L5_E; cell: 35; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L5_E'][35]] = 35
    # 36: Pop: L5_E; cell: 36; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L5_E'][36]] = 36
    # 37: Pop: L5_E; cell: 37; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L5_E'][37]] = 37
    # 38: Pop: L5_E; cell: 38; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L5_E'][38]] = 38
    # 39: Pop: L5_E; cell: 39; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L5_E'][39]] = 39
    # 40: Pop: L5_E; cell: 40; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L5_E'][40]] = 40
    # 41: Pop: L5_E; cell: 41; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L5_E'][41]] = 41
    # 42: Pop: L5_E; cell: 42; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L5_E'][42]] = 42
    # 43: Pop: L5_E; cell: 43; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L5_E'][43]] = 43
    # 44: Pop: L5_E; cell: 44; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L5_E'][44]] = 44
    # 45: Pop: L5_E; cell: 45; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L5_E'][45]] = 45
    # 46: Pop: L5_E; cell: 46; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L5_E'][46]] = 46
    # 47: Pop: L5_E; cell: 47; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L5_E'][47]] = 47

    spike_file_Spikes_file__L5_E = open('SimExample6_PyNN.L5_E.spikes', 'w')
    to_record_keys = to_record.keys()
    for t, id in zip(sim.allSimData['spkt'],sim.allSimData['spkid']):
        if id in to_record_keys:
            spike_file_Spikes_file__L5_E.write('%i\t%s\n'%(to_record[id],t/1000.))   # format: ID_TIME
    spike_file_Spikes_file__L5_E.close()


    print("Saving spikes to file: SimExample6_PyNN.L5_I.spikes (ref: Spikes_file__L5_I)")
    to_record = {}
    # 0: Pop: L5_I; cell: 0; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L5_I'][0]] = 0
    # 1: Pop: L5_I; cell: 1; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L5_I'][1]] = 1
    # 2: Pop: L5_I; cell: 2; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L5_I'][2]] = 2
    # 3: Pop: L5_I; cell: 3; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L5_I'][3]] = 3
    # 4: Pop: L5_I; cell: 4; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L5_I'][4]] = 4
    # 5: Pop: L5_I; cell: 5; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L5_I'][5]] = 5
    # 6: Pop: L5_I; cell: 6; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L5_I'][6]] = 6
    # 7: Pop: L5_I; cell: 7; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L5_I'][7]] = 7
    # 8: Pop: L5_I; cell: 8; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L5_I'][8]] = 8
    # 9: Pop: L5_I; cell: 9; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L5_I'][9]] = 9

    spike_file_Spikes_file__L5_I = open('SimExample6_PyNN.L5_I.spikes', 'w')
    to_record_keys = to_record.keys()
    for t, id in zip(sim.allSimData['spkt'],sim.allSimData['spkid']):
        if id in to_record_keys:
            spike_file_Spikes_file__L5_I.write('%i\t%s\n'%(to_record[id],t/1000.))   # format: ID_TIME
    spike_file_Spikes_file__L5_I.close()


    print("Saving spikes to file: SimExample6_PyNN.L6_E.spikes (ref: Spikes_file__L6_E)")
    to_record = {}
    # 0: Pop: L6_E; cell: 0; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][0]] = 0
    # 1: Pop: L6_E; cell: 1; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][1]] = 1
    # 2: Pop: L6_E; cell: 2; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][2]] = 2
    # 3: Pop: L6_E; cell: 3; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][3]] = 3
    # 4: Pop: L6_E; cell: 4; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][4]] = 4
    # 5: Pop: L6_E; cell: 5; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][5]] = 5
    # 6: Pop: L6_E; cell: 6; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][6]] = 6
    # 7: Pop: L6_E; cell: 7; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][7]] = 7
    # 8: Pop: L6_E; cell: 8; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][8]] = 8
    # 9: Pop: L6_E; cell: 9; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][9]] = 9
    # 10: Pop: L6_E; cell: 10; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][10]] = 10
    # 11: Pop: L6_E; cell: 11; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][11]] = 11
    # 12: Pop: L6_E; cell: 12; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][12]] = 12
    # 13: Pop: L6_E; cell: 13; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][13]] = 13
    # 14: Pop: L6_E; cell: 14; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][14]] = 14
    # 15: Pop: L6_E; cell: 15; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][15]] = 15
    # 16: Pop: L6_E; cell: 16; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][16]] = 16
    # 17: Pop: L6_E; cell: 17; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][17]] = 17
    # 18: Pop: L6_E; cell: 18; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][18]] = 18
    # 19: Pop: L6_E; cell: 19; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][19]] = 19
    # 20: Pop: L6_E; cell: 20; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][20]] = 20
    # 21: Pop: L6_E; cell: 21; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][21]] = 21
    # 22: Pop: L6_E; cell: 22; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][22]] = 22
    # 23: Pop: L6_E; cell: 23; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][23]] = 23
    # 24: Pop: L6_E; cell: 24; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][24]] = 24
    # 25: Pop: L6_E; cell: 25; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][25]] = 25
    # 26: Pop: L6_E; cell: 26; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][26]] = 26
    # 27: Pop: L6_E; cell: 27; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][27]] = 27
    # 28: Pop: L6_E; cell: 28; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][28]] = 28
    # 29: Pop: L6_E; cell: 29; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][29]] = 29
    # 30: Pop: L6_E; cell: 30; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][30]] = 30
    # 31: Pop: L6_E; cell: 31; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][31]] = 31
    # 32: Pop: L6_E; cell: 32; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][32]] = 32
    # 33: Pop: L6_E; cell: 33; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][33]] = 33
    # 34: Pop: L6_E; cell: 34; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][34]] = 34
    # 35: Pop: L6_E; cell: 35; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][35]] = 35
    # 36: Pop: L6_E; cell: 36; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][36]] = 36
    # 37: Pop: L6_E; cell: 37; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][37]] = 37
    # 38: Pop: L6_E; cell: 38; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][38]] = 38
    # 39: Pop: L6_E; cell: 39; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][39]] = 39
    # 40: Pop: L6_E; cell: 40; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][40]] = 40
    # 41: Pop: L6_E; cell: 41; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][41]] = 41
    # 42: Pop: L6_E; cell: 42; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][42]] = 42
    # 43: Pop: L6_E; cell: 43; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][43]] = 43
    # 44: Pop: L6_E; cell: 44; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][44]] = 44
    # 45: Pop: L6_E; cell: 45; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][45]] = 45
    # 46: Pop: L6_E; cell: 46; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][46]] = 46
    # 47: Pop: L6_E; cell: 47; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][47]] = 47
    # 48: Pop: L6_E; cell: 48; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][48]] = 48
    # 49: Pop: L6_E; cell: 49; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][49]] = 49
    # 50: Pop: L6_E; cell: 50; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][50]] = 50
    # 51: Pop: L6_E; cell: 51; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][51]] = 51
    # 52: Pop: L6_E; cell: 52; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][52]] = 52
    # 53: Pop: L6_E; cell: 53; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][53]] = 53
    # 54: Pop: L6_E; cell: 54; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][54]] = 54
    # 55: Pop: L6_E; cell: 55; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][55]] = 55
    # 56: Pop: L6_E; cell: 56; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][56]] = 56
    # 57: Pop: L6_E; cell: 57; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][57]] = 57
    # 58: Pop: L6_E; cell: 58; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][58]] = 58
    # 59: Pop: L6_E; cell: 59; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][59]] = 59
    # 60: Pop: L6_E; cell: 60; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][60]] = 60
    # 61: Pop: L6_E; cell: 61; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][61]] = 61
    # 62: Pop: L6_E; cell: 62; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][62]] = 62
    # 63: Pop: L6_E; cell: 63; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][63]] = 63
    # 64: Pop: L6_E; cell: 64; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][64]] = 64
    # 65: Pop: L6_E; cell: 65; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][65]] = 65
    # 66: Pop: L6_E; cell: 66; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][66]] = 66
    # 67: Pop: L6_E; cell: 67; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][67]] = 67
    # 68: Pop: L6_E; cell: 68; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][68]] = 68
    # 69: Pop: L6_E; cell: 69; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][69]] = 69
    # 70: Pop: L6_E; cell: 70; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][70]] = 70
    # 71: Pop: L6_E; cell: 71; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][71]] = 71
    # 72: Pop: L6_E; cell: 72; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][72]] = 72
    # 73: Pop: L6_E; cell: 73; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][73]] = 73
    # 74: Pop: L6_E; cell: 74; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][74]] = 74
    # 75: Pop: L6_E; cell: 75; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][75]] = 75
    # 76: Pop: L6_E; cell: 76; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][76]] = 76
    # 77: Pop: L6_E; cell: 77; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][77]] = 77
    # 78: Pop: L6_E; cell: 78; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][78]] = 78
    # 79: Pop: L6_E; cell: 79; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][79]] = 79
    # 80: Pop: L6_E; cell: 80; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][80]] = 80
    # 81: Pop: L6_E; cell: 81; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][81]] = 81
    # 82: Pop: L6_E; cell: 82; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][82]] = 82
    # 83: Pop: L6_E; cell: 83; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][83]] = 83
    # 84: Pop: L6_E; cell: 84; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][84]] = 84
    # 85: Pop: L6_E; cell: 85; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][85]] = 85
    # 86: Pop: L6_E; cell: 86; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][86]] = 86
    # 87: Pop: L6_E; cell: 87; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][87]] = 87
    # 88: Pop: L6_E; cell: 88; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][88]] = 88
    # 89: Pop: L6_E; cell: 89; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][89]] = 89
    # 90: Pop: L6_E; cell: 90; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][90]] = 90
    # 91: Pop: L6_E; cell: 91; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][91]] = 91
    # 92: Pop: L6_E; cell: 92; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][92]] = 92
    # 93: Pop: L6_E; cell: 93; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][93]] = 93
    # 94: Pop: L6_E; cell: 94; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][94]] = 94
    # 95: Pop: L6_E; cell: 95; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][95]] = 95
    # 96: Pop: L6_E; cell: 96; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][96]] = 96
    # 97: Pop: L6_E; cell: 97; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][97]] = 97
    # 98: Pop: L6_E; cell: 98; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][98]] = 98
    # 99: Pop: L6_E; cell: 99; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][99]] = 99
    # 100: Pop: L6_E; cell: 100; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][100]] = 100
    # 101: Pop: L6_E; cell: 101; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][101]] = 101
    # 102: Pop: L6_E; cell: 102; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][102]] = 102
    # 103: Pop: L6_E; cell: 103; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][103]] = 103
    # 104: Pop: L6_E; cell: 104; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][104]] = 104
    # 105: Pop: L6_E; cell: 105; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][105]] = 105
    # 106: Pop: L6_E; cell: 106; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][106]] = 106
    # 107: Pop: L6_E; cell: 107; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][107]] = 107
    # 108: Pop: L6_E; cell: 108; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][108]] = 108
    # 109: Pop: L6_E; cell: 109; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][109]] = 109
    # 110: Pop: L6_E; cell: 110; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][110]] = 110
    # 111: Pop: L6_E; cell: 111; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][111]] = 111
    # 112: Pop: L6_E; cell: 112; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][112]] = 112
    # 113: Pop: L6_E; cell: 113; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][113]] = 113
    # 114: Pop: L6_E; cell: 114; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][114]] = 114
    # 115: Pop: L6_E; cell: 115; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][115]] = 115
    # 116: Pop: L6_E; cell: 116; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][116]] = 116
    # 117: Pop: L6_E; cell: 117; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][117]] = 117
    # 118: Pop: L6_E; cell: 118; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][118]] = 118
    # 119: Pop: L6_E; cell: 119; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][119]] = 119
    # 120: Pop: L6_E; cell: 120; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][120]] = 120
    # 121: Pop: L6_E; cell: 121; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][121]] = 121
    # 122: Pop: L6_E; cell: 122; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][122]] = 122
    # 123: Pop: L6_E; cell: 123; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][123]] = 123
    # 124: Pop: L6_E; cell: 124; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][124]] = 124
    # 125: Pop: L6_E; cell: 125; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][125]] = 125
    # 126: Pop: L6_E; cell: 126; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][126]] = 126
    # 127: Pop: L6_E; cell: 127; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][127]] = 127
    # 128: Pop: L6_E; cell: 128; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][128]] = 128
    # 129: Pop: L6_E; cell: 129; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][129]] = 129
    # 130: Pop: L6_E; cell: 130; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][130]] = 130
    # 131: Pop: L6_E; cell: 131; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][131]] = 131
    # 132: Pop: L6_E; cell: 132; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][132]] = 132
    # 133: Pop: L6_E; cell: 133; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][133]] = 133
    # 134: Pop: L6_E; cell: 134; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][134]] = 134
    # 135: Pop: L6_E; cell: 135; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][135]] = 135
    # 136: Pop: L6_E; cell: 136; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][136]] = 136
    # 137: Pop: L6_E; cell: 137; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][137]] = 137
    # 138: Pop: L6_E; cell: 138; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][138]] = 138
    # 139: Pop: L6_E; cell: 139; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][139]] = 139
    # 140: Pop: L6_E; cell: 140; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][140]] = 140
    # 141: Pop: L6_E; cell: 141; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][141]] = 141
    # 142: Pop: L6_E; cell: 142; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_E'][142]] = 142

    spike_file_Spikes_file__L6_E = open('SimExample6_PyNN.L6_E.spikes', 'w')
    to_record_keys = to_record.keys()
    for t, id in zip(sim.allSimData['spkt'],sim.allSimData['spkid']):
        if id in to_record_keys:
            spike_file_Spikes_file__L6_E.write('%i\t%s\n'%(to_record[id],t/1000.))   # format: ID_TIME
    spike_file_Spikes_file__L6_E.close()


    print("Saving spikes to file: SimExample6_PyNN.L6_I.spikes (ref: Spikes_file__L6_I)")
    to_record = {}
    # 0: Pop: L6_I; cell: 0; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_I'][0]] = 0
    # 1: Pop: L6_I; cell: 1; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_I'][1]] = 1
    # 2: Pop: L6_I; cell: 2; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_I'][2]] = 2
    # 3: Pop: L6_I; cell: 3; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_I'][3]] = 3
    # 4: Pop: L6_I; cell: 4; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_I'][4]] = 4
    # 5: Pop: L6_I; cell: 5; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_I'][5]] = 5
    # 6: Pop: L6_I; cell: 6; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_I'][6]] = 6
    # 7: Pop: L6_I; cell: 7; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_I'][7]] = 7
    # 8: Pop: L6_I; cell: 8; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_I'][8]] = 8
    # 9: Pop: L6_I; cell: 9; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_I'][9]] = 9
    # 10: Pop: L6_I; cell: 10; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_I'][10]] = 10
    # 11: Pop: L6_I; cell: 11; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_I'][11]] = 11
    # 12: Pop: L6_I; cell: 12; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_I'][12]] = 12
    # 13: Pop: L6_I; cell: 13; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_I'][13]] = 13
    # 14: Pop: L6_I; cell: 14; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_I'][14]] = 14
    # 15: Pop: L6_I; cell: 15; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_I'][15]] = 15
    # 16: Pop: L6_I; cell: 16; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_I'][16]] = 16
    # 17: Pop: L6_I; cell: 17; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_I'][17]] = 17
    # 18: Pop: L6_I; cell: 18; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_I'][18]] = 18
    # 19: Pop: L6_I; cell: 19; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_I'][19]] = 19
    # 20: Pop: L6_I; cell: 20; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_I'][20]] = 20
    # 21: Pop: L6_I; cell: 21; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_I'][21]] = 21
    # 22: Pop: L6_I; cell: 22; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_I'][22]] = 22
    # 23: Pop: L6_I; cell: 23; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_I'][23]] = 23
    # 24: Pop: L6_I; cell: 24; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_I'][24]] = 24
    # 25: Pop: L6_I; cell: 25; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_I'][25]] = 25
    # 26: Pop: L6_I; cell: 26; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_I'][26]] = 26
    # 27: Pop: L6_I; cell: 27; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_I'][27]] = 27
    # 28: Pop: L6_I; cell: 28; segment id: $oc.segment_id; segment name: soma; value: spike
    to_record[gids['L6_I'][28]] = 28

    spike_file_Spikes_file__L6_I = open('SimExample6_PyNN.L6_I.spikes', 'w')
    to_record_keys = to_record.keys()
    for t, id in zip(sim.allSimData['spkt'],sim.allSimData['spkid']):
        if id in to_record_keys:
            spike_file_Spikes_file__L6_I.write('%i\t%s\n'%(to_record[id],t/1000.))   # format: ID_TIME
    spike_file_Spikes_file__L6_I.close()



    save_end = time.time()
    save_time = save_end - sim_end
    print("Finished saving results in %f seconds"%(save_time))


    report_file.write('StartTime=%s\n'%datetime.datetime.fromtimestamp(setup_start).strftime('%Y-%m-%d %H:%M:%S'))
    report_file.write('RealSetupAndSimulationTime=%s\n'%setup_sim_time)
    report_file.write('SimulationSaveTime=%s\n'%save_time)
    report_file.close()
    print("Saving report of simulation to %s"%('report.SimExample6_PyNN.txt'))

if '-nogui' in sys.argv:
    quit()
