'''
Neuron simulator export for:

Components:
    null (Type: notes)
    ifcell (Type: IF_curr_alpha:  tau_refrac=2.0 (dimensionless) v_thresh=20.0 (dimensionless) tau_m=20.0 (dimensionless) v_rest=0.0 (dimensionless) v_reset=0.0 (dimensionless) cm=0.001 (dimensionless) i_offset=0.0 (dimensionless) tau_syn_E=0.1 (dimensionless) tau_syn_I=0.1 (dimensionless) v_init=0.0 (dimensionless) MSEC=0.001 (SI time) MVOLT=0.001 (SI voltage) NFARAD=1.0E-9 (SI capacitance))
    ampa (Type: alphaCurrSynapse:  tau_syn=0.1 (dimensionless) MSEC=0.001 (SI time) MVOLT=0.001 (SI voltage) NAMP=1.0E-9 (SI current))
    gaba (Type: alphaCurrSynapse:  tau_syn=0.1 (dimensionless) MSEC=0.001 (SI time) MVOLT=0.001 (SI voltage) NAMP=1.0E-9 (SI current))
    poisson_input (Type: SpikeSourcePoisson:  start=0.0 (SI time) duration=1000000.0 (SI time) rate=10000.0 (SI per_time) end=1000000.0 (SI time) LONG_TIME=3.6E12 (SI time))
    Example7_Brunel2000 (Type: network)
    SimExample7 (Type: Simulation:  length=1.0 (SI time) step=2.5E-5 (SI time))


    This NEURON file has been generated by org.neuroml.export (see https://github.com/NeuroML/org.neuroml.export)
         org.neuroml.export  v1.5.4
         org.neuroml.model   v1.5.4
         jLEMS               v0.9.9.1

'''

import neuron

import time
import datetime
import sys

import hashlib
h = neuron.h
h.load_file("stdlib.hoc")

h.load_file("stdgui.hoc")

h("objref p")
h("p = new PythonObject()")

class NeuronSimulation():

    def __init__(self, tstop, dt, seed=123):

        print("\n    Starting simulation in NEURON of %sms generated from NeuroML2 model...\n"%tstop)

        self.setup_start = time.time()
        self.report_file = open('report.SimExample7.txt','w')
        print('Simulator version:  %s'%h.nrnversion())
        self.report_file.write('# Report of running simulation with %s\n'%h.nrnversion())
        self.report_file.write('Simulator=NEURON\n')
        self.report_file.write('SimulatorVersion=%s\n'%h.nrnversion())

        self.report_file.write('SimulationFile=%s\n'%__file__)
        self.report_file.write('PythonVersion=%s\n'%sys.version.replace('\n',' '))
        print('Python version:     %s'%sys.version.replace('\n',' '))
        self.report_file.write('NeuroMLExportVersion=1.5.4\n')
        self.seed = seed
        self.randoms = []
        self.next_global_id = 0  # Used in Random123 classes for elements using random(), etc. 

        self.next_spiking_input_id = 0  # Used in Random123 classes for elements using random(), etc. 

        '''
        Adding simulation Component(id=SimExample7 type=Simulation) of network/component: Example7_Brunel2000 (Type: network)
        
        '''
        # ######################   Population: Epop
        print("Population Epop contains 80 instance(s) of component: ifcell of type: IF_curr_alpha")

        h(" {n_Epop = 80} ")
        '''
        Population Epop contains instances of Component(id=ifcell type=IF_curr_alpha)
        whose dynamics will be implemented as a mechanism (ifcell) in a mod file
        '''
        h(" create Epop[80]")
        h(" objectvar m_ifcell_Epop[80] ")

        for i in range(int(h.n_Epop)):
            h.Epop[i].L = 10.0
            h.Epop[i](0.5).diam = 10.0
            h.Epop[i](0.5).cm = 0.3183098861837907
            h.Epop[i].push()
            h(" Epop[%i]  { m_ifcell_Epop[%i] = new ifcell(0.5) } "%(i,i))

            h.m_ifcell_Epop[i].tau_refrac = 2.0
            h.m_ifcell_Epop[i].v_thresh = 20.0
            h.m_ifcell_Epop[i].tau_m = 20.0
            h.m_ifcell_Epop[i].v_rest = 0.0
            h.m_ifcell_Epop[i].v_reset = 0.0
            h.m_ifcell_Epop[i].cm = 0.001
            h.m_ifcell_Epop[i].i_offset = 0.0
            h.m_ifcell_Epop[i].tau_syn_E = 0.1
            h.m_ifcell_Epop[i].tau_syn_I = 0.1
            h.m_ifcell_Epop[i].v_init = 0.0
            h.m_ifcell_Epop[i].MSEC = 1.0
            h.m_ifcell_Epop[i].MVOLT = 1.0
            h.m_ifcell_Epop[i].NFARAD = 0.001
            h.pop_section()

            self.next_global_id+=1

        h(" Epop[0] { pt3dclear() } ")
        h(" Epop[0] { pt3dadd(966.45355, 44.07326 + (5), 7.49147, 10) } ")
        h(" Epop[0] { pt3dadd(966.45355, 44.07326 + (-5), 7.49147, 10) } ")
        h(" Epop[1] { pt3dclear() } ")
        h(" Epop[1] { pt3dadd(910.97595, 93.9269 + (5), 582.2276, 10) } ")
        h(" Epop[1] { pt3dadd(910.97595, 93.9269 + (-5), 582.2276, 10) } ")
        h(" Epop[2] { pt3dclear() } ")
        h(" Epop[2] { pt3dadd(671.5635, 8.393823 + (5), 766.48096, 10) } ")
        h(" Epop[2] { pt3dadd(671.5635, 8.393823 + (-5), 766.48096, 10) } ")
        h(" Epop[3] { pt3dclear() } ")
        h(" Epop[3] { pt3dadd(236.80977, 3.081402 + (5), 788.7727, 10) } ")
        h(" Epop[3] { pt3dadd(236.80977, 3.081402 + (-5), 788.7727, 10) } ")
        h(" Epop[4] { pt3dclear() } ")
        h(" Epop[4] { pt3dadd(346.08896, 62.328148 + (5), 615.8157, 10) } ")
        h(" Epop[4] { pt3dadd(346.08896, 62.328148 + (-5), 615.8157, 10) } ")
        h(" Epop[5] { pt3dclear() } ")
        h(" Epop[5] { pt3dadd(148.55464, 18.309065 + (5), 114.41297, 10) } ")
        h(" Epop[5] { pt3dadd(148.55464, 18.309065 + (-5), 114.41297, 10) } ")
        h(" Epop[6] { pt3dclear() } ")
        h(" Epop[6] { pt3dadd(14.61878, 48.675156 + (5), 964.90155, 10) } ")
        h(" Epop[6] { pt3dadd(14.61878, 48.675156 + (-5), 964.90155, 10) } ")
        h(" Epop[7] { pt3dclear() } ")
        h(" Epop[7] { pt3dadd(64.56228, 54.108818 + (5), 465.89856, 10) } ")
        h(" Epop[7] { pt3dadd(64.56228, 54.108818 + (-5), 465.89856, 10) } ")
        h(" Epop[8] { pt3dclear() } ")
        h(" Epop[8] { pt3dadd(601.46344, 8.892883 + (5), 579.0027, 10) } ")
        h(" Epop[8] { pt3dadd(601.46344, 8.892883 + (-5), 579.0027, 10) } ")
        h(" Epop[9] { pt3dclear() } ")
        h(" Epop[9] { pt3dadd(269.5855, 55.643257 + (5), 644.6342, 10) } ")
        h(" Epop[9] { pt3dadd(269.5855, 55.643257 + (-5), 644.6342, 10) } ")
        h(" Epop[10] { pt3dclear() } ")
        h(" Epop[10] { pt3dadd(481.03638, 35.523914 + (5), 249.15211, 10) } ")
        h(" Epop[10] { pt3dadd(481.03638, 35.523914 + (-5), 249.15211, 10) } ")
        h(" Epop[11] { pt3dclear() } ")
        h(" Epop[11] { pt3dadd(933.5155, 45.338802 + (5), 530.1612, 10) } ")
        h(" Epop[11] { pt3dadd(933.5155, 45.338802 + (-5), 530.1612, 10) } ")
        h(" Epop[12] { pt3dclear() } ")
        h(" Epop[12] { pt3dadd(19.299566, 50.810192 + (5), 5.780237, 10) } ")
        h(" Epop[12] { pt3dadd(19.299566, 50.810192 + (-5), 5.780237, 10) } ")
        h(" Epop[13] { pt3dclear() } ")
        h(" Epop[13] { pt3dadd(143.76843, 47.282692 + (5), 377.34744, 10) } ")
        h(" Epop[13] { pt3dadd(143.76843, 47.282692 + (-5), 377.34744, 10) } ")
        h(" Epop[14] { pt3dclear() } ")
        h(" Epop[14] { pt3dadd(54.175198, 58.75285 + (5), 164.00322, 10) } ")
        h(" Epop[14] { pt3dadd(54.175198, 58.75285 + (-5), 164.00322, 10) } ")
        h(" Epop[15] { pt3dclear() } ")
        h(" Epop[15] { pt3dadd(557.33026, 14.424572 + (5), 937.30707, 10) } ")
        h(" Epop[15] { pt3dadd(557.33026, 14.424572 + (-5), 937.30707, 10) } ")
        h(" Epop[16] { pt3dclear() } ")
        h(" Epop[16] { pt3dadd(770.98, 95.69331 + (5), 141.22777, 10) } ")
        h(" Epop[16] { pt3dadd(770.98, 95.69331 + (-5), 141.22777, 10) } ")
        h(" Epop[17] { pt3dclear() } ")
        h(" Epop[17] { pt3dadd(305.3927, 3.9589624 + (5), 276.7837, 10) } ")
        h(" Epop[17] { pt3dadd(305.3927, 3.9589624 + (-5), 276.7837, 10) } ")
        h(" Epop[18] { pt3dclear() } ")
        h(" Epop[18] { pt3dadd(806.5125, 17.734304 + (5), 154.57051, 10) } ")
        h(" Epop[18] { pt3dadd(806.5125, 17.734304 + (-5), 154.57051, 10) } ")
        h(" Epop[19] { pt3dclear() } ")
        h(" Epop[19] { pt3dadd(954.7186, 15.45514 + (5), 833.8893, 10) } ")
        h(" Epop[19] { pt3dadd(954.7186, 15.45514 + (-5), 833.8893, 10) } ")
        h(" Epop[20] { pt3dclear() } ")
        h(" Epop[20] { pt3dadd(41.062805, 38.61835 + (5), 349.59232, 10) } ")
        h(" Epop[20] { pt3dadd(41.062805, 38.61835 + (-5), 349.59232, 10) } ")
        h(" Epop[21] { pt3dclear() } ")
        h(" Epop[21] { pt3dadd(341.7078, 81.64631 + (5), 475.9349, 10) } ")
        h(" Epop[21] { pt3dadd(341.7078, 81.64631 + (-5), 475.9349, 10) } ")
        h(" Epop[22] { pt3dclear() } ")
        h(" Epop[22] { pt3dadd(782.8903, 47.08401 + (5), 817.344, 10) } ")
        h(" Epop[22] { pt3dadd(782.8903, 47.08401 + (-5), 817.344, 10) } ")
        h(" Epop[23] { pt3dclear() } ")
        h(" Epop[23] { pt3dadd(881.5676, 43.95964 + (5), 781.0636, 10) } ")
        h(" Epop[23] { pt3dadd(881.5676, 43.95964 + (-5), 781.0636, 10) } ")
        h(" Epop[24] { pt3dclear() } ")
        h(" Epop[24] { pt3dadd(814.74115, 29.567892 + (5), 123.87667, 10) } ")
        h(" Epop[24] { pt3dadd(814.74115, 29.567892 + (-5), 123.87667, 10) } ")
        h(" Epop[25] { pt3dclear() } ")
        h(" Epop[25] { pt3dadd(185.62186, 43.60598 + (5), 119.46741, 10) } ")
        h(" Epop[25] { pt3dadd(185.62186, 43.60598 + (-5), 119.46741, 10) } ")
        h(" Epop[26] { pt3dclear() } ")
        h(" Epop[26] { pt3dadd(529.79913, 82.942116 + (5), 485.20114, 10) } ")
        h(" Epop[26] { pt3dadd(529.79913, 82.942116 + (-5), 485.20114, 10) } ")
        h(" Epop[27] { pt3dclear() } ")
        h(" Epop[27] { pt3dadd(817.734, 65.63916 + (5), 641.043, 10) } ")
        h(" Epop[27] { pt3dadd(817.734, 65.63916 + (-5), 641.043, 10) } ")
        h(" Epop[28] { pt3dclear() } ")
        h(" Epop[28] { pt3dadd(345.34894, 70.26589 + (5), 809.9406, 10) } ")
        h(" Epop[28] { pt3dadd(345.34894, 70.26589 + (-5), 809.9406, 10) } ")
        h(" Epop[29] { pt3dclear() } ")
        h(" Epop[29] { pt3dadd(157.16959, 90.799065 + (5), 269.33035, 10) } ")
        h(" Epop[29] { pt3dadd(157.16959, 90.799065 + (-5), 269.33035, 10) } ")
        h(" Epop[30] { pt3dclear() } ")
        h(" Epop[30] { pt3dadd(154.8465, 84.04792 + (5), 720.128, 10) } ")
        h(" Epop[30] { pt3dadd(154.8465, 84.04792 + (-5), 720.128, 10) } ")
        h(" Epop[31] { pt3dclear() } ")
        h(" Epop[31] { pt3dadd(793.5624, 44.667065 + (5), 70.77389, 10) } ")
        h(" Epop[31] { pt3dadd(793.5624, 44.667065 + (-5), 70.77389, 10) } ")
        h(" Epop[32] { pt3dclear() } ")
        h(" Epop[32] { pt3dadd(395.24304, 4.7735295 + (5), 286.1335, 10) } ")
        h(" Epop[32] { pt3dadd(395.24304, 4.7735295 + (-5), 286.1335, 10) } ")
        h(" Epop[33] { pt3dclear() } ")
        h(" Epop[33] { pt3dadd(37.994595, 50.671486 + (5), 87.6678, 10) } ")
        h(" Epop[33] { pt3dadd(37.994595, 50.671486 + (-5), 87.6678, 10) } ")
        h(" Epop[34] { pt3dclear() } ")
        h(" Epop[34] { pt3dadd(932.8256, 69.93873 + (5), 316.98602, 10) } ")
        h(" Epop[34] { pt3dadd(932.8256, 69.93873 + (-5), 316.98602, 10) } ")
        h(" Epop[35] { pt3dclear() } ")
        h(" Epop[35] { pt3dadd(945.0511, 6.6227603 + (5), 257.4289, 10) } ")
        h(" Epop[35] { pt3dadd(945.0511, 6.6227603 + (-5), 257.4289, 10) } ")
        h(" Epop[36] { pt3dclear() } ")
        h(" Epop[36] { pt3dadd(72.99965, 42.630424 + (5), 201.89677, 10) } ")
        h(" Epop[36] { pt3dadd(72.99965, 42.630424 + (-5), 201.89677, 10) } ")
        h(" Epop[37] { pt3dclear() } ")
        h(" Epop[37] { pt3dadd(396.64664, 70.48599 + (5), 887.35333, 10) } ")
        h(" Epop[37] { pt3dadd(396.64664, 70.48599 + (-5), 887.35333, 10) } ")
        h(" Epop[38] { pt3dclear() } ")
        h(" Epop[38] { pt3dadd(500.5178, 81.85316 + (5), 361.25452, 10) } ")
        h(" Epop[38] { pt3dadd(500.5178, 81.85316 + (-5), 361.25452, 10) } ")
        h(" Epop[39] { pt3dclear() } ")
        h(" Epop[39] { pt3dadd(858.68616, 51.503418 + (5), 702.41547, 10) } ")
        h(" Epop[39] { pt3dadd(858.68616, 51.503418 + (-5), 702.41547, 10) } ")
        h(" Epop[40] { pt3dclear() } ")
        h(" Epop[40] { pt3dadd(174.68991, 58.45118 + (5), 301.77707, 10) } ")
        h(" Epop[40] { pt3dadd(174.68991, 58.45118 + (-5), 301.77707, 10) } ")
        h(" Epop[41] { pt3dclear() } ")
        h(" Epop[41] { pt3dadd(812.8514, 53.434074 + (5), 499.5873, 10) } ")
        h(" Epop[41] { pt3dadd(812.8514, 53.434074 + (-5), 499.5873, 10) } ")
        h(" Epop[42] { pt3dclear() } ")
        h(" Epop[42] { pt3dadd(773.3252, 54.90307 + (5), 333.75803, 10) } ")
        h(" Epop[42] { pt3dadd(773.3252, 54.90307 + (-5), 333.75803, 10) } ")
        h(" Epop[43] { pt3dclear() } ")
        h(" Epop[43] { pt3dadd(130.93286, 62.4506 + (5), 925.3462, 10) } ")
        h(" Epop[43] { pt3dadd(130.93286, 62.4506 + (-5), 925.3462, 10) } ")
        h(" Epop[44] { pt3dclear() } ")
        h(" Epop[44] { pt3dadd(842.33887, 6.9749784 + (5), 325.28522, 10) } ")
        h(" Epop[44] { pt3dadd(842.33887, 6.9749784 + (-5), 325.28522, 10) } ")
        h(" Epop[45] { pt3dclear() } ")
        h(" Epop[45] { pt3dadd(1.7063742, 67.46972 + (5), 638.2801, 10) } ")
        h(" Epop[45] { pt3dadd(1.7063742, 67.46972 + (-5), 638.2801, 10) } ")
        h(" Epop[46] { pt3dclear() } ")
        h(" Epop[46] { pt3dadd(757.90875, 14.827393 + (5), 217.03369, 10) } ")
        h(" Epop[46] { pt3dadd(757.90875, 14.827393 + (-5), 217.03369, 10) } ")
        h(" Epop[47] { pt3dclear() } ")
        h(" Epop[47] { pt3dadd(432.77237, 73.672485 + (5), 207.119, 10) } ")
        h(" Epop[47] { pt3dadd(432.77237, 73.672485 + (-5), 207.119, 10) } ")
        h(" Epop[48] { pt3dclear() } ")
        h(" Epop[48] { pt3dadd(822.8369, 38.12011 + (5), 874.28577, 10) } ")
        h(" Epop[48] { pt3dadd(822.8369, 38.12011 + (-5), 874.28577, 10) } ")
        h(" Epop[49] { pt3dclear() } ")
        h(" Epop[49] { pt3dadd(960.02466, 53.74877 + (5), 921.0674, 10) } ")
        h(" Epop[49] { pt3dadd(960.02466, 53.74877 + (-5), 921.0674, 10) } ")
        h(" Epop[50] { pt3dclear() } ")
        h(" Epop[50] { pt3dadd(422.03687, 68.52701 + (5), 846.9089, 10) } ")
        h(" Epop[50] { pt3dadd(422.03687, 68.52701 + (-5), 846.9089, 10) } ")
        h(" Epop[51] { pt3dclear() } ")
        h(" Epop[51] { pt3dadd(838.76776, 9.286882 + (5), 260.31577, 10) } ")
        h(" Epop[51] { pt3dadd(838.76776, 9.286882 + (-5), 260.31577, 10) } ")
        h(" Epop[52] { pt3dclear() } ")
        h(" Epop[52] { pt3dadd(410.25803, 85.78243 + (5), 276.74252, 10) } ")
        h(" Epop[52] { pt3dadd(410.25803, 85.78243 + (-5), 276.74252, 10) } ")
        h(" Epop[53] { pt3dclear() } ")
        h(" Epop[53] { pt3dadd(113.738914, 37.534843 + (5), 213.88582, 10) } ")
        h(" Epop[53] { pt3dadd(113.738914, 37.534843 + (-5), 213.88582, 10) } ")
        h(" Epop[54] { pt3dclear() } ")
        h(" Epop[54] { pt3dadd(716.23663, 58.75095 + (5), 52.498955, 10) } ")
        h(" Epop[54] { pt3dadd(716.23663, 58.75095 + (-5), 52.498955, 10) } ")
        h(" Epop[55] { pt3dclear() } ")
        h(" Epop[55] { pt3dadd(877.43036, 44.055508 + (5), 776.887, 10) } ")
        h(" Epop[55] { pt3dadd(877.43036, 44.055508 + (-5), 776.887, 10) } ")
        h(" Epop[56] { pt3dclear() } ")
        h(" Epop[56] { pt3dadd(165.32071, 30.791716 + (5), 73.326294, 10) } ")
        h(" Epop[56] { pt3dadd(165.32071, 30.791716 + (-5), 73.326294, 10) } ")
        h(" Epop[57] { pt3dclear() } ")
        h(" Epop[57] { pt3dadd(394.99072, 42.891037 + (5), 682.79626, 10) } ")
        h(" Epop[57] { pt3dadd(394.99072, 42.891037 + (-5), 682.79626, 10) } ")
        h(" Epop[58] { pt3dclear() } ")
        h(" Epop[58] { pt3dadd(479.58786, 40.051186 + (5), 477.96198, 10) } ")
        h(" Epop[58] { pt3dadd(479.58786, 40.051186 + (-5), 477.96198, 10) } ")
        h(" Epop[59] { pt3dclear() } ")
        h(" Epop[59] { pt3dadd(281.2604, 36.952545 + (5), 600.4938, 10) } ")
        h(" Epop[59] { pt3dadd(281.2604, 36.952545 + (-5), 600.4938, 10) } ")
        h(" Epop[60] { pt3dclear() } ")
        h(" Epop[60] { pt3dadd(206.06798, 51.886433 + (5), 929.67267, 10) } ")
        h(" Epop[60] { pt3dadd(206.06798, 51.886433 + (-5), 929.67267, 10) } ")
        h(" Epop[61] { pt3dclear() } ")
        h(" Epop[61] { pt3dadd(457.41745, 66.831055 + (5), 659.8432, 10) } ")
        h(" Epop[61] { pt3dadd(457.41745, 66.831055 + (-5), 659.8432, 10) } ")
        h(" Epop[62] { pt3dclear() } ")
        h(" Epop[62] { pt3dadd(801.34515, 72.55504 + (5), 660.70703, 10) } ")
        h(" Epop[62] { pt3dadd(801.34515, 72.55504 + (-5), 660.70703, 10) } ")
        h(" Epop[63] { pt3dclear() } ")
        h(" Epop[63] { pt3dadd(103.71082, 36.663376 + (5), 794.06036, 10) } ")
        h(" Epop[63] { pt3dadd(103.71082, 36.663376 + (-5), 794.06036, 10) } ")
        h(" Epop[64] { pt3dclear() } ")
        h(" Epop[64] { pt3dadd(65.19273, 14.001766 + (5), 905.36017, 10) } ")
        h(" Epop[64] { pt3dadd(65.19273, 14.001766 + (-5), 905.36017, 10) } ")
        h(" Epop[65] { pt3dclear() } ")
        h(" Epop[65] { pt3dadd(588.01746, 98.01688 + (5), 753.58026, 10) } ")
        h(" Epop[65] { pt3dadd(588.01746, 98.01688 + (-5), 753.58026, 10) } ")
        h(" Epop[66] { pt3dclear() } ")
        h(" Epop[66] { pt3dadd(995.678, 29.86195 + (5), 686.0565, 10) } ")
        h(" Epop[66] { pt3dadd(995.678, 29.86195 + (-5), 686.0565, 10) } ")
        h(" Epop[67] { pt3dclear() } ")
        h(" Epop[67] { pt3dadd(330.58673, 94.59701 + (5), 293.78134, 10) } ")
        h(" Epop[67] { pt3dadd(330.58673, 94.59701 + (-5), 293.78134, 10) } ")
        h(" Epop[68] { pt3dclear() } ")
        h(" Epop[68] { pt3dadd(194.56633, 81.42844 + (5), 279.03467, 10) } ")
        h(" Epop[68] { pt3dadd(194.56633, 81.42844 + (-5), 279.03467, 10) } ")
        h(" Epop[69] { pt3dclear() } ")
        h(" Epop[69] { pt3dadd(534.0337, 60.22037 + (5), 339.63425, 10) } ")
        h(" Epop[69] { pt3dadd(534.0337, 60.22037 + (-5), 339.63425, 10) } ")
        h(" Epop[70] { pt3dclear() } ")
        h(" Epop[70] { pt3dadd(334.23486, 32.106117 + (5), 267.50378, 10) } ")
        h(" Epop[70] { pt3dadd(334.23486, 32.106117 + (-5), 267.50378, 10) } ")
        h(" Epop[71] { pt3dclear() } ")
        h(" Epop[71] { pt3dadd(759.67236, 58.922974 + (5), 548.24506, 10) } ")
        h(" Epop[71] { pt3dadd(759.67236, 58.922974 + (-5), 548.24506, 10) } ")
        h(" Epop[72] { pt3dclear() } ")
        h(" Epop[72] { pt3dadd(824.1385, 25.715061 + (5), 137.08331, 10) } ")
        h(" Epop[72] { pt3dadd(824.1385, 25.715061 + (-5), 137.08331, 10) } ")
        h(" Epop[73] { pt3dclear() } ")
        h(" Epop[73] { pt3dadd(28.37907, 3.7353952 + (5), 990.6762, 10) } ")
        h(" Epop[73] { pt3dadd(28.37907, 3.7353952 + (-5), 990.6762, 10) } ")
        h(" Epop[74] { pt3dclear() } ")
        h(" Epop[74] { pt3dadd(973.8147, 66.65997 + (5), 990.6604, 10) } ")
        h(" Epop[74] { pt3dadd(973.8147, 66.65997 + (-5), 990.6604, 10) } ")
        h(" Epop[75] { pt3dclear() } ")
        h(" Epop[75] { pt3dadd(515.6525, 43.45554 + (5), 515.28424, 10) } ")
        h(" Epop[75] { pt3dadd(515.6525, 43.45554 + (-5), 515.28424, 10) } ")
        h(" Epop[76] { pt3dclear() } ")
        h(" Epop[76] { pt3dadd(68.99685, 75.95808 + (5), 305.16153, 10) } ")
        h(" Epop[76] { pt3dadd(68.99685, 75.95808 + (-5), 305.16153, 10) } ")
        h(" Epop[77] { pt3dclear() } ")
        h(" Epop[77] { pt3dadd(698.08044, 90.95027 + (5), 219.59909, 10) } ")
        h(" Epop[77] { pt3dadd(698.08044, 90.95027 + (-5), 219.59909, 10) } ")
        h(" Epop[78] { pt3dclear() } ")
        h(" Epop[78] { pt3dadd(504.37628, 65.31418 + (5), 810.9583, 10) } ")
        h(" Epop[78] { pt3dadd(504.37628, 65.31418 + (-5), 810.9583, 10) } ")
        h(" Epop[79] { pt3dclear() } ")
        h(" Epop[79] { pt3dadd(682.7514, 33.10914 + (5), 564.1798, 10) } ")
        h(" Epop[79] { pt3dadd(682.7514, 33.10914 + (-5), 564.1798, 10) } ")

        # ######################   Population: expoisson
        print("Population expoisson contains 80 instance(s) of component: poisson_input of type: SpikeSourcePoisson")

        h(" {n_expoisson = 80} ")
        '''
        Population expoisson contains instances of Component(id=poisson_input type=SpikeSourcePoisson)
        whose dynamics will be implemented as a mechanism (poisson_input) in a mod file
        '''
        h(" create expoisson[80]")
        h(" objectvar m_poisson_input_expoisson[80] ")

        for i in range(int(h.n_expoisson)):
            h.expoisson[i].L = 10.0
            h.expoisson[i](0.5).diam = 10.0
            h.expoisson[i](0.5).cm = 318.31
            h.expoisson[i].push()
            h(" expoisson[%i]  { m_poisson_input_expoisson[%i] = new poisson_input(0.5) } "%(i,i))

            h.m_poisson_input_expoisson[i].start = 0.0
            h.m_poisson_input_expoisson[i].duration = 1.0E9
            h.m_poisson_input_expoisson[i].rate = 10.0
            h.m_poisson_input_expoisson[i].end = 1.0E9
            h.m_poisson_input_expoisson[i].LONG_TIME = 3.59999998E15
            # Spiking element (SpikeSourcePoisson), will require seeding...
            rand = h.Random()
            self.randoms.append(rand)
            #print("Seeding random generator on m_poisson_input_expoisson[i] (i=%i) with stim seed %s"%(i, self.seed))
            self._init_stim_randomizer(rand,"expoisson",i, self.seed)
            rand.negexp(1)
            h.m_poisson_input_expoisson[i].noiseFromRandom(rand)

            h.pop_section()

            self.next_global_id+=1

        h(" expoisson[0] { pt3dclear() } ")
        h(" expoisson[0] { pt3dadd(162.53429, 49.941605 + (5), 940.0481, 10) } ")
        h(" expoisson[0] { pt3dadd(162.53429, 49.941605 + (-5), 940.0481, 10) } ")
        h(" expoisson[1] { pt3dclear() } ")
        h(" expoisson[1] { pt3dadd(950.1827, 13.993868 + (5), 532.3138, 10) } ")
        h(" expoisson[1] { pt3dadd(950.1827, 13.993868 + (-5), 532.3138, 10) } ")
        h(" expoisson[2] { pt3dclear() } ")
        h(" expoisson[2] { pt3dadd(619.8618, 14.55319 + (5), 948.99097, 10) } ")
        h(" expoisson[2] { pt3dadd(619.8618, 14.55319 + (-5), 948.99097, 10) } ")
        h(" expoisson[3] { pt3dclear() } ")
        h(" expoisson[3] { pt3dadd(243.28574, 16.42501 + (5), 506.43164, 10) } ")
        h(" expoisson[3] { pt3dadd(243.28574, 16.42501 + (-5), 506.43164, 10) } ")
        h(" expoisson[4] { pt3dclear() } ")
        h(" expoisson[4] { pt3dadd(505.0036, 77.34484 + (5), 853.1773, 10) } ")
        h(" expoisson[4] { pt3dadd(505.0036, 77.34484 + (-5), 853.1773, 10) } ")
        h(" expoisson[5] { pt3dclear() } ")
        h(" expoisson[5] { pt3dadd(326.50317, 70.82273 + (5), 561.7224, 10) } ")
        h(" expoisson[5] { pt3dadd(326.50317, 70.82273 + (-5), 561.7224, 10) } ")
        h(" expoisson[6] { pt3dclear() } ")
        h(" expoisson[6] { pt3dadd(535.08124, 59.919914 + (5), 446.33777, 10) } ")
        h(" expoisson[6] { pt3dadd(535.08124, 59.919914 + (-5), 446.33777, 10) } ")
        h(" expoisson[7] { pt3dclear() } ")
        h(" expoisson[7] { pt3dadd(371.70374, 92.97232 + (5), 762.89905, 10) } ")
        h(" expoisson[7] { pt3dadd(371.70374, 92.97232 + (-5), 762.89905, 10) } ")
        h(" expoisson[8] { pt3dclear() } ")
        h(" expoisson[8] { pt3dadd(675.8695, 88.63111 + (5), 604.04224, 10) } ")
        h(" expoisson[8] { pt3dadd(675.8695, 88.63111 + (-5), 604.04224, 10) } ")
        h(" expoisson[9] { pt3dclear() } ")
        h(" expoisson[9] { pt3dadd(70.90206, 22.792301 + (5), 803.02026, 10) } ")
        h(" expoisson[9] { pt3dadd(70.90206, 22.792301 + (-5), 803.02026, 10) } ")
        h(" expoisson[10] { pt3dclear() } ")
        h(" expoisson[10] { pt3dadd(346.1863, 93.96198 + (5), 689.0523, 10) } ")
        h(" expoisson[10] { pt3dadd(346.1863, 93.96198 + (-5), 689.0523, 10) } ")
        h(" expoisson[11] { pt3dclear() } ")
        h(" expoisson[11] { pt3dadd(379.78674, 49.27859 + (5), 52.447567, 10) } ")
        h(" expoisson[11] { pt3dadd(379.78674, 49.27859 + (-5), 52.447567, 10) } ")
        h(" expoisson[12] { pt3dclear() } ")
        h(" expoisson[12] { pt3dadd(448.07565, 8.017792 + (5), 293.16406, 10) } ")
        h(" expoisson[12] { pt3dadd(448.07565, 8.017792 + (-5), 293.16406, 10) } ")
        h(" expoisson[13] { pt3dclear() } ")
        h(" expoisson[13] { pt3dadd(929.2915, 14.7894 + (5), 676.91736, 10) } ")
        h(" expoisson[13] { pt3dadd(929.2915, 14.7894 + (-5), 676.91736, 10) } ")
        h(" expoisson[14] { pt3dclear() } ")
        h(" expoisson[14] { pt3dadd(650.78894, 69.30677 + (5), 794.4701, 10) } ")
        h(" expoisson[14] { pt3dadd(650.78894, 69.30677 + (-5), 794.4701, 10) } ")
        h(" expoisson[15] { pt3dclear() } ")
        h(" expoisson[15] { pt3dadd(864.25616, 35.66087 + (5), 371.41156, 10) } ")
        h(" expoisson[15] { pt3dadd(864.25616, 35.66087 + (-5), 371.41156, 10) } ")
        h(" expoisson[16] { pt3dclear() } ")
        h(" expoisson[16] { pt3dadd(174.04942, 63.942448 + (5), 212.27072, 10) } ")
        h(" expoisson[16] { pt3dadd(174.04942, 63.942448 + (-5), 212.27072, 10) } ")
        h(" expoisson[17] { pt3dclear() } ")
        h(" expoisson[17] { pt3dadd(196.44952, 99.00923 + (5), 620.4217, 10) } ")
        h(" expoisson[17] { pt3dadd(196.44952, 99.00923 + (-5), 620.4217, 10) } ")
        h(" expoisson[18] { pt3dclear() } ")
        h(" expoisson[18] { pt3dadd(730.64703, 50.18556 + (5), 132.50043, 10) } ")
        h(" expoisson[18] { pt3dadd(730.64703, 50.18556 + (-5), 132.50043, 10) } ")
        h(" expoisson[19] { pt3dclear() } ")
        h(" expoisson[19] { pt3dadd(910.18207, 65.12464 + (5), 49.509315, 10) } ")
        h(" expoisson[19] { pt3dadd(910.18207, 65.12464 + (-5), 49.509315, 10) } ")
        h(" expoisson[20] { pt3dclear() } ")
        h(" expoisson[20] { pt3dadd(913.98816, 46.80477 + (5), 597.75977, 10) } ")
        h(" expoisson[20] { pt3dadd(913.98816, 46.80477 + (-5), 597.75977, 10) } ")
        h(" expoisson[21] { pt3dclear() } ")
        h(" expoisson[21] { pt3dadd(371.7923, 39.66542 + (5), 778.40753, 10) } ")
        h(" expoisson[21] { pt3dadd(371.7923, 39.66542 + (-5), 778.40753, 10) } ")
        h(" expoisson[22] { pt3dclear() } ")
        h(" expoisson[22] { pt3dadd(234.17012, 0.87451106 + (5), 312.74936, 10) } ")
        h(" expoisson[22] { pt3dadd(234.17012, 0.87451106 + (-5), 312.74936, 10) } ")
        h(" expoisson[23] { pt3dclear() } ")
        h(" expoisson[23] { pt3dadd(985.3726, 12.047353 + (5), 599.9056, 10) } ")
        h(" expoisson[23] { pt3dadd(985.3726, 12.047353 + (-5), 599.9056, 10) } ")
        h(" expoisson[24] { pt3dclear() } ")
        h(" expoisson[24] { pt3dadd(865.077, 53.39887 + (5), 593.56525, 10) } ")
        h(" expoisson[24] { pt3dadd(865.077, 53.39887 + (-5), 593.56525, 10) } ")
        h(" expoisson[25] { pt3dclear() } ")
        h(" expoisson[25] { pt3dadd(537.19635, 32.223682 + (5), 362.85516, 10) } ")
        h(" expoisson[25] { pt3dadd(537.19635, 32.223682 + (-5), 362.85516, 10) } ")
        h(" expoisson[26] { pt3dclear() } ")
        h(" expoisson[26] { pt3dadd(926.607, 71.21431 + (5), 642.6836, 10) } ")
        h(" expoisson[26] { pt3dadd(926.607, 71.21431 + (-5), 642.6836, 10) } ")
        h(" expoisson[27] { pt3dclear() } ")
        h(" expoisson[27] { pt3dadd(456.86792, 91.09721 + (5), 876.83606, 10) } ")
        h(" expoisson[27] { pt3dadd(456.86792, 91.09721 + (-5), 876.83606, 10) } ")
        h(" expoisson[28] { pt3dclear() } ")
        h(" expoisson[28] { pt3dadd(967.14886, 54.355824 + (5), 408.60992, 10) } ")
        h(" expoisson[28] { pt3dadd(967.14886, 54.355824 + (-5), 408.60992, 10) } ")
        h(" expoisson[29] { pt3dclear() } ")
        h(" expoisson[29] { pt3dadd(191.7215, 27.340328 + (5), 867.70215, 10) } ")
        h(" expoisson[29] { pt3dadd(191.7215, 27.340328 + (-5), 867.70215, 10) } ")
        h(" expoisson[30] { pt3dclear() } ")
        h(" expoisson[30] { pt3dadd(174.24661, 94.59593 + (5), 586.3581, 10) } ")
        h(" expoisson[30] { pt3dadd(174.24661, 94.59593 + (-5), 586.3581, 10) } ")
        h(" expoisson[31] { pt3dclear() } ")
        h(" expoisson[31] { pt3dadd(847.05865, 53.012093 + (5), 754.7609, 10) } ")
        h(" expoisson[31] { pt3dadd(847.05865, 53.012093 + (-5), 754.7609, 10) } ")
        h(" expoisson[32] { pt3dclear() } ")
        h(" expoisson[32] { pt3dadd(587.2074, 82.80736 + (5), 514.3343, 10) } ")
        h(" expoisson[32] { pt3dadd(587.2074, 82.80736 + (-5), 514.3343, 10) } ")
        h(" expoisson[33] { pt3dclear() } ")
        h(" expoisson[33] { pt3dadd(724.2079, 80.3506 + (5), 373.02954, 10) } ")
        h(" expoisson[33] { pt3dadd(724.2079, 80.3506 + (-5), 373.02954, 10) } ")
        h(" expoisson[34] { pt3dclear() } ")
        h(" expoisson[34] { pt3dadd(102.583824, 67.50025 + (5), 850.27924, 10) } ")
        h(" expoisson[34] { pt3dadd(102.583824, 67.50025 + (-5), 850.27924, 10) } ")
        h(" expoisson[35] { pt3dclear() } ")
        h(" expoisson[35] { pt3dadd(834.0532, 12.704253 + (5), 784.4155, 10) } ")
        h(" expoisson[35] { pt3dadd(834.0532, 12.704253 + (-5), 784.4155, 10) } ")
        h(" expoisson[36] { pt3dclear() } ")
        h(" expoisson[36] { pt3dadd(488.10538, 54.63551 + (5), 131.83867, 10) } ")
        h(" expoisson[36] { pt3dadd(488.10538, 54.63551 + (-5), 131.83867, 10) } ")
        h(" expoisson[37] { pt3dclear() } ")
        h(" expoisson[37] { pt3dadd(769.6515, 23.897272 + (5), 698.5024, 10) } ")
        h(" expoisson[37] { pt3dadd(769.6515, 23.897272 + (-5), 698.5024, 10) } ")
        h(" expoisson[38] { pt3dclear() } ")
        h(" expoisson[38] { pt3dadd(335.30792, 95.66119 + (5), 711.5024, 10) } ")
        h(" expoisson[38] { pt3dadd(335.30792, 95.66119 + (-5), 711.5024, 10) } ")
        h(" expoisson[39] { pt3dclear() } ")
        h(" expoisson[39] { pt3dadd(354.97708, 54.80486 + (5), 188.34671, 10) } ")
        h(" expoisson[39] { pt3dadd(354.97708, 54.80486 + (-5), 188.34671, 10) } ")
        h(" expoisson[40] { pt3dclear() } ")
        h(" expoisson[40] { pt3dadd(472.92447, 93.1134 + (5), 929.02155, 10) } ")
        h(" expoisson[40] { pt3dadd(472.92447, 93.1134 + (-5), 929.02155, 10) } ")
        h(" expoisson[41] { pt3dclear() } ")
        h(" expoisson[41] { pt3dadd(319.54306, 44.158092 + (5), 524.8705, 10) } ")
        h(" expoisson[41] { pt3dadd(319.54306, 44.158092 + (-5), 524.8705, 10) } ")
        h(" expoisson[42] { pt3dclear() } ")
        h(" expoisson[42] { pt3dadd(539.1696, 98.959206 + (5), 85.87229, 10) } ")
        h(" expoisson[42] { pt3dadd(539.1696, 98.959206 + (-5), 85.87229, 10) } ")
        h(" expoisson[43] { pt3dclear() } ")
        h(" expoisson[43] { pt3dadd(197.4601, 60.77046 + (5), 335.89282, 10) } ")
        h(" expoisson[43] { pt3dadd(197.4601, 60.77046 + (-5), 335.89282, 10) } ")
        h(" expoisson[44] { pt3dclear() } ")
        h(" expoisson[44] { pt3dadd(377.75537, 69.49132 + (5), 199.59496, 10) } ")
        h(" expoisson[44] { pt3dadd(377.75537, 69.49132 + (-5), 199.59496, 10) } ")
        h(" expoisson[45] { pt3dclear() } ")
        h(" expoisson[45] { pt3dadd(29.381931, 97.08306 + (5), 316.0367, 10) } ")
        h(" expoisson[45] { pt3dadd(29.381931, 97.08306 + (-5), 316.0367, 10) } ")
        h(" expoisson[46] { pt3dclear() } ")
        h(" expoisson[46] { pt3dadd(99.750374, 5.568992 + (5), 679.6458, 10) } ")
        h(" expoisson[46] { pt3dadd(99.750374, 5.568992 + (-5), 679.6458, 10) } ")
        h(" expoisson[47] { pt3dclear() } ")
        h(" expoisson[47] { pt3dadd(423.99353, 33.995575 + (5), 979.684, 10) } ")
        h(" expoisson[47] { pt3dadd(423.99353, 33.995575 + (-5), 979.684, 10) } ")
        h(" expoisson[48] { pt3dclear() } ")
        h(" expoisson[48] { pt3dadd(929.5963, 71.477135 + (5), 902.5336, 10) } ")
        h(" expoisson[48] { pt3dadd(929.5963, 71.477135 + (-5), 902.5336, 10) } ")
        h(" expoisson[49] { pt3dclear() } ")
        h(" expoisson[49] { pt3dadd(166.26346, 97.242874 + (5), 8.851776, 10) } ")
        h(" expoisson[49] { pt3dadd(166.26346, 97.242874 + (-5), 8.851776, 10) } ")
        h(" expoisson[50] { pt3dclear() } ")
        h(" expoisson[50] { pt3dadd(596.5996, 92.14748 + (5), 909.87494, 10) } ")
        h(" expoisson[50] { pt3dadd(596.5996, 92.14748 + (-5), 909.87494, 10) } ")
        h(" expoisson[51] { pt3dclear() } ")
        h(" expoisson[51] { pt3dadd(703.82275, 92.60151 + (5), 609.3799, 10) } ")
        h(" expoisson[51] { pt3dadd(703.82275, 92.60151 + (-5), 609.3799, 10) } ")
        h(" expoisson[52] { pt3dclear() } ")
        h(" expoisson[52] { pt3dadd(156.08403, 92.076225 + (5), 194.29791, 10) } ")
        h(" expoisson[52] { pt3dadd(156.08403, 92.076225 + (-5), 194.29791, 10) } ")
        h(" expoisson[53] { pt3dclear() } ")
        h(" expoisson[53] { pt3dadd(452.94827, 44.502964 + (5), 501.84238, 10) } ")
        h(" expoisson[53] { pt3dadd(452.94827, 44.502964 + (-5), 501.84238, 10) } ")
        h(" expoisson[54] { pt3dclear() } ")
        h(" expoisson[54] { pt3dadd(336.39667, 26.875835 + (5), 888.9117, 10) } ")
        h(" expoisson[54] { pt3dadd(336.39667, 26.875835 + (-5), 888.9117, 10) } ")
        h(" expoisson[55] { pt3dclear() } ")
        h(" expoisson[55] { pt3dadd(391.77734, 68.55585 + (5), 493.5494, 10) } ")
        h(" expoisson[55] { pt3dadd(391.77734, 68.55585 + (-5), 493.5494, 10) } ")
        h(" expoisson[56] { pt3dclear() } ")
        h(" expoisson[56] { pt3dadd(247.69107, 28.620316 + (5), 970.1953, 10) } ")
        h(" expoisson[56] { pt3dadd(247.69107, 28.620316 + (-5), 970.1953, 10) } ")
        h(" expoisson[57] { pt3dclear() } ")
        h(" expoisson[57] { pt3dadd(903.90314, 15.762963 + (5), 232.55795, 10) } ")
        h(" expoisson[57] { pt3dadd(903.90314, 15.762963 + (-5), 232.55795, 10) } ")
        h(" expoisson[58] { pt3dclear() } ")
        h(" expoisson[58] { pt3dadd(958.952, 92.14968 + (5), 353.8477, 10) } ")
        h(" expoisson[58] { pt3dadd(958.952, 92.14968 + (-5), 353.8477, 10) } ")
        h(" expoisson[59] { pt3dclear() } ")
        h(" expoisson[59] { pt3dadd(543.85004, 43.009758 + (5), 444.2691, 10) } ")
        h(" expoisson[59] { pt3dadd(543.85004, 43.009758 + (-5), 444.2691, 10) } ")
        h(" expoisson[60] { pt3dclear() } ")
        h(" expoisson[60] { pt3dadd(549.87866, 77.9905 + (5), 718.20245, 10) } ")
        h(" expoisson[60] { pt3dadd(549.87866, 77.9905 + (-5), 718.20245, 10) } ")
        h(" expoisson[61] { pt3dclear() } ")
        h(" expoisson[61] { pt3dadd(717.4416, 7.0814934 + (5), 244.3996, 10) } ")
        h(" expoisson[61] { pt3dadd(717.4416, 7.0814934 + (-5), 244.3996, 10) } ")
        h(" expoisson[62] { pt3dclear() } ")
        h(" expoisson[62] { pt3dadd(646.4595, 71.37197 + (5), 485.45145, 10) } ")
        h(" expoisson[62] { pt3dadd(646.4595, 71.37197 + (-5), 485.45145, 10) } ")
        h(" expoisson[63] { pt3dclear() } ")
        h(" expoisson[63] { pt3dadd(779.5099, 95.665634 + (5), 692.49316, 10) } ")
        h(" expoisson[63] { pt3dadd(779.5099, 95.665634 + (-5), 692.49316, 10) } ")
        h(" expoisson[64] { pt3dclear() } ")
        h(" expoisson[64] { pt3dadd(832.39856, 32.727486 + (5), 817.4645, 10) } ")
        h(" expoisson[64] { pt3dadd(832.39856, 32.727486 + (-5), 817.4645, 10) } ")
        h(" expoisson[65] { pt3dclear() } ")
        h(" expoisson[65] { pt3dadd(518.37256, 80.56483 + (5), 682.2735, 10) } ")
        h(" expoisson[65] { pt3dadd(518.37256, 80.56483 + (-5), 682.2735, 10) } ")
        h(" expoisson[66] { pt3dclear() } ")
        h(" expoisson[66] { pt3dadd(302.73853, 77.00904 + (5), 799.68243, 10) } ")
        h(" expoisson[66] { pt3dadd(302.73853, 77.00904 + (-5), 799.68243, 10) } ")
        h(" expoisson[67] { pt3dclear() } ")
        h(" expoisson[67] { pt3dadd(501.0651, 14.280347 + (5), 375.44794, 10) } ")
        h(" expoisson[67] { pt3dadd(501.0651, 14.280347 + (-5), 375.44794, 10) } ")
        h(" expoisson[68] { pt3dclear() } ")
        h(" expoisson[68] { pt3dadd(177.06389, 13.694798 + (5), 301.38092, 10) } ")
        h(" expoisson[68] { pt3dadd(177.06389, 13.694798 + (-5), 301.38092, 10) } ")
        h(" expoisson[69] { pt3dclear() } ")
        h(" expoisson[69] { pt3dadd(488.49393, 80.121506 + (5), 601.08746, 10) } ")
        h(" expoisson[69] { pt3dadd(488.49393, 80.121506 + (-5), 601.08746, 10) } ")
        h(" expoisson[70] { pt3dclear() } ")
        h(" expoisson[70] { pt3dadd(267.0268, 91.68777 + (5), 949.26965, 10) } ")
        h(" expoisson[70] { pt3dadd(267.0268, 91.68777 + (-5), 949.26965, 10) } ")
        h(" expoisson[71] { pt3dclear() } ")
        h(" expoisson[71] { pt3dadd(859.8179, 47.20016 + (5), 871.8823, 10) } ")
        h(" expoisson[71] { pt3dadd(859.8179, 47.20016 + (-5), 871.8823, 10) } ")
        h(" expoisson[72] { pt3dclear() } ")
        h(" expoisson[72] { pt3dadd(167.50838, 79.19886 + (5), 230.28506, 10) } ")
        h(" expoisson[72] { pt3dadd(167.50838, 79.19886 + (-5), 230.28506, 10) } ")
        h(" expoisson[73] { pt3dclear() } ")
        h(" expoisson[73] { pt3dadd(249.75061, 6.6816263 + (5), 825.557, 10) } ")
        h(" expoisson[73] { pt3dadd(249.75061, 6.6816263 + (-5), 825.557, 10) } ")
        h(" expoisson[74] { pt3dclear() } ")
        h(" expoisson[74] { pt3dadd(815.80176, 83.05084 + (5), 561.3888, 10) } ")
        h(" expoisson[74] { pt3dadd(815.80176, 83.05084 + (-5), 561.3888, 10) } ")
        h(" expoisson[75] { pt3dclear() } ")
        h(" expoisson[75] { pt3dadd(144.87123, 39.40662 + (5), 217.86781, 10) } ")
        h(" expoisson[75] { pt3dadd(144.87123, 39.40662 + (-5), 217.86781, 10) } ")
        h(" expoisson[76] { pt3dclear() } ")
        h(" expoisson[76] { pt3dadd(560.4376, 14.6176605 + (5), 212.0585, 10) } ")
        h(" expoisson[76] { pt3dadd(560.4376, 14.6176605 + (-5), 212.0585, 10) } ")
        h(" expoisson[77] { pt3dclear() } ")
        h(" expoisson[77] { pt3dadd(724.36206, 61.81105 + (5), 679.5928, 10) } ")
        h(" expoisson[77] { pt3dadd(724.36206, 61.81105 + (-5), 679.5928, 10) } ")
        h(" expoisson[78] { pt3dclear() } ")
        h(" expoisson[78] { pt3dadd(518.43616, 34.628353 + (5), 191.30829, 10) } ")
        h(" expoisson[78] { pt3dadd(518.43616, 34.628353 + (-5), 191.30829, 10) } ")
        h(" expoisson[79] { pt3dclear() } ")
        h(" expoisson[79] { pt3dadd(223.64742, 55.336037 + (5), 17.656237, 10) } ")
        h(" expoisson[79] { pt3dadd(223.64742, 55.336037 + (-5), 17.656237, 10) } ")

        # ######################   Population: Ipop
        print("Population Ipop contains 20 instance(s) of component: ifcell of type: IF_curr_alpha")

        h(" {n_Ipop = 20} ")
        '''
        Population Ipop contains instances of Component(id=ifcell type=IF_curr_alpha)
        whose dynamics will be implemented as a mechanism (ifcell) in a mod file
        '''
        h(" create Ipop[20]")
        h(" objectvar m_ifcell_Ipop[20] ")

        for i in range(int(h.n_Ipop)):
            h.Ipop[i].L = 10.0
            h.Ipop[i](0.5).diam = 10.0
            h.Ipop[i](0.5).cm = 0.3183098861837907
            h.Ipop[i].push()
            h(" Ipop[%i]  { m_ifcell_Ipop[%i] = new ifcell(0.5) } "%(i,i))

            h.m_ifcell_Ipop[i].tau_refrac = 2.0
            h.m_ifcell_Ipop[i].v_thresh = 20.0
            h.m_ifcell_Ipop[i].tau_m = 20.0
            h.m_ifcell_Ipop[i].v_rest = 0.0
            h.m_ifcell_Ipop[i].v_reset = 0.0
            h.m_ifcell_Ipop[i].cm = 0.001
            h.m_ifcell_Ipop[i].i_offset = 0.0
            h.m_ifcell_Ipop[i].tau_syn_E = 0.1
            h.m_ifcell_Ipop[i].tau_syn_I = 0.1
            h.m_ifcell_Ipop[i].v_init = 0.0
            h.m_ifcell_Ipop[i].MSEC = 1.0
            h.m_ifcell_Ipop[i].MVOLT = 1.0
            h.m_ifcell_Ipop[i].NFARAD = 0.001
            h.pop_section()

            self.next_global_id+=1

        h(" Ipop[0] { pt3dclear() } ")
        h(" Ipop[0] { pt3dadd(363.17102, 44.02678 + (5), 682.4989, 10) } ")
        h(" Ipop[0] { pt3dadd(363.17102, 44.02678 + (-5), 682.4989, 10) } ")
        h(" Ipop[1] { pt3dclear() } ")
        h(" Ipop[1] { pt3dadd(11.070575, 42.234966 + (5), 421.72043, 10) } ")
        h(" Ipop[1] { pt3dadd(11.070575, 42.234966 + (-5), 421.72043, 10) } ")
        h(" Ipop[2] { pt3dclear() } ")
        h(" Ipop[2] { pt3dadd(943.0442, 64.848434 + (5), 518.5364, 10) } ")
        h(" Ipop[2] { pt3dadd(943.0442, 64.848434 + (-5), 518.5364, 10) } ")
        h(" Ipop[3] { pt3dclear() } ")
        h(" Ipop[3] { pt3dadd(757.048, 77.16855 + (5), 780.38403, 10) } ")
        h(" Ipop[3] { pt3dadd(757.048, 77.16855 + (-5), 780.38403, 10) } ")
        h(" Ipop[4] { pt3dclear() } ")
        h(" Ipop[4] { pt3dadd(563.6236, 30.547668 + (5), 590.8044, 10) } ")
        h(" Ipop[4] { pt3dadd(563.6236, 30.547668 + (-5), 590.8044, 10) } ")
        h(" Ipop[5] { pt3dclear() } ")
        h(" Ipop[5] { pt3dadd(20.189749, 69.820465 + (5), 123.4154, 10) } ")
        h(" Ipop[5] { pt3dadd(20.189749, 69.820465 + (-5), 123.4154, 10) } ")
        h(" Ipop[6] { pt3dclear() } ")
        h(" Ipop[6] { pt3dadd(969.49, 57.198112 + (5), 759.24286, 10) } ")
        h(" Ipop[6] { pt3dadd(969.49, 57.198112 + (-5), 759.24286, 10) } ")
        h(" Ipop[7] { pt3dclear() } ")
        h(" Ipop[7] { pt3dadd(395.22443, 20.938 + (5), 431.31372, 10) } ")
        h(" Ipop[7] { pt3dadd(395.22443, 20.938 + (-5), 431.31372, 10) } ")
        h(" Ipop[8] { pt3dclear() } ")
        h(" Ipop[8] { pt3dadd(111.52308, 41.26185 + (5), 856.7409, 10) } ")
        h(" Ipop[8] { pt3dadd(111.52308, 41.26185 + (-5), 856.7409, 10) } ")
        h(" Ipop[9] { pt3dclear() } ")
        h(" Ipop[9] { pt3dadd(609.5774, 91.25135 + (5), 720.94525, 10) } ")
        h(" Ipop[9] { pt3dadd(609.5774, 91.25135 + (-5), 720.94525, 10) } ")
        h(" Ipop[10] { pt3dclear() } ")
        h(" Ipop[10] { pt3dadd(786.85376, 74.77378 + (5), 229.5672, 10) } ")
        h(" Ipop[10] { pt3dadd(786.85376, 74.77378 + (-5), 229.5672, 10) } ")
        h(" Ipop[11] { pt3dclear() } ")
        h(" Ipop[11] { pt3dadd(63.269367, 37.99296 + (5), 127.01075, 10) } ")
        h(" Ipop[11] { pt3dadd(63.269367, 37.99296 + (-5), 127.01075, 10) } ")
        h(" Ipop[12] { pt3dclear() } ")
        h(" Ipop[12] { pt3dadd(674.8421, 2.8768318 + (5), 508.4144, 10) } ")
        h(" Ipop[12] { pt3dadd(674.8421, 2.8768318 + (-5), 508.4144, 10) } ")
        h(" Ipop[13] { pt3dclear() } ")
        h(" Ipop[13] { pt3dadd(800.58026, 73.00044 + (5), 17.684675, 10) } ")
        h(" Ipop[13] { pt3dadd(800.58026, 73.00044 + (-5), 17.684675, 10) } ")
        h(" Ipop[14] { pt3dclear() } ")
        h(" Ipop[14] { pt3dadd(45.183804, 94.68919 + (5), 30.420876, 10) } ")
        h(" Ipop[14] { pt3dadd(45.183804, 94.68919 + (-5), 30.420876, 10) } ")
        h(" Ipop[15] { pt3dclear() } ")
        h(" Ipop[15] { pt3dadd(754.17194, 88.307434 + (5), 230.69972, 10) } ")
        h(" Ipop[15] { pt3dadd(754.17194, 88.307434 + (-5), 230.69972, 10) } ")
        h(" Ipop[16] { pt3dclear() } ")
        h(" Ipop[16] { pt3dadd(622.6474, 57.60969 + (5), 892.999, 10) } ")
        h(" Ipop[16] { pt3dadd(622.6474, 57.60969 + (-5), 892.999, 10) } ")
        h(" Ipop[17] { pt3dclear() } ")
        h(" Ipop[17] { pt3dadd(243.39484, 45.89724 + (5), 263.3482, 10) } ")
        h(" Ipop[17] { pt3dadd(243.39484, 45.89724 + (-5), 263.3482, 10) } ")
        h(" Ipop[18] { pt3dclear() } ")
        h(" Ipop[18] { pt3dadd(417.4313, 74.154945 + (5), 522.23724, 10) } ")
        h(" Ipop[18] { pt3dadd(417.4313, 74.154945 + (-5), 522.23724, 10) } ")
        h(" Ipop[19] { pt3dclear() } ")
        h(" Ipop[19] { pt3dadd(9.535349, 29.213268 + (5), 654.49207, 10) } ")
        h(" Ipop[19] { pt3dadd(9.535349, 29.213268 + (-5), 654.49207, 10) } ")

        # ######################   Population: inpoisson
        print("Population inpoisson contains 20 instance(s) of component: poisson_input of type: SpikeSourcePoisson")

        h(" {n_inpoisson = 20} ")
        '''
        Population inpoisson contains instances of Component(id=poisson_input type=SpikeSourcePoisson)
        whose dynamics will be implemented as a mechanism (poisson_input) in a mod file
        '''
        h(" create inpoisson[20]")
        h(" objectvar m_poisson_input_inpoisson[20] ")

        for i in range(int(h.n_inpoisson)):
            h.inpoisson[i].L = 10.0
            h.inpoisson[i](0.5).diam = 10.0
            h.inpoisson[i](0.5).cm = 318.31
            h.inpoisson[i].push()
            h(" inpoisson[%i]  { m_poisson_input_inpoisson[%i] = new poisson_input(0.5) } "%(i,i))

            h.m_poisson_input_inpoisson[i].start = 0.0
            h.m_poisson_input_inpoisson[i].duration = 1.0E9
            h.m_poisson_input_inpoisson[i].rate = 10.0
            h.m_poisson_input_inpoisson[i].end = 1.0E9
            h.m_poisson_input_inpoisson[i].LONG_TIME = 3.59999998E15
            # Spiking element (SpikeSourcePoisson), will require seeding...
            rand = h.Random()
            self.randoms.append(rand)
            #print("Seeding random generator on m_poisson_input_inpoisson[i] (i=%i) with stim seed %s"%(i, self.seed))
            self._init_stim_randomizer(rand,"inpoisson",i, self.seed)
            rand.negexp(1)
            h.m_poisson_input_inpoisson[i].noiseFromRandom(rand)

            h.pop_section()

            self.next_global_id+=1

        h(" inpoisson[0] { pt3dclear() } ")
        h(" inpoisson[0] { pt3dadd(954.689, 59.47511 + (5), 912.77814, 10) } ")
        h(" inpoisson[0] { pt3dadd(954.689, 59.47511 + (-5), 912.77814, 10) } ")
        h(" inpoisson[1] { pt3dclear() } ")
        h(" inpoisson[1] { pt3dadd(700.5118, 65.25185 + (5), 628.93964, 10) } ")
        h(" inpoisson[1] { pt3dadd(700.5118, 65.25185 + (-5), 628.93964, 10) } ")
        h(" inpoisson[2] { pt3dclear() } ")
        h(" inpoisson[2] { pt3dadd(606.1033, 92.04965 + (5), 424.78607, 10) } ")
        h(" inpoisson[2] { pt3dadd(606.1033, 92.04965 + (-5), 424.78607, 10) } ")
        h(" inpoisson[3] { pt3dclear() } ")
        h(" inpoisson[3] { pt3dadd(434.75165, 33.905403 + (5), 286.82507, 10) } ")
        h(" inpoisson[3] { pt3dadd(434.75165, 33.905403 + (-5), 286.82507, 10) } ")
        h(" inpoisson[4] { pt3dclear() } ")
        h(" inpoisson[4] { pt3dadd(94.0433, 88.86649 + (5), 833.3009, 10) } ")
        h(" inpoisson[4] { pt3dadd(94.0433, 88.86649 + (-5), 833.3009, 10) } ")
        h(" inpoisson[5] { pt3dclear() } ")
        h(" inpoisson[5] { pt3dadd(734.0699, 56.985237 + (5), 335.4079, 10) } ")
        h(" inpoisson[5] { pt3dadd(734.0699, 56.985237 + (-5), 335.4079, 10) } ")
        h(" inpoisson[6] { pt3dclear() } ")
        h(" inpoisson[6] { pt3dadd(527.4713, 60.158257 + (5), 658.4049, 10) } ")
        h(" inpoisson[6] { pt3dadd(527.4713, 60.158257 + (-5), 658.4049, 10) } ")
        h(" inpoisson[7] { pt3dclear() } ")
        h(" inpoisson[7] { pt3dadd(408.3156, 44.221886 + (5), 182.67879, 10) } ")
        h(" inpoisson[7] { pt3dadd(408.3156, 44.221886 + (-5), 182.67879, 10) } ")
        h(" inpoisson[8] { pt3dclear() } ")
        h(" inpoisson[8] { pt3dadd(106.64743, 90.09445 + (5), 331.21347, 10) } ")
        h(" inpoisson[8] { pt3dadd(106.64743, 90.09445 + (-5), 331.21347, 10) } ")
        h(" inpoisson[9] { pt3dclear() } ")
        h(" inpoisson[9] { pt3dadd(587.63934, 97.3636 + (5), 190.11862, 10) } ")
        h(" inpoisson[9] { pt3dadd(587.63934, 97.3636 + (-5), 190.11862, 10) } ")
        h(" inpoisson[10] { pt3dclear() } ")
        h(" inpoisson[10] { pt3dadd(517.71313, 39.639393 + (5), 317.9435, 10) } ")
        h(" inpoisson[10] { pt3dadd(517.71313, 39.639393 + (-5), 317.9435, 10) } ")
        h(" inpoisson[11] { pt3dclear() } ")
        h(" inpoisson[11] { pt3dadd(512.871, 63.75703 + (5), 946.4149, 10) } ")
        h(" inpoisson[11] { pt3dadd(512.871, 63.75703 + (-5), 946.4149, 10) } ")
        h(" inpoisson[12] { pt3dclear() } ")
        h(" inpoisson[12] { pt3dadd(641.576, 33.03509 + (5), 726.1089, 10) } ")
        h(" inpoisson[12] { pt3dadd(641.576, 33.03509 + (-5), 726.1089, 10) } ")
        h(" inpoisson[13] { pt3dclear() } ")
        h(" inpoisson[13] { pt3dadd(613.89325, 26.208155 + (5), 870.29816, 10) } ")
        h(" inpoisson[13] { pt3dadd(613.89325, 26.208155 + (-5), 870.29816, 10) } ")
        h(" inpoisson[14] { pt3dclear() } ")
        h(" inpoisson[14] { pt3dadd(76.34726, 91.211914 + (5), 450.65952, 10) } ")
        h(" inpoisson[14] { pt3dadd(76.34726, 91.211914 + (-5), 450.65952, 10) } ")
        h(" inpoisson[15] { pt3dclear() } ")
        h(" inpoisson[15] { pt3dadd(611.2574, 1.0511297 + (5), 36.34013, 10) } ")
        h(" inpoisson[15] { pt3dadd(611.2574, 1.0511297 + (-5), 36.34013, 10) } ")
        h(" inpoisson[16] { pt3dclear() } ")
        h(" inpoisson[16] { pt3dadd(610.1881, 10.791687 + (5), 664.18427, 10) } ")
        h(" inpoisson[16] { pt3dadd(610.1881, 10.791687 + (-5), 664.18427, 10) } ")
        h(" inpoisson[17] { pt3dclear() } ")
        h(" inpoisson[17] { pt3dadd(700.93353, 17.910017 + (5), 573.39825, 10) } ")
        h(" inpoisson[17] { pt3dadd(700.93353, 17.910017 + (-5), 573.39825, 10) } ")
        h(" inpoisson[18] { pt3dclear() } ")
        h(" inpoisson[18] { pt3dadd(266.84244, 83.05787 + (5), 754.25793, 10) } ")
        h(" inpoisson[18] { pt3dadd(266.84244, 83.05787 + (-5), 754.25793, 10) } ")
        h(" inpoisson[19] { pt3dclear() } ")
        h(" inpoisson[19] { pt3dadd(820.3003, 31.042995 + (5), 937.5219, 10) } ")
        h(" inpoisson[19] { pt3dadd(820.3003, 31.042995 + (-5), 937.5219, 10) } ")

        # ######################   Projection: projEinput
        print("Adding projection: projEinput, from expoisson to Epop with synapse ampa, 80 connection(s)")

        h("objectvar syn_projEinput_ampa[80]")

        h("objectvar netConn_projEinput_ampa[80]")

        # Connection 0: cell 0, seg 0 (0.5) [0.5 on expoisson[0]] -> cell 0, seg 0 (0.5) [0.5 on Epop[0]], weight: 4.1363508E-4, delay 0.025
        h("Epop[0] syn_projEinput_ampa[0] = new ampa(0.5)")
        h("expoisson[0] netConn_projEinput_ampa[0] = new NetCon(m_poisson_input_expoisson[0], syn_projEinput_ampa[0], 0.0, 0.025, 4.1363508E-4)")  

        # Connection 1: cell 1, seg 0 (0.5) [0.5 on expoisson[1]] -> cell 1, seg 0 (0.5) [0.5 on Epop[1]], weight: 4.1363508E-4, delay 0.025
        h("Epop[1] syn_projEinput_ampa[1] = new ampa(0.5)")
        h("expoisson[1] netConn_projEinput_ampa[1] = new NetCon(m_poisson_input_expoisson[1], syn_projEinput_ampa[1], 0.0, 0.025, 4.1363508E-4)")  

        # Connection 2: cell 2, seg 0 (0.5) [0.5 on expoisson[2]] -> cell 2, seg 0 (0.5) [0.5 on Epop[2]], weight: 4.1363508E-4, delay 0.025
        h("Epop[2] syn_projEinput_ampa[2] = new ampa(0.5)")
        h("expoisson[2] netConn_projEinput_ampa[2] = new NetCon(m_poisson_input_expoisson[2], syn_projEinput_ampa[2], 0.0, 0.025, 4.1363508E-4)")  

        # Connection 3: cell 3, seg 0 (0.5) [0.5 on expoisson[3]] -> cell 3, seg 0 (0.5) [0.5 on Epop[3]], weight: 4.1363508E-4, delay 0.025
        h("Epop[3] syn_projEinput_ampa[3] = new ampa(0.5)")
        h("expoisson[3] netConn_projEinput_ampa[3] = new NetCon(m_poisson_input_expoisson[3], syn_projEinput_ampa[3], 0.0, 0.025, 4.1363508E-4)")  

        # Connection 4: cell 4, seg 0 (0.5) [0.5 on expoisson[4]] -> cell 4, seg 0 (0.5) [0.5 on Epop[4]], weight: 4.1363508E-4, delay 0.025
        h("Epop[4] syn_projEinput_ampa[4] = new ampa(0.5)")
        h("expoisson[4] netConn_projEinput_ampa[4] = new NetCon(m_poisson_input_expoisson[4], syn_projEinput_ampa[4], 0.0, 0.025, 4.1363508E-4)")  

        # Connection 5: cell 5, seg 0 (0.5) [0.5 on expoisson[5]] -> cell 5, seg 0 (0.5) [0.5 on Epop[5]], weight: 4.1363508E-4, delay 0.025
        h("Epop[5] syn_projEinput_ampa[5] = new ampa(0.5)")
        h("expoisson[5] netConn_projEinput_ampa[5] = new NetCon(m_poisson_input_expoisson[5], syn_projEinput_ampa[5], 0.0, 0.025, 4.1363508E-4)")  

        # Connection 6: cell 6, seg 0 (0.5) [0.5 on expoisson[6]] -> cell 6, seg 0 (0.5) [0.5 on Epop[6]], weight: 4.1363508E-4, delay 0.025
        h("Epop[6] syn_projEinput_ampa[6] = new ampa(0.5)")
        h("expoisson[6] netConn_projEinput_ampa[6] = new NetCon(m_poisson_input_expoisson[6], syn_projEinput_ampa[6], 0.0, 0.025, 4.1363508E-4)")  

        # Connection 7: cell 7, seg 0 (0.5) [0.5 on expoisson[7]] -> cell 7, seg 0 (0.5) [0.5 on Epop[7]], weight: 4.1363508E-4, delay 0.025
        h("Epop[7] syn_projEinput_ampa[7] = new ampa(0.5)")
        h("expoisson[7] netConn_projEinput_ampa[7] = new NetCon(m_poisson_input_expoisson[7], syn_projEinput_ampa[7], 0.0, 0.025, 4.1363508E-4)")  

        # Connection 8: cell 8, seg 0 (0.5) [0.5 on expoisson[8]] -> cell 8, seg 0 (0.5) [0.5 on Epop[8]], weight: 4.1363508E-4, delay 0.025
        h("Epop[8] syn_projEinput_ampa[8] = new ampa(0.5)")
        h("expoisson[8] netConn_projEinput_ampa[8] = new NetCon(m_poisson_input_expoisson[8], syn_projEinput_ampa[8], 0.0, 0.025, 4.1363508E-4)")  

        # Connection 9: cell 9, seg 0 (0.5) [0.5 on expoisson[9]] -> cell 9, seg 0 (0.5) [0.5 on Epop[9]], weight: 4.1363508E-4, delay 0.025
        h("Epop[9] syn_projEinput_ampa[9] = new ampa(0.5)")
        h("expoisson[9] netConn_projEinput_ampa[9] = new NetCon(m_poisson_input_expoisson[9], syn_projEinput_ampa[9], 0.0, 0.025, 4.1363508E-4)")  

        # Connection 10: cell 10, seg 0 (0.5) [0.5 on expoisson[10]] -> cell 10, seg 0 (0.5) [0.5 on Epop[10]], weight: 4.1363508E-4, delay 0.025
        h("Epop[10] syn_projEinput_ampa[10] = new ampa(0.5)")
        h("expoisson[10] netConn_projEinput_ampa[10] = new NetCon(m_poisson_input_expoisson[10], syn_projEinput_ampa[10], 0.0, 0.025, 4.1363508E-4)")  

        # Connection 11: cell 11, seg 0 (0.5) [0.5 on expoisson[11]] -> cell 11, seg 0 (0.5) [0.5 on Epop[11]], weight: 4.1363508E-4, delay 0.025
        h("Epop[11] syn_projEinput_ampa[11] = new ampa(0.5)")
        h("expoisson[11] netConn_projEinput_ampa[11] = new NetCon(m_poisson_input_expoisson[11], syn_projEinput_ampa[11], 0.0, 0.025, 4.1363508E-4)")  

        # Connection 12: cell 12, seg 0 (0.5) [0.5 on expoisson[12]] -> cell 12, seg 0 (0.5) [0.5 on Epop[12]], weight: 4.1363508E-4, delay 0.025
        h("Epop[12] syn_projEinput_ampa[12] = new ampa(0.5)")
        h("expoisson[12] netConn_projEinput_ampa[12] = new NetCon(m_poisson_input_expoisson[12], syn_projEinput_ampa[12], 0.0, 0.025, 4.1363508E-4)")  

        # Connection 13: cell 13, seg 0 (0.5) [0.5 on expoisson[13]] -> cell 13, seg 0 (0.5) [0.5 on Epop[13]], weight: 4.1363508E-4, delay 0.025
        h("Epop[13] syn_projEinput_ampa[13] = new ampa(0.5)")
        h("expoisson[13] netConn_projEinput_ampa[13] = new NetCon(m_poisson_input_expoisson[13], syn_projEinput_ampa[13], 0.0, 0.025, 4.1363508E-4)")  

        # Connection 14: cell 14, seg 0 (0.5) [0.5 on expoisson[14]] -> cell 14, seg 0 (0.5) [0.5 on Epop[14]], weight: 4.1363508E-4, delay 0.025
        h("Epop[14] syn_projEinput_ampa[14] = new ampa(0.5)")
        h("expoisson[14] netConn_projEinput_ampa[14] = new NetCon(m_poisson_input_expoisson[14], syn_projEinput_ampa[14], 0.0, 0.025, 4.1363508E-4)")  

        # Connection 15: cell 15, seg 0 (0.5) [0.5 on expoisson[15]] -> cell 15, seg 0 (0.5) [0.5 on Epop[15]], weight: 4.1363508E-4, delay 0.025
        h("Epop[15] syn_projEinput_ampa[15] = new ampa(0.5)")
        h("expoisson[15] netConn_projEinput_ampa[15] = new NetCon(m_poisson_input_expoisson[15], syn_projEinput_ampa[15], 0.0, 0.025, 4.1363508E-4)")  

        # Connection 16: cell 16, seg 0 (0.5) [0.5 on expoisson[16]] -> cell 16, seg 0 (0.5) [0.5 on Epop[16]], weight: 4.1363508E-4, delay 0.025
        h("Epop[16] syn_projEinput_ampa[16] = new ampa(0.5)")
        h("expoisson[16] netConn_projEinput_ampa[16] = new NetCon(m_poisson_input_expoisson[16], syn_projEinput_ampa[16], 0.0, 0.025, 4.1363508E-4)")  

        # Connection 17: cell 17, seg 0 (0.5) [0.5 on expoisson[17]] -> cell 17, seg 0 (0.5) [0.5 on Epop[17]], weight: 4.1363508E-4, delay 0.025
        h("Epop[17] syn_projEinput_ampa[17] = new ampa(0.5)")
        h("expoisson[17] netConn_projEinput_ampa[17] = new NetCon(m_poisson_input_expoisson[17], syn_projEinput_ampa[17], 0.0, 0.025, 4.1363508E-4)")  

        # Connection 18: cell 18, seg 0 (0.5) [0.5 on expoisson[18]] -> cell 18, seg 0 (0.5) [0.5 on Epop[18]], weight: 4.1363508E-4, delay 0.025
        h("Epop[18] syn_projEinput_ampa[18] = new ampa(0.5)")
        h("expoisson[18] netConn_projEinput_ampa[18] = new NetCon(m_poisson_input_expoisson[18], syn_projEinput_ampa[18], 0.0, 0.025, 4.1363508E-4)")  

        # Connection 19: cell 19, seg 0 (0.5) [0.5 on expoisson[19]] -> cell 19, seg 0 (0.5) [0.5 on Epop[19]], weight: 4.1363508E-4, delay 0.025
        h("Epop[19] syn_projEinput_ampa[19] = new ampa(0.5)")
        h("expoisson[19] netConn_projEinput_ampa[19] = new NetCon(m_poisson_input_expoisson[19], syn_projEinput_ampa[19], 0.0, 0.025, 4.1363508E-4)")  

        # Connection 20: cell 20, seg 0 (0.5) [0.5 on expoisson[20]] -> cell 20, seg 0 (0.5) [0.5 on Epop[20]], weight: 4.1363508E-4, delay 0.025
        h("Epop[20] syn_projEinput_ampa[20] = new ampa(0.5)")
        h("expoisson[20] netConn_projEinput_ampa[20] = new NetCon(m_poisson_input_expoisson[20], syn_projEinput_ampa[20], 0.0, 0.025, 4.1363508E-4)")  

        # Connection 21: cell 21, seg 0 (0.5) [0.5 on expoisson[21]] -> cell 21, seg 0 (0.5) [0.5 on Epop[21]], weight: 4.1363508E-4, delay 0.025
        h("Epop[21] syn_projEinput_ampa[21] = new ampa(0.5)")
        h("expoisson[21] netConn_projEinput_ampa[21] = new NetCon(m_poisson_input_expoisson[21], syn_projEinput_ampa[21], 0.0, 0.025, 4.1363508E-4)")  

        # Connection 22: cell 22, seg 0 (0.5) [0.5 on expoisson[22]] -> cell 22, seg 0 (0.5) [0.5 on Epop[22]], weight: 4.1363508E-4, delay 0.025
        h("Epop[22] syn_projEinput_ampa[22] = new ampa(0.5)")
        h("expoisson[22] netConn_projEinput_ampa[22] = new NetCon(m_poisson_input_expoisson[22], syn_projEinput_ampa[22], 0.0, 0.025, 4.1363508E-4)")  

        # Connection 23: cell 23, seg 0 (0.5) [0.5 on expoisson[23]] -> cell 23, seg 0 (0.5) [0.5 on Epop[23]], weight: 4.1363508E-4, delay 0.025
        h("Epop[23] syn_projEinput_ampa[23] = new ampa(0.5)")
        h("expoisson[23] netConn_projEinput_ampa[23] = new NetCon(m_poisson_input_expoisson[23], syn_projEinput_ampa[23], 0.0, 0.025, 4.1363508E-4)")  

        # Connection 24: cell 24, seg 0 (0.5) [0.5 on expoisson[24]] -> cell 24, seg 0 (0.5) [0.5 on Epop[24]], weight: 4.1363508E-4, delay 0.025
        h("Epop[24] syn_projEinput_ampa[24] = new ampa(0.5)")
        h("expoisson[24] netConn_projEinput_ampa[24] = new NetCon(m_poisson_input_expoisson[24], syn_projEinput_ampa[24], 0.0, 0.025, 4.1363508E-4)")  

        # Connection 25: cell 25, seg 0 (0.5) [0.5 on expoisson[25]] -> cell 25, seg 0 (0.5) [0.5 on Epop[25]], weight: 4.1363508E-4, delay 0.025
        h("Epop[25] syn_projEinput_ampa[25] = new ampa(0.5)")
        h("expoisson[25] netConn_projEinput_ampa[25] = new NetCon(m_poisson_input_expoisson[25], syn_projEinput_ampa[25], 0.0, 0.025, 4.1363508E-4)")  

        # Connection 26: cell 26, seg 0 (0.5) [0.5 on expoisson[26]] -> cell 26, seg 0 (0.5) [0.5 on Epop[26]], weight: 4.1363508E-4, delay 0.025
        h("Epop[26] syn_projEinput_ampa[26] = new ampa(0.5)")
        h("expoisson[26] netConn_projEinput_ampa[26] = new NetCon(m_poisson_input_expoisson[26], syn_projEinput_ampa[26], 0.0, 0.025, 4.1363508E-4)")  

        # Connection 27: cell 27, seg 0 (0.5) [0.5 on expoisson[27]] -> cell 27, seg 0 (0.5) [0.5 on Epop[27]], weight: 4.1363508E-4, delay 0.025
        h("Epop[27] syn_projEinput_ampa[27] = new ampa(0.5)")
        h("expoisson[27] netConn_projEinput_ampa[27] = new NetCon(m_poisson_input_expoisson[27], syn_projEinput_ampa[27], 0.0, 0.025, 4.1363508E-4)")  

        # Connection 28: cell 28, seg 0 (0.5) [0.5 on expoisson[28]] -> cell 28, seg 0 (0.5) [0.5 on Epop[28]], weight: 4.1363508E-4, delay 0.025
        h("Epop[28] syn_projEinput_ampa[28] = new ampa(0.5)")
        h("expoisson[28] netConn_projEinput_ampa[28] = new NetCon(m_poisson_input_expoisson[28], syn_projEinput_ampa[28], 0.0, 0.025, 4.1363508E-4)")  

        # Connection 29: cell 29, seg 0 (0.5) [0.5 on expoisson[29]] -> cell 29, seg 0 (0.5) [0.5 on Epop[29]], weight: 4.1363508E-4, delay 0.025
        h("Epop[29] syn_projEinput_ampa[29] = new ampa(0.5)")
        h("expoisson[29] netConn_projEinput_ampa[29] = new NetCon(m_poisson_input_expoisson[29], syn_projEinput_ampa[29], 0.0, 0.025, 4.1363508E-4)")  

        # Connection 30: cell 30, seg 0 (0.5) [0.5 on expoisson[30]] -> cell 30, seg 0 (0.5) [0.5 on Epop[30]], weight: 4.1363508E-4, delay 0.025
        h("Epop[30] syn_projEinput_ampa[30] = new ampa(0.5)")
        h("expoisson[30] netConn_projEinput_ampa[30] = new NetCon(m_poisson_input_expoisson[30], syn_projEinput_ampa[30], 0.0, 0.025, 4.1363508E-4)")  

        # Connection 31: cell 31, seg 0 (0.5) [0.5 on expoisson[31]] -> cell 31, seg 0 (0.5) [0.5 on Epop[31]], weight: 4.1363508E-4, delay 0.025
        h("Epop[31] syn_projEinput_ampa[31] = new ampa(0.5)")
        h("expoisson[31] netConn_projEinput_ampa[31] = new NetCon(m_poisson_input_expoisson[31], syn_projEinput_ampa[31], 0.0, 0.025, 4.1363508E-4)")  

        # Connection 32: cell 32, seg 0 (0.5) [0.5 on expoisson[32]] -> cell 32, seg 0 (0.5) [0.5 on Epop[32]], weight: 4.1363508E-4, delay 0.025
        h("Epop[32] syn_projEinput_ampa[32] = new ampa(0.5)")
        h("expoisson[32] netConn_projEinput_ampa[32] = new NetCon(m_poisson_input_expoisson[32], syn_projEinput_ampa[32], 0.0, 0.025, 4.1363508E-4)")  

        # Connection 33: cell 33, seg 0 (0.5) [0.5 on expoisson[33]] -> cell 33, seg 0 (0.5) [0.5 on Epop[33]], weight: 4.1363508E-4, delay 0.025
        h("Epop[33] syn_projEinput_ampa[33] = new ampa(0.5)")
        h("expoisson[33] netConn_projEinput_ampa[33] = new NetCon(m_poisson_input_expoisson[33], syn_projEinput_ampa[33], 0.0, 0.025, 4.1363508E-4)")  

        # Connection 34: cell 34, seg 0 (0.5) [0.5 on expoisson[34]] -> cell 34, seg 0 (0.5) [0.5 on Epop[34]], weight: 4.1363508E-4, delay 0.025
        h("Epop[34] syn_projEinput_ampa[34] = new ampa(0.5)")
        h("expoisson[34] netConn_projEinput_ampa[34] = new NetCon(m_poisson_input_expoisson[34], syn_projEinput_ampa[34], 0.0, 0.025, 4.1363508E-4)")  

        # Connection 35: cell 35, seg 0 (0.5) [0.5 on expoisson[35]] -> cell 35, seg 0 (0.5) [0.5 on Epop[35]], weight: 4.1363508E-4, delay 0.025
        h("Epop[35] syn_projEinput_ampa[35] = new ampa(0.5)")
        h("expoisson[35] netConn_projEinput_ampa[35] = new NetCon(m_poisson_input_expoisson[35], syn_projEinput_ampa[35], 0.0, 0.025, 4.1363508E-4)")  

        # Connection 36: cell 36, seg 0 (0.5) [0.5 on expoisson[36]] -> cell 36, seg 0 (0.5) [0.5 on Epop[36]], weight: 4.1363508E-4, delay 0.025
        h("Epop[36] syn_projEinput_ampa[36] = new ampa(0.5)")
        h("expoisson[36] netConn_projEinput_ampa[36] = new NetCon(m_poisson_input_expoisson[36], syn_projEinput_ampa[36], 0.0, 0.025, 4.1363508E-4)")  

        # Connection 37: cell 37, seg 0 (0.5) [0.5 on expoisson[37]] -> cell 37, seg 0 (0.5) [0.5 on Epop[37]], weight: 4.1363508E-4, delay 0.025
        h("Epop[37] syn_projEinput_ampa[37] = new ampa(0.5)")
        h("expoisson[37] netConn_projEinput_ampa[37] = new NetCon(m_poisson_input_expoisson[37], syn_projEinput_ampa[37], 0.0, 0.025, 4.1363508E-4)")  

        # Connection 38: cell 38, seg 0 (0.5) [0.5 on expoisson[38]] -> cell 38, seg 0 (0.5) [0.5 on Epop[38]], weight: 4.1363508E-4, delay 0.025
        h("Epop[38] syn_projEinput_ampa[38] = new ampa(0.5)")
        h("expoisson[38] netConn_projEinput_ampa[38] = new NetCon(m_poisson_input_expoisson[38], syn_projEinput_ampa[38], 0.0, 0.025, 4.1363508E-4)")  

        # Connection 39: cell 39, seg 0 (0.5) [0.5 on expoisson[39]] -> cell 39, seg 0 (0.5) [0.5 on Epop[39]], weight: 4.1363508E-4, delay 0.025
        h("Epop[39] syn_projEinput_ampa[39] = new ampa(0.5)")
        h("expoisson[39] netConn_projEinput_ampa[39] = new NetCon(m_poisson_input_expoisson[39], syn_projEinput_ampa[39], 0.0, 0.025, 4.1363508E-4)")  

        # Connection 40: cell 40, seg 0 (0.5) [0.5 on expoisson[40]] -> cell 40, seg 0 (0.5) [0.5 on Epop[40]], weight: 4.1363508E-4, delay 0.025
        h("Epop[40] syn_projEinput_ampa[40] = new ampa(0.5)")
        h("expoisson[40] netConn_projEinput_ampa[40] = new NetCon(m_poisson_input_expoisson[40], syn_projEinput_ampa[40], 0.0, 0.025, 4.1363508E-4)")  

        # Connection 41: cell 41, seg 0 (0.5) [0.5 on expoisson[41]] -> cell 41, seg 0 (0.5) [0.5 on Epop[41]], weight: 4.1363508E-4, delay 0.025
        h("Epop[41] syn_projEinput_ampa[41] = new ampa(0.5)")
        h("expoisson[41] netConn_projEinput_ampa[41] = new NetCon(m_poisson_input_expoisson[41], syn_projEinput_ampa[41], 0.0, 0.025, 4.1363508E-4)")  

        # Connection 42: cell 42, seg 0 (0.5) [0.5 on expoisson[42]] -> cell 42, seg 0 (0.5) [0.5 on Epop[42]], weight: 4.1363508E-4, delay 0.025
        h("Epop[42] syn_projEinput_ampa[42] = new ampa(0.5)")
        h("expoisson[42] netConn_projEinput_ampa[42] = new NetCon(m_poisson_input_expoisson[42], syn_projEinput_ampa[42], 0.0, 0.025, 4.1363508E-4)")  

        # Connection 43: cell 43, seg 0 (0.5) [0.5 on expoisson[43]] -> cell 43, seg 0 (0.5) [0.5 on Epop[43]], weight: 4.1363508E-4, delay 0.025
        h("Epop[43] syn_projEinput_ampa[43] = new ampa(0.5)")
        h("expoisson[43] netConn_projEinput_ampa[43] = new NetCon(m_poisson_input_expoisson[43], syn_projEinput_ampa[43], 0.0, 0.025, 4.1363508E-4)")  

        # Connection 44: cell 44, seg 0 (0.5) [0.5 on expoisson[44]] -> cell 44, seg 0 (0.5) [0.5 on Epop[44]], weight: 4.1363508E-4, delay 0.025
        h("Epop[44] syn_projEinput_ampa[44] = new ampa(0.5)")
        h("expoisson[44] netConn_projEinput_ampa[44] = new NetCon(m_poisson_input_expoisson[44], syn_projEinput_ampa[44], 0.0, 0.025, 4.1363508E-4)")  

        # Connection 45: cell 45, seg 0 (0.5) [0.5 on expoisson[45]] -> cell 45, seg 0 (0.5) [0.5 on Epop[45]], weight: 4.1363508E-4, delay 0.025
        h("Epop[45] syn_projEinput_ampa[45] = new ampa(0.5)")
        h("expoisson[45] netConn_projEinput_ampa[45] = new NetCon(m_poisson_input_expoisson[45], syn_projEinput_ampa[45], 0.0, 0.025, 4.1363508E-4)")  

        # Connection 46: cell 46, seg 0 (0.5) [0.5 on expoisson[46]] -> cell 46, seg 0 (0.5) [0.5 on Epop[46]], weight: 4.1363508E-4, delay 0.025
        h("Epop[46] syn_projEinput_ampa[46] = new ampa(0.5)")
        h("expoisson[46] netConn_projEinput_ampa[46] = new NetCon(m_poisson_input_expoisson[46], syn_projEinput_ampa[46], 0.0, 0.025, 4.1363508E-4)")  

        # Connection 47: cell 47, seg 0 (0.5) [0.5 on expoisson[47]] -> cell 47, seg 0 (0.5) [0.5 on Epop[47]], weight: 4.1363508E-4, delay 0.025
        h("Epop[47] syn_projEinput_ampa[47] = new ampa(0.5)")
        h("expoisson[47] netConn_projEinput_ampa[47] = new NetCon(m_poisson_input_expoisson[47], syn_projEinput_ampa[47], 0.0, 0.025, 4.1363508E-4)")  

        # Connection 48: cell 48, seg 0 (0.5) [0.5 on expoisson[48]] -> cell 48, seg 0 (0.5) [0.5 on Epop[48]], weight: 4.1363508E-4, delay 0.025
        h("Epop[48] syn_projEinput_ampa[48] = new ampa(0.5)")
        h("expoisson[48] netConn_projEinput_ampa[48] = new NetCon(m_poisson_input_expoisson[48], syn_projEinput_ampa[48], 0.0, 0.025, 4.1363508E-4)")  

        # Connection 49: cell 49, seg 0 (0.5) [0.5 on expoisson[49]] -> cell 49, seg 0 (0.5) [0.5 on Epop[49]], weight: 4.1363508E-4, delay 0.025
        h("Epop[49] syn_projEinput_ampa[49] = new ampa(0.5)")
        h("expoisson[49] netConn_projEinput_ampa[49] = new NetCon(m_poisson_input_expoisson[49], syn_projEinput_ampa[49], 0.0, 0.025, 4.1363508E-4)")  

        # Connection 50: cell 50, seg 0 (0.5) [0.5 on expoisson[50]] -> cell 50, seg 0 (0.5) [0.5 on Epop[50]], weight: 4.1363508E-4, delay 0.025
        h("Epop[50] syn_projEinput_ampa[50] = new ampa(0.5)")
        h("expoisson[50] netConn_projEinput_ampa[50] = new NetCon(m_poisson_input_expoisson[50], syn_projEinput_ampa[50], 0.0, 0.025, 4.1363508E-4)")  

        # Connection 51: cell 51, seg 0 (0.5) [0.5 on expoisson[51]] -> cell 51, seg 0 (0.5) [0.5 on Epop[51]], weight: 4.1363508E-4, delay 0.025
        h("Epop[51] syn_projEinput_ampa[51] = new ampa(0.5)")
        h("expoisson[51] netConn_projEinput_ampa[51] = new NetCon(m_poisson_input_expoisson[51], syn_projEinput_ampa[51], 0.0, 0.025, 4.1363508E-4)")  

        # Connection 52: cell 52, seg 0 (0.5) [0.5 on expoisson[52]] -> cell 52, seg 0 (0.5) [0.5 on Epop[52]], weight: 4.1363508E-4, delay 0.025
        h("Epop[52] syn_projEinput_ampa[52] = new ampa(0.5)")
        h("expoisson[52] netConn_projEinput_ampa[52] = new NetCon(m_poisson_input_expoisson[52], syn_projEinput_ampa[52], 0.0, 0.025, 4.1363508E-4)")  

        # Connection 53: cell 53, seg 0 (0.5) [0.5 on expoisson[53]] -> cell 53, seg 0 (0.5) [0.5 on Epop[53]], weight: 4.1363508E-4, delay 0.025
        h("Epop[53] syn_projEinput_ampa[53] = new ampa(0.5)")
        h("expoisson[53] netConn_projEinput_ampa[53] = new NetCon(m_poisson_input_expoisson[53], syn_projEinput_ampa[53], 0.0, 0.025, 4.1363508E-4)")  

        # Connection 54: cell 54, seg 0 (0.5) [0.5 on expoisson[54]] -> cell 54, seg 0 (0.5) [0.5 on Epop[54]], weight: 4.1363508E-4, delay 0.025
        h("Epop[54] syn_projEinput_ampa[54] = new ampa(0.5)")
        h("expoisson[54] netConn_projEinput_ampa[54] = new NetCon(m_poisson_input_expoisson[54], syn_projEinput_ampa[54], 0.0, 0.025, 4.1363508E-4)")  

        # Connection 55: cell 55, seg 0 (0.5) [0.5 on expoisson[55]] -> cell 55, seg 0 (0.5) [0.5 on Epop[55]], weight: 4.1363508E-4, delay 0.025
        h("Epop[55] syn_projEinput_ampa[55] = new ampa(0.5)")
        h("expoisson[55] netConn_projEinput_ampa[55] = new NetCon(m_poisson_input_expoisson[55], syn_projEinput_ampa[55], 0.0, 0.025, 4.1363508E-4)")  

        # Connection 56: cell 56, seg 0 (0.5) [0.5 on expoisson[56]] -> cell 56, seg 0 (0.5) [0.5 on Epop[56]], weight: 4.1363508E-4, delay 0.025
        h("Epop[56] syn_projEinput_ampa[56] = new ampa(0.5)")
        h("expoisson[56] netConn_projEinput_ampa[56] = new NetCon(m_poisson_input_expoisson[56], syn_projEinput_ampa[56], 0.0, 0.025, 4.1363508E-4)")  

        # Connection 57: cell 57, seg 0 (0.5) [0.5 on expoisson[57]] -> cell 57, seg 0 (0.5) [0.5 on Epop[57]], weight: 4.1363508E-4, delay 0.025
        h("Epop[57] syn_projEinput_ampa[57] = new ampa(0.5)")
        h("expoisson[57] netConn_projEinput_ampa[57] = new NetCon(m_poisson_input_expoisson[57], syn_projEinput_ampa[57], 0.0, 0.025, 4.1363508E-4)")  

        # Connection 58: cell 58, seg 0 (0.5) [0.5 on expoisson[58]] -> cell 58, seg 0 (0.5) [0.5 on Epop[58]], weight: 4.1363508E-4, delay 0.025
        h("Epop[58] syn_projEinput_ampa[58] = new ampa(0.5)")
        h("expoisson[58] netConn_projEinput_ampa[58] = new NetCon(m_poisson_input_expoisson[58], syn_projEinput_ampa[58], 0.0, 0.025, 4.1363508E-4)")  

        # Connection 59: cell 59, seg 0 (0.5) [0.5 on expoisson[59]] -> cell 59, seg 0 (0.5) [0.5 on Epop[59]], weight: 4.1363508E-4, delay 0.025
        h("Epop[59] syn_projEinput_ampa[59] = new ampa(0.5)")
        h("expoisson[59] netConn_projEinput_ampa[59] = new NetCon(m_poisson_input_expoisson[59], syn_projEinput_ampa[59], 0.0, 0.025, 4.1363508E-4)")  

        # Connection 60: cell 60, seg 0 (0.5) [0.5 on expoisson[60]] -> cell 60, seg 0 (0.5) [0.5 on Epop[60]], weight: 4.1363508E-4, delay 0.025
        h("Epop[60] syn_projEinput_ampa[60] = new ampa(0.5)")
        h("expoisson[60] netConn_projEinput_ampa[60] = new NetCon(m_poisson_input_expoisson[60], syn_projEinput_ampa[60], 0.0, 0.025, 4.1363508E-4)")  

        # Connection 61: cell 61, seg 0 (0.5) [0.5 on expoisson[61]] -> cell 61, seg 0 (0.5) [0.5 on Epop[61]], weight: 4.1363508E-4, delay 0.025
        h("Epop[61] syn_projEinput_ampa[61] = new ampa(0.5)")
        h("expoisson[61] netConn_projEinput_ampa[61] = new NetCon(m_poisson_input_expoisson[61], syn_projEinput_ampa[61], 0.0, 0.025, 4.1363508E-4)")  

        # Connection 62: cell 62, seg 0 (0.5) [0.5 on expoisson[62]] -> cell 62, seg 0 (0.5) [0.5 on Epop[62]], weight: 4.1363508E-4, delay 0.025
        h("Epop[62] syn_projEinput_ampa[62] = new ampa(0.5)")
        h("expoisson[62] netConn_projEinput_ampa[62] = new NetCon(m_poisson_input_expoisson[62], syn_projEinput_ampa[62], 0.0, 0.025, 4.1363508E-4)")  

        # Connection 63: cell 63, seg 0 (0.5) [0.5 on expoisson[63]] -> cell 63, seg 0 (0.5) [0.5 on Epop[63]], weight: 4.1363508E-4, delay 0.025
        h("Epop[63] syn_projEinput_ampa[63] = new ampa(0.5)")
        h("expoisson[63] netConn_projEinput_ampa[63] = new NetCon(m_poisson_input_expoisson[63], syn_projEinput_ampa[63], 0.0, 0.025, 4.1363508E-4)")  

        # Connection 64: cell 64, seg 0 (0.5) [0.5 on expoisson[64]] -> cell 64, seg 0 (0.5) [0.5 on Epop[64]], weight: 4.1363508E-4, delay 0.025
        h("Epop[64] syn_projEinput_ampa[64] = new ampa(0.5)")
        h("expoisson[64] netConn_projEinput_ampa[64] = new NetCon(m_poisson_input_expoisson[64], syn_projEinput_ampa[64], 0.0, 0.025, 4.1363508E-4)")  

        # Connection 65: cell 65, seg 0 (0.5) [0.5 on expoisson[65]] -> cell 65, seg 0 (0.5) [0.5 on Epop[65]], weight: 4.1363508E-4, delay 0.025
        h("Epop[65] syn_projEinput_ampa[65] = new ampa(0.5)")
        h("expoisson[65] netConn_projEinput_ampa[65] = new NetCon(m_poisson_input_expoisson[65], syn_projEinput_ampa[65], 0.0, 0.025, 4.1363508E-4)")  

        # Connection 66: cell 66, seg 0 (0.5) [0.5 on expoisson[66]] -> cell 66, seg 0 (0.5) [0.5 on Epop[66]], weight: 4.1363508E-4, delay 0.025
        h("Epop[66] syn_projEinput_ampa[66] = new ampa(0.5)")
        h("expoisson[66] netConn_projEinput_ampa[66] = new NetCon(m_poisson_input_expoisson[66], syn_projEinput_ampa[66], 0.0, 0.025, 4.1363508E-4)")  

        # Connection 67: cell 67, seg 0 (0.5) [0.5 on expoisson[67]] -> cell 67, seg 0 (0.5) [0.5 on Epop[67]], weight: 4.1363508E-4, delay 0.025
        h("Epop[67] syn_projEinput_ampa[67] = new ampa(0.5)")
        h("expoisson[67] netConn_projEinput_ampa[67] = new NetCon(m_poisson_input_expoisson[67], syn_projEinput_ampa[67], 0.0, 0.025, 4.1363508E-4)")  

        # Connection 68: cell 68, seg 0 (0.5) [0.5 on expoisson[68]] -> cell 68, seg 0 (0.5) [0.5 on Epop[68]], weight: 4.1363508E-4, delay 0.025
        h("Epop[68] syn_projEinput_ampa[68] = new ampa(0.5)")
        h("expoisson[68] netConn_projEinput_ampa[68] = new NetCon(m_poisson_input_expoisson[68], syn_projEinput_ampa[68], 0.0, 0.025, 4.1363508E-4)")  

        # Connection 69: cell 69, seg 0 (0.5) [0.5 on expoisson[69]] -> cell 69, seg 0 (0.5) [0.5 on Epop[69]], weight: 4.1363508E-4, delay 0.025
        h("Epop[69] syn_projEinput_ampa[69] = new ampa(0.5)")
        h("expoisson[69] netConn_projEinput_ampa[69] = new NetCon(m_poisson_input_expoisson[69], syn_projEinput_ampa[69], 0.0, 0.025, 4.1363508E-4)")  

        # Connection 70: cell 70, seg 0 (0.5) [0.5 on expoisson[70]] -> cell 70, seg 0 (0.5) [0.5 on Epop[70]], weight: 4.1363508E-4, delay 0.025
        h("Epop[70] syn_projEinput_ampa[70] = new ampa(0.5)")
        h("expoisson[70] netConn_projEinput_ampa[70] = new NetCon(m_poisson_input_expoisson[70], syn_projEinput_ampa[70], 0.0, 0.025, 4.1363508E-4)")  

        # Connection 71: cell 71, seg 0 (0.5) [0.5 on expoisson[71]] -> cell 71, seg 0 (0.5) [0.5 on Epop[71]], weight: 4.1363508E-4, delay 0.025
        h("Epop[71] syn_projEinput_ampa[71] = new ampa(0.5)")
        h("expoisson[71] netConn_projEinput_ampa[71] = new NetCon(m_poisson_input_expoisson[71], syn_projEinput_ampa[71], 0.0, 0.025, 4.1363508E-4)")  

        # Connection 72: cell 72, seg 0 (0.5) [0.5 on expoisson[72]] -> cell 72, seg 0 (0.5) [0.5 on Epop[72]], weight: 4.1363508E-4, delay 0.025
        h("Epop[72] syn_projEinput_ampa[72] = new ampa(0.5)")
        h("expoisson[72] netConn_projEinput_ampa[72] = new NetCon(m_poisson_input_expoisson[72], syn_projEinput_ampa[72], 0.0, 0.025, 4.1363508E-4)")  

        # Connection 73: cell 73, seg 0 (0.5) [0.5 on expoisson[73]] -> cell 73, seg 0 (0.5) [0.5 on Epop[73]], weight: 4.1363508E-4, delay 0.025
        h("Epop[73] syn_projEinput_ampa[73] = new ampa(0.5)")
        h("expoisson[73] netConn_projEinput_ampa[73] = new NetCon(m_poisson_input_expoisson[73], syn_projEinput_ampa[73], 0.0, 0.025, 4.1363508E-4)")  

        # Connection 74: cell 74, seg 0 (0.5) [0.5 on expoisson[74]] -> cell 74, seg 0 (0.5) [0.5 on Epop[74]], weight: 4.1363508E-4, delay 0.025
        h("Epop[74] syn_projEinput_ampa[74] = new ampa(0.5)")
        h("expoisson[74] netConn_projEinput_ampa[74] = new NetCon(m_poisson_input_expoisson[74], syn_projEinput_ampa[74], 0.0, 0.025, 4.1363508E-4)")  

        # Connection 75: cell 75, seg 0 (0.5) [0.5 on expoisson[75]] -> cell 75, seg 0 (0.5) [0.5 on Epop[75]], weight: 4.1363508E-4, delay 0.025
        h("Epop[75] syn_projEinput_ampa[75] = new ampa(0.5)")
        h("expoisson[75] netConn_projEinput_ampa[75] = new NetCon(m_poisson_input_expoisson[75], syn_projEinput_ampa[75], 0.0, 0.025, 4.1363508E-4)")  

        # Connection 76: cell 76, seg 0 (0.5) [0.5 on expoisson[76]] -> cell 76, seg 0 (0.5) [0.5 on Epop[76]], weight: 4.1363508E-4, delay 0.025
        h("Epop[76] syn_projEinput_ampa[76] = new ampa(0.5)")
        h("expoisson[76] netConn_projEinput_ampa[76] = new NetCon(m_poisson_input_expoisson[76], syn_projEinput_ampa[76], 0.0, 0.025, 4.1363508E-4)")  

        # Connection 77: cell 77, seg 0 (0.5) [0.5 on expoisson[77]] -> cell 77, seg 0 (0.5) [0.5 on Epop[77]], weight: 4.1363508E-4, delay 0.025
        h("Epop[77] syn_projEinput_ampa[77] = new ampa(0.5)")
        h("expoisson[77] netConn_projEinput_ampa[77] = new NetCon(m_poisson_input_expoisson[77], syn_projEinput_ampa[77], 0.0, 0.025, 4.1363508E-4)")  

        # Connection 78: cell 78, seg 0 (0.5) [0.5 on expoisson[78]] -> cell 78, seg 0 (0.5) [0.5 on Epop[78]], weight: 4.1363508E-4, delay 0.025
        h("Epop[78] syn_projEinput_ampa[78] = new ampa(0.5)")
        h("expoisson[78] netConn_projEinput_ampa[78] = new NetCon(m_poisson_input_expoisson[78], syn_projEinput_ampa[78], 0.0, 0.025, 4.1363508E-4)")  

        # Connection 79: cell 79, seg 0 (0.5) [0.5 on expoisson[79]] -> cell 79, seg 0 (0.5) [0.5 on Epop[79]], weight: 4.1363508E-4, delay 0.025
        h("Epop[79] syn_projEinput_ampa[79] = new ampa(0.5)")
        h("expoisson[79] netConn_projEinput_ampa[79] = new NetCon(m_poisson_input_expoisson[79], syn_projEinput_ampa[79], 0.0, 0.025, 4.1363508E-4)")  

        # ######################   Projection: projIinput
        print("Adding projection: projIinput, from inpoisson to Ipop with synapse ampa, 20 connection(s)")

        h("objectvar syn_projIinput_ampa[20]")

        h("objectvar netConn_projIinput_ampa[20]")

        # Connection 0: cell 0, seg 0 (0.5) [0.5 on inpoisson[0]] -> cell 0, seg 0 (0.5) [0.5 on Ipop[0]], weight: 4.1363508E-4, delay 0.025
        h("Ipop[0] syn_projIinput_ampa[0] = new ampa(0.5)")
        h("inpoisson[0] netConn_projIinput_ampa[0] = new NetCon(m_poisson_input_inpoisson[0], syn_projIinput_ampa[0], 0.0, 0.025, 4.1363508E-4)")  

        # Connection 1: cell 1, seg 0 (0.5) [0.5 on inpoisson[1]] -> cell 1, seg 0 (0.5) [0.5 on Ipop[1]], weight: 4.1363508E-4, delay 0.025
        h("Ipop[1] syn_projIinput_ampa[1] = new ampa(0.5)")
        h("inpoisson[1] netConn_projIinput_ampa[1] = new NetCon(m_poisson_input_inpoisson[1], syn_projIinput_ampa[1], 0.0, 0.025, 4.1363508E-4)")  

        # Connection 2: cell 2, seg 0 (0.5) [0.5 on inpoisson[2]] -> cell 2, seg 0 (0.5) [0.5 on Ipop[2]], weight: 4.1363508E-4, delay 0.025
        h("Ipop[2] syn_projIinput_ampa[2] = new ampa(0.5)")
        h("inpoisson[2] netConn_projIinput_ampa[2] = new NetCon(m_poisson_input_inpoisson[2], syn_projIinput_ampa[2], 0.0, 0.025, 4.1363508E-4)")  

        # Connection 3: cell 3, seg 0 (0.5) [0.5 on inpoisson[3]] -> cell 3, seg 0 (0.5) [0.5 on Ipop[3]], weight: 4.1363508E-4, delay 0.025
        h("Ipop[3] syn_projIinput_ampa[3] = new ampa(0.5)")
        h("inpoisson[3] netConn_projIinput_ampa[3] = new NetCon(m_poisson_input_inpoisson[3], syn_projIinput_ampa[3], 0.0, 0.025, 4.1363508E-4)")  

        # Connection 4: cell 4, seg 0 (0.5) [0.5 on inpoisson[4]] -> cell 4, seg 0 (0.5) [0.5 on Ipop[4]], weight: 4.1363508E-4, delay 0.025
        h("Ipop[4] syn_projIinput_ampa[4] = new ampa(0.5)")
        h("inpoisson[4] netConn_projIinput_ampa[4] = new NetCon(m_poisson_input_inpoisson[4], syn_projIinput_ampa[4], 0.0, 0.025, 4.1363508E-4)")  

        # Connection 5: cell 5, seg 0 (0.5) [0.5 on inpoisson[5]] -> cell 5, seg 0 (0.5) [0.5 on Ipop[5]], weight: 4.1363508E-4, delay 0.025
        h("Ipop[5] syn_projIinput_ampa[5] = new ampa(0.5)")
        h("inpoisson[5] netConn_projIinput_ampa[5] = new NetCon(m_poisson_input_inpoisson[5], syn_projIinput_ampa[5], 0.0, 0.025, 4.1363508E-4)")  

        # Connection 6: cell 6, seg 0 (0.5) [0.5 on inpoisson[6]] -> cell 6, seg 0 (0.5) [0.5 on Ipop[6]], weight: 4.1363508E-4, delay 0.025
        h("Ipop[6] syn_projIinput_ampa[6] = new ampa(0.5)")
        h("inpoisson[6] netConn_projIinput_ampa[6] = new NetCon(m_poisson_input_inpoisson[6], syn_projIinput_ampa[6], 0.0, 0.025, 4.1363508E-4)")  

        # Connection 7: cell 7, seg 0 (0.5) [0.5 on inpoisson[7]] -> cell 7, seg 0 (0.5) [0.5 on Ipop[7]], weight: 4.1363508E-4, delay 0.025
        h("Ipop[7] syn_projIinput_ampa[7] = new ampa(0.5)")
        h("inpoisson[7] netConn_projIinput_ampa[7] = new NetCon(m_poisson_input_inpoisson[7], syn_projIinput_ampa[7], 0.0, 0.025, 4.1363508E-4)")  

        # Connection 8: cell 8, seg 0 (0.5) [0.5 on inpoisson[8]] -> cell 8, seg 0 (0.5) [0.5 on Ipop[8]], weight: 4.1363508E-4, delay 0.025
        h("Ipop[8] syn_projIinput_ampa[8] = new ampa(0.5)")
        h("inpoisson[8] netConn_projIinput_ampa[8] = new NetCon(m_poisson_input_inpoisson[8], syn_projIinput_ampa[8], 0.0, 0.025, 4.1363508E-4)")  

        # Connection 9: cell 9, seg 0 (0.5) [0.5 on inpoisson[9]] -> cell 9, seg 0 (0.5) [0.5 on Ipop[9]], weight: 4.1363508E-4, delay 0.025
        h("Ipop[9] syn_projIinput_ampa[9] = new ampa(0.5)")
        h("inpoisson[9] netConn_projIinput_ampa[9] = new NetCon(m_poisson_input_inpoisson[9], syn_projIinput_ampa[9], 0.0, 0.025, 4.1363508E-4)")  

        # Connection 10: cell 10, seg 0 (0.5) [0.5 on inpoisson[10]] -> cell 10, seg 0 (0.5) [0.5 on Ipop[10]], weight: 4.1363508E-4, delay 0.025
        h("Ipop[10] syn_projIinput_ampa[10] = new ampa(0.5)")
        h("inpoisson[10] netConn_projIinput_ampa[10] = new NetCon(m_poisson_input_inpoisson[10], syn_projIinput_ampa[10], 0.0, 0.025, 4.1363508E-4)")  

        # Connection 11: cell 11, seg 0 (0.5) [0.5 on inpoisson[11]] -> cell 11, seg 0 (0.5) [0.5 on Ipop[11]], weight: 4.1363508E-4, delay 0.025
        h("Ipop[11] syn_projIinput_ampa[11] = new ampa(0.5)")
        h("inpoisson[11] netConn_projIinput_ampa[11] = new NetCon(m_poisson_input_inpoisson[11], syn_projIinput_ampa[11], 0.0, 0.025, 4.1363508E-4)")  

        # Connection 12: cell 12, seg 0 (0.5) [0.5 on inpoisson[12]] -> cell 12, seg 0 (0.5) [0.5 on Ipop[12]], weight: 4.1363508E-4, delay 0.025
        h("Ipop[12] syn_projIinput_ampa[12] = new ampa(0.5)")
        h("inpoisson[12] netConn_projIinput_ampa[12] = new NetCon(m_poisson_input_inpoisson[12], syn_projIinput_ampa[12], 0.0, 0.025, 4.1363508E-4)")  

        # Connection 13: cell 13, seg 0 (0.5) [0.5 on inpoisson[13]] -> cell 13, seg 0 (0.5) [0.5 on Ipop[13]], weight: 4.1363508E-4, delay 0.025
        h("Ipop[13] syn_projIinput_ampa[13] = new ampa(0.5)")
        h("inpoisson[13] netConn_projIinput_ampa[13] = new NetCon(m_poisson_input_inpoisson[13], syn_projIinput_ampa[13], 0.0, 0.025, 4.1363508E-4)")  

        # Connection 14: cell 14, seg 0 (0.5) [0.5 on inpoisson[14]] -> cell 14, seg 0 (0.5) [0.5 on Ipop[14]], weight: 4.1363508E-4, delay 0.025
        h("Ipop[14] syn_projIinput_ampa[14] = new ampa(0.5)")
        h("inpoisson[14] netConn_projIinput_ampa[14] = new NetCon(m_poisson_input_inpoisson[14], syn_projIinput_ampa[14], 0.0, 0.025, 4.1363508E-4)")  

        # Connection 15: cell 15, seg 0 (0.5) [0.5 on inpoisson[15]] -> cell 15, seg 0 (0.5) [0.5 on Ipop[15]], weight: 4.1363508E-4, delay 0.025
        h("Ipop[15] syn_projIinput_ampa[15] = new ampa(0.5)")
        h("inpoisson[15] netConn_projIinput_ampa[15] = new NetCon(m_poisson_input_inpoisson[15], syn_projIinput_ampa[15], 0.0, 0.025, 4.1363508E-4)")  

        # Connection 16: cell 16, seg 0 (0.5) [0.5 on inpoisson[16]] -> cell 16, seg 0 (0.5) [0.5 on Ipop[16]], weight: 4.1363508E-4, delay 0.025
        h("Ipop[16] syn_projIinput_ampa[16] = new ampa(0.5)")
        h("inpoisson[16] netConn_projIinput_ampa[16] = new NetCon(m_poisson_input_inpoisson[16], syn_projIinput_ampa[16], 0.0, 0.025, 4.1363508E-4)")  

        # Connection 17: cell 17, seg 0 (0.5) [0.5 on inpoisson[17]] -> cell 17, seg 0 (0.5) [0.5 on Ipop[17]], weight: 4.1363508E-4, delay 0.025
        h("Ipop[17] syn_projIinput_ampa[17] = new ampa(0.5)")
        h("inpoisson[17] netConn_projIinput_ampa[17] = new NetCon(m_poisson_input_inpoisson[17], syn_projIinput_ampa[17], 0.0, 0.025, 4.1363508E-4)")  

        # Connection 18: cell 18, seg 0 (0.5) [0.5 on inpoisson[18]] -> cell 18, seg 0 (0.5) [0.5 on Ipop[18]], weight: 4.1363508E-4, delay 0.025
        h("Ipop[18] syn_projIinput_ampa[18] = new ampa(0.5)")
        h("inpoisson[18] netConn_projIinput_ampa[18] = new NetCon(m_poisson_input_inpoisson[18], syn_projIinput_ampa[18], 0.0, 0.025, 4.1363508E-4)")  

        # Connection 19: cell 19, seg 0 (0.5) [0.5 on inpoisson[19]] -> cell 19, seg 0 (0.5) [0.5 on Ipop[19]], weight: 4.1363508E-4, delay 0.025
        h("Ipop[19] syn_projIinput_ampa[19] = new ampa(0.5)")
        h("inpoisson[19] netConn_projIinput_ampa[19] = new NetCon(m_poisson_input_inpoisson[19], syn_projIinput_ampa[19], 0.0, 0.025, 4.1363508E-4)")  

        # ######################   Projection: projEE
        print("Adding projection: projEE, from Epop to Epop with synapse ampa, 6400 connection(s)")

        h("objectvar syn_projEE_ampa[6400]")

        h("objectvar netConn_projEE_ampa[6400]")

        # Connection 0: cell 0, seg 0 (0.5) [0.5 on Epop[0]] -> cell 0, seg 0 (0.5) [0.5 on Epop[0]], weight: 4.1363508E-4, delay 1.5
        h("Epop[0] syn_projEE_ampa[0] = new ampa(0.5)")
        h("Epop[0] netConn_projEE_ampa[0] = new NetCon(&v(0.5), syn_projEE_ampa[0], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1: cell 0, seg 0 (0.5) [0.5 on Epop[0]] -> cell 1, seg 0 (0.5) [0.5 on Epop[1]], weight: 4.1363508E-4, delay 1.5
        h("Epop[1] syn_projEE_ampa[1] = new ampa(0.5)")
        h("Epop[0] netConn_projEE_ampa[1] = new NetCon(&v(0.5), syn_projEE_ampa[1], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2: cell 0, seg 0 (0.5) [0.5 on Epop[0]] -> cell 2, seg 0 (0.5) [0.5 on Epop[2]], weight: 4.1363508E-4, delay 1.5
        h("Epop[2] syn_projEE_ampa[2] = new ampa(0.5)")
        h("Epop[0] netConn_projEE_ampa[2] = new NetCon(&v(0.5), syn_projEE_ampa[2], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3: cell 0, seg 0 (0.5) [0.5 on Epop[0]] -> cell 3, seg 0 (0.5) [0.5 on Epop[3]], weight: 4.1363508E-4, delay 1.5
        h("Epop[3] syn_projEE_ampa[3] = new ampa(0.5)")
        h("Epop[0] netConn_projEE_ampa[3] = new NetCon(&v(0.5), syn_projEE_ampa[3], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4: cell 0, seg 0 (0.5) [0.5 on Epop[0]] -> cell 4, seg 0 (0.5) [0.5 on Epop[4]], weight: 4.1363508E-4, delay 1.5
        h("Epop[4] syn_projEE_ampa[4] = new ampa(0.5)")
        h("Epop[0] netConn_projEE_ampa[4] = new NetCon(&v(0.5), syn_projEE_ampa[4], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5: cell 0, seg 0 (0.5) [0.5 on Epop[0]] -> cell 5, seg 0 (0.5) [0.5 on Epop[5]], weight: 4.1363508E-4, delay 1.5
        h("Epop[5] syn_projEE_ampa[5] = new ampa(0.5)")
        h("Epop[0] netConn_projEE_ampa[5] = new NetCon(&v(0.5), syn_projEE_ampa[5], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6: cell 0, seg 0 (0.5) [0.5 on Epop[0]] -> cell 6, seg 0 (0.5) [0.5 on Epop[6]], weight: 4.1363508E-4, delay 1.5
        h("Epop[6] syn_projEE_ampa[6] = new ampa(0.5)")
        h("Epop[0] netConn_projEE_ampa[6] = new NetCon(&v(0.5), syn_projEE_ampa[6], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 7: cell 0, seg 0 (0.5) [0.5 on Epop[0]] -> cell 7, seg 0 (0.5) [0.5 on Epop[7]], weight: 4.1363508E-4, delay 1.5
        h("Epop[7] syn_projEE_ampa[7] = new ampa(0.5)")
        h("Epop[0] netConn_projEE_ampa[7] = new NetCon(&v(0.5), syn_projEE_ampa[7], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 8: cell 0, seg 0 (0.5) [0.5 on Epop[0]] -> cell 8, seg 0 (0.5) [0.5 on Epop[8]], weight: 4.1363508E-4, delay 1.5
        h("Epop[8] syn_projEE_ampa[8] = new ampa(0.5)")
        h("Epop[0] netConn_projEE_ampa[8] = new NetCon(&v(0.5), syn_projEE_ampa[8], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 9: cell 0, seg 0 (0.5) [0.5 on Epop[0]] -> cell 9, seg 0 (0.5) [0.5 on Epop[9]], weight: 4.1363508E-4, delay 1.5
        h("Epop[9] syn_projEE_ampa[9] = new ampa(0.5)")
        h("Epop[0] netConn_projEE_ampa[9] = new NetCon(&v(0.5), syn_projEE_ampa[9], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 10: cell 0, seg 0 (0.5) [0.5 on Epop[0]] -> cell 10, seg 0 (0.5) [0.5 on Epop[10]], weight: 4.1363508E-4, delay 1.5
        h("Epop[10] syn_projEE_ampa[10] = new ampa(0.5)")
        h("Epop[0] netConn_projEE_ampa[10] = new NetCon(&v(0.5), syn_projEE_ampa[10], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 11: cell 0, seg 0 (0.5) [0.5 on Epop[0]] -> cell 11, seg 0 (0.5) [0.5 on Epop[11]], weight: 4.1363508E-4, delay 1.5
        h("Epop[11] syn_projEE_ampa[11] = new ampa(0.5)")
        h("Epop[0] netConn_projEE_ampa[11] = new NetCon(&v(0.5), syn_projEE_ampa[11], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 12: cell 0, seg 0 (0.5) [0.5 on Epop[0]] -> cell 12, seg 0 (0.5) [0.5 on Epop[12]], weight: 4.1363508E-4, delay 1.5
        h("Epop[12] syn_projEE_ampa[12] = new ampa(0.5)")
        h("Epop[0] netConn_projEE_ampa[12] = new NetCon(&v(0.5), syn_projEE_ampa[12], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 13: cell 0, seg 0 (0.5) [0.5 on Epop[0]] -> cell 13, seg 0 (0.5) [0.5 on Epop[13]], weight: 4.1363508E-4, delay 1.5
        h("Epop[13] syn_projEE_ampa[13] = new ampa(0.5)")
        h("Epop[0] netConn_projEE_ampa[13] = new NetCon(&v(0.5), syn_projEE_ampa[13], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 14: cell 0, seg 0 (0.5) [0.5 on Epop[0]] -> cell 14, seg 0 (0.5) [0.5 on Epop[14]], weight: 4.1363508E-4, delay 1.5
        h("Epop[14] syn_projEE_ampa[14] = new ampa(0.5)")
        h("Epop[0] netConn_projEE_ampa[14] = new NetCon(&v(0.5), syn_projEE_ampa[14], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 15: cell 0, seg 0 (0.5) [0.5 on Epop[0]] -> cell 15, seg 0 (0.5) [0.5 on Epop[15]], weight: 4.1363508E-4, delay 1.5
        h("Epop[15] syn_projEE_ampa[15] = new ampa(0.5)")
        h("Epop[0] netConn_projEE_ampa[15] = new NetCon(&v(0.5), syn_projEE_ampa[15], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 16: cell 0, seg 0 (0.5) [0.5 on Epop[0]] -> cell 16, seg 0 (0.5) [0.5 on Epop[16]], weight: 4.1363508E-4, delay 1.5
        h("Epop[16] syn_projEE_ampa[16] = new ampa(0.5)")
        h("Epop[0] netConn_projEE_ampa[16] = new NetCon(&v(0.5), syn_projEE_ampa[16], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 17: cell 0, seg 0 (0.5) [0.5 on Epop[0]] -> cell 17, seg 0 (0.5) [0.5 on Epop[17]], weight: 4.1363508E-4, delay 1.5
        h("Epop[17] syn_projEE_ampa[17] = new ampa(0.5)")
        h("Epop[0] netConn_projEE_ampa[17] = new NetCon(&v(0.5), syn_projEE_ampa[17], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 18: cell 0, seg 0 (0.5) [0.5 on Epop[0]] -> cell 18, seg 0 (0.5) [0.5 on Epop[18]], weight: 4.1363508E-4, delay 1.5
        h("Epop[18] syn_projEE_ampa[18] = new ampa(0.5)")
        h("Epop[0] netConn_projEE_ampa[18] = new NetCon(&v(0.5), syn_projEE_ampa[18], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 19: cell 0, seg 0 (0.5) [0.5 on Epop[0]] -> cell 19, seg 0 (0.5) [0.5 on Epop[19]], weight: 4.1363508E-4, delay 1.5
        h("Epop[19] syn_projEE_ampa[19] = new ampa(0.5)")
        h("Epop[0] netConn_projEE_ampa[19] = new NetCon(&v(0.5), syn_projEE_ampa[19], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 20: cell 0, seg 0 (0.5) [0.5 on Epop[0]] -> cell 20, seg 0 (0.5) [0.5 on Epop[20]], weight: 4.1363508E-4, delay 1.5
        h("Epop[20] syn_projEE_ampa[20] = new ampa(0.5)")
        h("Epop[0] netConn_projEE_ampa[20] = new NetCon(&v(0.5), syn_projEE_ampa[20], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 21: cell 0, seg 0 (0.5) [0.5 on Epop[0]] -> cell 21, seg 0 (0.5) [0.5 on Epop[21]], weight: 4.1363508E-4, delay 1.5
        h("Epop[21] syn_projEE_ampa[21] = new ampa(0.5)")
        h("Epop[0] netConn_projEE_ampa[21] = new NetCon(&v(0.5), syn_projEE_ampa[21], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 22: cell 0, seg 0 (0.5) [0.5 on Epop[0]] -> cell 22, seg 0 (0.5) [0.5 on Epop[22]], weight: 4.1363508E-4, delay 1.5
        h("Epop[22] syn_projEE_ampa[22] = new ampa(0.5)")
        h("Epop[0] netConn_projEE_ampa[22] = new NetCon(&v(0.5), syn_projEE_ampa[22], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 23: cell 0, seg 0 (0.5) [0.5 on Epop[0]] -> cell 23, seg 0 (0.5) [0.5 on Epop[23]], weight: 4.1363508E-4, delay 1.5
        h("Epop[23] syn_projEE_ampa[23] = new ampa(0.5)")
        h("Epop[0] netConn_projEE_ampa[23] = new NetCon(&v(0.5), syn_projEE_ampa[23], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 24: cell 0, seg 0 (0.5) [0.5 on Epop[0]] -> cell 24, seg 0 (0.5) [0.5 on Epop[24]], weight: 4.1363508E-4, delay 1.5
        h("Epop[24] syn_projEE_ampa[24] = new ampa(0.5)")
        h("Epop[0] netConn_projEE_ampa[24] = new NetCon(&v(0.5), syn_projEE_ampa[24], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 25: cell 0, seg 0 (0.5) [0.5 on Epop[0]] -> cell 25, seg 0 (0.5) [0.5 on Epop[25]], weight: 4.1363508E-4, delay 1.5
        h("Epop[25] syn_projEE_ampa[25] = new ampa(0.5)")
        h("Epop[0] netConn_projEE_ampa[25] = new NetCon(&v(0.5), syn_projEE_ampa[25], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 26: cell 0, seg 0 (0.5) [0.5 on Epop[0]] -> cell 26, seg 0 (0.5) [0.5 on Epop[26]], weight: 4.1363508E-4, delay 1.5
        h("Epop[26] syn_projEE_ampa[26] = new ampa(0.5)")
        h("Epop[0] netConn_projEE_ampa[26] = new NetCon(&v(0.5), syn_projEE_ampa[26], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 27: cell 0, seg 0 (0.5) [0.5 on Epop[0]] -> cell 27, seg 0 (0.5) [0.5 on Epop[27]], weight: 4.1363508E-4, delay 1.5
        h("Epop[27] syn_projEE_ampa[27] = new ampa(0.5)")
        h("Epop[0] netConn_projEE_ampa[27] = new NetCon(&v(0.5), syn_projEE_ampa[27], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 28: cell 0, seg 0 (0.5) [0.5 on Epop[0]] -> cell 28, seg 0 (0.5) [0.5 on Epop[28]], weight: 4.1363508E-4, delay 1.5
        h("Epop[28] syn_projEE_ampa[28] = new ampa(0.5)")
        h("Epop[0] netConn_projEE_ampa[28] = new NetCon(&v(0.5), syn_projEE_ampa[28], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 29: cell 0, seg 0 (0.5) [0.5 on Epop[0]] -> cell 29, seg 0 (0.5) [0.5 on Epop[29]], weight: 4.1363508E-4, delay 1.5
        h("Epop[29] syn_projEE_ampa[29] = new ampa(0.5)")
        h("Epop[0] netConn_projEE_ampa[29] = new NetCon(&v(0.5), syn_projEE_ampa[29], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 30: cell 0, seg 0 (0.5) [0.5 on Epop[0]] -> cell 30, seg 0 (0.5) [0.5 on Epop[30]], weight: 4.1363508E-4, delay 1.5
        h("Epop[30] syn_projEE_ampa[30] = new ampa(0.5)")
        h("Epop[0] netConn_projEE_ampa[30] = new NetCon(&v(0.5), syn_projEE_ampa[30], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 31: cell 0, seg 0 (0.5) [0.5 on Epop[0]] -> cell 31, seg 0 (0.5) [0.5 on Epop[31]], weight: 4.1363508E-4, delay 1.5
        h("Epop[31] syn_projEE_ampa[31] = new ampa(0.5)")
        h("Epop[0] netConn_projEE_ampa[31] = new NetCon(&v(0.5), syn_projEE_ampa[31], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 32: cell 0, seg 0 (0.5) [0.5 on Epop[0]] -> cell 32, seg 0 (0.5) [0.5 on Epop[32]], weight: 4.1363508E-4, delay 1.5
        h("Epop[32] syn_projEE_ampa[32] = new ampa(0.5)")
        h("Epop[0] netConn_projEE_ampa[32] = new NetCon(&v(0.5), syn_projEE_ampa[32], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 33: cell 0, seg 0 (0.5) [0.5 on Epop[0]] -> cell 33, seg 0 (0.5) [0.5 on Epop[33]], weight: 4.1363508E-4, delay 1.5
        h("Epop[33] syn_projEE_ampa[33] = new ampa(0.5)")
        h("Epop[0] netConn_projEE_ampa[33] = new NetCon(&v(0.5), syn_projEE_ampa[33], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 34: cell 0, seg 0 (0.5) [0.5 on Epop[0]] -> cell 34, seg 0 (0.5) [0.5 on Epop[34]], weight: 4.1363508E-4, delay 1.5
        h("Epop[34] syn_projEE_ampa[34] = new ampa(0.5)")
        h("Epop[0] netConn_projEE_ampa[34] = new NetCon(&v(0.5), syn_projEE_ampa[34], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 35: cell 0, seg 0 (0.5) [0.5 on Epop[0]] -> cell 35, seg 0 (0.5) [0.5 on Epop[35]], weight: 4.1363508E-4, delay 1.5
        h("Epop[35] syn_projEE_ampa[35] = new ampa(0.5)")
        h("Epop[0] netConn_projEE_ampa[35] = new NetCon(&v(0.5), syn_projEE_ampa[35], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 36: cell 0, seg 0 (0.5) [0.5 on Epop[0]] -> cell 36, seg 0 (0.5) [0.5 on Epop[36]], weight: 4.1363508E-4, delay 1.5
        h("Epop[36] syn_projEE_ampa[36] = new ampa(0.5)")
        h("Epop[0] netConn_projEE_ampa[36] = new NetCon(&v(0.5), syn_projEE_ampa[36], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 37: cell 0, seg 0 (0.5) [0.5 on Epop[0]] -> cell 37, seg 0 (0.5) [0.5 on Epop[37]], weight: 4.1363508E-4, delay 1.5
        h("Epop[37] syn_projEE_ampa[37] = new ampa(0.5)")
        h("Epop[0] netConn_projEE_ampa[37] = new NetCon(&v(0.5), syn_projEE_ampa[37], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 38: cell 0, seg 0 (0.5) [0.5 on Epop[0]] -> cell 38, seg 0 (0.5) [0.5 on Epop[38]], weight: 4.1363508E-4, delay 1.5
        h("Epop[38] syn_projEE_ampa[38] = new ampa(0.5)")
        h("Epop[0] netConn_projEE_ampa[38] = new NetCon(&v(0.5), syn_projEE_ampa[38], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 39: cell 0, seg 0 (0.5) [0.5 on Epop[0]] -> cell 39, seg 0 (0.5) [0.5 on Epop[39]], weight: 4.1363508E-4, delay 1.5
        h("Epop[39] syn_projEE_ampa[39] = new ampa(0.5)")
        h("Epop[0] netConn_projEE_ampa[39] = new NetCon(&v(0.5), syn_projEE_ampa[39], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 40: cell 0, seg 0 (0.5) [0.5 on Epop[0]] -> cell 40, seg 0 (0.5) [0.5 on Epop[40]], weight: 4.1363508E-4, delay 1.5
        h("Epop[40] syn_projEE_ampa[40] = new ampa(0.5)")
        h("Epop[0] netConn_projEE_ampa[40] = new NetCon(&v(0.5), syn_projEE_ampa[40], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 41: cell 0, seg 0 (0.5) [0.5 on Epop[0]] -> cell 41, seg 0 (0.5) [0.5 on Epop[41]], weight: 4.1363508E-4, delay 1.5
        h("Epop[41] syn_projEE_ampa[41] = new ampa(0.5)")
        h("Epop[0] netConn_projEE_ampa[41] = new NetCon(&v(0.5), syn_projEE_ampa[41], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 42: cell 0, seg 0 (0.5) [0.5 on Epop[0]] -> cell 42, seg 0 (0.5) [0.5 on Epop[42]], weight: 4.1363508E-4, delay 1.5
        h("Epop[42] syn_projEE_ampa[42] = new ampa(0.5)")
        h("Epop[0] netConn_projEE_ampa[42] = new NetCon(&v(0.5), syn_projEE_ampa[42], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 43: cell 0, seg 0 (0.5) [0.5 on Epop[0]] -> cell 43, seg 0 (0.5) [0.5 on Epop[43]], weight: 4.1363508E-4, delay 1.5
        h("Epop[43] syn_projEE_ampa[43] = new ampa(0.5)")
        h("Epop[0] netConn_projEE_ampa[43] = new NetCon(&v(0.5), syn_projEE_ampa[43], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 44: cell 0, seg 0 (0.5) [0.5 on Epop[0]] -> cell 44, seg 0 (0.5) [0.5 on Epop[44]], weight: 4.1363508E-4, delay 1.5
        h("Epop[44] syn_projEE_ampa[44] = new ampa(0.5)")
        h("Epop[0] netConn_projEE_ampa[44] = new NetCon(&v(0.5), syn_projEE_ampa[44], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 45: cell 0, seg 0 (0.5) [0.5 on Epop[0]] -> cell 45, seg 0 (0.5) [0.5 on Epop[45]], weight: 4.1363508E-4, delay 1.5
        h("Epop[45] syn_projEE_ampa[45] = new ampa(0.5)")
        h("Epop[0] netConn_projEE_ampa[45] = new NetCon(&v(0.5), syn_projEE_ampa[45], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 46: cell 0, seg 0 (0.5) [0.5 on Epop[0]] -> cell 46, seg 0 (0.5) [0.5 on Epop[46]], weight: 4.1363508E-4, delay 1.5
        h("Epop[46] syn_projEE_ampa[46] = new ampa(0.5)")
        h("Epop[0] netConn_projEE_ampa[46] = new NetCon(&v(0.5), syn_projEE_ampa[46], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 47: cell 0, seg 0 (0.5) [0.5 on Epop[0]] -> cell 47, seg 0 (0.5) [0.5 on Epop[47]], weight: 4.1363508E-4, delay 1.5
        h("Epop[47] syn_projEE_ampa[47] = new ampa(0.5)")
        h("Epop[0] netConn_projEE_ampa[47] = new NetCon(&v(0.5), syn_projEE_ampa[47], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 48: cell 0, seg 0 (0.5) [0.5 on Epop[0]] -> cell 48, seg 0 (0.5) [0.5 on Epop[48]], weight: 4.1363508E-4, delay 1.5
        h("Epop[48] syn_projEE_ampa[48] = new ampa(0.5)")
        h("Epop[0] netConn_projEE_ampa[48] = new NetCon(&v(0.5), syn_projEE_ampa[48], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 49: cell 0, seg 0 (0.5) [0.5 on Epop[0]] -> cell 49, seg 0 (0.5) [0.5 on Epop[49]], weight: 4.1363508E-4, delay 1.5
        h("Epop[49] syn_projEE_ampa[49] = new ampa(0.5)")
        h("Epop[0] netConn_projEE_ampa[49] = new NetCon(&v(0.5), syn_projEE_ampa[49], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 50: cell 0, seg 0 (0.5) [0.5 on Epop[0]] -> cell 50, seg 0 (0.5) [0.5 on Epop[50]], weight: 4.1363508E-4, delay 1.5
        h("Epop[50] syn_projEE_ampa[50] = new ampa(0.5)")
        h("Epop[0] netConn_projEE_ampa[50] = new NetCon(&v(0.5), syn_projEE_ampa[50], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 51: cell 0, seg 0 (0.5) [0.5 on Epop[0]] -> cell 51, seg 0 (0.5) [0.5 on Epop[51]], weight: 4.1363508E-4, delay 1.5
        h("Epop[51] syn_projEE_ampa[51] = new ampa(0.5)")
        h("Epop[0] netConn_projEE_ampa[51] = new NetCon(&v(0.5), syn_projEE_ampa[51], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 52: cell 0, seg 0 (0.5) [0.5 on Epop[0]] -> cell 52, seg 0 (0.5) [0.5 on Epop[52]], weight: 4.1363508E-4, delay 1.5
        h("Epop[52] syn_projEE_ampa[52] = new ampa(0.5)")
        h("Epop[0] netConn_projEE_ampa[52] = new NetCon(&v(0.5), syn_projEE_ampa[52], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 53: cell 0, seg 0 (0.5) [0.5 on Epop[0]] -> cell 53, seg 0 (0.5) [0.5 on Epop[53]], weight: 4.1363508E-4, delay 1.5
        h("Epop[53] syn_projEE_ampa[53] = new ampa(0.5)")
        h("Epop[0] netConn_projEE_ampa[53] = new NetCon(&v(0.5), syn_projEE_ampa[53], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 54: cell 0, seg 0 (0.5) [0.5 on Epop[0]] -> cell 54, seg 0 (0.5) [0.5 on Epop[54]], weight: 4.1363508E-4, delay 1.5
        h("Epop[54] syn_projEE_ampa[54] = new ampa(0.5)")
        h("Epop[0] netConn_projEE_ampa[54] = new NetCon(&v(0.5), syn_projEE_ampa[54], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 55: cell 0, seg 0 (0.5) [0.5 on Epop[0]] -> cell 55, seg 0 (0.5) [0.5 on Epop[55]], weight: 4.1363508E-4, delay 1.5
        h("Epop[55] syn_projEE_ampa[55] = new ampa(0.5)")
        h("Epop[0] netConn_projEE_ampa[55] = new NetCon(&v(0.5), syn_projEE_ampa[55], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 56: cell 0, seg 0 (0.5) [0.5 on Epop[0]] -> cell 56, seg 0 (0.5) [0.5 on Epop[56]], weight: 4.1363508E-4, delay 1.5
        h("Epop[56] syn_projEE_ampa[56] = new ampa(0.5)")
        h("Epop[0] netConn_projEE_ampa[56] = new NetCon(&v(0.5), syn_projEE_ampa[56], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 57: cell 0, seg 0 (0.5) [0.5 on Epop[0]] -> cell 57, seg 0 (0.5) [0.5 on Epop[57]], weight: 4.1363508E-4, delay 1.5
        h("Epop[57] syn_projEE_ampa[57] = new ampa(0.5)")
        h("Epop[0] netConn_projEE_ampa[57] = new NetCon(&v(0.5), syn_projEE_ampa[57], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 58: cell 0, seg 0 (0.5) [0.5 on Epop[0]] -> cell 58, seg 0 (0.5) [0.5 on Epop[58]], weight: 4.1363508E-4, delay 1.5
        h("Epop[58] syn_projEE_ampa[58] = new ampa(0.5)")
        h("Epop[0] netConn_projEE_ampa[58] = new NetCon(&v(0.5), syn_projEE_ampa[58], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 59: cell 0, seg 0 (0.5) [0.5 on Epop[0]] -> cell 59, seg 0 (0.5) [0.5 on Epop[59]], weight: 4.1363508E-4, delay 1.5
        h("Epop[59] syn_projEE_ampa[59] = new ampa(0.5)")
        h("Epop[0] netConn_projEE_ampa[59] = new NetCon(&v(0.5), syn_projEE_ampa[59], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 60: cell 0, seg 0 (0.5) [0.5 on Epop[0]] -> cell 60, seg 0 (0.5) [0.5 on Epop[60]], weight: 4.1363508E-4, delay 1.5
        h("Epop[60] syn_projEE_ampa[60] = new ampa(0.5)")
        h("Epop[0] netConn_projEE_ampa[60] = new NetCon(&v(0.5), syn_projEE_ampa[60], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 61: cell 0, seg 0 (0.5) [0.5 on Epop[0]] -> cell 61, seg 0 (0.5) [0.5 on Epop[61]], weight: 4.1363508E-4, delay 1.5
        h("Epop[61] syn_projEE_ampa[61] = new ampa(0.5)")
        h("Epop[0] netConn_projEE_ampa[61] = new NetCon(&v(0.5), syn_projEE_ampa[61], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 62: cell 0, seg 0 (0.5) [0.5 on Epop[0]] -> cell 62, seg 0 (0.5) [0.5 on Epop[62]], weight: 4.1363508E-4, delay 1.5
        h("Epop[62] syn_projEE_ampa[62] = new ampa(0.5)")
        h("Epop[0] netConn_projEE_ampa[62] = new NetCon(&v(0.5), syn_projEE_ampa[62], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 63: cell 0, seg 0 (0.5) [0.5 on Epop[0]] -> cell 63, seg 0 (0.5) [0.5 on Epop[63]], weight: 4.1363508E-4, delay 1.5
        h("Epop[63] syn_projEE_ampa[63] = new ampa(0.5)")
        h("Epop[0] netConn_projEE_ampa[63] = new NetCon(&v(0.5), syn_projEE_ampa[63], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 64: cell 0, seg 0 (0.5) [0.5 on Epop[0]] -> cell 64, seg 0 (0.5) [0.5 on Epop[64]], weight: 4.1363508E-4, delay 1.5
        h("Epop[64] syn_projEE_ampa[64] = new ampa(0.5)")
        h("Epop[0] netConn_projEE_ampa[64] = new NetCon(&v(0.5), syn_projEE_ampa[64], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 65: cell 0, seg 0 (0.5) [0.5 on Epop[0]] -> cell 65, seg 0 (0.5) [0.5 on Epop[65]], weight: 4.1363508E-4, delay 1.5
        h("Epop[65] syn_projEE_ampa[65] = new ampa(0.5)")
        h("Epop[0] netConn_projEE_ampa[65] = new NetCon(&v(0.5), syn_projEE_ampa[65], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 66: cell 0, seg 0 (0.5) [0.5 on Epop[0]] -> cell 66, seg 0 (0.5) [0.5 on Epop[66]], weight: 4.1363508E-4, delay 1.5
        h("Epop[66] syn_projEE_ampa[66] = new ampa(0.5)")
        h("Epop[0] netConn_projEE_ampa[66] = new NetCon(&v(0.5), syn_projEE_ampa[66], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 67: cell 0, seg 0 (0.5) [0.5 on Epop[0]] -> cell 67, seg 0 (0.5) [0.5 on Epop[67]], weight: 4.1363508E-4, delay 1.5
        h("Epop[67] syn_projEE_ampa[67] = new ampa(0.5)")
        h("Epop[0] netConn_projEE_ampa[67] = new NetCon(&v(0.5), syn_projEE_ampa[67], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 68: cell 0, seg 0 (0.5) [0.5 on Epop[0]] -> cell 68, seg 0 (0.5) [0.5 on Epop[68]], weight: 4.1363508E-4, delay 1.5
        h("Epop[68] syn_projEE_ampa[68] = new ampa(0.5)")
        h("Epop[0] netConn_projEE_ampa[68] = new NetCon(&v(0.5), syn_projEE_ampa[68], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 69: cell 0, seg 0 (0.5) [0.5 on Epop[0]] -> cell 69, seg 0 (0.5) [0.5 on Epop[69]], weight: 4.1363508E-4, delay 1.5
        h("Epop[69] syn_projEE_ampa[69] = new ampa(0.5)")
        h("Epop[0] netConn_projEE_ampa[69] = new NetCon(&v(0.5), syn_projEE_ampa[69], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 70: cell 0, seg 0 (0.5) [0.5 on Epop[0]] -> cell 70, seg 0 (0.5) [0.5 on Epop[70]], weight: 4.1363508E-4, delay 1.5
        h("Epop[70] syn_projEE_ampa[70] = new ampa(0.5)")
        h("Epop[0] netConn_projEE_ampa[70] = new NetCon(&v(0.5), syn_projEE_ampa[70], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 71: cell 0, seg 0 (0.5) [0.5 on Epop[0]] -> cell 71, seg 0 (0.5) [0.5 on Epop[71]], weight: 4.1363508E-4, delay 1.5
        h("Epop[71] syn_projEE_ampa[71] = new ampa(0.5)")
        h("Epop[0] netConn_projEE_ampa[71] = new NetCon(&v(0.5), syn_projEE_ampa[71], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 72: cell 0, seg 0 (0.5) [0.5 on Epop[0]] -> cell 72, seg 0 (0.5) [0.5 on Epop[72]], weight: 4.1363508E-4, delay 1.5
        h("Epop[72] syn_projEE_ampa[72] = new ampa(0.5)")
        h("Epop[0] netConn_projEE_ampa[72] = new NetCon(&v(0.5), syn_projEE_ampa[72], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 73: cell 0, seg 0 (0.5) [0.5 on Epop[0]] -> cell 73, seg 0 (0.5) [0.5 on Epop[73]], weight: 4.1363508E-4, delay 1.5
        h("Epop[73] syn_projEE_ampa[73] = new ampa(0.5)")
        h("Epop[0] netConn_projEE_ampa[73] = new NetCon(&v(0.5), syn_projEE_ampa[73], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 74: cell 0, seg 0 (0.5) [0.5 on Epop[0]] -> cell 74, seg 0 (0.5) [0.5 on Epop[74]], weight: 4.1363508E-4, delay 1.5
        h("Epop[74] syn_projEE_ampa[74] = new ampa(0.5)")
        h("Epop[0] netConn_projEE_ampa[74] = new NetCon(&v(0.5), syn_projEE_ampa[74], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 75: cell 0, seg 0 (0.5) [0.5 on Epop[0]] -> cell 75, seg 0 (0.5) [0.5 on Epop[75]], weight: 4.1363508E-4, delay 1.5
        h("Epop[75] syn_projEE_ampa[75] = new ampa(0.5)")
        h("Epop[0] netConn_projEE_ampa[75] = new NetCon(&v(0.5), syn_projEE_ampa[75], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 76: cell 0, seg 0 (0.5) [0.5 on Epop[0]] -> cell 76, seg 0 (0.5) [0.5 on Epop[76]], weight: 4.1363508E-4, delay 1.5
        h("Epop[76] syn_projEE_ampa[76] = new ampa(0.5)")
        h("Epop[0] netConn_projEE_ampa[76] = new NetCon(&v(0.5), syn_projEE_ampa[76], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 77: cell 0, seg 0 (0.5) [0.5 on Epop[0]] -> cell 77, seg 0 (0.5) [0.5 on Epop[77]], weight: 4.1363508E-4, delay 1.5
        h("Epop[77] syn_projEE_ampa[77] = new ampa(0.5)")
        h("Epop[0] netConn_projEE_ampa[77] = new NetCon(&v(0.5), syn_projEE_ampa[77], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 78: cell 0, seg 0 (0.5) [0.5 on Epop[0]] -> cell 78, seg 0 (0.5) [0.5 on Epop[78]], weight: 4.1363508E-4, delay 1.5
        h("Epop[78] syn_projEE_ampa[78] = new ampa(0.5)")
        h("Epop[0] netConn_projEE_ampa[78] = new NetCon(&v(0.5), syn_projEE_ampa[78], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 79: cell 0, seg 0 (0.5) [0.5 on Epop[0]] -> cell 79, seg 0 (0.5) [0.5 on Epop[79]], weight: 4.1363508E-4, delay 1.5
        h("Epop[79] syn_projEE_ampa[79] = new ampa(0.5)")
        h("Epop[0] netConn_projEE_ampa[79] = new NetCon(&v(0.5), syn_projEE_ampa[79], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 80: cell 1, seg 0 (0.5) [0.5 on Epop[1]] -> cell 0, seg 0 (0.5) [0.5 on Epop[0]], weight: 4.1363508E-4, delay 1.5
        h("Epop[0] syn_projEE_ampa[80] = new ampa(0.5)")
        h("Epop[1] netConn_projEE_ampa[80] = new NetCon(&v(0.5), syn_projEE_ampa[80], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 81: cell 1, seg 0 (0.5) [0.5 on Epop[1]] -> cell 1, seg 0 (0.5) [0.5 on Epop[1]], weight: 4.1363508E-4, delay 1.5
        h("Epop[1] syn_projEE_ampa[81] = new ampa(0.5)")
        h("Epop[1] netConn_projEE_ampa[81] = new NetCon(&v(0.5), syn_projEE_ampa[81], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 82: cell 1, seg 0 (0.5) [0.5 on Epop[1]] -> cell 2, seg 0 (0.5) [0.5 on Epop[2]], weight: 4.1363508E-4, delay 1.5
        h("Epop[2] syn_projEE_ampa[82] = new ampa(0.5)")
        h("Epop[1] netConn_projEE_ampa[82] = new NetCon(&v(0.5), syn_projEE_ampa[82], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 83: cell 1, seg 0 (0.5) [0.5 on Epop[1]] -> cell 3, seg 0 (0.5) [0.5 on Epop[3]], weight: 4.1363508E-4, delay 1.5
        h("Epop[3] syn_projEE_ampa[83] = new ampa(0.5)")
        h("Epop[1] netConn_projEE_ampa[83] = new NetCon(&v(0.5), syn_projEE_ampa[83], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 84: cell 1, seg 0 (0.5) [0.5 on Epop[1]] -> cell 4, seg 0 (0.5) [0.5 on Epop[4]], weight: 4.1363508E-4, delay 1.5
        h("Epop[4] syn_projEE_ampa[84] = new ampa(0.5)")
        h("Epop[1] netConn_projEE_ampa[84] = new NetCon(&v(0.5), syn_projEE_ampa[84], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 85: cell 1, seg 0 (0.5) [0.5 on Epop[1]] -> cell 5, seg 0 (0.5) [0.5 on Epop[5]], weight: 4.1363508E-4, delay 1.5
        h("Epop[5] syn_projEE_ampa[85] = new ampa(0.5)")
        h("Epop[1] netConn_projEE_ampa[85] = new NetCon(&v(0.5), syn_projEE_ampa[85], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 86: cell 1, seg 0 (0.5) [0.5 on Epop[1]] -> cell 6, seg 0 (0.5) [0.5 on Epop[6]], weight: 4.1363508E-4, delay 1.5
        h("Epop[6] syn_projEE_ampa[86] = new ampa(0.5)")
        h("Epop[1] netConn_projEE_ampa[86] = new NetCon(&v(0.5), syn_projEE_ampa[86], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 87: cell 1, seg 0 (0.5) [0.5 on Epop[1]] -> cell 7, seg 0 (0.5) [0.5 on Epop[7]], weight: 4.1363508E-4, delay 1.5
        h("Epop[7] syn_projEE_ampa[87] = new ampa(0.5)")
        h("Epop[1] netConn_projEE_ampa[87] = new NetCon(&v(0.5), syn_projEE_ampa[87], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 88: cell 1, seg 0 (0.5) [0.5 on Epop[1]] -> cell 8, seg 0 (0.5) [0.5 on Epop[8]], weight: 4.1363508E-4, delay 1.5
        h("Epop[8] syn_projEE_ampa[88] = new ampa(0.5)")
        h("Epop[1] netConn_projEE_ampa[88] = new NetCon(&v(0.5), syn_projEE_ampa[88], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 89: cell 1, seg 0 (0.5) [0.5 on Epop[1]] -> cell 9, seg 0 (0.5) [0.5 on Epop[9]], weight: 4.1363508E-4, delay 1.5
        h("Epop[9] syn_projEE_ampa[89] = new ampa(0.5)")
        h("Epop[1] netConn_projEE_ampa[89] = new NetCon(&v(0.5), syn_projEE_ampa[89], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 90: cell 1, seg 0 (0.5) [0.5 on Epop[1]] -> cell 10, seg 0 (0.5) [0.5 on Epop[10]], weight: 4.1363508E-4, delay 1.5
        h("Epop[10] syn_projEE_ampa[90] = new ampa(0.5)")
        h("Epop[1] netConn_projEE_ampa[90] = new NetCon(&v(0.5), syn_projEE_ampa[90], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 91: cell 1, seg 0 (0.5) [0.5 on Epop[1]] -> cell 11, seg 0 (0.5) [0.5 on Epop[11]], weight: 4.1363508E-4, delay 1.5
        h("Epop[11] syn_projEE_ampa[91] = new ampa(0.5)")
        h("Epop[1] netConn_projEE_ampa[91] = new NetCon(&v(0.5), syn_projEE_ampa[91], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 92: cell 1, seg 0 (0.5) [0.5 on Epop[1]] -> cell 12, seg 0 (0.5) [0.5 on Epop[12]], weight: 4.1363508E-4, delay 1.5
        h("Epop[12] syn_projEE_ampa[92] = new ampa(0.5)")
        h("Epop[1] netConn_projEE_ampa[92] = new NetCon(&v(0.5), syn_projEE_ampa[92], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 93: cell 1, seg 0 (0.5) [0.5 on Epop[1]] -> cell 13, seg 0 (0.5) [0.5 on Epop[13]], weight: 4.1363508E-4, delay 1.5
        h("Epop[13] syn_projEE_ampa[93] = new ampa(0.5)")
        h("Epop[1] netConn_projEE_ampa[93] = new NetCon(&v(0.5), syn_projEE_ampa[93], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 94: cell 1, seg 0 (0.5) [0.5 on Epop[1]] -> cell 14, seg 0 (0.5) [0.5 on Epop[14]], weight: 4.1363508E-4, delay 1.5
        h("Epop[14] syn_projEE_ampa[94] = new ampa(0.5)")
        h("Epop[1] netConn_projEE_ampa[94] = new NetCon(&v(0.5), syn_projEE_ampa[94], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 95: cell 1, seg 0 (0.5) [0.5 on Epop[1]] -> cell 15, seg 0 (0.5) [0.5 on Epop[15]], weight: 4.1363508E-4, delay 1.5
        h("Epop[15] syn_projEE_ampa[95] = new ampa(0.5)")
        h("Epop[1] netConn_projEE_ampa[95] = new NetCon(&v(0.5), syn_projEE_ampa[95], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 96: cell 1, seg 0 (0.5) [0.5 on Epop[1]] -> cell 16, seg 0 (0.5) [0.5 on Epop[16]], weight: 4.1363508E-4, delay 1.5
        h("Epop[16] syn_projEE_ampa[96] = new ampa(0.5)")
        h("Epop[1] netConn_projEE_ampa[96] = new NetCon(&v(0.5), syn_projEE_ampa[96], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 97: cell 1, seg 0 (0.5) [0.5 on Epop[1]] -> cell 17, seg 0 (0.5) [0.5 on Epop[17]], weight: 4.1363508E-4, delay 1.5
        h("Epop[17] syn_projEE_ampa[97] = new ampa(0.5)")
        h("Epop[1] netConn_projEE_ampa[97] = new NetCon(&v(0.5), syn_projEE_ampa[97], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 98: cell 1, seg 0 (0.5) [0.5 on Epop[1]] -> cell 18, seg 0 (0.5) [0.5 on Epop[18]], weight: 4.1363508E-4, delay 1.5
        h("Epop[18] syn_projEE_ampa[98] = new ampa(0.5)")
        h("Epop[1] netConn_projEE_ampa[98] = new NetCon(&v(0.5), syn_projEE_ampa[98], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 99: cell 1, seg 0 (0.5) [0.5 on Epop[1]] -> cell 19, seg 0 (0.5) [0.5 on Epop[19]], weight: 4.1363508E-4, delay 1.5
        h("Epop[19] syn_projEE_ampa[99] = new ampa(0.5)")
        h("Epop[1] netConn_projEE_ampa[99] = new NetCon(&v(0.5), syn_projEE_ampa[99], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 100: cell 1, seg 0 (0.5) [0.5 on Epop[1]] -> cell 20, seg 0 (0.5) [0.5 on Epop[20]], weight: 4.1363508E-4, delay 1.5
        h("Epop[20] syn_projEE_ampa[100] = new ampa(0.5)")
        h("Epop[1] netConn_projEE_ampa[100] = new NetCon(&v(0.5), syn_projEE_ampa[100], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 101: cell 1, seg 0 (0.5) [0.5 on Epop[1]] -> cell 21, seg 0 (0.5) [0.5 on Epop[21]], weight: 4.1363508E-4, delay 1.5
        h("Epop[21] syn_projEE_ampa[101] = new ampa(0.5)")
        h("Epop[1] netConn_projEE_ampa[101] = new NetCon(&v(0.5), syn_projEE_ampa[101], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 102: cell 1, seg 0 (0.5) [0.5 on Epop[1]] -> cell 22, seg 0 (0.5) [0.5 on Epop[22]], weight: 4.1363508E-4, delay 1.5
        h("Epop[22] syn_projEE_ampa[102] = new ampa(0.5)")
        h("Epop[1] netConn_projEE_ampa[102] = new NetCon(&v(0.5), syn_projEE_ampa[102], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 103: cell 1, seg 0 (0.5) [0.5 on Epop[1]] -> cell 23, seg 0 (0.5) [0.5 on Epop[23]], weight: 4.1363508E-4, delay 1.5
        h("Epop[23] syn_projEE_ampa[103] = new ampa(0.5)")
        h("Epop[1] netConn_projEE_ampa[103] = new NetCon(&v(0.5), syn_projEE_ampa[103], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 104: cell 1, seg 0 (0.5) [0.5 on Epop[1]] -> cell 24, seg 0 (0.5) [0.5 on Epop[24]], weight: 4.1363508E-4, delay 1.5
        h("Epop[24] syn_projEE_ampa[104] = new ampa(0.5)")
        h("Epop[1] netConn_projEE_ampa[104] = new NetCon(&v(0.5), syn_projEE_ampa[104], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 105: cell 1, seg 0 (0.5) [0.5 on Epop[1]] -> cell 25, seg 0 (0.5) [0.5 on Epop[25]], weight: 4.1363508E-4, delay 1.5
        h("Epop[25] syn_projEE_ampa[105] = new ampa(0.5)")
        h("Epop[1] netConn_projEE_ampa[105] = new NetCon(&v(0.5), syn_projEE_ampa[105], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 106: cell 1, seg 0 (0.5) [0.5 on Epop[1]] -> cell 26, seg 0 (0.5) [0.5 on Epop[26]], weight: 4.1363508E-4, delay 1.5
        h("Epop[26] syn_projEE_ampa[106] = new ampa(0.5)")
        h("Epop[1] netConn_projEE_ampa[106] = new NetCon(&v(0.5), syn_projEE_ampa[106], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 107: cell 1, seg 0 (0.5) [0.5 on Epop[1]] -> cell 27, seg 0 (0.5) [0.5 on Epop[27]], weight: 4.1363508E-4, delay 1.5
        h("Epop[27] syn_projEE_ampa[107] = new ampa(0.5)")
        h("Epop[1] netConn_projEE_ampa[107] = new NetCon(&v(0.5), syn_projEE_ampa[107], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 108: cell 1, seg 0 (0.5) [0.5 on Epop[1]] -> cell 28, seg 0 (0.5) [0.5 on Epop[28]], weight: 4.1363508E-4, delay 1.5
        h("Epop[28] syn_projEE_ampa[108] = new ampa(0.5)")
        h("Epop[1] netConn_projEE_ampa[108] = new NetCon(&v(0.5), syn_projEE_ampa[108], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 109: cell 1, seg 0 (0.5) [0.5 on Epop[1]] -> cell 29, seg 0 (0.5) [0.5 on Epop[29]], weight: 4.1363508E-4, delay 1.5
        h("Epop[29] syn_projEE_ampa[109] = new ampa(0.5)")
        h("Epop[1] netConn_projEE_ampa[109] = new NetCon(&v(0.5), syn_projEE_ampa[109], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 110: cell 1, seg 0 (0.5) [0.5 on Epop[1]] -> cell 30, seg 0 (0.5) [0.5 on Epop[30]], weight: 4.1363508E-4, delay 1.5
        h("Epop[30] syn_projEE_ampa[110] = new ampa(0.5)")
        h("Epop[1] netConn_projEE_ampa[110] = new NetCon(&v(0.5), syn_projEE_ampa[110], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 111: cell 1, seg 0 (0.5) [0.5 on Epop[1]] -> cell 31, seg 0 (0.5) [0.5 on Epop[31]], weight: 4.1363508E-4, delay 1.5
        h("Epop[31] syn_projEE_ampa[111] = new ampa(0.5)")
        h("Epop[1] netConn_projEE_ampa[111] = new NetCon(&v(0.5), syn_projEE_ampa[111], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 112: cell 1, seg 0 (0.5) [0.5 on Epop[1]] -> cell 32, seg 0 (0.5) [0.5 on Epop[32]], weight: 4.1363508E-4, delay 1.5
        h("Epop[32] syn_projEE_ampa[112] = new ampa(0.5)")
        h("Epop[1] netConn_projEE_ampa[112] = new NetCon(&v(0.5), syn_projEE_ampa[112], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 113: cell 1, seg 0 (0.5) [0.5 on Epop[1]] -> cell 33, seg 0 (0.5) [0.5 on Epop[33]], weight: 4.1363508E-4, delay 1.5
        h("Epop[33] syn_projEE_ampa[113] = new ampa(0.5)")
        h("Epop[1] netConn_projEE_ampa[113] = new NetCon(&v(0.5), syn_projEE_ampa[113], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 114: cell 1, seg 0 (0.5) [0.5 on Epop[1]] -> cell 34, seg 0 (0.5) [0.5 on Epop[34]], weight: 4.1363508E-4, delay 1.5
        h("Epop[34] syn_projEE_ampa[114] = new ampa(0.5)")
        h("Epop[1] netConn_projEE_ampa[114] = new NetCon(&v(0.5), syn_projEE_ampa[114], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 115: cell 1, seg 0 (0.5) [0.5 on Epop[1]] -> cell 35, seg 0 (0.5) [0.5 on Epop[35]], weight: 4.1363508E-4, delay 1.5
        h("Epop[35] syn_projEE_ampa[115] = new ampa(0.5)")
        h("Epop[1] netConn_projEE_ampa[115] = new NetCon(&v(0.5), syn_projEE_ampa[115], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 116: cell 1, seg 0 (0.5) [0.5 on Epop[1]] -> cell 36, seg 0 (0.5) [0.5 on Epop[36]], weight: 4.1363508E-4, delay 1.5
        h("Epop[36] syn_projEE_ampa[116] = new ampa(0.5)")
        h("Epop[1] netConn_projEE_ampa[116] = new NetCon(&v(0.5), syn_projEE_ampa[116], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 117: cell 1, seg 0 (0.5) [0.5 on Epop[1]] -> cell 37, seg 0 (0.5) [0.5 on Epop[37]], weight: 4.1363508E-4, delay 1.5
        h("Epop[37] syn_projEE_ampa[117] = new ampa(0.5)")
        h("Epop[1] netConn_projEE_ampa[117] = new NetCon(&v(0.5), syn_projEE_ampa[117], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 118: cell 1, seg 0 (0.5) [0.5 on Epop[1]] -> cell 38, seg 0 (0.5) [0.5 on Epop[38]], weight: 4.1363508E-4, delay 1.5
        h("Epop[38] syn_projEE_ampa[118] = new ampa(0.5)")
        h("Epop[1] netConn_projEE_ampa[118] = new NetCon(&v(0.5), syn_projEE_ampa[118], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 119: cell 1, seg 0 (0.5) [0.5 on Epop[1]] -> cell 39, seg 0 (0.5) [0.5 on Epop[39]], weight: 4.1363508E-4, delay 1.5
        h("Epop[39] syn_projEE_ampa[119] = new ampa(0.5)")
        h("Epop[1] netConn_projEE_ampa[119] = new NetCon(&v(0.5), syn_projEE_ampa[119], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 120: cell 1, seg 0 (0.5) [0.5 on Epop[1]] -> cell 40, seg 0 (0.5) [0.5 on Epop[40]], weight: 4.1363508E-4, delay 1.5
        h("Epop[40] syn_projEE_ampa[120] = new ampa(0.5)")
        h("Epop[1] netConn_projEE_ampa[120] = new NetCon(&v(0.5), syn_projEE_ampa[120], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 121: cell 1, seg 0 (0.5) [0.5 on Epop[1]] -> cell 41, seg 0 (0.5) [0.5 on Epop[41]], weight: 4.1363508E-4, delay 1.5
        h("Epop[41] syn_projEE_ampa[121] = new ampa(0.5)")
        h("Epop[1] netConn_projEE_ampa[121] = new NetCon(&v(0.5), syn_projEE_ampa[121], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 122: cell 1, seg 0 (0.5) [0.5 on Epop[1]] -> cell 42, seg 0 (0.5) [0.5 on Epop[42]], weight: 4.1363508E-4, delay 1.5
        h("Epop[42] syn_projEE_ampa[122] = new ampa(0.5)")
        h("Epop[1] netConn_projEE_ampa[122] = new NetCon(&v(0.5), syn_projEE_ampa[122], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 123: cell 1, seg 0 (0.5) [0.5 on Epop[1]] -> cell 43, seg 0 (0.5) [0.5 on Epop[43]], weight: 4.1363508E-4, delay 1.5
        h("Epop[43] syn_projEE_ampa[123] = new ampa(0.5)")
        h("Epop[1] netConn_projEE_ampa[123] = new NetCon(&v(0.5), syn_projEE_ampa[123], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 124: cell 1, seg 0 (0.5) [0.5 on Epop[1]] -> cell 44, seg 0 (0.5) [0.5 on Epop[44]], weight: 4.1363508E-4, delay 1.5
        h("Epop[44] syn_projEE_ampa[124] = new ampa(0.5)")
        h("Epop[1] netConn_projEE_ampa[124] = new NetCon(&v(0.5), syn_projEE_ampa[124], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 125: cell 1, seg 0 (0.5) [0.5 on Epop[1]] -> cell 45, seg 0 (0.5) [0.5 on Epop[45]], weight: 4.1363508E-4, delay 1.5
        h("Epop[45] syn_projEE_ampa[125] = new ampa(0.5)")
        h("Epop[1] netConn_projEE_ampa[125] = new NetCon(&v(0.5), syn_projEE_ampa[125], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 126: cell 1, seg 0 (0.5) [0.5 on Epop[1]] -> cell 46, seg 0 (0.5) [0.5 on Epop[46]], weight: 4.1363508E-4, delay 1.5
        h("Epop[46] syn_projEE_ampa[126] = new ampa(0.5)")
        h("Epop[1] netConn_projEE_ampa[126] = new NetCon(&v(0.5), syn_projEE_ampa[126], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 127: cell 1, seg 0 (0.5) [0.5 on Epop[1]] -> cell 47, seg 0 (0.5) [0.5 on Epop[47]], weight: 4.1363508E-4, delay 1.5
        h("Epop[47] syn_projEE_ampa[127] = new ampa(0.5)")
        h("Epop[1] netConn_projEE_ampa[127] = new NetCon(&v(0.5), syn_projEE_ampa[127], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 128: cell 1, seg 0 (0.5) [0.5 on Epop[1]] -> cell 48, seg 0 (0.5) [0.5 on Epop[48]], weight: 4.1363508E-4, delay 1.5
        h("Epop[48] syn_projEE_ampa[128] = new ampa(0.5)")
        h("Epop[1] netConn_projEE_ampa[128] = new NetCon(&v(0.5), syn_projEE_ampa[128], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 129: cell 1, seg 0 (0.5) [0.5 on Epop[1]] -> cell 49, seg 0 (0.5) [0.5 on Epop[49]], weight: 4.1363508E-4, delay 1.5
        h("Epop[49] syn_projEE_ampa[129] = new ampa(0.5)")
        h("Epop[1] netConn_projEE_ampa[129] = new NetCon(&v(0.5), syn_projEE_ampa[129], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 130: cell 1, seg 0 (0.5) [0.5 on Epop[1]] -> cell 50, seg 0 (0.5) [0.5 on Epop[50]], weight: 4.1363508E-4, delay 1.5
        h("Epop[50] syn_projEE_ampa[130] = new ampa(0.5)")
        h("Epop[1] netConn_projEE_ampa[130] = new NetCon(&v(0.5), syn_projEE_ampa[130], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 131: cell 1, seg 0 (0.5) [0.5 on Epop[1]] -> cell 51, seg 0 (0.5) [0.5 on Epop[51]], weight: 4.1363508E-4, delay 1.5
        h("Epop[51] syn_projEE_ampa[131] = new ampa(0.5)")
        h("Epop[1] netConn_projEE_ampa[131] = new NetCon(&v(0.5), syn_projEE_ampa[131], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 132: cell 1, seg 0 (0.5) [0.5 on Epop[1]] -> cell 52, seg 0 (0.5) [0.5 on Epop[52]], weight: 4.1363508E-4, delay 1.5
        h("Epop[52] syn_projEE_ampa[132] = new ampa(0.5)")
        h("Epop[1] netConn_projEE_ampa[132] = new NetCon(&v(0.5), syn_projEE_ampa[132], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 133: cell 1, seg 0 (0.5) [0.5 on Epop[1]] -> cell 53, seg 0 (0.5) [0.5 on Epop[53]], weight: 4.1363508E-4, delay 1.5
        h("Epop[53] syn_projEE_ampa[133] = new ampa(0.5)")
        h("Epop[1] netConn_projEE_ampa[133] = new NetCon(&v(0.5), syn_projEE_ampa[133], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 134: cell 1, seg 0 (0.5) [0.5 on Epop[1]] -> cell 54, seg 0 (0.5) [0.5 on Epop[54]], weight: 4.1363508E-4, delay 1.5
        h("Epop[54] syn_projEE_ampa[134] = new ampa(0.5)")
        h("Epop[1] netConn_projEE_ampa[134] = new NetCon(&v(0.5), syn_projEE_ampa[134], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 135: cell 1, seg 0 (0.5) [0.5 on Epop[1]] -> cell 55, seg 0 (0.5) [0.5 on Epop[55]], weight: 4.1363508E-4, delay 1.5
        h("Epop[55] syn_projEE_ampa[135] = new ampa(0.5)")
        h("Epop[1] netConn_projEE_ampa[135] = new NetCon(&v(0.5), syn_projEE_ampa[135], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 136: cell 1, seg 0 (0.5) [0.5 on Epop[1]] -> cell 56, seg 0 (0.5) [0.5 on Epop[56]], weight: 4.1363508E-4, delay 1.5
        h("Epop[56] syn_projEE_ampa[136] = new ampa(0.5)")
        h("Epop[1] netConn_projEE_ampa[136] = new NetCon(&v(0.5), syn_projEE_ampa[136], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 137: cell 1, seg 0 (0.5) [0.5 on Epop[1]] -> cell 57, seg 0 (0.5) [0.5 on Epop[57]], weight: 4.1363508E-4, delay 1.5
        h("Epop[57] syn_projEE_ampa[137] = new ampa(0.5)")
        h("Epop[1] netConn_projEE_ampa[137] = new NetCon(&v(0.5), syn_projEE_ampa[137], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 138: cell 1, seg 0 (0.5) [0.5 on Epop[1]] -> cell 58, seg 0 (0.5) [0.5 on Epop[58]], weight: 4.1363508E-4, delay 1.5
        h("Epop[58] syn_projEE_ampa[138] = new ampa(0.5)")
        h("Epop[1] netConn_projEE_ampa[138] = new NetCon(&v(0.5), syn_projEE_ampa[138], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 139: cell 1, seg 0 (0.5) [0.5 on Epop[1]] -> cell 59, seg 0 (0.5) [0.5 on Epop[59]], weight: 4.1363508E-4, delay 1.5
        h("Epop[59] syn_projEE_ampa[139] = new ampa(0.5)")
        h("Epop[1] netConn_projEE_ampa[139] = new NetCon(&v(0.5), syn_projEE_ampa[139], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 140: cell 1, seg 0 (0.5) [0.5 on Epop[1]] -> cell 60, seg 0 (0.5) [0.5 on Epop[60]], weight: 4.1363508E-4, delay 1.5
        h("Epop[60] syn_projEE_ampa[140] = new ampa(0.5)")
        h("Epop[1] netConn_projEE_ampa[140] = new NetCon(&v(0.5), syn_projEE_ampa[140], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 141: cell 1, seg 0 (0.5) [0.5 on Epop[1]] -> cell 61, seg 0 (0.5) [0.5 on Epop[61]], weight: 4.1363508E-4, delay 1.5
        h("Epop[61] syn_projEE_ampa[141] = new ampa(0.5)")
        h("Epop[1] netConn_projEE_ampa[141] = new NetCon(&v(0.5), syn_projEE_ampa[141], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 142: cell 1, seg 0 (0.5) [0.5 on Epop[1]] -> cell 62, seg 0 (0.5) [0.5 on Epop[62]], weight: 4.1363508E-4, delay 1.5
        h("Epop[62] syn_projEE_ampa[142] = new ampa(0.5)")
        h("Epop[1] netConn_projEE_ampa[142] = new NetCon(&v(0.5), syn_projEE_ampa[142], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 143: cell 1, seg 0 (0.5) [0.5 on Epop[1]] -> cell 63, seg 0 (0.5) [0.5 on Epop[63]], weight: 4.1363508E-4, delay 1.5
        h("Epop[63] syn_projEE_ampa[143] = new ampa(0.5)")
        h("Epop[1] netConn_projEE_ampa[143] = new NetCon(&v(0.5), syn_projEE_ampa[143], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 144: cell 1, seg 0 (0.5) [0.5 on Epop[1]] -> cell 64, seg 0 (0.5) [0.5 on Epop[64]], weight: 4.1363508E-4, delay 1.5
        h("Epop[64] syn_projEE_ampa[144] = new ampa(0.5)")
        h("Epop[1] netConn_projEE_ampa[144] = new NetCon(&v(0.5), syn_projEE_ampa[144], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 145: cell 1, seg 0 (0.5) [0.5 on Epop[1]] -> cell 65, seg 0 (0.5) [0.5 on Epop[65]], weight: 4.1363508E-4, delay 1.5
        h("Epop[65] syn_projEE_ampa[145] = new ampa(0.5)")
        h("Epop[1] netConn_projEE_ampa[145] = new NetCon(&v(0.5), syn_projEE_ampa[145], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 146: cell 1, seg 0 (0.5) [0.5 on Epop[1]] -> cell 66, seg 0 (0.5) [0.5 on Epop[66]], weight: 4.1363508E-4, delay 1.5
        h("Epop[66] syn_projEE_ampa[146] = new ampa(0.5)")
        h("Epop[1] netConn_projEE_ampa[146] = new NetCon(&v(0.5), syn_projEE_ampa[146], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 147: cell 1, seg 0 (0.5) [0.5 on Epop[1]] -> cell 67, seg 0 (0.5) [0.5 on Epop[67]], weight: 4.1363508E-4, delay 1.5
        h("Epop[67] syn_projEE_ampa[147] = new ampa(0.5)")
        h("Epop[1] netConn_projEE_ampa[147] = new NetCon(&v(0.5), syn_projEE_ampa[147], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 148: cell 1, seg 0 (0.5) [0.5 on Epop[1]] -> cell 68, seg 0 (0.5) [0.5 on Epop[68]], weight: 4.1363508E-4, delay 1.5
        h("Epop[68] syn_projEE_ampa[148] = new ampa(0.5)")
        h("Epop[1] netConn_projEE_ampa[148] = new NetCon(&v(0.5), syn_projEE_ampa[148], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 149: cell 1, seg 0 (0.5) [0.5 on Epop[1]] -> cell 69, seg 0 (0.5) [0.5 on Epop[69]], weight: 4.1363508E-4, delay 1.5
        h("Epop[69] syn_projEE_ampa[149] = new ampa(0.5)")
        h("Epop[1] netConn_projEE_ampa[149] = new NetCon(&v(0.5), syn_projEE_ampa[149], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 150: cell 1, seg 0 (0.5) [0.5 on Epop[1]] -> cell 70, seg 0 (0.5) [0.5 on Epop[70]], weight: 4.1363508E-4, delay 1.5
        h("Epop[70] syn_projEE_ampa[150] = new ampa(0.5)")
        h("Epop[1] netConn_projEE_ampa[150] = new NetCon(&v(0.5), syn_projEE_ampa[150], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 151: cell 1, seg 0 (0.5) [0.5 on Epop[1]] -> cell 71, seg 0 (0.5) [0.5 on Epop[71]], weight: 4.1363508E-4, delay 1.5
        h("Epop[71] syn_projEE_ampa[151] = new ampa(0.5)")
        h("Epop[1] netConn_projEE_ampa[151] = new NetCon(&v(0.5), syn_projEE_ampa[151], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 152: cell 1, seg 0 (0.5) [0.5 on Epop[1]] -> cell 72, seg 0 (0.5) [0.5 on Epop[72]], weight: 4.1363508E-4, delay 1.5
        h("Epop[72] syn_projEE_ampa[152] = new ampa(0.5)")
        h("Epop[1] netConn_projEE_ampa[152] = new NetCon(&v(0.5), syn_projEE_ampa[152], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 153: cell 1, seg 0 (0.5) [0.5 on Epop[1]] -> cell 73, seg 0 (0.5) [0.5 on Epop[73]], weight: 4.1363508E-4, delay 1.5
        h("Epop[73] syn_projEE_ampa[153] = new ampa(0.5)")
        h("Epop[1] netConn_projEE_ampa[153] = new NetCon(&v(0.5), syn_projEE_ampa[153], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 154: cell 1, seg 0 (0.5) [0.5 on Epop[1]] -> cell 74, seg 0 (0.5) [0.5 on Epop[74]], weight: 4.1363508E-4, delay 1.5
        h("Epop[74] syn_projEE_ampa[154] = new ampa(0.5)")
        h("Epop[1] netConn_projEE_ampa[154] = new NetCon(&v(0.5), syn_projEE_ampa[154], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 155: cell 1, seg 0 (0.5) [0.5 on Epop[1]] -> cell 75, seg 0 (0.5) [0.5 on Epop[75]], weight: 4.1363508E-4, delay 1.5
        h("Epop[75] syn_projEE_ampa[155] = new ampa(0.5)")
        h("Epop[1] netConn_projEE_ampa[155] = new NetCon(&v(0.5), syn_projEE_ampa[155], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 156: cell 1, seg 0 (0.5) [0.5 on Epop[1]] -> cell 76, seg 0 (0.5) [0.5 on Epop[76]], weight: 4.1363508E-4, delay 1.5
        h("Epop[76] syn_projEE_ampa[156] = new ampa(0.5)")
        h("Epop[1] netConn_projEE_ampa[156] = new NetCon(&v(0.5), syn_projEE_ampa[156], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 157: cell 1, seg 0 (0.5) [0.5 on Epop[1]] -> cell 77, seg 0 (0.5) [0.5 on Epop[77]], weight: 4.1363508E-4, delay 1.5
        h("Epop[77] syn_projEE_ampa[157] = new ampa(0.5)")
        h("Epop[1] netConn_projEE_ampa[157] = new NetCon(&v(0.5), syn_projEE_ampa[157], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 158: cell 1, seg 0 (0.5) [0.5 on Epop[1]] -> cell 78, seg 0 (0.5) [0.5 on Epop[78]], weight: 4.1363508E-4, delay 1.5
        h("Epop[78] syn_projEE_ampa[158] = new ampa(0.5)")
        h("Epop[1] netConn_projEE_ampa[158] = new NetCon(&v(0.5), syn_projEE_ampa[158], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 159: cell 1, seg 0 (0.5) [0.5 on Epop[1]] -> cell 79, seg 0 (0.5) [0.5 on Epop[79]], weight: 4.1363508E-4, delay 1.5
        h("Epop[79] syn_projEE_ampa[159] = new ampa(0.5)")
        h("Epop[1] netConn_projEE_ampa[159] = new NetCon(&v(0.5), syn_projEE_ampa[159], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 160: cell 2, seg 0 (0.5) [0.5 on Epop[2]] -> cell 0, seg 0 (0.5) [0.5 on Epop[0]], weight: 4.1363508E-4, delay 1.5
        h("Epop[0] syn_projEE_ampa[160] = new ampa(0.5)")
        h("Epop[2] netConn_projEE_ampa[160] = new NetCon(&v(0.5), syn_projEE_ampa[160], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 161: cell 2, seg 0 (0.5) [0.5 on Epop[2]] -> cell 1, seg 0 (0.5) [0.5 on Epop[1]], weight: 4.1363508E-4, delay 1.5
        h("Epop[1] syn_projEE_ampa[161] = new ampa(0.5)")
        h("Epop[2] netConn_projEE_ampa[161] = new NetCon(&v(0.5), syn_projEE_ampa[161], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 162: cell 2, seg 0 (0.5) [0.5 on Epop[2]] -> cell 2, seg 0 (0.5) [0.5 on Epop[2]], weight: 4.1363508E-4, delay 1.5
        h("Epop[2] syn_projEE_ampa[162] = new ampa(0.5)")
        h("Epop[2] netConn_projEE_ampa[162] = new NetCon(&v(0.5), syn_projEE_ampa[162], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 163: cell 2, seg 0 (0.5) [0.5 on Epop[2]] -> cell 3, seg 0 (0.5) [0.5 on Epop[3]], weight: 4.1363508E-4, delay 1.5
        h("Epop[3] syn_projEE_ampa[163] = new ampa(0.5)")
        h("Epop[2] netConn_projEE_ampa[163] = new NetCon(&v(0.5), syn_projEE_ampa[163], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 164: cell 2, seg 0 (0.5) [0.5 on Epop[2]] -> cell 4, seg 0 (0.5) [0.5 on Epop[4]], weight: 4.1363508E-4, delay 1.5
        h("Epop[4] syn_projEE_ampa[164] = new ampa(0.5)")
        h("Epop[2] netConn_projEE_ampa[164] = new NetCon(&v(0.5), syn_projEE_ampa[164], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 165: cell 2, seg 0 (0.5) [0.5 on Epop[2]] -> cell 5, seg 0 (0.5) [0.5 on Epop[5]], weight: 4.1363508E-4, delay 1.5
        h("Epop[5] syn_projEE_ampa[165] = new ampa(0.5)")
        h("Epop[2] netConn_projEE_ampa[165] = new NetCon(&v(0.5), syn_projEE_ampa[165], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 166: cell 2, seg 0 (0.5) [0.5 on Epop[2]] -> cell 6, seg 0 (0.5) [0.5 on Epop[6]], weight: 4.1363508E-4, delay 1.5
        h("Epop[6] syn_projEE_ampa[166] = new ampa(0.5)")
        h("Epop[2] netConn_projEE_ampa[166] = new NetCon(&v(0.5), syn_projEE_ampa[166], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 167: cell 2, seg 0 (0.5) [0.5 on Epop[2]] -> cell 7, seg 0 (0.5) [0.5 on Epop[7]], weight: 4.1363508E-4, delay 1.5
        h("Epop[7] syn_projEE_ampa[167] = new ampa(0.5)")
        h("Epop[2] netConn_projEE_ampa[167] = new NetCon(&v(0.5), syn_projEE_ampa[167], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 168: cell 2, seg 0 (0.5) [0.5 on Epop[2]] -> cell 8, seg 0 (0.5) [0.5 on Epop[8]], weight: 4.1363508E-4, delay 1.5
        h("Epop[8] syn_projEE_ampa[168] = new ampa(0.5)")
        h("Epop[2] netConn_projEE_ampa[168] = new NetCon(&v(0.5), syn_projEE_ampa[168], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 169: cell 2, seg 0 (0.5) [0.5 on Epop[2]] -> cell 9, seg 0 (0.5) [0.5 on Epop[9]], weight: 4.1363508E-4, delay 1.5
        h("Epop[9] syn_projEE_ampa[169] = new ampa(0.5)")
        h("Epop[2] netConn_projEE_ampa[169] = new NetCon(&v(0.5), syn_projEE_ampa[169], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 170: cell 2, seg 0 (0.5) [0.5 on Epop[2]] -> cell 10, seg 0 (0.5) [0.5 on Epop[10]], weight: 4.1363508E-4, delay 1.5
        h("Epop[10] syn_projEE_ampa[170] = new ampa(0.5)")
        h("Epop[2] netConn_projEE_ampa[170] = new NetCon(&v(0.5), syn_projEE_ampa[170], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 171: cell 2, seg 0 (0.5) [0.5 on Epop[2]] -> cell 11, seg 0 (0.5) [0.5 on Epop[11]], weight: 4.1363508E-4, delay 1.5
        h("Epop[11] syn_projEE_ampa[171] = new ampa(0.5)")
        h("Epop[2] netConn_projEE_ampa[171] = new NetCon(&v(0.5), syn_projEE_ampa[171], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 172: cell 2, seg 0 (0.5) [0.5 on Epop[2]] -> cell 12, seg 0 (0.5) [0.5 on Epop[12]], weight: 4.1363508E-4, delay 1.5
        h("Epop[12] syn_projEE_ampa[172] = new ampa(0.5)")
        h("Epop[2] netConn_projEE_ampa[172] = new NetCon(&v(0.5), syn_projEE_ampa[172], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 173: cell 2, seg 0 (0.5) [0.5 on Epop[2]] -> cell 13, seg 0 (0.5) [0.5 on Epop[13]], weight: 4.1363508E-4, delay 1.5
        h("Epop[13] syn_projEE_ampa[173] = new ampa(0.5)")
        h("Epop[2] netConn_projEE_ampa[173] = new NetCon(&v(0.5), syn_projEE_ampa[173], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 174: cell 2, seg 0 (0.5) [0.5 on Epop[2]] -> cell 14, seg 0 (0.5) [0.5 on Epop[14]], weight: 4.1363508E-4, delay 1.5
        h("Epop[14] syn_projEE_ampa[174] = new ampa(0.5)")
        h("Epop[2] netConn_projEE_ampa[174] = new NetCon(&v(0.5), syn_projEE_ampa[174], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 175: cell 2, seg 0 (0.5) [0.5 on Epop[2]] -> cell 15, seg 0 (0.5) [0.5 on Epop[15]], weight: 4.1363508E-4, delay 1.5
        h("Epop[15] syn_projEE_ampa[175] = new ampa(0.5)")
        h("Epop[2] netConn_projEE_ampa[175] = new NetCon(&v(0.5), syn_projEE_ampa[175], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 176: cell 2, seg 0 (0.5) [0.5 on Epop[2]] -> cell 16, seg 0 (0.5) [0.5 on Epop[16]], weight: 4.1363508E-4, delay 1.5
        h("Epop[16] syn_projEE_ampa[176] = new ampa(0.5)")
        h("Epop[2] netConn_projEE_ampa[176] = new NetCon(&v(0.5), syn_projEE_ampa[176], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 177: cell 2, seg 0 (0.5) [0.5 on Epop[2]] -> cell 17, seg 0 (0.5) [0.5 on Epop[17]], weight: 4.1363508E-4, delay 1.5
        h("Epop[17] syn_projEE_ampa[177] = new ampa(0.5)")
        h("Epop[2] netConn_projEE_ampa[177] = new NetCon(&v(0.5), syn_projEE_ampa[177], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 178: cell 2, seg 0 (0.5) [0.5 on Epop[2]] -> cell 18, seg 0 (0.5) [0.5 on Epop[18]], weight: 4.1363508E-4, delay 1.5
        h("Epop[18] syn_projEE_ampa[178] = new ampa(0.5)")
        h("Epop[2] netConn_projEE_ampa[178] = new NetCon(&v(0.5), syn_projEE_ampa[178], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 179: cell 2, seg 0 (0.5) [0.5 on Epop[2]] -> cell 19, seg 0 (0.5) [0.5 on Epop[19]], weight: 4.1363508E-4, delay 1.5
        h("Epop[19] syn_projEE_ampa[179] = new ampa(0.5)")
        h("Epop[2] netConn_projEE_ampa[179] = new NetCon(&v(0.5), syn_projEE_ampa[179], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 180: cell 2, seg 0 (0.5) [0.5 on Epop[2]] -> cell 20, seg 0 (0.5) [0.5 on Epop[20]], weight: 4.1363508E-4, delay 1.5
        h("Epop[20] syn_projEE_ampa[180] = new ampa(0.5)")
        h("Epop[2] netConn_projEE_ampa[180] = new NetCon(&v(0.5), syn_projEE_ampa[180], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 181: cell 2, seg 0 (0.5) [0.5 on Epop[2]] -> cell 21, seg 0 (0.5) [0.5 on Epop[21]], weight: 4.1363508E-4, delay 1.5
        h("Epop[21] syn_projEE_ampa[181] = new ampa(0.5)")
        h("Epop[2] netConn_projEE_ampa[181] = new NetCon(&v(0.5), syn_projEE_ampa[181], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 182: cell 2, seg 0 (0.5) [0.5 on Epop[2]] -> cell 22, seg 0 (0.5) [0.5 on Epop[22]], weight: 4.1363508E-4, delay 1.5
        h("Epop[22] syn_projEE_ampa[182] = new ampa(0.5)")
        h("Epop[2] netConn_projEE_ampa[182] = new NetCon(&v(0.5), syn_projEE_ampa[182], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 183: cell 2, seg 0 (0.5) [0.5 on Epop[2]] -> cell 23, seg 0 (0.5) [0.5 on Epop[23]], weight: 4.1363508E-4, delay 1.5
        h("Epop[23] syn_projEE_ampa[183] = new ampa(0.5)")
        h("Epop[2] netConn_projEE_ampa[183] = new NetCon(&v(0.5), syn_projEE_ampa[183], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 184: cell 2, seg 0 (0.5) [0.5 on Epop[2]] -> cell 24, seg 0 (0.5) [0.5 on Epop[24]], weight: 4.1363508E-4, delay 1.5
        h("Epop[24] syn_projEE_ampa[184] = new ampa(0.5)")
        h("Epop[2] netConn_projEE_ampa[184] = new NetCon(&v(0.5), syn_projEE_ampa[184], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 185: cell 2, seg 0 (0.5) [0.5 on Epop[2]] -> cell 25, seg 0 (0.5) [0.5 on Epop[25]], weight: 4.1363508E-4, delay 1.5
        h("Epop[25] syn_projEE_ampa[185] = new ampa(0.5)")
        h("Epop[2] netConn_projEE_ampa[185] = new NetCon(&v(0.5), syn_projEE_ampa[185], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 186: cell 2, seg 0 (0.5) [0.5 on Epop[2]] -> cell 26, seg 0 (0.5) [0.5 on Epop[26]], weight: 4.1363508E-4, delay 1.5
        h("Epop[26] syn_projEE_ampa[186] = new ampa(0.5)")
        h("Epop[2] netConn_projEE_ampa[186] = new NetCon(&v(0.5), syn_projEE_ampa[186], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 187: cell 2, seg 0 (0.5) [0.5 on Epop[2]] -> cell 27, seg 0 (0.5) [0.5 on Epop[27]], weight: 4.1363508E-4, delay 1.5
        h("Epop[27] syn_projEE_ampa[187] = new ampa(0.5)")
        h("Epop[2] netConn_projEE_ampa[187] = new NetCon(&v(0.5), syn_projEE_ampa[187], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 188: cell 2, seg 0 (0.5) [0.5 on Epop[2]] -> cell 28, seg 0 (0.5) [0.5 on Epop[28]], weight: 4.1363508E-4, delay 1.5
        h("Epop[28] syn_projEE_ampa[188] = new ampa(0.5)")
        h("Epop[2] netConn_projEE_ampa[188] = new NetCon(&v(0.5), syn_projEE_ampa[188], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 189: cell 2, seg 0 (0.5) [0.5 on Epop[2]] -> cell 29, seg 0 (0.5) [0.5 on Epop[29]], weight: 4.1363508E-4, delay 1.5
        h("Epop[29] syn_projEE_ampa[189] = new ampa(0.5)")
        h("Epop[2] netConn_projEE_ampa[189] = new NetCon(&v(0.5), syn_projEE_ampa[189], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 190: cell 2, seg 0 (0.5) [0.5 on Epop[2]] -> cell 30, seg 0 (0.5) [0.5 on Epop[30]], weight: 4.1363508E-4, delay 1.5
        h("Epop[30] syn_projEE_ampa[190] = new ampa(0.5)")
        h("Epop[2] netConn_projEE_ampa[190] = new NetCon(&v(0.5), syn_projEE_ampa[190], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 191: cell 2, seg 0 (0.5) [0.5 on Epop[2]] -> cell 31, seg 0 (0.5) [0.5 on Epop[31]], weight: 4.1363508E-4, delay 1.5
        h("Epop[31] syn_projEE_ampa[191] = new ampa(0.5)")
        h("Epop[2] netConn_projEE_ampa[191] = new NetCon(&v(0.5), syn_projEE_ampa[191], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 192: cell 2, seg 0 (0.5) [0.5 on Epop[2]] -> cell 32, seg 0 (0.5) [0.5 on Epop[32]], weight: 4.1363508E-4, delay 1.5
        h("Epop[32] syn_projEE_ampa[192] = new ampa(0.5)")
        h("Epop[2] netConn_projEE_ampa[192] = new NetCon(&v(0.5), syn_projEE_ampa[192], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 193: cell 2, seg 0 (0.5) [0.5 on Epop[2]] -> cell 33, seg 0 (0.5) [0.5 on Epop[33]], weight: 4.1363508E-4, delay 1.5
        h("Epop[33] syn_projEE_ampa[193] = new ampa(0.5)")
        h("Epop[2] netConn_projEE_ampa[193] = new NetCon(&v(0.5), syn_projEE_ampa[193], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 194: cell 2, seg 0 (0.5) [0.5 on Epop[2]] -> cell 34, seg 0 (0.5) [0.5 on Epop[34]], weight: 4.1363508E-4, delay 1.5
        h("Epop[34] syn_projEE_ampa[194] = new ampa(0.5)")
        h("Epop[2] netConn_projEE_ampa[194] = new NetCon(&v(0.5), syn_projEE_ampa[194], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 195: cell 2, seg 0 (0.5) [0.5 on Epop[2]] -> cell 35, seg 0 (0.5) [0.5 on Epop[35]], weight: 4.1363508E-4, delay 1.5
        h("Epop[35] syn_projEE_ampa[195] = new ampa(0.5)")
        h("Epop[2] netConn_projEE_ampa[195] = new NetCon(&v(0.5), syn_projEE_ampa[195], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 196: cell 2, seg 0 (0.5) [0.5 on Epop[2]] -> cell 36, seg 0 (0.5) [0.5 on Epop[36]], weight: 4.1363508E-4, delay 1.5
        h("Epop[36] syn_projEE_ampa[196] = new ampa(0.5)")
        h("Epop[2] netConn_projEE_ampa[196] = new NetCon(&v(0.5), syn_projEE_ampa[196], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 197: cell 2, seg 0 (0.5) [0.5 on Epop[2]] -> cell 37, seg 0 (0.5) [0.5 on Epop[37]], weight: 4.1363508E-4, delay 1.5
        h("Epop[37] syn_projEE_ampa[197] = new ampa(0.5)")
        h("Epop[2] netConn_projEE_ampa[197] = new NetCon(&v(0.5), syn_projEE_ampa[197], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 198: cell 2, seg 0 (0.5) [0.5 on Epop[2]] -> cell 38, seg 0 (0.5) [0.5 on Epop[38]], weight: 4.1363508E-4, delay 1.5
        h("Epop[38] syn_projEE_ampa[198] = new ampa(0.5)")
        h("Epop[2] netConn_projEE_ampa[198] = new NetCon(&v(0.5), syn_projEE_ampa[198], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 199: cell 2, seg 0 (0.5) [0.5 on Epop[2]] -> cell 39, seg 0 (0.5) [0.5 on Epop[39]], weight: 4.1363508E-4, delay 1.5
        h("Epop[39] syn_projEE_ampa[199] = new ampa(0.5)")
        h("Epop[2] netConn_projEE_ampa[199] = new NetCon(&v(0.5), syn_projEE_ampa[199], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 200: cell 2, seg 0 (0.5) [0.5 on Epop[2]] -> cell 40, seg 0 (0.5) [0.5 on Epop[40]], weight: 4.1363508E-4, delay 1.5
        h("Epop[40] syn_projEE_ampa[200] = new ampa(0.5)")
        h("Epop[2] netConn_projEE_ampa[200] = new NetCon(&v(0.5), syn_projEE_ampa[200], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 201: cell 2, seg 0 (0.5) [0.5 on Epop[2]] -> cell 41, seg 0 (0.5) [0.5 on Epop[41]], weight: 4.1363508E-4, delay 1.5
        h("Epop[41] syn_projEE_ampa[201] = new ampa(0.5)")
        h("Epop[2] netConn_projEE_ampa[201] = new NetCon(&v(0.5), syn_projEE_ampa[201], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 202: cell 2, seg 0 (0.5) [0.5 on Epop[2]] -> cell 42, seg 0 (0.5) [0.5 on Epop[42]], weight: 4.1363508E-4, delay 1.5
        h("Epop[42] syn_projEE_ampa[202] = new ampa(0.5)")
        h("Epop[2] netConn_projEE_ampa[202] = new NetCon(&v(0.5), syn_projEE_ampa[202], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 203: cell 2, seg 0 (0.5) [0.5 on Epop[2]] -> cell 43, seg 0 (0.5) [0.5 on Epop[43]], weight: 4.1363508E-4, delay 1.5
        h("Epop[43] syn_projEE_ampa[203] = new ampa(0.5)")
        h("Epop[2] netConn_projEE_ampa[203] = new NetCon(&v(0.5), syn_projEE_ampa[203], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 204: cell 2, seg 0 (0.5) [0.5 on Epop[2]] -> cell 44, seg 0 (0.5) [0.5 on Epop[44]], weight: 4.1363508E-4, delay 1.5
        h("Epop[44] syn_projEE_ampa[204] = new ampa(0.5)")
        h("Epop[2] netConn_projEE_ampa[204] = new NetCon(&v(0.5), syn_projEE_ampa[204], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 205: cell 2, seg 0 (0.5) [0.5 on Epop[2]] -> cell 45, seg 0 (0.5) [0.5 on Epop[45]], weight: 4.1363508E-4, delay 1.5
        h("Epop[45] syn_projEE_ampa[205] = new ampa(0.5)")
        h("Epop[2] netConn_projEE_ampa[205] = new NetCon(&v(0.5), syn_projEE_ampa[205], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 206: cell 2, seg 0 (0.5) [0.5 on Epop[2]] -> cell 46, seg 0 (0.5) [0.5 on Epop[46]], weight: 4.1363508E-4, delay 1.5
        h("Epop[46] syn_projEE_ampa[206] = new ampa(0.5)")
        h("Epop[2] netConn_projEE_ampa[206] = new NetCon(&v(0.5), syn_projEE_ampa[206], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 207: cell 2, seg 0 (0.5) [0.5 on Epop[2]] -> cell 47, seg 0 (0.5) [0.5 on Epop[47]], weight: 4.1363508E-4, delay 1.5
        h("Epop[47] syn_projEE_ampa[207] = new ampa(0.5)")
        h("Epop[2] netConn_projEE_ampa[207] = new NetCon(&v(0.5), syn_projEE_ampa[207], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 208: cell 2, seg 0 (0.5) [0.5 on Epop[2]] -> cell 48, seg 0 (0.5) [0.5 on Epop[48]], weight: 4.1363508E-4, delay 1.5
        h("Epop[48] syn_projEE_ampa[208] = new ampa(0.5)")
        h("Epop[2] netConn_projEE_ampa[208] = new NetCon(&v(0.5), syn_projEE_ampa[208], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 209: cell 2, seg 0 (0.5) [0.5 on Epop[2]] -> cell 49, seg 0 (0.5) [0.5 on Epop[49]], weight: 4.1363508E-4, delay 1.5
        h("Epop[49] syn_projEE_ampa[209] = new ampa(0.5)")
        h("Epop[2] netConn_projEE_ampa[209] = new NetCon(&v(0.5), syn_projEE_ampa[209], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 210: cell 2, seg 0 (0.5) [0.5 on Epop[2]] -> cell 50, seg 0 (0.5) [0.5 on Epop[50]], weight: 4.1363508E-4, delay 1.5
        h("Epop[50] syn_projEE_ampa[210] = new ampa(0.5)")
        h("Epop[2] netConn_projEE_ampa[210] = new NetCon(&v(0.5), syn_projEE_ampa[210], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 211: cell 2, seg 0 (0.5) [0.5 on Epop[2]] -> cell 51, seg 0 (0.5) [0.5 on Epop[51]], weight: 4.1363508E-4, delay 1.5
        h("Epop[51] syn_projEE_ampa[211] = new ampa(0.5)")
        h("Epop[2] netConn_projEE_ampa[211] = new NetCon(&v(0.5), syn_projEE_ampa[211], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 212: cell 2, seg 0 (0.5) [0.5 on Epop[2]] -> cell 52, seg 0 (0.5) [0.5 on Epop[52]], weight: 4.1363508E-4, delay 1.5
        h("Epop[52] syn_projEE_ampa[212] = new ampa(0.5)")
        h("Epop[2] netConn_projEE_ampa[212] = new NetCon(&v(0.5), syn_projEE_ampa[212], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 213: cell 2, seg 0 (0.5) [0.5 on Epop[2]] -> cell 53, seg 0 (0.5) [0.5 on Epop[53]], weight: 4.1363508E-4, delay 1.5
        h("Epop[53] syn_projEE_ampa[213] = new ampa(0.5)")
        h("Epop[2] netConn_projEE_ampa[213] = new NetCon(&v(0.5), syn_projEE_ampa[213], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 214: cell 2, seg 0 (0.5) [0.5 on Epop[2]] -> cell 54, seg 0 (0.5) [0.5 on Epop[54]], weight: 4.1363508E-4, delay 1.5
        h("Epop[54] syn_projEE_ampa[214] = new ampa(0.5)")
        h("Epop[2] netConn_projEE_ampa[214] = new NetCon(&v(0.5), syn_projEE_ampa[214], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 215: cell 2, seg 0 (0.5) [0.5 on Epop[2]] -> cell 55, seg 0 (0.5) [0.5 on Epop[55]], weight: 4.1363508E-4, delay 1.5
        h("Epop[55] syn_projEE_ampa[215] = new ampa(0.5)")
        h("Epop[2] netConn_projEE_ampa[215] = new NetCon(&v(0.5), syn_projEE_ampa[215], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 216: cell 2, seg 0 (0.5) [0.5 on Epop[2]] -> cell 56, seg 0 (0.5) [0.5 on Epop[56]], weight: 4.1363508E-4, delay 1.5
        h("Epop[56] syn_projEE_ampa[216] = new ampa(0.5)")
        h("Epop[2] netConn_projEE_ampa[216] = new NetCon(&v(0.5), syn_projEE_ampa[216], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 217: cell 2, seg 0 (0.5) [0.5 on Epop[2]] -> cell 57, seg 0 (0.5) [0.5 on Epop[57]], weight: 4.1363508E-4, delay 1.5
        h("Epop[57] syn_projEE_ampa[217] = new ampa(0.5)")
        h("Epop[2] netConn_projEE_ampa[217] = new NetCon(&v(0.5), syn_projEE_ampa[217], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 218: cell 2, seg 0 (0.5) [0.5 on Epop[2]] -> cell 58, seg 0 (0.5) [0.5 on Epop[58]], weight: 4.1363508E-4, delay 1.5
        h("Epop[58] syn_projEE_ampa[218] = new ampa(0.5)")
        h("Epop[2] netConn_projEE_ampa[218] = new NetCon(&v(0.5), syn_projEE_ampa[218], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 219: cell 2, seg 0 (0.5) [0.5 on Epop[2]] -> cell 59, seg 0 (0.5) [0.5 on Epop[59]], weight: 4.1363508E-4, delay 1.5
        h("Epop[59] syn_projEE_ampa[219] = new ampa(0.5)")
        h("Epop[2] netConn_projEE_ampa[219] = new NetCon(&v(0.5), syn_projEE_ampa[219], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 220: cell 2, seg 0 (0.5) [0.5 on Epop[2]] -> cell 60, seg 0 (0.5) [0.5 on Epop[60]], weight: 4.1363508E-4, delay 1.5
        h("Epop[60] syn_projEE_ampa[220] = new ampa(0.5)")
        h("Epop[2] netConn_projEE_ampa[220] = new NetCon(&v(0.5), syn_projEE_ampa[220], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 221: cell 2, seg 0 (0.5) [0.5 on Epop[2]] -> cell 61, seg 0 (0.5) [0.5 on Epop[61]], weight: 4.1363508E-4, delay 1.5
        h("Epop[61] syn_projEE_ampa[221] = new ampa(0.5)")
        h("Epop[2] netConn_projEE_ampa[221] = new NetCon(&v(0.5), syn_projEE_ampa[221], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 222: cell 2, seg 0 (0.5) [0.5 on Epop[2]] -> cell 62, seg 0 (0.5) [0.5 on Epop[62]], weight: 4.1363508E-4, delay 1.5
        h("Epop[62] syn_projEE_ampa[222] = new ampa(0.5)")
        h("Epop[2] netConn_projEE_ampa[222] = new NetCon(&v(0.5), syn_projEE_ampa[222], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 223: cell 2, seg 0 (0.5) [0.5 on Epop[2]] -> cell 63, seg 0 (0.5) [0.5 on Epop[63]], weight: 4.1363508E-4, delay 1.5
        h("Epop[63] syn_projEE_ampa[223] = new ampa(0.5)")
        h("Epop[2] netConn_projEE_ampa[223] = new NetCon(&v(0.5), syn_projEE_ampa[223], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 224: cell 2, seg 0 (0.5) [0.5 on Epop[2]] -> cell 64, seg 0 (0.5) [0.5 on Epop[64]], weight: 4.1363508E-4, delay 1.5
        h("Epop[64] syn_projEE_ampa[224] = new ampa(0.5)")
        h("Epop[2] netConn_projEE_ampa[224] = new NetCon(&v(0.5), syn_projEE_ampa[224], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 225: cell 2, seg 0 (0.5) [0.5 on Epop[2]] -> cell 65, seg 0 (0.5) [0.5 on Epop[65]], weight: 4.1363508E-4, delay 1.5
        h("Epop[65] syn_projEE_ampa[225] = new ampa(0.5)")
        h("Epop[2] netConn_projEE_ampa[225] = new NetCon(&v(0.5), syn_projEE_ampa[225], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 226: cell 2, seg 0 (0.5) [0.5 on Epop[2]] -> cell 66, seg 0 (0.5) [0.5 on Epop[66]], weight: 4.1363508E-4, delay 1.5
        h("Epop[66] syn_projEE_ampa[226] = new ampa(0.5)")
        h("Epop[2] netConn_projEE_ampa[226] = new NetCon(&v(0.5), syn_projEE_ampa[226], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 227: cell 2, seg 0 (0.5) [0.5 on Epop[2]] -> cell 67, seg 0 (0.5) [0.5 on Epop[67]], weight: 4.1363508E-4, delay 1.5
        h("Epop[67] syn_projEE_ampa[227] = new ampa(0.5)")
        h("Epop[2] netConn_projEE_ampa[227] = new NetCon(&v(0.5), syn_projEE_ampa[227], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 228: cell 2, seg 0 (0.5) [0.5 on Epop[2]] -> cell 68, seg 0 (0.5) [0.5 on Epop[68]], weight: 4.1363508E-4, delay 1.5
        h("Epop[68] syn_projEE_ampa[228] = new ampa(0.5)")
        h("Epop[2] netConn_projEE_ampa[228] = new NetCon(&v(0.5), syn_projEE_ampa[228], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 229: cell 2, seg 0 (0.5) [0.5 on Epop[2]] -> cell 69, seg 0 (0.5) [0.5 on Epop[69]], weight: 4.1363508E-4, delay 1.5
        h("Epop[69] syn_projEE_ampa[229] = new ampa(0.5)")
        h("Epop[2] netConn_projEE_ampa[229] = new NetCon(&v(0.5), syn_projEE_ampa[229], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 230: cell 2, seg 0 (0.5) [0.5 on Epop[2]] -> cell 70, seg 0 (0.5) [0.5 on Epop[70]], weight: 4.1363508E-4, delay 1.5
        h("Epop[70] syn_projEE_ampa[230] = new ampa(0.5)")
        h("Epop[2] netConn_projEE_ampa[230] = new NetCon(&v(0.5), syn_projEE_ampa[230], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 231: cell 2, seg 0 (0.5) [0.5 on Epop[2]] -> cell 71, seg 0 (0.5) [0.5 on Epop[71]], weight: 4.1363508E-4, delay 1.5
        h("Epop[71] syn_projEE_ampa[231] = new ampa(0.5)")
        h("Epop[2] netConn_projEE_ampa[231] = new NetCon(&v(0.5), syn_projEE_ampa[231], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 232: cell 2, seg 0 (0.5) [0.5 on Epop[2]] -> cell 72, seg 0 (0.5) [0.5 on Epop[72]], weight: 4.1363508E-4, delay 1.5
        h("Epop[72] syn_projEE_ampa[232] = new ampa(0.5)")
        h("Epop[2] netConn_projEE_ampa[232] = new NetCon(&v(0.5), syn_projEE_ampa[232], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 233: cell 2, seg 0 (0.5) [0.5 on Epop[2]] -> cell 73, seg 0 (0.5) [0.5 on Epop[73]], weight: 4.1363508E-4, delay 1.5
        h("Epop[73] syn_projEE_ampa[233] = new ampa(0.5)")
        h("Epop[2] netConn_projEE_ampa[233] = new NetCon(&v(0.5), syn_projEE_ampa[233], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 234: cell 2, seg 0 (0.5) [0.5 on Epop[2]] -> cell 74, seg 0 (0.5) [0.5 on Epop[74]], weight: 4.1363508E-4, delay 1.5
        h("Epop[74] syn_projEE_ampa[234] = new ampa(0.5)")
        h("Epop[2] netConn_projEE_ampa[234] = new NetCon(&v(0.5), syn_projEE_ampa[234], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 235: cell 2, seg 0 (0.5) [0.5 on Epop[2]] -> cell 75, seg 0 (0.5) [0.5 on Epop[75]], weight: 4.1363508E-4, delay 1.5
        h("Epop[75] syn_projEE_ampa[235] = new ampa(0.5)")
        h("Epop[2] netConn_projEE_ampa[235] = new NetCon(&v(0.5), syn_projEE_ampa[235], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 236: cell 2, seg 0 (0.5) [0.5 on Epop[2]] -> cell 76, seg 0 (0.5) [0.5 on Epop[76]], weight: 4.1363508E-4, delay 1.5
        h("Epop[76] syn_projEE_ampa[236] = new ampa(0.5)")
        h("Epop[2] netConn_projEE_ampa[236] = new NetCon(&v(0.5), syn_projEE_ampa[236], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 237: cell 2, seg 0 (0.5) [0.5 on Epop[2]] -> cell 77, seg 0 (0.5) [0.5 on Epop[77]], weight: 4.1363508E-4, delay 1.5
        h("Epop[77] syn_projEE_ampa[237] = new ampa(0.5)")
        h("Epop[2] netConn_projEE_ampa[237] = new NetCon(&v(0.5), syn_projEE_ampa[237], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 238: cell 2, seg 0 (0.5) [0.5 on Epop[2]] -> cell 78, seg 0 (0.5) [0.5 on Epop[78]], weight: 4.1363508E-4, delay 1.5
        h("Epop[78] syn_projEE_ampa[238] = new ampa(0.5)")
        h("Epop[2] netConn_projEE_ampa[238] = new NetCon(&v(0.5), syn_projEE_ampa[238], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 239: cell 2, seg 0 (0.5) [0.5 on Epop[2]] -> cell 79, seg 0 (0.5) [0.5 on Epop[79]], weight: 4.1363508E-4, delay 1.5
        h("Epop[79] syn_projEE_ampa[239] = new ampa(0.5)")
        h("Epop[2] netConn_projEE_ampa[239] = new NetCon(&v(0.5), syn_projEE_ampa[239], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 240: cell 3, seg 0 (0.5) [0.5 on Epop[3]] -> cell 0, seg 0 (0.5) [0.5 on Epop[0]], weight: 4.1363508E-4, delay 1.5
        h("Epop[0] syn_projEE_ampa[240] = new ampa(0.5)")
        h("Epop[3] netConn_projEE_ampa[240] = new NetCon(&v(0.5), syn_projEE_ampa[240], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 241: cell 3, seg 0 (0.5) [0.5 on Epop[3]] -> cell 1, seg 0 (0.5) [0.5 on Epop[1]], weight: 4.1363508E-4, delay 1.5
        h("Epop[1] syn_projEE_ampa[241] = new ampa(0.5)")
        h("Epop[3] netConn_projEE_ampa[241] = new NetCon(&v(0.5), syn_projEE_ampa[241], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 242: cell 3, seg 0 (0.5) [0.5 on Epop[3]] -> cell 2, seg 0 (0.5) [0.5 on Epop[2]], weight: 4.1363508E-4, delay 1.5
        h("Epop[2] syn_projEE_ampa[242] = new ampa(0.5)")
        h("Epop[3] netConn_projEE_ampa[242] = new NetCon(&v(0.5), syn_projEE_ampa[242], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 243: cell 3, seg 0 (0.5) [0.5 on Epop[3]] -> cell 3, seg 0 (0.5) [0.5 on Epop[3]], weight: 4.1363508E-4, delay 1.5
        h("Epop[3] syn_projEE_ampa[243] = new ampa(0.5)")
        h("Epop[3] netConn_projEE_ampa[243] = new NetCon(&v(0.5), syn_projEE_ampa[243], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 244: cell 3, seg 0 (0.5) [0.5 on Epop[3]] -> cell 4, seg 0 (0.5) [0.5 on Epop[4]], weight: 4.1363508E-4, delay 1.5
        h("Epop[4] syn_projEE_ampa[244] = new ampa(0.5)")
        h("Epop[3] netConn_projEE_ampa[244] = new NetCon(&v(0.5), syn_projEE_ampa[244], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 245: cell 3, seg 0 (0.5) [0.5 on Epop[3]] -> cell 5, seg 0 (0.5) [0.5 on Epop[5]], weight: 4.1363508E-4, delay 1.5
        h("Epop[5] syn_projEE_ampa[245] = new ampa(0.5)")
        h("Epop[3] netConn_projEE_ampa[245] = new NetCon(&v(0.5), syn_projEE_ampa[245], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 246: cell 3, seg 0 (0.5) [0.5 on Epop[3]] -> cell 6, seg 0 (0.5) [0.5 on Epop[6]], weight: 4.1363508E-4, delay 1.5
        h("Epop[6] syn_projEE_ampa[246] = new ampa(0.5)")
        h("Epop[3] netConn_projEE_ampa[246] = new NetCon(&v(0.5), syn_projEE_ampa[246], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 247: cell 3, seg 0 (0.5) [0.5 on Epop[3]] -> cell 7, seg 0 (0.5) [0.5 on Epop[7]], weight: 4.1363508E-4, delay 1.5
        h("Epop[7] syn_projEE_ampa[247] = new ampa(0.5)")
        h("Epop[3] netConn_projEE_ampa[247] = new NetCon(&v(0.5), syn_projEE_ampa[247], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 248: cell 3, seg 0 (0.5) [0.5 on Epop[3]] -> cell 8, seg 0 (0.5) [0.5 on Epop[8]], weight: 4.1363508E-4, delay 1.5
        h("Epop[8] syn_projEE_ampa[248] = new ampa(0.5)")
        h("Epop[3] netConn_projEE_ampa[248] = new NetCon(&v(0.5), syn_projEE_ampa[248], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 249: cell 3, seg 0 (0.5) [0.5 on Epop[3]] -> cell 9, seg 0 (0.5) [0.5 on Epop[9]], weight: 4.1363508E-4, delay 1.5
        h("Epop[9] syn_projEE_ampa[249] = new ampa(0.5)")
        h("Epop[3] netConn_projEE_ampa[249] = new NetCon(&v(0.5), syn_projEE_ampa[249], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 250: cell 3, seg 0 (0.5) [0.5 on Epop[3]] -> cell 10, seg 0 (0.5) [0.5 on Epop[10]], weight: 4.1363508E-4, delay 1.5
        h("Epop[10] syn_projEE_ampa[250] = new ampa(0.5)")
        h("Epop[3] netConn_projEE_ampa[250] = new NetCon(&v(0.5), syn_projEE_ampa[250], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 251: cell 3, seg 0 (0.5) [0.5 on Epop[3]] -> cell 11, seg 0 (0.5) [0.5 on Epop[11]], weight: 4.1363508E-4, delay 1.5
        h("Epop[11] syn_projEE_ampa[251] = new ampa(0.5)")
        h("Epop[3] netConn_projEE_ampa[251] = new NetCon(&v(0.5), syn_projEE_ampa[251], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 252: cell 3, seg 0 (0.5) [0.5 on Epop[3]] -> cell 12, seg 0 (0.5) [0.5 on Epop[12]], weight: 4.1363508E-4, delay 1.5
        h("Epop[12] syn_projEE_ampa[252] = new ampa(0.5)")
        h("Epop[3] netConn_projEE_ampa[252] = new NetCon(&v(0.5), syn_projEE_ampa[252], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 253: cell 3, seg 0 (0.5) [0.5 on Epop[3]] -> cell 13, seg 0 (0.5) [0.5 on Epop[13]], weight: 4.1363508E-4, delay 1.5
        h("Epop[13] syn_projEE_ampa[253] = new ampa(0.5)")
        h("Epop[3] netConn_projEE_ampa[253] = new NetCon(&v(0.5), syn_projEE_ampa[253], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 254: cell 3, seg 0 (0.5) [0.5 on Epop[3]] -> cell 14, seg 0 (0.5) [0.5 on Epop[14]], weight: 4.1363508E-4, delay 1.5
        h("Epop[14] syn_projEE_ampa[254] = new ampa(0.5)")
        h("Epop[3] netConn_projEE_ampa[254] = new NetCon(&v(0.5), syn_projEE_ampa[254], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 255: cell 3, seg 0 (0.5) [0.5 on Epop[3]] -> cell 15, seg 0 (0.5) [0.5 on Epop[15]], weight: 4.1363508E-4, delay 1.5
        h("Epop[15] syn_projEE_ampa[255] = new ampa(0.5)")
        h("Epop[3] netConn_projEE_ampa[255] = new NetCon(&v(0.5), syn_projEE_ampa[255], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 256: cell 3, seg 0 (0.5) [0.5 on Epop[3]] -> cell 16, seg 0 (0.5) [0.5 on Epop[16]], weight: 4.1363508E-4, delay 1.5
        h("Epop[16] syn_projEE_ampa[256] = new ampa(0.5)")
        h("Epop[3] netConn_projEE_ampa[256] = new NetCon(&v(0.5), syn_projEE_ampa[256], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 257: cell 3, seg 0 (0.5) [0.5 on Epop[3]] -> cell 17, seg 0 (0.5) [0.5 on Epop[17]], weight: 4.1363508E-4, delay 1.5
        h("Epop[17] syn_projEE_ampa[257] = new ampa(0.5)")
        h("Epop[3] netConn_projEE_ampa[257] = new NetCon(&v(0.5), syn_projEE_ampa[257], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 258: cell 3, seg 0 (0.5) [0.5 on Epop[3]] -> cell 18, seg 0 (0.5) [0.5 on Epop[18]], weight: 4.1363508E-4, delay 1.5
        h("Epop[18] syn_projEE_ampa[258] = new ampa(0.5)")
        h("Epop[3] netConn_projEE_ampa[258] = new NetCon(&v(0.5), syn_projEE_ampa[258], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 259: cell 3, seg 0 (0.5) [0.5 on Epop[3]] -> cell 19, seg 0 (0.5) [0.5 on Epop[19]], weight: 4.1363508E-4, delay 1.5
        h("Epop[19] syn_projEE_ampa[259] = new ampa(0.5)")
        h("Epop[3] netConn_projEE_ampa[259] = new NetCon(&v(0.5), syn_projEE_ampa[259], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 260: cell 3, seg 0 (0.5) [0.5 on Epop[3]] -> cell 20, seg 0 (0.5) [0.5 on Epop[20]], weight: 4.1363508E-4, delay 1.5
        h("Epop[20] syn_projEE_ampa[260] = new ampa(0.5)")
        h("Epop[3] netConn_projEE_ampa[260] = new NetCon(&v(0.5), syn_projEE_ampa[260], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 261: cell 3, seg 0 (0.5) [0.5 on Epop[3]] -> cell 21, seg 0 (0.5) [0.5 on Epop[21]], weight: 4.1363508E-4, delay 1.5
        h("Epop[21] syn_projEE_ampa[261] = new ampa(0.5)")
        h("Epop[3] netConn_projEE_ampa[261] = new NetCon(&v(0.5), syn_projEE_ampa[261], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 262: cell 3, seg 0 (0.5) [0.5 on Epop[3]] -> cell 22, seg 0 (0.5) [0.5 on Epop[22]], weight: 4.1363508E-4, delay 1.5
        h("Epop[22] syn_projEE_ampa[262] = new ampa(0.5)")
        h("Epop[3] netConn_projEE_ampa[262] = new NetCon(&v(0.5), syn_projEE_ampa[262], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 263: cell 3, seg 0 (0.5) [0.5 on Epop[3]] -> cell 23, seg 0 (0.5) [0.5 on Epop[23]], weight: 4.1363508E-4, delay 1.5
        h("Epop[23] syn_projEE_ampa[263] = new ampa(0.5)")
        h("Epop[3] netConn_projEE_ampa[263] = new NetCon(&v(0.5), syn_projEE_ampa[263], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 264: cell 3, seg 0 (0.5) [0.5 on Epop[3]] -> cell 24, seg 0 (0.5) [0.5 on Epop[24]], weight: 4.1363508E-4, delay 1.5
        h("Epop[24] syn_projEE_ampa[264] = new ampa(0.5)")
        h("Epop[3] netConn_projEE_ampa[264] = new NetCon(&v(0.5), syn_projEE_ampa[264], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 265: cell 3, seg 0 (0.5) [0.5 on Epop[3]] -> cell 25, seg 0 (0.5) [0.5 on Epop[25]], weight: 4.1363508E-4, delay 1.5
        h("Epop[25] syn_projEE_ampa[265] = new ampa(0.5)")
        h("Epop[3] netConn_projEE_ampa[265] = new NetCon(&v(0.5), syn_projEE_ampa[265], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 266: cell 3, seg 0 (0.5) [0.5 on Epop[3]] -> cell 26, seg 0 (0.5) [0.5 on Epop[26]], weight: 4.1363508E-4, delay 1.5
        h("Epop[26] syn_projEE_ampa[266] = new ampa(0.5)")
        h("Epop[3] netConn_projEE_ampa[266] = new NetCon(&v(0.5), syn_projEE_ampa[266], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 267: cell 3, seg 0 (0.5) [0.5 on Epop[3]] -> cell 27, seg 0 (0.5) [0.5 on Epop[27]], weight: 4.1363508E-4, delay 1.5
        h("Epop[27] syn_projEE_ampa[267] = new ampa(0.5)")
        h("Epop[3] netConn_projEE_ampa[267] = new NetCon(&v(0.5), syn_projEE_ampa[267], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 268: cell 3, seg 0 (0.5) [0.5 on Epop[3]] -> cell 28, seg 0 (0.5) [0.5 on Epop[28]], weight: 4.1363508E-4, delay 1.5
        h("Epop[28] syn_projEE_ampa[268] = new ampa(0.5)")
        h("Epop[3] netConn_projEE_ampa[268] = new NetCon(&v(0.5), syn_projEE_ampa[268], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 269: cell 3, seg 0 (0.5) [0.5 on Epop[3]] -> cell 29, seg 0 (0.5) [0.5 on Epop[29]], weight: 4.1363508E-4, delay 1.5
        h("Epop[29] syn_projEE_ampa[269] = new ampa(0.5)")
        h("Epop[3] netConn_projEE_ampa[269] = new NetCon(&v(0.5), syn_projEE_ampa[269], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 270: cell 3, seg 0 (0.5) [0.5 on Epop[3]] -> cell 30, seg 0 (0.5) [0.5 on Epop[30]], weight: 4.1363508E-4, delay 1.5
        h("Epop[30] syn_projEE_ampa[270] = new ampa(0.5)")
        h("Epop[3] netConn_projEE_ampa[270] = new NetCon(&v(0.5), syn_projEE_ampa[270], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 271: cell 3, seg 0 (0.5) [0.5 on Epop[3]] -> cell 31, seg 0 (0.5) [0.5 on Epop[31]], weight: 4.1363508E-4, delay 1.5
        h("Epop[31] syn_projEE_ampa[271] = new ampa(0.5)")
        h("Epop[3] netConn_projEE_ampa[271] = new NetCon(&v(0.5), syn_projEE_ampa[271], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 272: cell 3, seg 0 (0.5) [0.5 on Epop[3]] -> cell 32, seg 0 (0.5) [0.5 on Epop[32]], weight: 4.1363508E-4, delay 1.5
        h("Epop[32] syn_projEE_ampa[272] = new ampa(0.5)")
        h("Epop[3] netConn_projEE_ampa[272] = new NetCon(&v(0.5), syn_projEE_ampa[272], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 273: cell 3, seg 0 (0.5) [0.5 on Epop[3]] -> cell 33, seg 0 (0.5) [0.5 on Epop[33]], weight: 4.1363508E-4, delay 1.5
        h("Epop[33] syn_projEE_ampa[273] = new ampa(0.5)")
        h("Epop[3] netConn_projEE_ampa[273] = new NetCon(&v(0.5), syn_projEE_ampa[273], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 274: cell 3, seg 0 (0.5) [0.5 on Epop[3]] -> cell 34, seg 0 (0.5) [0.5 on Epop[34]], weight: 4.1363508E-4, delay 1.5
        h("Epop[34] syn_projEE_ampa[274] = new ampa(0.5)")
        h("Epop[3] netConn_projEE_ampa[274] = new NetCon(&v(0.5), syn_projEE_ampa[274], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 275: cell 3, seg 0 (0.5) [0.5 on Epop[3]] -> cell 35, seg 0 (0.5) [0.5 on Epop[35]], weight: 4.1363508E-4, delay 1.5
        h("Epop[35] syn_projEE_ampa[275] = new ampa(0.5)")
        h("Epop[3] netConn_projEE_ampa[275] = new NetCon(&v(0.5), syn_projEE_ampa[275], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 276: cell 3, seg 0 (0.5) [0.5 on Epop[3]] -> cell 36, seg 0 (0.5) [0.5 on Epop[36]], weight: 4.1363508E-4, delay 1.5
        h("Epop[36] syn_projEE_ampa[276] = new ampa(0.5)")
        h("Epop[3] netConn_projEE_ampa[276] = new NetCon(&v(0.5), syn_projEE_ampa[276], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 277: cell 3, seg 0 (0.5) [0.5 on Epop[3]] -> cell 37, seg 0 (0.5) [0.5 on Epop[37]], weight: 4.1363508E-4, delay 1.5
        h("Epop[37] syn_projEE_ampa[277] = new ampa(0.5)")
        h("Epop[3] netConn_projEE_ampa[277] = new NetCon(&v(0.5), syn_projEE_ampa[277], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 278: cell 3, seg 0 (0.5) [0.5 on Epop[3]] -> cell 38, seg 0 (0.5) [0.5 on Epop[38]], weight: 4.1363508E-4, delay 1.5
        h("Epop[38] syn_projEE_ampa[278] = new ampa(0.5)")
        h("Epop[3] netConn_projEE_ampa[278] = new NetCon(&v(0.5), syn_projEE_ampa[278], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 279: cell 3, seg 0 (0.5) [0.5 on Epop[3]] -> cell 39, seg 0 (0.5) [0.5 on Epop[39]], weight: 4.1363508E-4, delay 1.5
        h("Epop[39] syn_projEE_ampa[279] = new ampa(0.5)")
        h("Epop[3] netConn_projEE_ampa[279] = new NetCon(&v(0.5), syn_projEE_ampa[279], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 280: cell 3, seg 0 (0.5) [0.5 on Epop[3]] -> cell 40, seg 0 (0.5) [0.5 on Epop[40]], weight: 4.1363508E-4, delay 1.5
        h("Epop[40] syn_projEE_ampa[280] = new ampa(0.5)")
        h("Epop[3] netConn_projEE_ampa[280] = new NetCon(&v(0.5), syn_projEE_ampa[280], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 281: cell 3, seg 0 (0.5) [0.5 on Epop[3]] -> cell 41, seg 0 (0.5) [0.5 on Epop[41]], weight: 4.1363508E-4, delay 1.5
        h("Epop[41] syn_projEE_ampa[281] = new ampa(0.5)")
        h("Epop[3] netConn_projEE_ampa[281] = new NetCon(&v(0.5), syn_projEE_ampa[281], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 282: cell 3, seg 0 (0.5) [0.5 on Epop[3]] -> cell 42, seg 0 (0.5) [0.5 on Epop[42]], weight: 4.1363508E-4, delay 1.5
        h("Epop[42] syn_projEE_ampa[282] = new ampa(0.5)")
        h("Epop[3] netConn_projEE_ampa[282] = new NetCon(&v(0.5), syn_projEE_ampa[282], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 283: cell 3, seg 0 (0.5) [0.5 on Epop[3]] -> cell 43, seg 0 (0.5) [0.5 on Epop[43]], weight: 4.1363508E-4, delay 1.5
        h("Epop[43] syn_projEE_ampa[283] = new ampa(0.5)")
        h("Epop[3] netConn_projEE_ampa[283] = new NetCon(&v(0.5), syn_projEE_ampa[283], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 284: cell 3, seg 0 (0.5) [0.5 on Epop[3]] -> cell 44, seg 0 (0.5) [0.5 on Epop[44]], weight: 4.1363508E-4, delay 1.5
        h("Epop[44] syn_projEE_ampa[284] = new ampa(0.5)")
        h("Epop[3] netConn_projEE_ampa[284] = new NetCon(&v(0.5), syn_projEE_ampa[284], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 285: cell 3, seg 0 (0.5) [0.5 on Epop[3]] -> cell 45, seg 0 (0.5) [0.5 on Epop[45]], weight: 4.1363508E-4, delay 1.5
        h("Epop[45] syn_projEE_ampa[285] = new ampa(0.5)")
        h("Epop[3] netConn_projEE_ampa[285] = new NetCon(&v(0.5), syn_projEE_ampa[285], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 286: cell 3, seg 0 (0.5) [0.5 on Epop[3]] -> cell 46, seg 0 (0.5) [0.5 on Epop[46]], weight: 4.1363508E-4, delay 1.5
        h("Epop[46] syn_projEE_ampa[286] = new ampa(0.5)")
        h("Epop[3] netConn_projEE_ampa[286] = new NetCon(&v(0.5), syn_projEE_ampa[286], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 287: cell 3, seg 0 (0.5) [0.5 on Epop[3]] -> cell 47, seg 0 (0.5) [0.5 on Epop[47]], weight: 4.1363508E-4, delay 1.5
        h("Epop[47] syn_projEE_ampa[287] = new ampa(0.5)")
        h("Epop[3] netConn_projEE_ampa[287] = new NetCon(&v(0.5), syn_projEE_ampa[287], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 288: cell 3, seg 0 (0.5) [0.5 on Epop[3]] -> cell 48, seg 0 (0.5) [0.5 on Epop[48]], weight: 4.1363508E-4, delay 1.5
        h("Epop[48] syn_projEE_ampa[288] = new ampa(0.5)")
        h("Epop[3] netConn_projEE_ampa[288] = new NetCon(&v(0.5), syn_projEE_ampa[288], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 289: cell 3, seg 0 (0.5) [0.5 on Epop[3]] -> cell 49, seg 0 (0.5) [0.5 on Epop[49]], weight: 4.1363508E-4, delay 1.5
        h("Epop[49] syn_projEE_ampa[289] = new ampa(0.5)")
        h("Epop[3] netConn_projEE_ampa[289] = new NetCon(&v(0.5), syn_projEE_ampa[289], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 290: cell 3, seg 0 (0.5) [0.5 on Epop[3]] -> cell 50, seg 0 (0.5) [0.5 on Epop[50]], weight: 4.1363508E-4, delay 1.5
        h("Epop[50] syn_projEE_ampa[290] = new ampa(0.5)")
        h("Epop[3] netConn_projEE_ampa[290] = new NetCon(&v(0.5), syn_projEE_ampa[290], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 291: cell 3, seg 0 (0.5) [0.5 on Epop[3]] -> cell 51, seg 0 (0.5) [0.5 on Epop[51]], weight: 4.1363508E-4, delay 1.5
        h("Epop[51] syn_projEE_ampa[291] = new ampa(0.5)")
        h("Epop[3] netConn_projEE_ampa[291] = new NetCon(&v(0.5), syn_projEE_ampa[291], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 292: cell 3, seg 0 (0.5) [0.5 on Epop[3]] -> cell 52, seg 0 (0.5) [0.5 on Epop[52]], weight: 4.1363508E-4, delay 1.5
        h("Epop[52] syn_projEE_ampa[292] = new ampa(0.5)")
        h("Epop[3] netConn_projEE_ampa[292] = new NetCon(&v(0.5), syn_projEE_ampa[292], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 293: cell 3, seg 0 (0.5) [0.5 on Epop[3]] -> cell 53, seg 0 (0.5) [0.5 on Epop[53]], weight: 4.1363508E-4, delay 1.5
        h("Epop[53] syn_projEE_ampa[293] = new ampa(0.5)")
        h("Epop[3] netConn_projEE_ampa[293] = new NetCon(&v(0.5), syn_projEE_ampa[293], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 294: cell 3, seg 0 (0.5) [0.5 on Epop[3]] -> cell 54, seg 0 (0.5) [0.5 on Epop[54]], weight: 4.1363508E-4, delay 1.5
        h("Epop[54] syn_projEE_ampa[294] = new ampa(0.5)")
        h("Epop[3] netConn_projEE_ampa[294] = new NetCon(&v(0.5), syn_projEE_ampa[294], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 295: cell 3, seg 0 (0.5) [0.5 on Epop[3]] -> cell 55, seg 0 (0.5) [0.5 on Epop[55]], weight: 4.1363508E-4, delay 1.5
        h("Epop[55] syn_projEE_ampa[295] = new ampa(0.5)")
        h("Epop[3] netConn_projEE_ampa[295] = new NetCon(&v(0.5), syn_projEE_ampa[295], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 296: cell 3, seg 0 (0.5) [0.5 on Epop[3]] -> cell 56, seg 0 (0.5) [0.5 on Epop[56]], weight: 4.1363508E-4, delay 1.5
        h("Epop[56] syn_projEE_ampa[296] = new ampa(0.5)")
        h("Epop[3] netConn_projEE_ampa[296] = new NetCon(&v(0.5), syn_projEE_ampa[296], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 297: cell 3, seg 0 (0.5) [0.5 on Epop[3]] -> cell 57, seg 0 (0.5) [0.5 on Epop[57]], weight: 4.1363508E-4, delay 1.5
        h("Epop[57] syn_projEE_ampa[297] = new ampa(0.5)")
        h("Epop[3] netConn_projEE_ampa[297] = new NetCon(&v(0.5), syn_projEE_ampa[297], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 298: cell 3, seg 0 (0.5) [0.5 on Epop[3]] -> cell 58, seg 0 (0.5) [0.5 on Epop[58]], weight: 4.1363508E-4, delay 1.5
        h("Epop[58] syn_projEE_ampa[298] = new ampa(0.5)")
        h("Epop[3] netConn_projEE_ampa[298] = new NetCon(&v(0.5), syn_projEE_ampa[298], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 299: cell 3, seg 0 (0.5) [0.5 on Epop[3]] -> cell 59, seg 0 (0.5) [0.5 on Epop[59]], weight: 4.1363508E-4, delay 1.5
        h("Epop[59] syn_projEE_ampa[299] = new ampa(0.5)")
        h("Epop[3] netConn_projEE_ampa[299] = new NetCon(&v(0.5), syn_projEE_ampa[299], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 300: cell 3, seg 0 (0.5) [0.5 on Epop[3]] -> cell 60, seg 0 (0.5) [0.5 on Epop[60]], weight: 4.1363508E-4, delay 1.5
        h("Epop[60] syn_projEE_ampa[300] = new ampa(0.5)")
        h("Epop[3] netConn_projEE_ampa[300] = new NetCon(&v(0.5), syn_projEE_ampa[300], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 301: cell 3, seg 0 (0.5) [0.5 on Epop[3]] -> cell 61, seg 0 (0.5) [0.5 on Epop[61]], weight: 4.1363508E-4, delay 1.5
        h("Epop[61] syn_projEE_ampa[301] = new ampa(0.5)")
        h("Epop[3] netConn_projEE_ampa[301] = new NetCon(&v(0.5), syn_projEE_ampa[301], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 302: cell 3, seg 0 (0.5) [0.5 on Epop[3]] -> cell 62, seg 0 (0.5) [0.5 on Epop[62]], weight: 4.1363508E-4, delay 1.5
        h("Epop[62] syn_projEE_ampa[302] = new ampa(0.5)")
        h("Epop[3] netConn_projEE_ampa[302] = new NetCon(&v(0.5), syn_projEE_ampa[302], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 303: cell 3, seg 0 (0.5) [0.5 on Epop[3]] -> cell 63, seg 0 (0.5) [0.5 on Epop[63]], weight: 4.1363508E-4, delay 1.5
        h("Epop[63] syn_projEE_ampa[303] = new ampa(0.5)")
        h("Epop[3] netConn_projEE_ampa[303] = new NetCon(&v(0.5), syn_projEE_ampa[303], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 304: cell 3, seg 0 (0.5) [0.5 on Epop[3]] -> cell 64, seg 0 (0.5) [0.5 on Epop[64]], weight: 4.1363508E-4, delay 1.5
        h("Epop[64] syn_projEE_ampa[304] = new ampa(0.5)")
        h("Epop[3] netConn_projEE_ampa[304] = new NetCon(&v(0.5), syn_projEE_ampa[304], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 305: cell 3, seg 0 (0.5) [0.5 on Epop[3]] -> cell 65, seg 0 (0.5) [0.5 on Epop[65]], weight: 4.1363508E-4, delay 1.5
        h("Epop[65] syn_projEE_ampa[305] = new ampa(0.5)")
        h("Epop[3] netConn_projEE_ampa[305] = new NetCon(&v(0.5), syn_projEE_ampa[305], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 306: cell 3, seg 0 (0.5) [0.5 on Epop[3]] -> cell 66, seg 0 (0.5) [0.5 on Epop[66]], weight: 4.1363508E-4, delay 1.5
        h("Epop[66] syn_projEE_ampa[306] = new ampa(0.5)")
        h("Epop[3] netConn_projEE_ampa[306] = new NetCon(&v(0.5), syn_projEE_ampa[306], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 307: cell 3, seg 0 (0.5) [0.5 on Epop[3]] -> cell 67, seg 0 (0.5) [0.5 on Epop[67]], weight: 4.1363508E-4, delay 1.5
        h("Epop[67] syn_projEE_ampa[307] = new ampa(0.5)")
        h("Epop[3] netConn_projEE_ampa[307] = new NetCon(&v(0.5), syn_projEE_ampa[307], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 308: cell 3, seg 0 (0.5) [0.5 on Epop[3]] -> cell 68, seg 0 (0.5) [0.5 on Epop[68]], weight: 4.1363508E-4, delay 1.5
        h("Epop[68] syn_projEE_ampa[308] = new ampa(0.5)")
        h("Epop[3] netConn_projEE_ampa[308] = new NetCon(&v(0.5), syn_projEE_ampa[308], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 309: cell 3, seg 0 (0.5) [0.5 on Epop[3]] -> cell 69, seg 0 (0.5) [0.5 on Epop[69]], weight: 4.1363508E-4, delay 1.5
        h("Epop[69] syn_projEE_ampa[309] = new ampa(0.5)")
        h("Epop[3] netConn_projEE_ampa[309] = new NetCon(&v(0.5), syn_projEE_ampa[309], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 310: cell 3, seg 0 (0.5) [0.5 on Epop[3]] -> cell 70, seg 0 (0.5) [0.5 on Epop[70]], weight: 4.1363508E-4, delay 1.5
        h("Epop[70] syn_projEE_ampa[310] = new ampa(0.5)")
        h("Epop[3] netConn_projEE_ampa[310] = new NetCon(&v(0.5), syn_projEE_ampa[310], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 311: cell 3, seg 0 (0.5) [0.5 on Epop[3]] -> cell 71, seg 0 (0.5) [0.5 on Epop[71]], weight: 4.1363508E-4, delay 1.5
        h("Epop[71] syn_projEE_ampa[311] = new ampa(0.5)")
        h("Epop[3] netConn_projEE_ampa[311] = new NetCon(&v(0.5), syn_projEE_ampa[311], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 312: cell 3, seg 0 (0.5) [0.5 on Epop[3]] -> cell 72, seg 0 (0.5) [0.5 on Epop[72]], weight: 4.1363508E-4, delay 1.5
        h("Epop[72] syn_projEE_ampa[312] = new ampa(0.5)")
        h("Epop[3] netConn_projEE_ampa[312] = new NetCon(&v(0.5), syn_projEE_ampa[312], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 313: cell 3, seg 0 (0.5) [0.5 on Epop[3]] -> cell 73, seg 0 (0.5) [0.5 on Epop[73]], weight: 4.1363508E-4, delay 1.5
        h("Epop[73] syn_projEE_ampa[313] = new ampa(0.5)")
        h("Epop[3] netConn_projEE_ampa[313] = new NetCon(&v(0.5), syn_projEE_ampa[313], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 314: cell 3, seg 0 (0.5) [0.5 on Epop[3]] -> cell 74, seg 0 (0.5) [0.5 on Epop[74]], weight: 4.1363508E-4, delay 1.5
        h("Epop[74] syn_projEE_ampa[314] = new ampa(0.5)")
        h("Epop[3] netConn_projEE_ampa[314] = new NetCon(&v(0.5), syn_projEE_ampa[314], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 315: cell 3, seg 0 (0.5) [0.5 on Epop[3]] -> cell 75, seg 0 (0.5) [0.5 on Epop[75]], weight: 4.1363508E-4, delay 1.5
        h("Epop[75] syn_projEE_ampa[315] = new ampa(0.5)")
        h("Epop[3] netConn_projEE_ampa[315] = new NetCon(&v(0.5), syn_projEE_ampa[315], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 316: cell 3, seg 0 (0.5) [0.5 on Epop[3]] -> cell 76, seg 0 (0.5) [0.5 on Epop[76]], weight: 4.1363508E-4, delay 1.5
        h("Epop[76] syn_projEE_ampa[316] = new ampa(0.5)")
        h("Epop[3] netConn_projEE_ampa[316] = new NetCon(&v(0.5), syn_projEE_ampa[316], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 317: cell 3, seg 0 (0.5) [0.5 on Epop[3]] -> cell 77, seg 0 (0.5) [0.5 on Epop[77]], weight: 4.1363508E-4, delay 1.5
        h("Epop[77] syn_projEE_ampa[317] = new ampa(0.5)")
        h("Epop[3] netConn_projEE_ampa[317] = new NetCon(&v(0.5), syn_projEE_ampa[317], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 318: cell 3, seg 0 (0.5) [0.5 on Epop[3]] -> cell 78, seg 0 (0.5) [0.5 on Epop[78]], weight: 4.1363508E-4, delay 1.5
        h("Epop[78] syn_projEE_ampa[318] = new ampa(0.5)")
        h("Epop[3] netConn_projEE_ampa[318] = new NetCon(&v(0.5), syn_projEE_ampa[318], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 319: cell 3, seg 0 (0.5) [0.5 on Epop[3]] -> cell 79, seg 0 (0.5) [0.5 on Epop[79]], weight: 4.1363508E-4, delay 1.5
        h("Epop[79] syn_projEE_ampa[319] = new ampa(0.5)")
        h("Epop[3] netConn_projEE_ampa[319] = new NetCon(&v(0.5), syn_projEE_ampa[319], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 320: cell 4, seg 0 (0.5) [0.5 on Epop[4]] -> cell 0, seg 0 (0.5) [0.5 on Epop[0]], weight: 4.1363508E-4, delay 1.5
        h("Epop[0] syn_projEE_ampa[320] = new ampa(0.5)")
        h("Epop[4] netConn_projEE_ampa[320] = new NetCon(&v(0.5), syn_projEE_ampa[320], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 321: cell 4, seg 0 (0.5) [0.5 on Epop[4]] -> cell 1, seg 0 (0.5) [0.5 on Epop[1]], weight: 4.1363508E-4, delay 1.5
        h("Epop[1] syn_projEE_ampa[321] = new ampa(0.5)")
        h("Epop[4] netConn_projEE_ampa[321] = new NetCon(&v(0.5), syn_projEE_ampa[321], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 322: cell 4, seg 0 (0.5) [0.5 on Epop[4]] -> cell 2, seg 0 (0.5) [0.5 on Epop[2]], weight: 4.1363508E-4, delay 1.5
        h("Epop[2] syn_projEE_ampa[322] = new ampa(0.5)")
        h("Epop[4] netConn_projEE_ampa[322] = new NetCon(&v(0.5), syn_projEE_ampa[322], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 323: cell 4, seg 0 (0.5) [0.5 on Epop[4]] -> cell 3, seg 0 (0.5) [0.5 on Epop[3]], weight: 4.1363508E-4, delay 1.5
        h("Epop[3] syn_projEE_ampa[323] = new ampa(0.5)")
        h("Epop[4] netConn_projEE_ampa[323] = new NetCon(&v(0.5), syn_projEE_ampa[323], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 324: cell 4, seg 0 (0.5) [0.5 on Epop[4]] -> cell 4, seg 0 (0.5) [0.5 on Epop[4]], weight: 4.1363508E-4, delay 1.5
        h("Epop[4] syn_projEE_ampa[324] = new ampa(0.5)")
        h("Epop[4] netConn_projEE_ampa[324] = new NetCon(&v(0.5), syn_projEE_ampa[324], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 325: cell 4, seg 0 (0.5) [0.5 on Epop[4]] -> cell 5, seg 0 (0.5) [0.5 on Epop[5]], weight: 4.1363508E-4, delay 1.5
        h("Epop[5] syn_projEE_ampa[325] = new ampa(0.5)")
        h("Epop[4] netConn_projEE_ampa[325] = new NetCon(&v(0.5), syn_projEE_ampa[325], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 326: cell 4, seg 0 (0.5) [0.5 on Epop[4]] -> cell 6, seg 0 (0.5) [0.5 on Epop[6]], weight: 4.1363508E-4, delay 1.5
        h("Epop[6] syn_projEE_ampa[326] = new ampa(0.5)")
        h("Epop[4] netConn_projEE_ampa[326] = new NetCon(&v(0.5), syn_projEE_ampa[326], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 327: cell 4, seg 0 (0.5) [0.5 on Epop[4]] -> cell 7, seg 0 (0.5) [0.5 on Epop[7]], weight: 4.1363508E-4, delay 1.5
        h("Epop[7] syn_projEE_ampa[327] = new ampa(0.5)")
        h("Epop[4] netConn_projEE_ampa[327] = new NetCon(&v(0.5), syn_projEE_ampa[327], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 328: cell 4, seg 0 (0.5) [0.5 on Epop[4]] -> cell 8, seg 0 (0.5) [0.5 on Epop[8]], weight: 4.1363508E-4, delay 1.5
        h("Epop[8] syn_projEE_ampa[328] = new ampa(0.5)")
        h("Epop[4] netConn_projEE_ampa[328] = new NetCon(&v(0.5), syn_projEE_ampa[328], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 329: cell 4, seg 0 (0.5) [0.5 on Epop[4]] -> cell 9, seg 0 (0.5) [0.5 on Epop[9]], weight: 4.1363508E-4, delay 1.5
        h("Epop[9] syn_projEE_ampa[329] = new ampa(0.5)")
        h("Epop[4] netConn_projEE_ampa[329] = new NetCon(&v(0.5), syn_projEE_ampa[329], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 330: cell 4, seg 0 (0.5) [0.5 on Epop[4]] -> cell 10, seg 0 (0.5) [0.5 on Epop[10]], weight: 4.1363508E-4, delay 1.5
        h("Epop[10] syn_projEE_ampa[330] = new ampa(0.5)")
        h("Epop[4] netConn_projEE_ampa[330] = new NetCon(&v(0.5), syn_projEE_ampa[330], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 331: cell 4, seg 0 (0.5) [0.5 on Epop[4]] -> cell 11, seg 0 (0.5) [0.5 on Epop[11]], weight: 4.1363508E-4, delay 1.5
        h("Epop[11] syn_projEE_ampa[331] = new ampa(0.5)")
        h("Epop[4] netConn_projEE_ampa[331] = new NetCon(&v(0.5), syn_projEE_ampa[331], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 332: cell 4, seg 0 (0.5) [0.5 on Epop[4]] -> cell 12, seg 0 (0.5) [0.5 on Epop[12]], weight: 4.1363508E-4, delay 1.5
        h("Epop[12] syn_projEE_ampa[332] = new ampa(0.5)")
        h("Epop[4] netConn_projEE_ampa[332] = new NetCon(&v(0.5), syn_projEE_ampa[332], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 333: cell 4, seg 0 (0.5) [0.5 on Epop[4]] -> cell 13, seg 0 (0.5) [0.5 on Epop[13]], weight: 4.1363508E-4, delay 1.5
        h("Epop[13] syn_projEE_ampa[333] = new ampa(0.5)")
        h("Epop[4] netConn_projEE_ampa[333] = new NetCon(&v(0.5), syn_projEE_ampa[333], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 334: cell 4, seg 0 (0.5) [0.5 on Epop[4]] -> cell 14, seg 0 (0.5) [0.5 on Epop[14]], weight: 4.1363508E-4, delay 1.5
        h("Epop[14] syn_projEE_ampa[334] = new ampa(0.5)")
        h("Epop[4] netConn_projEE_ampa[334] = new NetCon(&v(0.5), syn_projEE_ampa[334], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 335: cell 4, seg 0 (0.5) [0.5 on Epop[4]] -> cell 15, seg 0 (0.5) [0.5 on Epop[15]], weight: 4.1363508E-4, delay 1.5
        h("Epop[15] syn_projEE_ampa[335] = new ampa(0.5)")
        h("Epop[4] netConn_projEE_ampa[335] = new NetCon(&v(0.5), syn_projEE_ampa[335], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 336: cell 4, seg 0 (0.5) [0.5 on Epop[4]] -> cell 16, seg 0 (0.5) [0.5 on Epop[16]], weight: 4.1363508E-4, delay 1.5
        h("Epop[16] syn_projEE_ampa[336] = new ampa(0.5)")
        h("Epop[4] netConn_projEE_ampa[336] = new NetCon(&v(0.5), syn_projEE_ampa[336], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 337: cell 4, seg 0 (0.5) [0.5 on Epop[4]] -> cell 17, seg 0 (0.5) [0.5 on Epop[17]], weight: 4.1363508E-4, delay 1.5
        h("Epop[17] syn_projEE_ampa[337] = new ampa(0.5)")
        h("Epop[4] netConn_projEE_ampa[337] = new NetCon(&v(0.5), syn_projEE_ampa[337], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 338: cell 4, seg 0 (0.5) [0.5 on Epop[4]] -> cell 18, seg 0 (0.5) [0.5 on Epop[18]], weight: 4.1363508E-4, delay 1.5
        h("Epop[18] syn_projEE_ampa[338] = new ampa(0.5)")
        h("Epop[4] netConn_projEE_ampa[338] = new NetCon(&v(0.5), syn_projEE_ampa[338], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 339: cell 4, seg 0 (0.5) [0.5 on Epop[4]] -> cell 19, seg 0 (0.5) [0.5 on Epop[19]], weight: 4.1363508E-4, delay 1.5
        h("Epop[19] syn_projEE_ampa[339] = new ampa(0.5)")
        h("Epop[4] netConn_projEE_ampa[339] = new NetCon(&v(0.5), syn_projEE_ampa[339], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 340: cell 4, seg 0 (0.5) [0.5 on Epop[4]] -> cell 20, seg 0 (0.5) [0.5 on Epop[20]], weight: 4.1363508E-4, delay 1.5
        h("Epop[20] syn_projEE_ampa[340] = new ampa(0.5)")
        h("Epop[4] netConn_projEE_ampa[340] = new NetCon(&v(0.5), syn_projEE_ampa[340], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 341: cell 4, seg 0 (0.5) [0.5 on Epop[4]] -> cell 21, seg 0 (0.5) [0.5 on Epop[21]], weight: 4.1363508E-4, delay 1.5
        h("Epop[21] syn_projEE_ampa[341] = new ampa(0.5)")
        h("Epop[4] netConn_projEE_ampa[341] = new NetCon(&v(0.5), syn_projEE_ampa[341], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 342: cell 4, seg 0 (0.5) [0.5 on Epop[4]] -> cell 22, seg 0 (0.5) [0.5 on Epop[22]], weight: 4.1363508E-4, delay 1.5
        h("Epop[22] syn_projEE_ampa[342] = new ampa(0.5)")
        h("Epop[4] netConn_projEE_ampa[342] = new NetCon(&v(0.5), syn_projEE_ampa[342], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 343: cell 4, seg 0 (0.5) [0.5 on Epop[4]] -> cell 23, seg 0 (0.5) [0.5 on Epop[23]], weight: 4.1363508E-4, delay 1.5
        h("Epop[23] syn_projEE_ampa[343] = new ampa(0.5)")
        h("Epop[4] netConn_projEE_ampa[343] = new NetCon(&v(0.5), syn_projEE_ampa[343], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 344: cell 4, seg 0 (0.5) [0.5 on Epop[4]] -> cell 24, seg 0 (0.5) [0.5 on Epop[24]], weight: 4.1363508E-4, delay 1.5
        h("Epop[24] syn_projEE_ampa[344] = new ampa(0.5)")
        h("Epop[4] netConn_projEE_ampa[344] = new NetCon(&v(0.5), syn_projEE_ampa[344], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 345: cell 4, seg 0 (0.5) [0.5 on Epop[4]] -> cell 25, seg 0 (0.5) [0.5 on Epop[25]], weight: 4.1363508E-4, delay 1.5
        h("Epop[25] syn_projEE_ampa[345] = new ampa(0.5)")
        h("Epop[4] netConn_projEE_ampa[345] = new NetCon(&v(0.5), syn_projEE_ampa[345], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 346: cell 4, seg 0 (0.5) [0.5 on Epop[4]] -> cell 26, seg 0 (0.5) [0.5 on Epop[26]], weight: 4.1363508E-4, delay 1.5
        h("Epop[26] syn_projEE_ampa[346] = new ampa(0.5)")
        h("Epop[4] netConn_projEE_ampa[346] = new NetCon(&v(0.5), syn_projEE_ampa[346], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 347: cell 4, seg 0 (0.5) [0.5 on Epop[4]] -> cell 27, seg 0 (0.5) [0.5 on Epop[27]], weight: 4.1363508E-4, delay 1.5
        h("Epop[27] syn_projEE_ampa[347] = new ampa(0.5)")
        h("Epop[4] netConn_projEE_ampa[347] = new NetCon(&v(0.5), syn_projEE_ampa[347], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 348: cell 4, seg 0 (0.5) [0.5 on Epop[4]] -> cell 28, seg 0 (0.5) [0.5 on Epop[28]], weight: 4.1363508E-4, delay 1.5
        h("Epop[28] syn_projEE_ampa[348] = new ampa(0.5)")
        h("Epop[4] netConn_projEE_ampa[348] = new NetCon(&v(0.5), syn_projEE_ampa[348], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 349: cell 4, seg 0 (0.5) [0.5 on Epop[4]] -> cell 29, seg 0 (0.5) [0.5 on Epop[29]], weight: 4.1363508E-4, delay 1.5
        h("Epop[29] syn_projEE_ampa[349] = new ampa(0.5)")
        h("Epop[4] netConn_projEE_ampa[349] = new NetCon(&v(0.5), syn_projEE_ampa[349], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 350: cell 4, seg 0 (0.5) [0.5 on Epop[4]] -> cell 30, seg 0 (0.5) [0.5 on Epop[30]], weight: 4.1363508E-4, delay 1.5
        h("Epop[30] syn_projEE_ampa[350] = new ampa(0.5)")
        h("Epop[4] netConn_projEE_ampa[350] = new NetCon(&v(0.5), syn_projEE_ampa[350], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 351: cell 4, seg 0 (0.5) [0.5 on Epop[4]] -> cell 31, seg 0 (0.5) [0.5 on Epop[31]], weight: 4.1363508E-4, delay 1.5
        h("Epop[31] syn_projEE_ampa[351] = new ampa(0.5)")
        h("Epop[4] netConn_projEE_ampa[351] = new NetCon(&v(0.5), syn_projEE_ampa[351], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 352: cell 4, seg 0 (0.5) [0.5 on Epop[4]] -> cell 32, seg 0 (0.5) [0.5 on Epop[32]], weight: 4.1363508E-4, delay 1.5
        h("Epop[32] syn_projEE_ampa[352] = new ampa(0.5)")
        h("Epop[4] netConn_projEE_ampa[352] = new NetCon(&v(0.5), syn_projEE_ampa[352], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 353: cell 4, seg 0 (0.5) [0.5 on Epop[4]] -> cell 33, seg 0 (0.5) [0.5 on Epop[33]], weight: 4.1363508E-4, delay 1.5
        h("Epop[33] syn_projEE_ampa[353] = new ampa(0.5)")
        h("Epop[4] netConn_projEE_ampa[353] = new NetCon(&v(0.5), syn_projEE_ampa[353], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 354: cell 4, seg 0 (0.5) [0.5 on Epop[4]] -> cell 34, seg 0 (0.5) [0.5 on Epop[34]], weight: 4.1363508E-4, delay 1.5
        h("Epop[34] syn_projEE_ampa[354] = new ampa(0.5)")
        h("Epop[4] netConn_projEE_ampa[354] = new NetCon(&v(0.5), syn_projEE_ampa[354], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 355: cell 4, seg 0 (0.5) [0.5 on Epop[4]] -> cell 35, seg 0 (0.5) [0.5 on Epop[35]], weight: 4.1363508E-4, delay 1.5
        h("Epop[35] syn_projEE_ampa[355] = new ampa(0.5)")
        h("Epop[4] netConn_projEE_ampa[355] = new NetCon(&v(0.5), syn_projEE_ampa[355], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 356: cell 4, seg 0 (0.5) [0.5 on Epop[4]] -> cell 36, seg 0 (0.5) [0.5 on Epop[36]], weight: 4.1363508E-4, delay 1.5
        h("Epop[36] syn_projEE_ampa[356] = new ampa(0.5)")
        h("Epop[4] netConn_projEE_ampa[356] = new NetCon(&v(0.5), syn_projEE_ampa[356], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 357: cell 4, seg 0 (0.5) [0.5 on Epop[4]] -> cell 37, seg 0 (0.5) [0.5 on Epop[37]], weight: 4.1363508E-4, delay 1.5
        h("Epop[37] syn_projEE_ampa[357] = new ampa(0.5)")
        h("Epop[4] netConn_projEE_ampa[357] = new NetCon(&v(0.5), syn_projEE_ampa[357], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 358: cell 4, seg 0 (0.5) [0.5 on Epop[4]] -> cell 38, seg 0 (0.5) [0.5 on Epop[38]], weight: 4.1363508E-4, delay 1.5
        h("Epop[38] syn_projEE_ampa[358] = new ampa(0.5)")
        h("Epop[4] netConn_projEE_ampa[358] = new NetCon(&v(0.5), syn_projEE_ampa[358], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 359: cell 4, seg 0 (0.5) [0.5 on Epop[4]] -> cell 39, seg 0 (0.5) [0.5 on Epop[39]], weight: 4.1363508E-4, delay 1.5
        h("Epop[39] syn_projEE_ampa[359] = new ampa(0.5)")
        h("Epop[4] netConn_projEE_ampa[359] = new NetCon(&v(0.5), syn_projEE_ampa[359], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 360: cell 4, seg 0 (0.5) [0.5 on Epop[4]] -> cell 40, seg 0 (0.5) [0.5 on Epop[40]], weight: 4.1363508E-4, delay 1.5
        h("Epop[40] syn_projEE_ampa[360] = new ampa(0.5)")
        h("Epop[4] netConn_projEE_ampa[360] = new NetCon(&v(0.5), syn_projEE_ampa[360], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 361: cell 4, seg 0 (0.5) [0.5 on Epop[4]] -> cell 41, seg 0 (0.5) [0.5 on Epop[41]], weight: 4.1363508E-4, delay 1.5
        h("Epop[41] syn_projEE_ampa[361] = new ampa(0.5)")
        h("Epop[4] netConn_projEE_ampa[361] = new NetCon(&v(0.5), syn_projEE_ampa[361], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 362: cell 4, seg 0 (0.5) [0.5 on Epop[4]] -> cell 42, seg 0 (0.5) [0.5 on Epop[42]], weight: 4.1363508E-4, delay 1.5
        h("Epop[42] syn_projEE_ampa[362] = new ampa(0.5)")
        h("Epop[4] netConn_projEE_ampa[362] = new NetCon(&v(0.5), syn_projEE_ampa[362], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 363: cell 4, seg 0 (0.5) [0.5 on Epop[4]] -> cell 43, seg 0 (0.5) [0.5 on Epop[43]], weight: 4.1363508E-4, delay 1.5
        h("Epop[43] syn_projEE_ampa[363] = new ampa(0.5)")
        h("Epop[4] netConn_projEE_ampa[363] = new NetCon(&v(0.5), syn_projEE_ampa[363], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 364: cell 4, seg 0 (0.5) [0.5 on Epop[4]] -> cell 44, seg 0 (0.5) [0.5 on Epop[44]], weight: 4.1363508E-4, delay 1.5
        h("Epop[44] syn_projEE_ampa[364] = new ampa(0.5)")
        h("Epop[4] netConn_projEE_ampa[364] = new NetCon(&v(0.5), syn_projEE_ampa[364], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 365: cell 4, seg 0 (0.5) [0.5 on Epop[4]] -> cell 45, seg 0 (0.5) [0.5 on Epop[45]], weight: 4.1363508E-4, delay 1.5
        h("Epop[45] syn_projEE_ampa[365] = new ampa(0.5)")
        h("Epop[4] netConn_projEE_ampa[365] = new NetCon(&v(0.5), syn_projEE_ampa[365], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 366: cell 4, seg 0 (0.5) [0.5 on Epop[4]] -> cell 46, seg 0 (0.5) [0.5 on Epop[46]], weight: 4.1363508E-4, delay 1.5
        h("Epop[46] syn_projEE_ampa[366] = new ampa(0.5)")
        h("Epop[4] netConn_projEE_ampa[366] = new NetCon(&v(0.5), syn_projEE_ampa[366], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 367: cell 4, seg 0 (0.5) [0.5 on Epop[4]] -> cell 47, seg 0 (0.5) [0.5 on Epop[47]], weight: 4.1363508E-4, delay 1.5
        h("Epop[47] syn_projEE_ampa[367] = new ampa(0.5)")
        h("Epop[4] netConn_projEE_ampa[367] = new NetCon(&v(0.5), syn_projEE_ampa[367], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 368: cell 4, seg 0 (0.5) [0.5 on Epop[4]] -> cell 48, seg 0 (0.5) [0.5 on Epop[48]], weight: 4.1363508E-4, delay 1.5
        h("Epop[48] syn_projEE_ampa[368] = new ampa(0.5)")
        h("Epop[4] netConn_projEE_ampa[368] = new NetCon(&v(0.5), syn_projEE_ampa[368], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 369: cell 4, seg 0 (0.5) [0.5 on Epop[4]] -> cell 49, seg 0 (0.5) [0.5 on Epop[49]], weight: 4.1363508E-4, delay 1.5
        h("Epop[49] syn_projEE_ampa[369] = new ampa(0.5)")
        h("Epop[4] netConn_projEE_ampa[369] = new NetCon(&v(0.5), syn_projEE_ampa[369], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 370: cell 4, seg 0 (0.5) [0.5 on Epop[4]] -> cell 50, seg 0 (0.5) [0.5 on Epop[50]], weight: 4.1363508E-4, delay 1.5
        h("Epop[50] syn_projEE_ampa[370] = new ampa(0.5)")
        h("Epop[4] netConn_projEE_ampa[370] = new NetCon(&v(0.5), syn_projEE_ampa[370], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 371: cell 4, seg 0 (0.5) [0.5 on Epop[4]] -> cell 51, seg 0 (0.5) [0.5 on Epop[51]], weight: 4.1363508E-4, delay 1.5
        h("Epop[51] syn_projEE_ampa[371] = new ampa(0.5)")
        h("Epop[4] netConn_projEE_ampa[371] = new NetCon(&v(0.5), syn_projEE_ampa[371], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 372: cell 4, seg 0 (0.5) [0.5 on Epop[4]] -> cell 52, seg 0 (0.5) [0.5 on Epop[52]], weight: 4.1363508E-4, delay 1.5
        h("Epop[52] syn_projEE_ampa[372] = new ampa(0.5)")
        h("Epop[4] netConn_projEE_ampa[372] = new NetCon(&v(0.5), syn_projEE_ampa[372], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 373: cell 4, seg 0 (0.5) [0.5 on Epop[4]] -> cell 53, seg 0 (0.5) [0.5 on Epop[53]], weight: 4.1363508E-4, delay 1.5
        h("Epop[53] syn_projEE_ampa[373] = new ampa(0.5)")
        h("Epop[4] netConn_projEE_ampa[373] = new NetCon(&v(0.5), syn_projEE_ampa[373], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 374: cell 4, seg 0 (0.5) [0.5 on Epop[4]] -> cell 54, seg 0 (0.5) [0.5 on Epop[54]], weight: 4.1363508E-4, delay 1.5
        h("Epop[54] syn_projEE_ampa[374] = new ampa(0.5)")
        h("Epop[4] netConn_projEE_ampa[374] = new NetCon(&v(0.5), syn_projEE_ampa[374], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 375: cell 4, seg 0 (0.5) [0.5 on Epop[4]] -> cell 55, seg 0 (0.5) [0.5 on Epop[55]], weight: 4.1363508E-4, delay 1.5
        h("Epop[55] syn_projEE_ampa[375] = new ampa(0.5)")
        h("Epop[4] netConn_projEE_ampa[375] = new NetCon(&v(0.5), syn_projEE_ampa[375], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 376: cell 4, seg 0 (0.5) [0.5 on Epop[4]] -> cell 56, seg 0 (0.5) [0.5 on Epop[56]], weight: 4.1363508E-4, delay 1.5
        h("Epop[56] syn_projEE_ampa[376] = new ampa(0.5)")
        h("Epop[4] netConn_projEE_ampa[376] = new NetCon(&v(0.5), syn_projEE_ampa[376], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 377: cell 4, seg 0 (0.5) [0.5 on Epop[4]] -> cell 57, seg 0 (0.5) [0.5 on Epop[57]], weight: 4.1363508E-4, delay 1.5
        h("Epop[57] syn_projEE_ampa[377] = new ampa(0.5)")
        h("Epop[4] netConn_projEE_ampa[377] = new NetCon(&v(0.5), syn_projEE_ampa[377], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 378: cell 4, seg 0 (0.5) [0.5 on Epop[4]] -> cell 58, seg 0 (0.5) [0.5 on Epop[58]], weight: 4.1363508E-4, delay 1.5
        h("Epop[58] syn_projEE_ampa[378] = new ampa(0.5)")
        h("Epop[4] netConn_projEE_ampa[378] = new NetCon(&v(0.5), syn_projEE_ampa[378], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 379: cell 4, seg 0 (0.5) [0.5 on Epop[4]] -> cell 59, seg 0 (0.5) [0.5 on Epop[59]], weight: 4.1363508E-4, delay 1.5
        h("Epop[59] syn_projEE_ampa[379] = new ampa(0.5)")
        h("Epop[4] netConn_projEE_ampa[379] = new NetCon(&v(0.5), syn_projEE_ampa[379], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 380: cell 4, seg 0 (0.5) [0.5 on Epop[4]] -> cell 60, seg 0 (0.5) [0.5 on Epop[60]], weight: 4.1363508E-4, delay 1.5
        h("Epop[60] syn_projEE_ampa[380] = new ampa(0.5)")
        h("Epop[4] netConn_projEE_ampa[380] = new NetCon(&v(0.5), syn_projEE_ampa[380], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 381: cell 4, seg 0 (0.5) [0.5 on Epop[4]] -> cell 61, seg 0 (0.5) [0.5 on Epop[61]], weight: 4.1363508E-4, delay 1.5
        h("Epop[61] syn_projEE_ampa[381] = new ampa(0.5)")
        h("Epop[4] netConn_projEE_ampa[381] = new NetCon(&v(0.5), syn_projEE_ampa[381], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 382: cell 4, seg 0 (0.5) [0.5 on Epop[4]] -> cell 62, seg 0 (0.5) [0.5 on Epop[62]], weight: 4.1363508E-4, delay 1.5
        h("Epop[62] syn_projEE_ampa[382] = new ampa(0.5)")
        h("Epop[4] netConn_projEE_ampa[382] = new NetCon(&v(0.5), syn_projEE_ampa[382], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 383: cell 4, seg 0 (0.5) [0.5 on Epop[4]] -> cell 63, seg 0 (0.5) [0.5 on Epop[63]], weight: 4.1363508E-4, delay 1.5
        h("Epop[63] syn_projEE_ampa[383] = new ampa(0.5)")
        h("Epop[4] netConn_projEE_ampa[383] = new NetCon(&v(0.5), syn_projEE_ampa[383], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 384: cell 4, seg 0 (0.5) [0.5 on Epop[4]] -> cell 64, seg 0 (0.5) [0.5 on Epop[64]], weight: 4.1363508E-4, delay 1.5
        h("Epop[64] syn_projEE_ampa[384] = new ampa(0.5)")
        h("Epop[4] netConn_projEE_ampa[384] = new NetCon(&v(0.5), syn_projEE_ampa[384], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 385: cell 4, seg 0 (0.5) [0.5 on Epop[4]] -> cell 65, seg 0 (0.5) [0.5 on Epop[65]], weight: 4.1363508E-4, delay 1.5
        h("Epop[65] syn_projEE_ampa[385] = new ampa(0.5)")
        h("Epop[4] netConn_projEE_ampa[385] = new NetCon(&v(0.5), syn_projEE_ampa[385], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 386: cell 4, seg 0 (0.5) [0.5 on Epop[4]] -> cell 66, seg 0 (0.5) [0.5 on Epop[66]], weight: 4.1363508E-4, delay 1.5
        h("Epop[66] syn_projEE_ampa[386] = new ampa(0.5)")
        h("Epop[4] netConn_projEE_ampa[386] = new NetCon(&v(0.5), syn_projEE_ampa[386], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 387: cell 4, seg 0 (0.5) [0.5 on Epop[4]] -> cell 67, seg 0 (0.5) [0.5 on Epop[67]], weight: 4.1363508E-4, delay 1.5
        h("Epop[67] syn_projEE_ampa[387] = new ampa(0.5)")
        h("Epop[4] netConn_projEE_ampa[387] = new NetCon(&v(0.5), syn_projEE_ampa[387], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 388: cell 4, seg 0 (0.5) [0.5 on Epop[4]] -> cell 68, seg 0 (0.5) [0.5 on Epop[68]], weight: 4.1363508E-4, delay 1.5
        h("Epop[68] syn_projEE_ampa[388] = new ampa(0.5)")
        h("Epop[4] netConn_projEE_ampa[388] = new NetCon(&v(0.5), syn_projEE_ampa[388], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 389: cell 4, seg 0 (0.5) [0.5 on Epop[4]] -> cell 69, seg 0 (0.5) [0.5 on Epop[69]], weight: 4.1363508E-4, delay 1.5
        h("Epop[69] syn_projEE_ampa[389] = new ampa(0.5)")
        h("Epop[4] netConn_projEE_ampa[389] = new NetCon(&v(0.5), syn_projEE_ampa[389], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 390: cell 4, seg 0 (0.5) [0.5 on Epop[4]] -> cell 70, seg 0 (0.5) [0.5 on Epop[70]], weight: 4.1363508E-4, delay 1.5
        h("Epop[70] syn_projEE_ampa[390] = new ampa(0.5)")
        h("Epop[4] netConn_projEE_ampa[390] = new NetCon(&v(0.5), syn_projEE_ampa[390], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 391: cell 4, seg 0 (0.5) [0.5 on Epop[4]] -> cell 71, seg 0 (0.5) [0.5 on Epop[71]], weight: 4.1363508E-4, delay 1.5
        h("Epop[71] syn_projEE_ampa[391] = new ampa(0.5)")
        h("Epop[4] netConn_projEE_ampa[391] = new NetCon(&v(0.5), syn_projEE_ampa[391], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 392: cell 4, seg 0 (0.5) [0.5 on Epop[4]] -> cell 72, seg 0 (0.5) [0.5 on Epop[72]], weight: 4.1363508E-4, delay 1.5
        h("Epop[72] syn_projEE_ampa[392] = new ampa(0.5)")
        h("Epop[4] netConn_projEE_ampa[392] = new NetCon(&v(0.5), syn_projEE_ampa[392], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 393: cell 4, seg 0 (0.5) [0.5 on Epop[4]] -> cell 73, seg 0 (0.5) [0.5 on Epop[73]], weight: 4.1363508E-4, delay 1.5
        h("Epop[73] syn_projEE_ampa[393] = new ampa(0.5)")
        h("Epop[4] netConn_projEE_ampa[393] = new NetCon(&v(0.5), syn_projEE_ampa[393], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 394: cell 4, seg 0 (0.5) [0.5 on Epop[4]] -> cell 74, seg 0 (0.5) [0.5 on Epop[74]], weight: 4.1363508E-4, delay 1.5
        h("Epop[74] syn_projEE_ampa[394] = new ampa(0.5)")
        h("Epop[4] netConn_projEE_ampa[394] = new NetCon(&v(0.5), syn_projEE_ampa[394], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 395: cell 4, seg 0 (0.5) [0.5 on Epop[4]] -> cell 75, seg 0 (0.5) [0.5 on Epop[75]], weight: 4.1363508E-4, delay 1.5
        h("Epop[75] syn_projEE_ampa[395] = new ampa(0.5)")
        h("Epop[4] netConn_projEE_ampa[395] = new NetCon(&v(0.5), syn_projEE_ampa[395], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 396: cell 4, seg 0 (0.5) [0.5 on Epop[4]] -> cell 76, seg 0 (0.5) [0.5 on Epop[76]], weight: 4.1363508E-4, delay 1.5
        h("Epop[76] syn_projEE_ampa[396] = new ampa(0.5)")
        h("Epop[4] netConn_projEE_ampa[396] = new NetCon(&v(0.5), syn_projEE_ampa[396], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 397: cell 4, seg 0 (0.5) [0.5 on Epop[4]] -> cell 77, seg 0 (0.5) [0.5 on Epop[77]], weight: 4.1363508E-4, delay 1.5
        h("Epop[77] syn_projEE_ampa[397] = new ampa(0.5)")
        h("Epop[4] netConn_projEE_ampa[397] = new NetCon(&v(0.5), syn_projEE_ampa[397], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 398: cell 4, seg 0 (0.5) [0.5 on Epop[4]] -> cell 78, seg 0 (0.5) [0.5 on Epop[78]], weight: 4.1363508E-4, delay 1.5
        h("Epop[78] syn_projEE_ampa[398] = new ampa(0.5)")
        h("Epop[4] netConn_projEE_ampa[398] = new NetCon(&v(0.5), syn_projEE_ampa[398], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 399: cell 4, seg 0 (0.5) [0.5 on Epop[4]] -> cell 79, seg 0 (0.5) [0.5 on Epop[79]], weight: 4.1363508E-4, delay 1.5
        h("Epop[79] syn_projEE_ampa[399] = new ampa(0.5)")
        h("Epop[4] netConn_projEE_ampa[399] = new NetCon(&v(0.5), syn_projEE_ampa[399], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 400: cell 5, seg 0 (0.5) [0.5 on Epop[5]] -> cell 0, seg 0 (0.5) [0.5 on Epop[0]], weight: 4.1363508E-4, delay 1.5
        h("Epop[0] syn_projEE_ampa[400] = new ampa(0.5)")
        h("Epop[5] netConn_projEE_ampa[400] = new NetCon(&v(0.5), syn_projEE_ampa[400], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 401: cell 5, seg 0 (0.5) [0.5 on Epop[5]] -> cell 1, seg 0 (0.5) [0.5 on Epop[1]], weight: 4.1363508E-4, delay 1.5
        h("Epop[1] syn_projEE_ampa[401] = new ampa(0.5)")
        h("Epop[5] netConn_projEE_ampa[401] = new NetCon(&v(0.5), syn_projEE_ampa[401], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 402: cell 5, seg 0 (0.5) [0.5 on Epop[5]] -> cell 2, seg 0 (0.5) [0.5 on Epop[2]], weight: 4.1363508E-4, delay 1.5
        h("Epop[2] syn_projEE_ampa[402] = new ampa(0.5)")
        h("Epop[5] netConn_projEE_ampa[402] = new NetCon(&v(0.5), syn_projEE_ampa[402], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 403: cell 5, seg 0 (0.5) [0.5 on Epop[5]] -> cell 3, seg 0 (0.5) [0.5 on Epop[3]], weight: 4.1363508E-4, delay 1.5
        h("Epop[3] syn_projEE_ampa[403] = new ampa(0.5)")
        h("Epop[5] netConn_projEE_ampa[403] = new NetCon(&v(0.5), syn_projEE_ampa[403], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 404: cell 5, seg 0 (0.5) [0.5 on Epop[5]] -> cell 4, seg 0 (0.5) [0.5 on Epop[4]], weight: 4.1363508E-4, delay 1.5
        h("Epop[4] syn_projEE_ampa[404] = new ampa(0.5)")
        h("Epop[5] netConn_projEE_ampa[404] = new NetCon(&v(0.5), syn_projEE_ampa[404], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 405: cell 5, seg 0 (0.5) [0.5 on Epop[5]] -> cell 5, seg 0 (0.5) [0.5 on Epop[5]], weight: 4.1363508E-4, delay 1.5
        h("Epop[5] syn_projEE_ampa[405] = new ampa(0.5)")
        h("Epop[5] netConn_projEE_ampa[405] = new NetCon(&v(0.5), syn_projEE_ampa[405], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 406: cell 5, seg 0 (0.5) [0.5 on Epop[5]] -> cell 6, seg 0 (0.5) [0.5 on Epop[6]], weight: 4.1363508E-4, delay 1.5
        h("Epop[6] syn_projEE_ampa[406] = new ampa(0.5)")
        h("Epop[5] netConn_projEE_ampa[406] = new NetCon(&v(0.5), syn_projEE_ampa[406], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 407: cell 5, seg 0 (0.5) [0.5 on Epop[5]] -> cell 7, seg 0 (0.5) [0.5 on Epop[7]], weight: 4.1363508E-4, delay 1.5
        h("Epop[7] syn_projEE_ampa[407] = new ampa(0.5)")
        h("Epop[5] netConn_projEE_ampa[407] = new NetCon(&v(0.5), syn_projEE_ampa[407], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 408: cell 5, seg 0 (0.5) [0.5 on Epop[5]] -> cell 8, seg 0 (0.5) [0.5 on Epop[8]], weight: 4.1363508E-4, delay 1.5
        h("Epop[8] syn_projEE_ampa[408] = new ampa(0.5)")
        h("Epop[5] netConn_projEE_ampa[408] = new NetCon(&v(0.5), syn_projEE_ampa[408], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 409: cell 5, seg 0 (0.5) [0.5 on Epop[5]] -> cell 9, seg 0 (0.5) [0.5 on Epop[9]], weight: 4.1363508E-4, delay 1.5
        h("Epop[9] syn_projEE_ampa[409] = new ampa(0.5)")
        h("Epop[5] netConn_projEE_ampa[409] = new NetCon(&v(0.5), syn_projEE_ampa[409], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 410: cell 5, seg 0 (0.5) [0.5 on Epop[5]] -> cell 10, seg 0 (0.5) [0.5 on Epop[10]], weight: 4.1363508E-4, delay 1.5
        h("Epop[10] syn_projEE_ampa[410] = new ampa(0.5)")
        h("Epop[5] netConn_projEE_ampa[410] = new NetCon(&v(0.5), syn_projEE_ampa[410], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 411: cell 5, seg 0 (0.5) [0.5 on Epop[5]] -> cell 11, seg 0 (0.5) [0.5 on Epop[11]], weight: 4.1363508E-4, delay 1.5
        h("Epop[11] syn_projEE_ampa[411] = new ampa(0.5)")
        h("Epop[5] netConn_projEE_ampa[411] = new NetCon(&v(0.5), syn_projEE_ampa[411], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 412: cell 5, seg 0 (0.5) [0.5 on Epop[5]] -> cell 12, seg 0 (0.5) [0.5 on Epop[12]], weight: 4.1363508E-4, delay 1.5
        h("Epop[12] syn_projEE_ampa[412] = new ampa(0.5)")
        h("Epop[5] netConn_projEE_ampa[412] = new NetCon(&v(0.5), syn_projEE_ampa[412], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 413: cell 5, seg 0 (0.5) [0.5 on Epop[5]] -> cell 13, seg 0 (0.5) [0.5 on Epop[13]], weight: 4.1363508E-4, delay 1.5
        h("Epop[13] syn_projEE_ampa[413] = new ampa(0.5)")
        h("Epop[5] netConn_projEE_ampa[413] = new NetCon(&v(0.5), syn_projEE_ampa[413], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 414: cell 5, seg 0 (0.5) [0.5 on Epop[5]] -> cell 14, seg 0 (0.5) [0.5 on Epop[14]], weight: 4.1363508E-4, delay 1.5
        h("Epop[14] syn_projEE_ampa[414] = new ampa(0.5)")
        h("Epop[5] netConn_projEE_ampa[414] = new NetCon(&v(0.5), syn_projEE_ampa[414], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 415: cell 5, seg 0 (0.5) [0.5 on Epop[5]] -> cell 15, seg 0 (0.5) [0.5 on Epop[15]], weight: 4.1363508E-4, delay 1.5
        h("Epop[15] syn_projEE_ampa[415] = new ampa(0.5)")
        h("Epop[5] netConn_projEE_ampa[415] = new NetCon(&v(0.5), syn_projEE_ampa[415], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 416: cell 5, seg 0 (0.5) [0.5 on Epop[5]] -> cell 16, seg 0 (0.5) [0.5 on Epop[16]], weight: 4.1363508E-4, delay 1.5
        h("Epop[16] syn_projEE_ampa[416] = new ampa(0.5)")
        h("Epop[5] netConn_projEE_ampa[416] = new NetCon(&v(0.5), syn_projEE_ampa[416], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 417: cell 5, seg 0 (0.5) [0.5 on Epop[5]] -> cell 17, seg 0 (0.5) [0.5 on Epop[17]], weight: 4.1363508E-4, delay 1.5
        h("Epop[17] syn_projEE_ampa[417] = new ampa(0.5)")
        h("Epop[5] netConn_projEE_ampa[417] = new NetCon(&v(0.5), syn_projEE_ampa[417], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 418: cell 5, seg 0 (0.5) [0.5 on Epop[5]] -> cell 18, seg 0 (0.5) [0.5 on Epop[18]], weight: 4.1363508E-4, delay 1.5
        h("Epop[18] syn_projEE_ampa[418] = new ampa(0.5)")
        h("Epop[5] netConn_projEE_ampa[418] = new NetCon(&v(0.5), syn_projEE_ampa[418], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 419: cell 5, seg 0 (0.5) [0.5 on Epop[5]] -> cell 19, seg 0 (0.5) [0.5 on Epop[19]], weight: 4.1363508E-4, delay 1.5
        h("Epop[19] syn_projEE_ampa[419] = new ampa(0.5)")
        h("Epop[5] netConn_projEE_ampa[419] = new NetCon(&v(0.5), syn_projEE_ampa[419], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 420: cell 5, seg 0 (0.5) [0.5 on Epop[5]] -> cell 20, seg 0 (0.5) [0.5 on Epop[20]], weight: 4.1363508E-4, delay 1.5
        h("Epop[20] syn_projEE_ampa[420] = new ampa(0.5)")
        h("Epop[5] netConn_projEE_ampa[420] = new NetCon(&v(0.5), syn_projEE_ampa[420], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 421: cell 5, seg 0 (0.5) [0.5 on Epop[5]] -> cell 21, seg 0 (0.5) [0.5 on Epop[21]], weight: 4.1363508E-4, delay 1.5
        h("Epop[21] syn_projEE_ampa[421] = new ampa(0.5)")
        h("Epop[5] netConn_projEE_ampa[421] = new NetCon(&v(0.5), syn_projEE_ampa[421], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 422: cell 5, seg 0 (0.5) [0.5 on Epop[5]] -> cell 22, seg 0 (0.5) [0.5 on Epop[22]], weight: 4.1363508E-4, delay 1.5
        h("Epop[22] syn_projEE_ampa[422] = new ampa(0.5)")
        h("Epop[5] netConn_projEE_ampa[422] = new NetCon(&v(0.5), syn_projEE_ampa[422], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 423: cell 5, seg 0 (0.5) [0.5 on Epop[5]] -> cell 23, seg 0 (0.5) [0.5 on Epop[23]], weight: 4.1363508E-4, delay 1.5
        h("Epop[23] syn_projEE_ampa[423] = new ampa(0.5)")
        h("Epop[5] netConn_projEE_ampa[423] = new NetCon(&v(0.5), syn_projEE_ampa[423], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 424: cell 5, seg 0 (0.5) [0.5 on Epop[5]] -> cell 24, seg 0 (0.5) [0.5 on Epop[24]], weight: 4.1363508E-4, delay 1.5
        h("Epop[24] syn_projEE_ampa[424] = new ampa(0.5)")
        h("Epop[5] netConn_projEE_ampa[424] = new NetCon(&v(0.5), syn_projEE_ampa[424], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 425: cell 5, seg 0 (0.5) [0.5 on Epop[5]] -> cell 25, seg 0 (0.5) [0.5 on Epop[25]], weight: 4.1363508E-4, delay 1.5
        h("Epop[25] syn_projEE_ampa[425] = new ampa(0.5)")
        h("Epop[5] netConn_projEE_ampa[425] = new NetCon(&v(0.5), syn_projEE_ampa[425], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 426: cell 5, seg 0 (0.5) [0.5 on Epop[5]] -> cell 26, seg 0 (0.5) [0.5 on Epop[26]], weight: 4.1363508E-4, delay 1.5
        h("Epop[26] syn_projEE_ampa[426] = new ampa(0.5)")
        h("Epop[5] netConn_projEE_ampa[426] = new NetCon(&v(0.5), syn_projEE_ampa[426], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 427: cell 5, seg 0 (0.5) [0.5 on Epop[5]] -> cell 27, seg 0 (0.5) [0.5 on Epop[27]], weight: 4.1363508E-4, delay 1.5
        h("Epop[27] syn_projEE_ampa[427] = new ampa(0.5)")
        h("Epop[5] netConn_projEE_ampa[427] = new NetCon(&v(0.5), syn_projEE_ampa[427], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 428: cell 5, seg 0 (0.5) [0.5 on Epop[5]] -> cell 28, seg 0 (0.5) [0.5 on Epop[28]], weight: 4.1363508E-4, delay 1.5
        h("Epop[28] syn_projEE_ampa[428] = new ampa(0.5)")
        h("Epop[5] netConn_projEE_ampa[428] = new NetCon(&v(0.5), syn_projEE_ampa[428], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 429: cell 5, seg 0 (0.5) [0.5 on Epop[5]] -> cell 29, seg 0 (0.5) [0.5 on Epop[29]], weight: 4.1363508E-4, delay 1.5
        h("Epop[29] syn_projEE_ampa[429] = new ampa(0.5)")
        h("Epop[5] netConn_projEE_ampa[429] = new NetCon(&v(0.5), syn_projEE_ampa[429], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 430: cell 5, seg 0 (0.5) [0.5 on Epop[5]] -> cell 30, seg 0 (0.5) [0.5 on Epop[30]], weight: 4.1363508E-4, delay 1.5
        h("Epop[30] syn_projEE_ampa[430] = new ampa(0.5)")
        h("Epop[5] netConn_projEE_ampa[430] = new NetCon(&v(0.5), syn_projEE_ampa[430], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 431: cell 5, seg 0 (0.5) [0.5 on Epop[5]] -> cell 31, seg 0 (0.5) [0.5 on Epop[31]], weight: 4.1363508E-4, delay 1.5
        h("Epop[31] syn_projEE_ampa[431] = new ampa(0.5)")
        h("Epop[5] netConn_projEE_ampa[431] = new NetCon(&v(0.5), syn_projEE_ampa[431], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 432: cell 5, seg 0 (0.5) [0.5 on Epop[5]] -> cell 32, seg 0 (0.5) [0.5 on Epop[32]], weight: 4.1363508E-4, delay 1.5
        h("Epop[32] syn_projEE_ampa[432] = new ampa(0.5)")
        h("Epop[5] netConn_projEE_ampa[432] = new NetCon(&v(0.5), syn_projEE_ampa[432], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 433: cell 5, seg 0 (0.5) [0.5 on Epop[5]] -> cell 33, seg 0 (0.5) [0.5 on Epop[33]], weight: 4.1363508E-4, delay 1.5
        h("Epop[33] syn_projEE_ampa[433] = new ampa(0.5)")
        h("Epop[5] netConn_projEE_ampa[433] = new NetCon(&v(0.5), syn_projEE_ampa[433], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 434: cell 5, seg 0 (0.5) [0.5 on Epop[5]] -> cell 34, seg 0 (0.5) [0.5 on Epop[34]], weight: 4.1363508E-4, delay 1.5
        h("Epop[34] syn_projEE_ampa[434] = new ampa(0.5)")
        h("Epop[5] netConn_projEE_ampa[434] = new NetCon(&v(0.5), syn_projEE_ampa[434], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 435: cell 5, seg 0 (0.5) [0.5 on Epop[5]] -> cell 35, seg 0 (0.5) [0.5 on Epop[35]], weight: 4.1363508E-4, delay 1.5
        h("Epop[35] syn_projEE_ampa[435] = new ampa(0.5)")
        h("Epop[5] netConn_projEE_ampa[435] = new NetCon(&v(0.5), syn_projEE_ampa[435], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 436: cell 5, seg 0 (0.5) [0.5 on Epop[5]] -> cell 36, seg 0 (0.5) [0.5 on Epop[36]], weight: 4.1363508E-4, delay 1.5
        h("Epop[36] syn_projEE_ampa[436] = new ampa(0.5)")
        h("Epop[5] netConn_projEE_ampa[436] = new NetCon(&v(0.5), syn_projEE_ampa[436], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 437: cell 5, seg 0 (0.5) [0.5 on Epop[5]] -> cell 37, seg 0 (0.5) [0.5 on Epop[37]], weight: 4.1363508E-4, delay 1.5
        h("Epop[37] syn_projEE_ampa[437] = new ampa(0.5)")
        h("Epop[5] netConn_projEE_ampa[437] = new NetCon(&v(0.5), syn_projEE_ampa[437], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 438: cell 5, seg 0 (0.5) [0.5 on Epop[5]] -> cell 38, seg 0 (0.5) [0.5 on Epop[38]], weight: 4.1363508E-4, delay 1.5
        h("Epop[38] syn_projEE_ampa[438] = new ampa(0.5)")
        h("Epop[5] netConn_projEE_ampa[438] = new NetCon(&v(0.5), syn_projEE_ampa[438], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 439: cell 5, seg 0 (0.5) [0.5 on Epop[5]] -> cell 39, seg 0 (0.5) [0.5 on Epop[39]], weight: 4.1363508E-4, delay 1.5
        h("Epop[39] syn_projEE_ampa[439] = new ampa(0.5)")
        h("Epop[5] netConn_projEE_ampa[439] = new NetCon(&v(0.5), syn_projEE_ampa[439], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 440: cell 5, seg 0 (0.5) [0.5 on Epop[5]] -> cell 40, seg 0 (0.5) [0.5 on Epop[40]], weight: 4.1363508E-4, delay 1.5
        h("Epop[40] syn_projEE_ampa[440] = new ampa(0.5)")
        h("Epop[5] netConn_projEE_ampa[440] = new NetCon(&v(0.5), syn_projEE_ampa[440], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 441: cell 5, seg 0 (0.5) [0.5 on Epop[5]] -> cell 41, seg 0 (0.5) [0.5 on Epop[41]], weight: 4.1363508E-4, delay 1.5
        h("Epop[41] syn_projEE_ampa[441] = new ampa(0.5)")
        h("Epop[5] netConn_projEE_ampa[441] = new NetCon(&v(0.5), syn_projEE_ampa[441], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 442: cell 5, seg 0 (0.5) [0.5 on Epop[5]] -> cell 42, seg 0 (0.5) [0.5 on Epop[42]], weight: 4.1363508E-4, delay 1.5
        h("Epop[42] syn_projEE_ampa[442] = new ampa(0.5)")
        h("Epop[5] netConn_projEE_ampa[442] = new NetCon(&v(0.5), syn_projEE_ampa[442], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 443: cell 5, seg 0 (0.5) [0.5 on Epop[5]] -> cell 43, seg 0 (0.5) [0.5 on Epop[43]], weight: 4.1363508E-4, delay 1.5
        h("Epop[43] syn_projEE_ampa[443] = new ampa(0.5)")
        h("Epop[5] netConn_projEE_ampa[443] = new NetCon(&v(0.5), syn_projEE_ampa[443], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 444: cell 5, seg 0 (0.5) [0.5 on Epop[5]] -> cell 44, seg 0 (0.5) [0.5 on Epop[44]], weight: 4.1363508E-4, delay 1.5
        h("Epop[44] syn_projEE_ampa[444] = new ampa(0.5)")
        h("Epop[5] netConn_projEE_ampa[444] = new NetCon(&v(0.5), syn_projEE_ampa[444], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 445: cell 5, seg 0 (0.5) [0.5 on Epop[5]] -> cell 45, seg 0 (0.5) [0.5 on Epop[45]], weight: 4.1363508E-4, delay 1.5
        h("Epop[45] syn_projEE_ampa[445] = new ampa(0.5)")
        h("Epop[5] netConn_projEE_ampa[445] = new NetCon(&v(0.5), syn_projEE_ampa[445], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 446: cell 5, seg 0 (0.5) [0.5 on Epop[5]] -> cell 46, seg 0 (0.5) [0.5 on Epop[46]], weight: 4.1363508E-4, delay 1.5
        h("Epop[46] syn_projEE_ampa[446] = new ampa(0.5)")
        h("Epop[5] netConn_projEE_ampa[446] = new NetCon(&v(0.5), syn_projEE_ampa[446], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 447: cell 5, seg 0 (0.5) [0.5 on Epop[5]] -> cell 47, seg 0 (0.5) [0.5 on Epop[47]], weight: 4.1363508E-4, delay 1.5
        h("Epop[47] syn_projEE_ampa[447] = new ampa(0.5)")
        h("Epop[5] netConn_projEE_ampa[447] = new NetCon(&v(0.5), syn_projEE_ampa[447], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 448: cell 5, seg 0 (0.5) [0.5 on Epop[5]] -> cell 48, seg 0 (0.5) [0.5 on Epop[48]], weight: 4.1363508E-4, delay 1.5
        h("Epop[48] syn_projEE_ampa[448] = new ampa(0.5)")
        h("Epop[5] netConn_projEE_ampa[448] = new NetCon(&v(0.5), syn_projEE_ampa[448], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 449: cell 5, seg 0 (0.5) [0.5 on Epop[5]] -> cell 49, seg 0 (0.5) [0.5 on Epop[49]], weight: 4.1363508E-4, delay 1.5
        h("Epop[49] syn_projEE_ampa[449] = new ampa(0.5)")
        h("Epop[5] netConn_projEE_ampa[449] = new NetCon(&v(0.5), syn_projEE_ampa[449], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 450: cell 5, seg 0 (0.5) [0.5 on Epop[5]] -> cell 50, seg 0 (0.5) [0.5 on Epop[50]], weight: 4.1363508E-4, delay 1.5
        h("Epop[50] syn_projEE_ampa[450] = new ampa(0.5)")
        h("Epop[5] netConn_projEE_ampa[450] = new NetCon(&v(0.5), syn_projEE_ampa[450], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 451: cell 5, seg 0 (0.5) [0.5 on Epop[5]] -> cell 51, seg 0 (0.5) [0.5 on Epop[51]], weight: 4.1363508E-4, delay 1.5
        h("Epop[51] syn_projEE_ampa[451] = new ampa(0.5)")
        h("Epop[5] netConn_projEE_ampa[451] = new NetCon(&v(0.5), syn_projEE_ampa[451], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 452: cell 5, seg 0 (0.5) [0.5 on Epop[5]] -> cell 52, seg 0 (0.5) [0.5 on Epop[52]], weight: 4.1363508E-4, delay 1.5
        h("Epop[52] syn_projEE_ampa[452] = new ampa(0.5)")
        h("Epop[5] netConn_projEE_ampa[452] = new NetCon(&v(0.5), syn_projEE_ampa[452], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 453: cell 5, seg 0 (0.5) [0.5 on Epop[5]] -> cell 53, seg 0 (0.5) [0.5 on Epop[53]], weight: 4.1363508E-4, delay 1.5
        h("Epop[53] syn_projEE_ampa[453] = new ampa(0.5)")
        h("Epop[5] netConn_projEE_ampa[453] = new NetCon(&v(0.5), syn_projEE_ampa[453], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 454: cell 5, seg 0 (0.5) [0.5 on Epop[5]] -> cell 54, seg 0 (0.5) [0.5 on Epop[54]], weight: 4.1363508E-4, delay 1.5
        h("Epop[54] syn_projEE_ampa[454] = new ampa(0.5)")
        h("Epop[5] netConn_projEE_ampa[454] = new NetCon(&v(0.5), syn_projEE_ampa[454], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 455: cell 5, seg 0 (0.5) [0.5 on Epop[5]] -> cell 55, seg 0 (0.5) [0.5 on Epop[55]], weight: 4.1363508E-4, delay 1.5
        h("Epop[55] syn_projEE_ampa[455] = new ampa(0.5)")
        h("Epop[5] netConn_projEE_ampa[455] = new NetCon(&v(0.5), syn_projEE_ampa[455], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 456: cell 5, seg 0 (0.5) [0.5 on Epop[5]] -> cell 56, seg 0 (0.5) [0.5 on Epop[56]], weight: 4.1363508E-4, delay 1.5
        h("Epop[56] syn_projEE_ampa[456] = new ampa(0.5)")
        h("Epop[5] netConn_projEE_ampa[456] = new NetCon(&v(0.5), syn_projEE_ampa[456], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 457: cell 5, seg 0 (0.5) [0.5 on Epop[5]] -> cell 57, seg 0 (0.5) [0.5 on Epop[57]], weight: 4.1363508E-4, delay 1.5
        h("Epop[57] syn_projEE_ampa[457] = new ampa(0.5)")
        h("Epop[5] netConn_projEE_ampa[457] = new NetCon(&v(0.5), syn_projEE_ampa[457], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 458: cell 5, seg 0 (0.5) [0.5 on Epop[5]] -> cell 58, seg 0 (0.5) [0.5 on Epop[58]], weight: 4.1363508E-4, delay 1.5
        h("Epop[58] syn_projEE_ampa[458] = new ampa(0.5)")
        h("Epop[5] netConn_projEE_ampa[458] = new NetCon(&v(0.5), syn_projEE_ampa[458], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 459: cell 5, seg 0 (0.5) [0.5 on Epop[5]] -> cell 59, seg 0 (0.5) [0.5 on Epop[59]], weight: 4.1363508E-4, delay 1.5
        h("Epop[59] syn_projEE_ampa[459] = new ampa(0.5)")
        h("Epop[5] netConn_projEE_ampa[459] = new NetCon(&v(0.5), syn_projEE_ampa[459], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 460: cell 5, seg 0 (0.5) [0.5 on Epop[5]] -> cell 60, seg 0 (0.5) [0.5 on Epop[60]], weight: 4.1363508E-4, delay 1.5
        h("Epop[60] syn_projEE_ampa[460] = new ampa(0.5)")
        h("Epop[5] netConn_projEE_ampa[460] = new NetCon(&v(0.5), syn_projEE_ampa[460], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 461: cell 5, seg 0 (0.5) [0.5 on Epop[5]] -> cell 61, seg 0 (0.5) [0.5 on Epop[61]], weight: 4.1363508E-4, delay 1.5
        h("Epop[61] syn_projEE_ampa[461] = new ampa(0.5)")
        h("Epop[5] netConn_projEE_ampa[461] = new NetCon(&v(0.5), syn_projEE_ampa[461], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 462: cell 5, seg 0 (0.5) [0.5 on Epop[5]] -> cell 62, seg 0 (0.5) [0.5 on Epop[62]], weight: 4.1363508E-4, delay 1.5
        h("Epop[62] syn_projEE_ampa[462] = new ampa(0.5)")
        h("Epop[5] netConn_projEE_ampa[462] = new NetCon(&v(0.5), syn_projEE_ampa[462], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 463: cell 5, seg 0 (0.5) [0.5 on Epop[5]] -> cell 63, seg 0 (0.5) [0.5 on Epop[63]], weight: 4.1363508E-4, delay 1.5
        h("Epop[63] syn_projEE_ampa[463] = new ampa(0.5)")
        h("Epop[5] netConn_projEE_ampa[463] = new NetCon(&v(0.5), syn_projEE_ampa[463], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 464: cell 5, seg 0 (0.5) [0.5 on Epop[5]] -> cell 64, seg 0 (0.5) [0.5 on Epop[64]], weight: 4.1363508E-4, delay 1.5
        h("Epop[64] syn_projEE_ampa[464] = new ampa(0.5)")
        h("Epop[5] netConn_projEE_ampa[464] = new NetCon(&v(0.5), syn_projEE_ampa[464], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 465: cell 5, seg 0 (0.5) [0.5 on Epop[5]] -> cell 65, seg 0 (0.5) [0.5 on Epop[65]], weight: 4.1363508E-4, delay 1.5
        h("Epop[65] syn_projEE_ampa[465] = new ampa(0.5)")
        h("Epop[5] netConn_projEE_ampa[465] = new NetCon(&v(0.5), syn_projEE_ampa[465], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 466: cell 5, seg 0 (0.5) [0.5 on Epop[5]] -> cell 66, seg 0 (0.5) [0.5 on Epop[66]], weight: 4.1363508E-4, delay 1.5
        h("Epop[66] syn_projEE_ampa[466] = new ampa(0.5)")
        h("Epop[5] netConn_projEE_ampa[466] = new NetCon(&v(0.5), syn_projEE_ampa[466], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 467: cell 5, seg 0 (0.5) [0.5 on Epop[5]] -> cell 67, seg 0 (0.5) [0.5 on Epop[67]], weight: 4.1363508E-4, delay 1.5
        h("Epop[67] syn_projEE_ampa[467] = new ampa(0.5)")
        h("Epop[5] netConn_projEE_ampa[467] = new NetCon(&v(0.5), syn_projEE_ampa[467], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 468: cell 5, seg 0 (0.5) [0.5 on Epop[5]] -> cell 68, seg 0 (0.5) [0.5 on Epop[68]], weight: 4.1363508E-4, delay 1.5
        h("Epop[68] syn_projEE_ampa[468] = new ampa(0.5)")
        h("Epop[5] netConn_projEE_ampa[468] = new NetCon(&v(0.5), syn_projEE_ampa[468], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 469: cell 5, seg 0 (0.5) [0.5 on Epop[5]] -> cell 69, seg 0 (0.5) [0.5 on Epop[69]], weight: 4.1363508E-4, delay 1.5
        h("Epop[69] syn_projEE_ampa[469] = new ampa(0.5)")
        h("Epop[5] netConn_projEE_ampa[469] = new NetCon(&v(0.5), syn_projEE_ampa[469], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 470: cell 5, seg 0 (0.5) [0.5 on Epop[5]] -> cell 70, seg 0 (0.5) [0.5 on Epop[70]], weight: 4.1363508E-4, delay 1.5
        h("Epop[70] syn_projEE_ampa[470] = new ampa(0.5)")
        h("Epop[5] netConn_projEE_ampa[470] = new NetCon(&v(0.5), syn_projEE_ampa[470], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 471: cell 5, seg 0 (0.5) [0.5 on Epop[5]] -> cell 71, seg 0 (0.5) [0.5 on Epop[71]], weight: 4.1363508E-4, delay 1.5
        h("Epop[71] syn_projEE_ampa[471] = new ampa(0.5)")
        h("Epop[5] netConn_projEE_ampa[471] = new NetCon(&v(0.5), syn_projEE_ampa[471], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 472: cell 5, seg 0 (0.5) [0.5 on Epop[5]] -> cell 72, seg 0 (0.5) [0.5 on Epop[72]], weight: 4.1363508E-4, delay 1.5
        h("Epop[72] syn_projEE_ampa[472] = new ampa(0.5)")
        h("Epop[5] netConn_projEE_ampa[472] = new NetCon(&v(0.5), syn_projEE_ampa[472], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 473: cell 5, seg 0 (0.5) [0.5 on Epop[5]] -> cell 73, seg 0 (0.5) [0.5 on Epop[73]], weight: 4.1363508E-4, delay 1.5
        h("Epop[73] syn_projEE_ampa[473] = new ampa(0.5)")
        h("Epop[5] netConn_projEE_ampa[473] = new NetCon(&v(0.5), syn_projEE_ampa[473], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 474: cell 5, seg 0 (0.5) [0.5 on Epop[5]] -> cell 74, seg 0 (0.5) [0.5 on Epop[74]], weight: 4.1363508E-4, delay 1.5
        h("Epop[74] syn_projEE_ampa[474] = new ampa(0.5)")
        h("Epop[5] netConn_projEE_ampa[474] = new NetCon(&v(0.5), syn_projEE_ampa[474], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 475: cell 5, seg 0 (0.5) [0.5 on Epop[5]] -> cell 75, seg 0 (0.5) [0.5 on Epop[75]], weight: 4.1363508E-4, delay 1.5
        h("Epop[75] syn_projEE_ampa[475] = new ampa(0.5)")
        h("Epop[5] netConn_projEE_ampa[475] = new NetCon(&v(0.5), syn_projEE_ampa[475], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 476: cell 5, seg 0 (0.5) [0.5 on Epop[5]] -> cell 76, seg 0 (0.5) [0.5 on Epop[76]], weight: 4.1363508E-4, delay 1.5
        h("Epop[76] syn_projEE_ampa[476] = new ampa(0.5)")
        h("Epop[5] netConn_projEE_ampa[476] = new NetCon(&v(0.5), syn_projEE_ampa[476], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 477: cell 5, seg 0 (0.5) [0.5 on Epop[5]] -> cell 77, seg 0 (0.5) [0.5 on Epop[77]], weight: 4.1363508E-4, delay 1.5
        h("Epop[77] syn_projEE_ampa[477] = new ampa(0.5)")
        h("Epop[5] netConn_projEE_ampa[477] = new NetCon(&v(0.5), syn_projEE_ampa[477], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 478: cell 5, seg 0 (0.5) [0.5 on Epop[5]] -> cell 78, seg 0 (0.5) [0.5 on Epop[78]], weight: 4.1363508E-4, delay 1.5
        h("Epop[78] syn_projEE_ampa[478] = new ampa(0.5)")
        h("Epop[5] netConn_projEE_ampa[478] = new NetCon(&v(0.5), syn_projEE_ampa[478], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 479: cell 5, seg 0 (0.5) [0.5 on Epop[5]] -> cell 79, seg 0 (0.5) [0.5 on Epop[79]], weight: 4.1363508E-4, delay 1.5
        h("Epop[79] syn_projEE_ampa[479] = new ampa(0.5)")
        h("Epop[5] netConn_projEE_ampa[479] = new NetCon(&v(0.5), syn_projEE_ampa[479], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 480: cell 6, seg 0 (0.5) [0.5 on Epop[6]] -> cell 0, seg 0 (0.5) [0.5 on Epop[0]], weight: 4.1363508E-4, delay 1.5
        h("Epop[0] syn_projEE_ampa[480] = new ampa(0.5)")
        h("Epop[6] netConn_projEE_ampa[480] = new NetCon(&v(0.5), syn_projEE_ampa[480], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 481: cell 6, seg 0 (0.5) [0.5 on Epop[6]] -> cell 1, seg 0 (0.5) [0.5 on Epop[1]], weight: 4.1363508E-4, delay 1.5
        h("Epop[1] syn_projEE_ampa[481] = new ampa(0.5)")
        h("Epop[6] netConn_projEE_ampa[481] = new NetCon(&v(0.5), syn_projEE_ampa[481], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 482: cell 6, seg 0 (0.5) [0.5 on Epop[6]] -> cell 2, seg 0 (0.5) [0.5 on Epop[2]], weight: 4.1363508E-4, delay 1.5
        h("Epop[2] syn_projEE_ampa[482] = new ampa(0.5)")
        h("Epop[6] netConn_projEE_ampa[482] = new NetCon(&v(0.5), syn_projEE_ampa[482], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 483: cell 6, seg 0 (0.5) [0.5 on Epop[6]] -> cell 3, seg 0 (0.5) [0.5 on Epop[3]], weight: 4.1363508E-4, delay 1.5
        h("Epop[3] syn_projEE_ampa[483] = new ampa(0.5)")
        h("Epop[6] netConn_projEE_ampa[483] = new NetCon(&v(0.5), syn_projEE_ampa[483], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 484: cell 6, seg 0 (0.5) [0.5 on Epop[6]] -> cell 4, seg 0 (0.5) [0.5 on Epop[4]], weight: 4.1363508E-4, delay 1.5
        h("Epop[4] syn_projEE_ampa[484] = new ampa(0.5)")
        h("Epop[6] netConn_projEE_ampa[484] = new NetCon(&v(0.5), syn_projEE_ampa[484], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 485: cell 6, seg 0 (0.5) [0.5 on Epop[6]] -> cell 5, seg 0 (0.5) [0.5 on Epop[5]], weight: 4.1363508E-4, delay 1.5
        h("Epop[5] syn_projEE_ampa[485] = new ampa(0.5)")
        h("Epop[6] netConn_projEE_ampa[485] = new NetCon(&v(0.5), syn_projEE_ampa[485], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 486: cell 6, seg 0 (0.5) [0.5 on Epop[6]] -> cell 6, seg 0 (0.5) [0.5 on Epop[6]], weight: 4.1363508E-4, delay 1.5
        h("Epop[6] syn_projEE_ampa[486] = new ampa(0.5)")
        h("Epop[6] netConn_projEE_ampa[486] = new NetCon(&v(0.5), syn_projEE_ampa[486], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 487: cell 6, seg 0 (0.5) [0.5 on Epop[6]] -> cell 7, seg 0 (0.5) [0.5 on Epop[7]], weight: 4.1363508E-4, delay 1.5
        h("Epop[7] syn_projEE_ampa[487] = new ampa(0.5)")
        h("Epop[6] netConn_projEE_ampa[487] = new NetCon(&v(0.5), syn_projEE_ampa[487], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 488: cell 6, seg 0 (0.5) [0.5 on Epop[6]] -> cell 8, seg 0 (0.5) [0.5 on Epop[8]], weight: 4.1363508E-4, delay 1.5
        h("Epop[8] syn_projEE_ampa[488] = new ampa(0.5)")
        h("Epop[6] netConn_projEE_ampa[488] = new NetCon(&v(0.5), syn_projEE_ampa[488], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 489: cell 6, seg 0 (0.5) [0.5 on Epop[6]] -> cell 9, seg 0 (0.5) [0.5 on Epop[9]], weight: 4.1363508E-4, delay 1.5
        h("Epop[9] syn_projEE_ampa[489] = new ampa(0.5)")
        h("Epop[6] netConn_projEE_ampa[489] = new NetCon(&v(0.5), syn_projEE_ampa[489], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 490: cell 6, seg 0 (0.5) [0.5 on Epop[6]] -> cell 10, seg 0 (0.5) [0.5 on Epop[10]], weight: 4.1363508E-4, delay 1.5
        h("Epop[10] syn_projEE_ampa[490] = new ampa(0.5)")
        h("Epop[6] netConn_projEE_ampa[490] = new NetCon(&v(0.5), syn_projEE_ampa[490], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 491: cell 6, seg 0 (0.5) [0.5 on Epop[6]] -> cell 11, seg 0 (0.5) [0.5 on Epop[11]], weight: 4.1363508E-4, delay 1.5
        h("Epop[11] syn_projEE_ampa[491] = new ampa(0.5)")
        h("Epop[6] netConn_projEE_ampa[491] = new NetCon(&v(0.5), syn_projEE_ampa[491], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 492: cell 6, seg 0 (0.5) [0.5 on Epop[6]] -> cell 12, seg 0 (0.5) [0.5 on Epop[12]], weight: 4.1363508E-4, delay 1.5
        h("Epop[12] syn_projEE_ampa[492] = new ampa(0.5)")
        h("Epop[6] netConn_projEE_ampa[492] = new NetCon(&v(0.5), syn_projEE_ampa[492], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 493: cell 6, seg 0 (0.5) [0.5 on Epop[6]] -> cell 13, seg 0 (0.5) [0.5 on Epop[13]], weight: 4.1363508E-4, delay 1.5
        h("Epop[13] syn_projEE_ampa[493] = new ampa(0.5)")
        h("Epop[6] netConn_projEE_ampa[493] = new NetCon(&v(0.5), syn_projEE_ampa[493], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 494: cell 6, seg 0 (0.5) [0.5 on Epop[6]] -> cell 14, seg 0 (0.5) [0.5 on Epop[14]], weight: 4.1363508E-4, delay 1.5
        h("Epop[14] syn_projEE_ampa[494] = new ampa(0.5)")
        h("Epop[6] netConn_projEE_ampa[494] = new NetCon(&v(0.5), syn_projEE_ampa[494], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 495: cell 6, seg 0 (0.5) [0.5 on Epop[6]] -> cell 15, seg 0 (0.5) [0.5 on Epop[15]], weight: 4.1363508E-4, delay 1.5
        h("Epop[15] syn_projEE_ampa[495] = new ampa(0.5)")
        h("Epop[6] netConn_projEE_ampa[495] = new NetCon(&v(0.5), syn_projEE_ampa[495], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 496: cell 6, seg 0 (0.5) [0.5 on Epop[6]] -> cell 16, seg 0 (0.5) [0.5 on Epop[16]], weight: 4.1363508E-4, delay 1.5
        h("Epop[16] syn_projEE_ampa[496] = new ampa(0.5)")
        h("Epop[6] netConn_projEE_ampa[496] = new NetCon(&v(0.5), syn_projEE_ampa[496], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 497: cell 6, seg 0 (0.5) [0.5 on Epop[6]] -> cell 17, seg 0 (0.5) [0.5 on Epop[17]], weight: 4.1363508E-4, delay 1.5
        h("Epop[17] syn_projEE_ampa[497] = new ampa(0.5)")
        h("Epop[6] netConn_projEE_ampa[497] = new NetCon(&v(0.5), syn_projEE_ampa[497], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 498: cell 6, seg 0 (0.5) [0.5 on Epop[6]] -> cell 18, seg 0 (0.5) [0.5 on Epop[18]], weight: 4.1363508E-4, delay 1.5
        h("Epop[18] syn_projEE_ampa[498] = new ampa(0.5)")
        h("Epop[6] netConn_projEE_ampa[498] = new NetCon(&v(0.5), syn_projEE_ampa[498], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 499: cell 6, seg 0 (0.5) [0.5 on Epop[6]] -> cell 19, seg 0 (0.5) [0.5 on Epop[19]], weight: 4.1363508E-4, delay 1.5
        h("Epop[19] syn_projEE_ampa[499] = new ampa(0.5)")
        h("Epop[6] netConn_projEE_ampa[499] = new NetCon(&v(0.5), syn_projEE_ampa[499], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 500: cell 6, seg 0 (0.5) [0.5 on Epop[6]] -> cell 20, seg 0 (0.5) [0.5 on Epop[20]], weight: 4.1363508E-4, delay 1.5
        h("Epop[20] syn_projEE_ampa[500] = new ampa(0.5)")
        h("Epop[6] netConn_projEE_ampa[500] = new NetCon(&v(0.5), syn_projEE_ampa[500], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 501: cell 6, seg 0 (0.5) [0.5 on Epop[6]] -> cell 21, seg 0 (0.5) [0.5 on Epop[21]], weight: 4.1363508E-4, delay 1.5
        h("Epop[21] syn_projEE_ampa[501] = new ampa(0.5)")
        h("Epop[6] netConn_projEE_ampa[501] = new NetCon(&v(0.5), syn_projEE_ampa[501], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 502: cell 6, seg 0 (0.5) [0.5 on Epop[6]] -> cell 22, seg 0 (0.5) [0.5 on Epop[22]], weight: 4.1363508E-4, delay 1.5
        h("Epop[22] syn_projEE_ampa[502] = new ampa(0.5)")
        h("Epop[6] netConn_projEE_ampa[502] = new NetCon(&v(0.5), syn_projEE_ampa[502], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 503: cell 6, seg 0 (0.5) [0.5 on Epop[6]] -> cell 23, seg 0 (0.5) [0.5 on Epop[23]], weight: 4.1363508E-4, delay 1.5
        h("Epop[23] syn_projEE_ampa[503] = new ampa(0.5)")
        h("Epop[6] netConn_projEE_ampa[503] = new NetCon(&v(0.5), syn_projEE_ampa[503], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 504: cell 6, seg 0 (0.5) [0.5 on Epop[6]] -> cell 24, seg 0 (0.5) [0.5 on Epop[24]], weight: 4.1363508E-4, delay 1.5
        h("Epop[24] syn_projEE_ampa[504] = new ampa(0.5)")
        h("Epop[6] netConn_projEE_ampa[504] = new NetCon(&v(0.5), syn_projEE_ampa[504], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 505: cell 6, seg 0 (0.5) [0.5 on Epop[6]] -> cell 25, seg 0 (0.5) [0.5 on Epop[25]], weight: 4.1363508E-4, delay 1.5
        h("Epop[25] syn_projEE_ampa[505] = new ampa(0.5)")
        h("Epop[6] netConn_projEE_ampa[505] = new NetCon(&v(0.5), syn_projEE_ampa[505], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 506: cell 6, seg 0 (0.5) [0.5 on Epop[6]] -> cell 26, seg 0 (0.5) [0.5 on Epop[26]], weight: 4.1363508E-4, delay 1.5
        h("Epop[26] syn_projEE_ampa[506] = new ampa(0.5)")
        h("Epop[6] netConn_projEE_ampa[506] = new NetCon(&v(0.5), syn_projEE_ampa[506], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 507: cell 6, seg 0 (0.5) [0.5 on Epop[6]] -> cell 27, seg 0 (0.5) [0.5 on Epop[27]], weight: 4.1363508E-4, delay 1.5
        h("Epop[27] syn_projEE_ampa[507] = new ampa(0.5)")
        h("Epop[6] netConn_projEE_ampa[507] = new NetCon(&v(0.5), syn_projEE_ampa[507], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 508: cell 6, seg 0 (0.5) [0.5 on Epop[6]] -> cell 28, seg 0 (0.5) [0.5 on Epop[28]], weight: 4.1363508E-4, delay 1.5
        h("Epop[28] syn_projEE_ampa[508] = new ampa(0.5)")
        h("Epop[6] netConn_projEE_ampa[508] = new NetCon(&v(0.5), syn_projEE_ampa[508], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 509: cell 6, seg 0 (0.5) [0.5 on Epop[6]] -> cell 29, seg 0 (0.5) [0.5 on Epop[29]], weight: 4.1363508E-4, delay 1.5
        h("Epop[29] syn_projEE_ampa[509] = new ampa(0.5)")
        h("Epop[6] netConn_projEE_ampa[509] = new NetCon(&v(0.5), syn_projEE_ampa[509], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 510: cell 6, seg 0 (0.5) [0.5 on Epop[6]] -> cell 30, seg 0 (0.5) [0.5 on Epop[30]], weight: 4.1363508E-4, delay 1.5
        h("Epop[30] syn_projEE_ampa[510] = new ampa(0.5)")
        h("Epop[6] netConn_projEE_ampa[510] = new NetCon(&v(0.5), syn_projEE_ampa[510], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 511: cell 6, seg 0 (0.5) [0.5 on Epop[6]] -> cell 31, seg 0 (0.5) [0.5 on Epop[31]], weight: 4.1363508E-4, delay 1.5
        h("Epop[31] syn_projEE_ampa[511] = new ampa(0.5)")
        h("Epop[6] netConn_projEE_ampa[511] = new NetCon(&v(0.5), syn_projEE_ampa[511], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 512: cell 6, seg 0 (0.5) [0.5 on Epop[6]] -> cell 32, seg 0 (0.5) [0.5 on Epop[32]], weight: 4.1363508E-4, delay 1.5
        h("Epop[32] syn_projEE_ampa[512] = new ampa(0.5)")
        h("Epop[6] netConn_projEE_ampa[512] = new NetCon(&v(0.5), syn_projEE_ampa[512], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 513: cell 6, seg 0 (0.5) [0.5 on Epop[6]] -> cell 33, seg 0 (0.5) [0.5 on Epop[33]], weight: 4.1363508E-4, delay 1.5
        h("Epop[33] syn_projEE_ampa[513] = new ampa(0.5)")
        h("Epop[6] netConn_projEE_ampa[513] = new NetCon(&v(0.5), syn_projEE_ampa[513], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 514: cell 6, seg 0 (0.5) [0.5 on Epop[6]] -> cell 34, seg 0 (0.5) [0.5 on Epop[34]], weight: 4.1363508E-4, delay 1.5
        h("Epop[34] syn_projEE_ampa[514] = new ampa(0.5)")
        h("Epop[6] netConn_projEE_ampa[514] = new NetCon(&v(0.5), syn_projEE_ampa[514], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 515: cell 6, seg 0 (0.5) [0.5 on Epop[6]] -> cell 35, seg 0 (0.5) [0.5 on Epop[35]], weight: 4.1363508E-4, delay 1.5
        h("Epop[35] syn_projEE_ampa[515] = new ampa(0.5)")
        h("Epop[6] netConn_projEE_ampa[515] = new NetCon(&v(0.5), syn_projEE_ampa[515], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 516: cell 6, seg 0 (0.5) [0.5 on Epop[6]] -> cell 36, seg 0 (0.5) [0.5 on Epop[36]], weight: 4.1363508E-4, delay 1.5
        h("Epop[36] syn_projEE_ampa[516] = new ampa(0.5)")
        h("Epop[6] netConn_projEE_ampa[516] = new NetCon(&v(0.5), syn_projEE_ampa[516], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 517: cell 6, seg 0 (0.5) [0.5 on Epop[6]] -> cell 37, seg 0 (0.5) [0.5 on Epop[37]], weight: 4.1363508E-4, delay 1.5
        h("Epop[37] syn_projEE_ampa[517] = new ampa(0.5)")
        h("Epop[6] netConn_projEE_ampa[517] = new NetCon(&v(0.5), syn_projEE_ampa[517], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 518: cell 6, seg 0 (0.5) [0.5 on Epop[6]] -> cell 38, seg 0 (0.5) [0.5 on Epop[38]], weight: 4.1363508E-4, delay 1.5
        h("Epop[38] syn_projEE_ampa[518] = new ampa(0.5)")
        h("Epop[6] netConn_projEE_ampa[518] = new NetCon(&v(0.5), syn_projEE_ampa[518], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 519: cell 6, seg 0 (0.5) [0.5 on Epop[6]] -> cell 39, seg 0 (0.5) [0.5 on Epop[39]], weight: 4.1363508E-4, delay 1.5
        h("Epop[39] syn_projEE_ampa[519] = new ampa(0.5)")
        h("Epop[6] netConn_projEE_ampa[519] = new NetCon(&v(0.5), syn_projEE_ampa[519], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 520: cell 6, seg 0 (0.5) [0.5 on Epop[6]] -> cell 40, seg 0 (0.5) [0.5 on Epop[40]], weight: 4.1363508E-4, delay 1.5
        h("Epop[40] syn_projEE_ampa[520] = new ampa(0.5)")
        h("Epop[6] netConn_projEE_ampa[520] = new NetCon(&v(0.5), syn_projEE_ampa[520], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 521: cell 6, seg 0 (0.5) [0.5 on Epop[6]] -> cell 41, seg 0 (0.5) [0.5 on Epop[41]], weight: 4.1363508E-4, delay 1.5
        h("Epop[41] syn_projEE_ampa[521] = new ampa(0.5)")
        h("Epop[6] netConn_projEE_ampa[521] = new NetCon(&v(0.5), syn_projEE_ampa[521], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 522: cell 6, seg 0 (0.5) [0.5 on Epop[6]] -> cell 42, seg 0 (0.5) [0.5 on Epop[42]], weight: 4.1363508E-4, delay 1.5
        h("Epop[42] syn_projEE_ampa[522] = new ampa(0.5)")
        h("Epop[6] netConn_projEE_ampa[522] = new NetCon(&v(0.5), syn_projEE_ampa[522], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 523: cell 6, seg 0 (0.5) [0.5 on Epop[6]] -> cell 43, seg 0 (0.5) [0.5 on Epop[43]], weight: 4.1363508E-4, delay 1.5
        h("Epop[43] syn_projEE_ampa[523] = new ampa(0.5)")
        h("Epop[6] netConn_projEE_ampa[523] = new NetCon(&v(0.5), syn_projEE_ampa[523], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 524: cell 6, seg 0 (0.5) [0.5 on Epop[6]] -> cell 44, seg 0 (0.5) [0.5 on Epop[44]], weight: 4.1363508E-4, delay 1.5
        h("Epop[44] syn_projEE_ampa[524] = new ampa(0.5)")
        h("Epop[6] netConn_projEE_ampa[524] = new NetCon(&v(0.5), syn_projEE_ampa[524], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 525: cell 6, seg 0 (0.5) [0.5 on Epop[6]] -> cell 45, seg 0 (0.5) [0.5 on Epop[45]], weight: 4.1363508E-4, delay 1.5
        h("Epop[45] syn_projEE_ampa[525] = new ampa(0.5)")
        h("Epop[6] netConn_projEE_ampa[525] = new NetCon(&v(0.5), syn_projEE_ampa[525], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 526: cell 6, seg 0 (0.5) [0.5 on Epop[6]] -> cell 46, seg 0 (0.5) [0.5 on Epop[46]], weight: 4.1363508E-4, delay 1.5
        h("Epop[46] syn_projEE_ampa[526] = new ampa(0.5)")
        h("Epop[6] netConn_projEE_ampa[526] = new NetCon(&v(0.5), syn_projEE_ampa[526], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 527: cell 6, seg 0 (0.5) [0.5 on Epop[6]] -> cell 47, seg 0 (0.5) [0.5 on Epop[47]], weight: 4.1363508E-4, delay 1.5
        h("Epop[47] syn_projEE_ampa[527] = new ampa(0.5)")
        h("Epop[6] netConn_projEE_ampa[527] = new NetCon(&v(0.5), syn_projEE_ampa[527], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 528: cell 6, seg 0 (0.5) [0.5 on Epop[6]] -> cell 48, seg 0 (0.5) [0.5 on Epop[48]], weight: 4.1363508E-4, delay 1.5
        h("Epop[48] syn_projEE_ampa[528] = new ampa(0.5)")
        h("Epop[6] netConn_projEE_ampa[528] = new NetCon(&v(0.5), syn_projEE_ampa[528], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 529: cell 6, seg 0 (0.5) [0.5 on Epop[6]] -> cell 49, seg 0 (0.5) [0.5 on Epop[49]], weight: 4.1363508E-4, delay 1.5
        h("Epop[49] syn_projEE_ampa[529] = new ampa(0.5)")
        h("Epop[6] netConn_projEE_ampa[529] = new NetCon(&v(0.5), syn_projEE_ampa[529], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 530: cell 6, seg 0 (0.5) [0.5 on Epop[6]] -> cell 50, seg 0 (0.5) [0.5 on Epop[50]], weight: 4.1363508E-4, delay 1.5
        h("Epop[50] syn_projEE_ampa[530] = new ampa(0.5)")
        h("Epop[6] netConn_projEE_ampa[530] = new NetCon(&v(0.5), syn_projEE_ampa[530], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 531: cell 6, seg 0 (0.5) [0.5 on Epop[6]] -> cell 51, seg 0 (0.5) [0.5 on Epop[51]], weight: 4.1363508E-4, delay 1.5
        h("Epop[51] syn_projEE_ampa[531] = new ampa(0.5)")
        h("Epop[6] netConn_projEE_ampa[531] = new NetCon(&v(0.5), syn_projEE_ampa[531], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 532: cell 6, seg 0 (0.5) [0.5 on Epop[6]] -> cell 52, seg 0 (0.5) [0.5 on Epop[52]], weight: 4.1363508E-4, delay 1.5
        h("Epop[52] syn_projEE_ampa[532] = new ampa(0.5)")
        h("Epop[6] netConn_projEE_ampa[532] = new NetCon(&v(0.5), syn_projEE_ampa[532], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 533: cell 6, seg 0 (0.5) [0.5 on Epop[6]] -> cell 53, seg 0 (0.5) [0.5 on Epop[53]], weight: 4.1363508E-4, delay 1.5
        h("Epop[53] syn_projEE_ampa[533] = new ampa(0.5)")
        h("Epop[6] netConn_projEE_ampa[533] = new NetCon(&v(0.5), syn_projEE_ampa[533], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 534: cell 6, seg 0 (0.5) [0.5 on Epop[6]] -> cell 54, seg 0 (0.5) [0.5 on Epop[54]], weight: 4.1363508E-4, delay 1.5
        h("Epop[54] syn_projEE_ampa[534] = new ampa(0.5)")
        h("Epop[6] netConn_projEE_ampa[534] = new NetCon(&v(0.5), syn_projEE_ampa[534], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 535: cell 6, seg 0 (0.5) [0.5 on Epop[6]] -> cell 55, seg 0 (0.5) [0.5 on Epop[55]], weight: 4.1363508E-4, delay 1.5
        h("Epop[55] syn_projEE_ampa[535] = new ampa(0.5)")
        h("Epop[6] netConn_projEE_ampa[535] = new NetCon(&v(0.5), syn_projEE_ampa[535], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 536: cell 6, seg 0 (0.5) [0.5 on Epop[6]] -> cell 56, seg 0 (0.5) [0.5 on Epop[56]], weight: 4.1363508E-4, delay 1.5
        h("Epop[56] syn_projEE_ampa[536] = new ampa(0.5)")
        h("Epop[6] netConn_projEE_ampa[536] = new NetCon(&v(0.5), syn_projEE_ampa[536], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 537: cell 6, seg 0 (0.5) [0.5 on Epop[6]] -> cell 57, seg 0 (0.5) [0.5 on Epop[57]], weight: 4.1363508E-4, delay 1.5
        h("Epop[57] syn_projEE_ampa[537] = new ampa(0.5)")
        h("Epop[6] netConn_projEE_ampa[537] = new NetCon(&v(0.5), syn_projEE_ampa[537], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 538: cell 6, seg 0 (0.5) [0.5 on Epop[6]] -> cell 58, seg 0 (0.5) [0.5 on Epop[58]], weight: 4.1363508E-4, delay 1.5
        h("Epop[58] syn_projEE_ampa[538] = new ampa(0.5)")
        h("Epop[6] netConn_projEE_ampa[538] = new NetCon(&v(0.5), syn_projEE_ampa[538], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 539: cell 6, seg 0 (0.5) [0.5 on Epop[6]] -> cell 59, seg 0 (0.5) [0.5 on Epop[59]], weight: 4.1363508E-4, delay 1.5
        h("Epop[59] syn_projEE_ampa[539] = new ampa(0.5)")
        h("Epop[6] netConn_projEE_ampa[539] = new NetCon(&v(0.5), syn_projEE_ampa[539], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 540: cell 6, seg 0 (0.5) [0.5 on Epop[6]] -> cell 60, seg 0 (0.5) [0.5 on Epop[60]], weight: 4.1363508E-4, delay 1.5
        h("Epop[60] syn_projEE_ampa[540] = new ampa(0.5)")
        h("Epop[6] netConn_projEE_ampa[540] = new NetCon(&v(0.5), syn_projEE_ampa[540], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 541: cell 6, seg 0 (0.5) [0.5 on Epop[6]] -> cell 61, seg 0 (0.5) [0.5 on Epop[61]], weight: 4.1363508E-4, delay 1.5
        h("Epop[61] syn_projEE_ampa[541] = new ampa(0.5)")
        h("Epop[6] netConn_projEE_ampa[541] = new NetCon(&v(0.5), syn_projEE_ampa[541], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 542: cell 6, seg 0 (0.5) [0.5 on Epop[6]] -> cell 62, seg 0 (0.5) [0.5 on Epop[62]], weight: 4.1363508E-4, delay 1.5
        h("Epop[62] syn_projEE_ampa[542] = new ampa(0.5)")
        h("Epop[6] netConn_projEE_ampa[542] = new NetCon(&v(0.5), syn_projEE_ampa[542], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 543: cell 6, seg 0 (0.5) [0.5 on Epop[6]] -> cell 63, seg 0 (0.5) [0.5 on Epop[63]], weight: 4.1363508E-4, delay 1.5
        h("Epop[63] syn_projEE_ampa[543] = new ampa(0.5)")
        h("Epop[6] netConn_projEE_ampa[543] = new NetCon(&v(0.5), syn_projEE_ampa[543], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 544: cell 6, seg 0 (0.5) [0.5 on Epop[6]] -> cell 64, seg 0 (0.5) [0.5 on Epop[64]], weight: 4.1363508E-4, delay 1.5
        h("Epop[64] syn_projEE_ampa[544] = new ampa(0.5)")
        h("Epop[6] netConn_projEE_ampa[544] = new NetCon(&v(0.5), syn_projEE_ampa[544], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 545: cell 6, seg 0 (0.5) [0.5 on Epop[6]] -> cell 65, seg 0 (0.5) [0.5 on Epop[65]], weight: 4.1363508E-4, delay 1.5
        h("Epop[65] syn_projEE_ampa[545] = new ampa(0.5)")
        h("Epop[6] netConn_projEE_ampa[545] = new NetCon(&v(0.5), syn_projEE_ampa[545], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 546: cell 6, seg 0 (0.5) [0.5 on Epop[6]] -> cell 66, seg 0 (0.5) [0.5 on Epop[66]], weight: 4.1363508E-4, delay 1.5
        h("Epop[66] syn_projEE_ampa[546] = new ampa(0.5)")
        h("Epop[6] netConn_projEE_ampa[546] = new NetCon(&v(0.5), syn_projEE_ampa[546], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 547: cell 6, seg 0 (0.5) [0.5 on Epop[6]] -> cell 67, seg 0 (0.5) [0.5 on Epop[67]], weight: 4.1363508E-4, delay 1.5
        h("Epop[67] syn_projEE_ampa[547] = new ampa(0.5)")
        h("Epop[6] netConn_projEE_ampa[547] = new NetCon(&v(0.5), syn_projEE_ampa[547], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 548: cell 6, seg 0 (0.5) [0.5 on Epop[6]] -> cell 68, seg 0 (0.5) [0.5 on Epop[68]], weight: 4.1363508E-4, delay 1.5
        h("Epop[68] syn_projEE_ampa[548] = new ampa(0.5)")
        h("Epop[6] netConn_projEE_ampa[548] = new NetCon(&v(0.5), syn_projEE_ampa[548], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 549: cell 6, seg 0 (0.5) [0.5 on Epop[6]] -> cell 69, seg 0 (0.5) [0.5 on Epop[69]], weight: 4.1363508E-4, delay 1.5
        h("Epop[69] syn_projEE_ampa[549] = new ampa(0.5)")
        h("Epop[6] netConn_projEE_ampa[549] = new NetCon(&v(0.5), syn_projEE_ampa[549], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 550: cell 6, seg 0 (0.5) [0.5 on Epop[6]] -> cell 70, seg 0 (0.5) [0.5 on Epop[70]], weight: 4.1363508E-4, delay 1.5
        h("Epop[70] syn_projEE_ampa[550] = new ampa(0.5)")
        h("Epop[6] netConn_projEE_ampa[550] = new NetCon(&v(0.5), syn_projEE_ampa[550], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 551: cell 6, seg 0 (0.5) [0.5 on Epop[6]] -> cell 71, seg 0 (0.5) [0.5 on Epop[71]], weight: 4.1363508E-4, delay 1.5
        h("Epop[71] syn_projEE_ampa[551] = new ampa(0.5)")
        h("Epop[6] netConn_projEE_ampa[551] = new NetCon(&v(0.5), syn_projEE_ampa[551], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 552: cell 6, seg 0 (0.5) [0.5 on Epop[6]] -> cell 72, seg 0 (0.5) [0.5 on Epop[72]], weight: 4.1363508E-4, delay 1.5
        h("Epop[72] syn_projEE_ampa[552] = new ampa(0.5)")
        h("Epop[6] netConn_projEE_ampa[552] = new NetCon(&v(0.5), syn_projEE_ampa[552], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 553: cell 6, seg 0 (0.5) [0.5 on Epop[6]] -> cell 73, seg 0 (0.5) [0.5 on Epop[73]], weight: 4.1363508E-4, delay 1.5
        h("Epop[73] syn_projEE_ampa[553] = new ampa(0.5)")
        h("Epop[6] netConn_projEE_ampa[553] = new NetCon(&v(0.5), syn_projEE_ampa[553], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 554: cell 6, seg 0 (0.5) [0.5 on Epop[6]] -> cell 74, seg 0 (0.5) [0.5 on Epop[74]], weight: 4.1363508E-4, delay 1.5
        h("Epop[74] syn_projEE_ampa[554] = new ampa(0.5)")
        h("Epop[6] netConn_projEE_ampa[554] = new NetCon(&v(0.5), syn_projEE_ampa[554], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 555: cell 6, seg 0 (0.5) [0.5 on Epop[6]] -> cell 75, seg 0 (0.5) [0.5 on Epop[75]], weight: 4.1363508E-4, delay 1.5
        h("Epop[75] syn_projEE_ampa[555] = new ampa(0.5)")
        h("Epop[6] netConn_projEE_ampa[555] = new NetCon(&v(0.5), syn_projEE_ampa[555], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 556: cell 6, seg 0 (0.5) [0.5 on Epop[6]] -> cell 76, seg 0 (0.5) [0.5 on Epop[76]], weight: 4.1363508E-4, delay 1.5
        h("Epop[76] syn_projEE_ampa[556] = new ampa(0.5)")
        h("Epop[6] netConn_projEE_ampa[556] = new NetCon(&v(0.5), syn_projEE_ampa[556], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 557: cell 6, seg 0 (0.5) [0.5 on Epop[6]] -> cell 77, seg 0 (0.5) [0.5 on Epop[77]], weight: 4.1363508E-4, delay 1.5
        h("Epop[77] syn_projEE_ampa[557] = new ampa(0.5)")
        h("Epop[6] netConn_projEE_ampa[557] = new NetCon(&v(0.5), syn_projEE_ampa[557], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 558: cell 6, seg 0 (0.5) [0.5 on Epop[6]] -> cell 78, seg 0 (0.5) [0.5 on Epop[78]], weight: 4.1363508E-4, delay 1.5
        h("Epop[78] syn_projEE_ampa[558] = new ampa(0.5)")
        h("Epop[6] netConn_projEE_ampa[558] = new NetCon(&v(0.5), syn_projEE_ampa[558], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 559: cell 6, seg 0 (0.5) [0.5 on Epop[6]] -> cell 79, seg 0 (0.5) [0.5 on Epop[79]], weight: 4.1363508E-4, delay 1.5
        h("Epop[79] syn_projEE_ampa[559] = new ampa(0.5)")
        h("Epop[6] netConn_projEE_ampa[559] = new NetCon(&v(0.5), syn_projEE_ampa[559], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 560: cell 7, seg 0 (0.5) [0.5 on Epop[7]] -> cell 0, seg 0 (0.5) [0.5 on Epop[0]], weight: 4.1363508E-4, delay 1.5
        h("Epop[0] syn_projEE_ampa[560] = new ampa(0.5)")
        h("Epop[7] netConn_projEE_ampa[560] = new NetCon(&v(0.5), syn_projEE_ampa[560], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 561: cell 7, seg 0 (0.5) [0.5 on Epop[7]] -> cell 1, seg 0 (0.5) [0.5 on Epop[1]], weight: 4.1363508E-4, delay 1.5
        h("Epop[1] syn_projEE_ampa[561] = new ampa(0.5)")
        h("Epop[7] netConn_projEE_ampa[561] = new NetCon(&v(0.5), syn_projEE_ampa[561], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 562: cell 7, seg 0 (0.5) [0.5 on Epop[7]] -> cell 2, seg 0 (0.5) [0.5 on Epop[2]], weight: 4.1363508E-4, delay 1.5
        h("Epop[2] syn_projEE_ampa[562] = new ampa(0.5)")
        h("Epop[7] netConn_projEE_ampa[562] = new NetCon(&v(0.5), syn_projEE_ampa[562], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 563: cell 7, seg 0 (0.5) [0.5 on Epop[7]] -> cell 3, seg 0 (0.5) [0.5 on Epop[3]], weight: 4.1363508E-4, delay 1.5
        h("Epop[3] syn_projEE_ampa[563] = new ampa(0.5)")
        h("Epop[7] netConn_projEE_ampa[563] = new NetCon(&v(0.5), syn_projEE_ampa[563], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 564: cell 7, seg 0 (0.5) [0.5 on Epop[7]] -> cell 4, seg 0 (0.5) [0.5 on Epop[4]], weight: 4.1363508E-4, delay 1.5
        h("Epop[4] syn_projEE_ampa[564] = new ampa(0.5)")
        h("Epop[7] netConn_projEE_ampa[564] = new NetCon(&v(0.5), syn_projEE_ampa[564], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 565: cell 7, seg 0 (0.5) [0.5 on Epop[7]] -> cell 5, seg 0 (0.5) [0.5 on Epop[5]], weight: 4.1363508E-4, delay 1.5
        h("Epop[5] syn_projEE_ampa[565] = new ampa(0.5)")
        h("Epop[7] netConn_projEE_ampa[565] = new NetCon(&v(0.5), syn_projEE_ampa[565], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 566: cell 7, seg 0 (0.5) [0.5 on Epop[7]] -> cell 6, seg 0 (0.5) [0.5 on Epop[6]], weight: 4.1363508E-4, delay 1.5
        h("Epop[6] syn_projEE_ampa[566] = new ampa(0.5)")
        h("Epop[7] netConn_projEE_ampa[566] = new NetCon(&v(0.5), syn_projEE_ampa[566], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 567: cell 7, seg 0 (0.5) [0.5 on Epop[7]] -> cell 7, seg 0 (0.5) [0.5 on Epop[7]], weight: 4.1363508E-4, delay 1.5
        h("Epop[7] syn_projEE_ampa[567] = new ampa(0.5)")
        h("Epop[7] netConn_projEE_ampa[567] = new NetCon(&v(0.5), syn_projEE_ampa[567], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 568: cell 7, seg 0 (0.5) [0.5 on Epop[7]] -> cell 8, seg 0 (0.5) [0.5 on Epop[8]], weight: 4.1363508E-4, delay 1.5
        h("Epop[8] syn_projEE_ampa[568] = new ampa(0.5)")
        h("Epop[7] netConn_projEE_ampa[568] = new NetCon(&v(0.5), syn_projEE_ampa[568], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 569: cell 7, seg 0 (0.5) [0.5 on Epop[7]] -> cell 9, seg 0 (0.5) [0.5 on Epop[9]], weight: 4.1363508E-4, delay 1.5
        h("Epop[9] syn_projEE_ampa[569] = new ampa(0.5)")
        h("Epop[7] netConn_projEE_ampa[569] = new NetCon(&v(0.5), syn_projEE_ampa[569], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 570: cell 7, seg 0 (0.5) [0.5 on Epop[7]] -> cell 10, seg 0 (0.5) [0.5 on Epop[10]], weight: 4.1363508E-4, delay 1.5
        h("Epop[10] syn_projEE_ampa[570] = new ampa(0.5)")
        h("Epop[7] netConn_projEE_ampa[570] = new NetCon(&v(0.5), syn_projEE_ampa[570], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 571: cell 7, seg 0 (0.5) [0.5 on Epop[7]] -> cell 11, seg 0 (0.5) [0.5 on Epop[11]], weight: 4.1363508E-4, delay 1.5
        h("Epop[11] syn_projEE_ampa[571] = new ampa(0.5)")
        h("Epop[7] netConn_projEE_ampa[571] = new NetCon(&v(0.5), syn_projEE_ampa[571], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 572: cell 7, seg 0 (0.5) [0.5 on Epop[7]] -> cell 12, seg 0 (0.5) [0.5 on Epop[12]], weight: 4.1363508E-4, delay 1.5
        h("Epop[12] syn_projEE_ampa[572] = new ampa(0.5)")
        h("Epop[7] netConn_projEE_ampa[572] = new NetCon(&v(0.5), syn_projEE_ampa[572], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 573: cell 7, seg 0 (0.5) [0.5 on Epop[7]] -> cell 13, seg 0 (0.5) [0.5 on Epop[13]], weight: 4.1363508E-4, delay 1.5
        h("Epop[13] syn_projEE_ampa[573] = new ampa(0.5)")
        h("Epop[7] netConn_projEE_ampa[573] = new NetCon(&v(0.5), syn_projEE_ampa[573], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 574: cell 7, seg 0 (0.5) [0.5 on Epop[7]] -> cell 14, seg 0 (0.5) [0.5 on Epop[14]], weight: 4.1363508E-4, delay 1.5
        h("Epop[14] syn_projEE_ampa[574] = new ampa(0.5)")
        h("Epop[7] netConn_projEE_ampa[574] = new NetCon(&v(0.5), syn_projEE_ampa[574], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 575: cell 7, seg 0 (0.5) [0.5 on Epop[7]] -> cell 15, seg 0 (0.5) [0.5 on Epop[15]], weight: 4.1363508E-4, delay 1.5
        h("Epop[15] syn_projEE_ampa[575] = new ampa(0.5)")
        h("Epop[7] netConn_projEE_ampa[575] = new NetCon(&v(0.5), syn_projEE_ampa[575], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 576: cell 7, seg 0 (0.5) [0.5 on Epop[7]] -> cell 16, seg 0 (0.5) [0.5 on Epop[16]], weight: 4.1363508E-4, delay 1.5
        h("Epop[16] syn_projEE_ampa[576] = new ampa(0.5)")
        h("Epop[7] netConn_projEE_ampa[576] = new NetCon(&v(0.5), syn_projEE_ampa[576], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 577: cell 7, seg 0 (0.5) [0.5 on Epop[7]] -> cell 17, seg 0 (0.5) [0.5 on Epop[17]], weight: 4.1363508E-4, delay 1.5
        h("Epop[17] syn_projEE_ampa[577] = new ampa(0.5)")
        h("Epop[7] netConn_projEE_ampa[577] = new NetCon(&v(0.5), syn_projEE_ampa[577], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 578: cell 7, seg 0 (0.5) [0.5 on Epop[7]] -> cell 18, seg 0 (0.5) [0.5 on Epop[18]], weight: 4.1363508E-4, delay 1.5
        h("Epop[18] syn_projEE_ampa[578] = new ampa(0.5)")
        h("Epop[7] netConn_projEE_ampa[578] = new NetCon(&v(0.5), syn_projEE_ampa[578], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 579: cell 7, seg 0 (0.5) [0.5 on Epop[7]] -> cell 19, seg 0 (0.5) [0.5 on Epop[19]], weight: 4.1363508E-4, delay 1.5
        h("Epop[19] syn_projEE_ampa[579] = new ampa(0.5)")
        h("Epop[7] netConn_projEE_ampa[579] = new NetCon(&v(0.5), syn_projEE_ampa[579], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 580: cell 7, seg 0 (0.5) [0.5 on Epop[7]] -> cell 20, seg 0 (0.5) [0.5 on Epop[20]], weight: 4.1363508E-4, delay 1.5
        h("Epop[20] syn_projEE_ampa[580] = new ampa(0.5)")
        h("Epop[7] netConn_projEE_ampa[580] = new NetCon(&v(0.5), syn_projEE_ampa[580], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 581: cell 7, seg 0 (0.5) [0.5 on Epop[7]] -> cell 21, seg 0 (0.5) [0.5 on Epop[21]], weight: 4.1363508E-4, delay 1.5
        h("Epop[21] syn_projEE_ampa[581] = new ampa(0.5)")
        h("Epop[7] netConn_projEE_ampa[581] = new NetCon(&v(0.5), syn_projEE_ampa[581], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 582: cell 7, seg 0 (0.5) [0.5 on Epop[7]] -> cell 22, seg 0 (0.5) [0.5 on Epop[22]], weight: 4.1363508E-4, delay 1.5
        h("Epop[22] syn_projEE_ampa[582] = new ampa(0.5)")
        h("Epop[7] netConn_projEE_ampa[582] = new NetCon(&v(0.5), syn_projEE_ampa[582], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 583: cell 7, seg 0 (0.5) [0.5 on Epop[7]] -> cell 23, seg 0 (0.5) [0.5 on Epop[23]], weight: 4.1363508E-4, delay 1.5
        h("Epop[23] syn_projEE_ampa[583] = new ampa(0.5)")
        h("Epop[7] netConn_projEE_ampa[583] = new NetCon(&v(0.5), syn_projEE_ampa[583], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 584: cell 7, seg 0 (0.5) [0.5 on Epop[7]] -> cell 24, seg 0 (0.5) [0.5 on Epop[24]], weight: 4.1363508E-4, delay 1.5
        h("Epop[24] syn_projEE_ampa[584] = new ampa(0.5)")
        h("Epop[7] netConn_projEE_ampa[584] = new NetCon(&v(0.5), syn_projEE_ampa[584], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 585: cell 7, seg 0 (0.5) [0.5 on Epop[7]] -> cell 25, seg 0 (0.5) [0.5 on Epop[25]], weight: 4.1363508E-4, delay 1.5
        h("Epop[25] syn_projEE_ampa[585] = new ampa(0.5)")
        h("Epop[7] netConn_projEE_ampa[585] = new NetCon(&v(0.5), syn_projEE_ampa[585], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 586: cell 7, seg 0 (0.5) [0.5 on Epop[7]] -> cell 26, seg 0 (0.5) [0.5 on Epop[26]], weight: 4.1363508E-4, delay 1.5
        h("Epop[26] syn_projEE_ampa[586] = new ampa(0.5)")
        h("Epop[7] netConn_projEE_ampa[586] = new NetCon(&v(0.5), syn_projEE_ampa[586], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 587: cell 7, seg 0 (0.5) [0.5 on Epop[7]] -> cell 27, seg 0 (0.5) [0.5 on Epop[27]], weight: 4.1363508E-4, delay 1.5
        h("Epop[27] syn_projEE_ampa[587] = new ampa(0.5)")
        h("Epop[7] netConn_projEE_ampa[587] = new NetCon(&v(0.5), syn_projEE_ampa[587], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 588: cell 7, seg 0 (0.5) [0.5 on Epop[7]] -> cell 28, seg 0 (0.5) [0.5 on Epop[28]], weight: 4.1363508E-4, delay 1.5
        h("Epop[28] syn_projEE_ampa[588] = new ampa(0.5)")
        h("Epop[7] netConn_projEE_ampa[588] = new NetCon(&v(0.5), syn_projEE_ampa[588], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 589: cell 7, seg 0 (0.5) [0.5 on Epop[7]] -> cell 29, seg 0 (0.5) [0.5 on Epop[29]], weight: 4.1363508E-4, delay 1.5
        h("Epop[29] syn_projEE_ampa[589] = new ampa(0.5)")
        h("Epop[7] netConn_projEE_ampa[589] = new NetCon(&v(0.5), syn_projEE_ampa[589], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 590: cell 7, seg 0 (0.5) [0.5 on Epop[7]] -> cell 30, seg 0 (0.5) [0.5 on Epop[30]], weight: 4.1363508E-4, delay 1.5
        h("Epop[30] syn_projEE_ampa[590] = new ampa(0.5)")
        h("Epop[7] netConn_projEE_ampa[590] = new NetCon(&v(0.5), syn_projEE_ampa[590], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 591: cell 7, seg 0 (0.5) [0.5 on Epop[7]] -> cell 31, seg 0 (0.5) [0.5 on Epop[31]], weight: 4.1363508E-4, delay 1.5
        h("Epop[31] syn_projEE_ampa[591] = new ampa(0.5)")
        h("Epop[7] netConn_projEE_ampa[591] = new NetCon(&v(0.5), syn_projEE_ampa[591], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 592: cell 7, seg 0 (0.5) [0.5 on Epop[7]] -> cell 32, seg 0 (0.5) [0.5 on Epop[32]], weight: 4.1363508E-4, delay 1.5
        h("Epop[32] syn_projEE_ampa[592] = new ampa(0.5)")
        h("Epop[7] netConn_projEE_ampa[592] = new NetCon(&v(0.5), syn_projEE_ampa[592], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 593: cell 7, seg 0 (0.5) [0.5 on Epop[7]] -> cell 33, seg 0 (0.5) [0.5 on Epop[33]], weight: 4.1363508E-4, delay 1.5
        h("Epop[33] syn_projEE_ampa[593] = new ampa(0.5)")
        h("Epop[7] netConn_projEE_ampa[593] = new NetCon(&v(0.5), syn_projEE_ampa[593], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 594: cell 7, seg 0 (0.5) [0.5 on Epop[7]] -> cell 34, seg 0 (0.5) [0.5 on Epop[34]], weight: 4.1363508E-4, delay 1.5
        h("Epop[34] syn_projEE_ampa[594] = new ampa(0.5)")
        h("Epop[7] netConn_projEE_ampa[594] = new NetCon(&v(0.5), syn_projEE_ampa[594], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 595: cell 7, seg 0 (0.5) [0.5 on Epop[7]] -> cell 35, seg 0 (0.5) [0.5 on Epop[35]], weight: 4.1363508E-4, delay 1.5
        h("Epop[35] syn_projEE_ampa[595] = new ampa(0.5)")
        h("Epop[7] netConn_projEE_ampa[595] = new NetCon(&v(0.5), syn_projEE_ampa[595], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 596: cell 7, seg 0 (0.5) [0.5 on Epop[7]] -> cell 36, seg 0 (0.5) [0.5 on Epop[36]], weight: 4.1363508E-4, delay 1.5
        h("Epop[36] syn_projEE_ampa[596] = new ampa(0.5)")
        h("Epop[7] netConn_projEE_ampa[596] = new NetCon(&v(0.5), syn_projEE_ampa[596], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 597: cell 7, seg 0 (0.5) [0.5 on Epop[7]] -> cell 37, seg 0 (0.5) [0.5 on Epop[37]], weight: 4.1363508E-4, delay 1.5
        h("Epop[37] syn_projEE_ampa[597] = new ampa(0.5)")
        h("Epop[7] netConn_projEE_ampa[597] = new NetCon(&v(0.5), syn_projEE_ampa[597], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 598: cell 7, seg 0 (0.5) [0.5 on Epop[7]] -> cell 38, seg 0 (0.5) [0.5 on Epop[38]], weight: 4.1363508E-4, delay 1.5
        h("Epop[38] syn_projEE_ampa[598] = new ampa(0.5)")
        h("Epop[7] netConn_projEE_ampa[598] = new NetCon(&v(0.5), syn_projEE_ampa[598], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 599: cell 7, seg 0 (0.5) [0.5 on Epop[7]] -> cell 39, seg 0 (0.5) [0.5 on Epop[39]], weight: 4.1363508E-4, delay 1.5
        h("Epop[39] syn_projEE_ampa[599] = new ampa(0.5)")
        h("Epop[7] netConn_projEE_ampa[599] = new NetCon(&v(0.5), syn_projEE_ampa[599], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 600: cell 7, seg 0 (0.5) [0.5 on Epop[7]] -> cell 40, seg 0 (0.5) [0.5 on Epop[40]], weight: 4.1363508E-4, delay 1.5
        h("Epop[40] syn_projEE_ampa[600] = new ampa(0.5)")
        h("Epop[7] netConn_projEE_ampa[600] = new NetCon(&v(0.5), syn_projEE_ampa[600], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 601: cell 7, seg 0 (0.5) [0.5 on Epop[7]] -> cell 41, seg 0 (0.5) [0.5 on Epop[41]], weight: 4.1363508E-4, delay 1.5
        h("Epop[41] syn_projEE_ampa[601] = new ampa(0.5)")
        h("Epop[7] netConn_projEE_ampa[601] = new NetCon(&v(0.5), syn_projEE_ampa[601], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 602: cell 7, seg 0 (0.5) [0.5 on Epop[7]] -> cell 42, seg 0 (0.5) [0.5 on Epop[42]], weight: 4.1363508E-4, delay 1.5
        h("Epop[42] syn_projEE_ampa[602] = new ampa(0.5)")
        h("Epop[7] netConn_projEE_ampa[602] = new NetCon(&v(0.5), syn_projEE_ampa[602], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 603: cell 7, seg 0 (0.5) [0.5 on Epop[7]] -> cell 43, seg 0 (0.5) [0.5 on Epop[43]], weight: 4.1363508E-4, delay 1.5
        h("Epop[43] syn_projEE_ampa[603] = new ampa(0.5)")
        h("Epop[7] netConn_projEE_ampa[603] = new NetCon(&v(0.5), syn_projEE_ampa[603], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 604: cell 7, seg 0 (0.5) [0.5 on Epop[7]] -> cell 44, seg 0 (0.5) [0.5 on Epop[44]], weight: 4.1363508E-4, delay 1.5
        h("Epop[44] syn_projEE_ampa[604] = new ampa(0.5)")
        h("Epop[7] netConn_projEE_ampa[604] = new NetCon(&v(0.5), syn_projEE_ampa[604], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 605: cell 7, seg 0 (0.5) [0.5 on Epop[7]] -> cell 45, seg 0 (0.5) [0.5 on Epop[45]], weight: 4.1363508E-4, delay 1.5
        h("Epop[45] syn_projEE_ampa[605] = new ampa(0.5)")
        h("Epop[7] netConn_projEE_ampa[605] = new NetCon(&v(0.5), syn_projEE_ampa[605], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 606: cell 7, seg 0 (0.5) [0.5 on Epop[7]] -> cell 46, seg 0 (0.5) [0.5 on Epop[46]], weight: 4.1363508E-4, delay 1.5
        h("Epop[46] syn_projEE_ampa[606] = new ampa(0.5)")
        h("Epop[7] netConn_projEE_ampa[606] = new NetCon(&v(0.5), syn_projEE_ampa[606], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 607: cell 7, seg 0 (0.5) [0.5 on Epop[7]] -> cell 47, seg 0 (0.5) [0.5 on Epop[47]], weight: 4.1363508E-4, delay 1.5
        h("Epop[47] syn_projEE_ampa[607] = new ampa(0.5)")
        h("Epop[7] netConn_projEE_ampa[607] = new NetCon(&v(0.5), syn_projEE_ampa[607], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 608: cell 7, seg 0 (0.5) [0.5 on Epop[7]] -> cell 48, seg 0 (0.5) [0.5 on Epop[48]], weight: 4.1363508E-4, delay 1.5
        h("Epop[48] syn_projEE_ampa[608] = new ampa(0.5)")
        h("Epop[7] netConn_projEE_ampa[608] = new NetCon(&v(0.5), syn_projEE_ampa[608], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 609: cell 7, seg 0 (0.5) [0.5 on Epop[7]] -> cell 49, seg 0 (0.5) [0.5 on Epop[49]], weight: 4.1363508E-4, delay 1.5
        h("Epop[49] syn_projEE_ampa[609] = new ampa(0.5)")
        h("Epop[7] netConn_projEE_ampa[609] = new NetCon(&v(0.5), syn_projEE_ampa[609], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 610: cell 7, seg 0 (0.5) [0.5 on Epop[7]] -> cell 50, seg 0 (0.5) [0.5 on Epop[50]], weight: 4.1363508E-4, delay 1.5
        h("Epop[50] syn_projEE_ampa[610] = new ampa(0.5)")
        h("Epop[7] netConn_projEE_ampa[610] = new NetCon(&v(0.5), syn_projEE_ampa[610], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 611: cell 7, seg 0 (0.5) [0.5 on Epop[7]] -> cell 51, seg 0 (0.5) [0.5 on Epop[51]], weight: 4.1363508E-4, delay 1.5
        h("Epop[51] syn_projEE_ampa[611] = new ampa(0.5)")
        h("Epop[7] netConn_projEE_ampa[611] = new NetCon(&v(0.5), syn_projEE_ampa[611], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 612: cell 7, seg 0 (0.5) [0.5 on Epop[7]] -> cell 52, seg 0 (0.5) [0.5 on Epop[52]], weight: 4.1363508E-4, delay 1.5
        h("Epop[52] syn_projEE_ampa[612] = new ampa(0.5)")
        h("Epop[7] netConn_projEE_ampa[612] = new NetCon(&v(0.5), syn_projEE_ampa[612], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 613: cell 7, seg 0 (0.5) [0.5 on Epop[7]] -> cell 53, seg 0 (0.5) [0.5 on Epop[53]], weight: 4.1363508E-4, delay 1.5
        h("Epop[53] syn_projEE_ampa[613] = new ampa(0.5)")
        h("Epop[7] netConn_projEE_ampa[613] = new NetCon(&v(0.5), syn_projEE_ampa[613], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 614: cell 7, seg 0 (0.5) [0.5 on Epop[7]] -> cell 54, seg 0 (0.5) [0.5 on Epop[54]], weight: 4.1363508E-4, delay 1.5
        h("Epop[54] syn_projEE_ampa[614] = new ampa(0.5)")
        h("Epop[7] netConn_projEE_ampa[614] = new NetCon(&v(0.5), syn_projEE_ampa[614], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 615: cell 7, seg 0 (0.5) [0.5 on Epop[7]] -> cell 55, seg 0 (0.5) [0.5 on Epop[55]], weight: 4.1363508E-4, delay 1.5
        h("Epop[55] syn_projEE_ampa[615] = new ampa(0.5)")
        h("Epop[7] netConn_projEE_ampa[615] = new NetCon(&v(0.5), syn_projEE_ampa[615], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 616: cell 7, seg 0 (0.5) [0.5 on Epop[7]] -> cell 56, seg 0 (0.5) [0.5 on Epop[56]], weight: 4.1363508E-4, delay 1.5
        h("Epop[56] syn_projEE_ampa[616] = new ampa(0.5)")
        h("Epop[7] netConn_projEE_ampa[616] = new NetCon(&v(0.5), syn_projEE_ampa[616], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 617: cell 7, seg 0 (0.5) [0.5 on Epop[7]] -> cell 57, seg 0 (0.5) [0.5 on Epop[57]], weight: 4.1363508E-4, delay 1.5
        h("Epop[57] syn_projEE_ampa[617] = new ampa(0.5)")
        h("Epop[7] netConn_projEE_ampa[617] = new NetCon(&v(0.5), syn_projEE_ampa[617], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 618: cell 7, seg 0 (0.5) [0.5 on Epop[7]] -> cell 58, seg 0 (0.5) [0.5 on Epop[58]], weight: 4.1363508E-4, delay 1.5
        h("Epop[58] syn_projEE_ampa[618] = new ampa(0.5)")
        h("Epop[7] netConn_projEE_ampa[618] = new NetCon(&v(0.5), syn_projEE_ampa[618], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 619: cell 7, seg 0 (0.5) [0.5 on Epop[7]] -> cell 59, seg 0 (0.5) [0.5 on Epop[59]], weight: 4.1363508E-4, delay 1.5
        h("Epop[59] syn_projEE_ampa[619] = new ampa(0.5)")
        h("Epop[7] netConn_projEE_ampa[619] = new NetCon(&v(0.5), syn_projEE_ampa[619], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 620: cell 7, seg 0 (0.5) [0.5 on Epop[7]] -> cell 60, seg 0 (0.5) [0.5 on Epop[60]], weight: 4.1363508E-4, delay 1.5
        h("Epop[60] syn_projEE_ampa[620] = new ampa(0.5)")
        h("Epop[7] netConn_projEE_ampa[620] = new NetCon(&v(0.5), syn_projEE_ampa[620], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 621: cell 7, seg 0 (0.5) [0.5 on Epop[7]] -> cell 61, seg 0 (0.5) [0.5 on Epop[61]], weight: 4.1363508E-4, delay 1.5
        h("Epop[61] syn_projEE_ampa[621] = new ampa(0.5)")
        h("Epop[7] netConn_projEE_ampa[621] = new NetCon(&v(0.5), syn_projEE_ampa[621], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 622: cell 7, seg 0 (0.5) [0.5 on Epop[7]] -> cell 62, seg 0 (0.5) [0.5 on Epop[62]], weight: 4.1363508E-4, delay 1.5
        h("Epop[62] syn_projEE_ampa[622] = new ampa(0.5)")
        h("Epop[7] netConn_projEE_ampa[622] = new NetCon(&v(0.5), syn_projEE_ampa[622], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 623: cell 7, seg 0 (0.5) [0.5 on Epop[7]] -> cell 63, seg 0 (0.5) [0.5 on Epop[63]], weight: 4.1363508E-4, delay 1.5
        h("Epop[63] syn_projEE_ampa[623] = new ampa(0.5)")
        h("Epop[7] netConn_projEE_ampa[623] = new NetCon(&v(0.5), syn_projEE_ampa[623], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 624: cell 7, seg 0 (0.5) [0.5 on Epop[7]] -> cell 64, seg 0 (0.5) [0.5 on Epop[64]], weight: 4.1363508E-4, delay 1.5
        h("Epop[64] syn_projEE_ampa[624] = new ampa(0.5)")
        h("Epop[7] netConn_projEE_ampa[624] = new NetCon(&v(0.5), syn_projEE_ampa[624], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 625: cell 7, seg 0 (0.5) [0.5 on Epop[7]] -> cell 65, seg 0 (0.5) [0.5 on Epop[65]], weight: 4.1363508E-4, delay 1.5
        h("Epop[65] syn_projEE_ampa[625] = new ampa(0.5)")
        h("Epop[7] netConn_projEE_ampa[625] = new NetCon(&v(0.5), syn_projEE_ampa[625], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 626: cell 7, seg 0 (0.5) [0.5 on Epop[7]] -> cell 66, seg 0 (0.5) [0.5 on Epop[66]], weight: 4.1363508E-4, delay 1.5
        h("Epop[66] syn_projEE_ampa[626] = new ampa(0.5)")
        h("Epop[7] netConn_projEE_ampa[626] = new NetCon(&v(0.5), syn_projEE_ampa[626], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 627: cell 7, seg 0 (0.5) [0.5 on Epop[7]] -> cell 67, seg 0 (0.5) [0.5 on Epop[67]], weight: 4.1363508E-4, delay 1.5
        h("Epop[67] syn_projEE_ampa[627] = new ampa(0.5)")
        h("Epop[7] netConn_projEE_ampa[627] = new NetCon(&v(0.5), syn_projEE_ampa[627], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 628: cell 7, seg 0 (0.5) [0.5 on Epop[7]] -> cell 68, seg 0 (0.5) [0.5 on Epop[68]], weight: 4.1363508E-4, delay 1.5
        h("Epop[68] syn_projEE_ampa[628] = new ampa(0.5)")
        h("Epop[7] netConn_projEE_ampa[628] = new NetCon(&v(0.5), syn_projEE_ampa[628], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 629: cell 7, seg 0 (0.5) [0.5 on Epop[7]] -> cell 69, seg 0 (0.5) [0.5 on Epop[69]], weight: 4.1363508E-4, delay 1.5
        h("Epop[69] syn_projEE_ampa[629] = new ampa(0.5)")
        h("Epop[7] netConn_projEE_ampa[629] = new NetCon(&v(0.5), syn_projEE_ampa[629], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 630: cell 7, seg 0 (0.5) [0.5 on Epop[7]] -> cell 70, seg 0 (0.5) [0.5 on Epop[70]], weight: 4.1363508E-4, delay 1.5
        h("Epop[70] syn_projEE_ampa[630] = new ampa(0.5)")
        h("Epop[7] netConn_projEE_ampa[630] = new NetCon(&v(0.5), syn_projEE_ampa[630], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 631: cell 7, seg 0 (0.5) [0.5 on Epop[7]] -> cell 71, seg 0 (0.5) [0.5 on Epop[71]], weight: 4.1363508E-4, delay 1.5
        h("Epop[71] syn_projEE_ampa[631] = new ampa(0.5)")
        h("Epop[7] netConn_projEE_ampa[631] = new NetCon(&v(0.5), syn_projEE_ampa[631], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 632: cell 7, seg 0 (0.5) [0.5 on Epop[7]] -> cell 72, seg 0 (0.5) [0.5 on Epop[72]], weight: 4.1363508E-4, delay 1.5
        h("Epop[72] syn_projEE_ampa[632] = new ampa(0.5)")
        h("Epop[7] netConn_projEE_ampa[632] = new NetCon(&v(0.5), syn_projEE_ampa[632], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 633: cell 7, seg 0 (0.5) [0.5 on Epop[7]] -> cell 73, seg 0 (0.5) [0.5 on Epop[73]], weight: 4.1363508E-4, delay 1.5
        h("Epop[73] syn_projEE_ampa[633] = new ampa(0.5)")
        h("Epop[7] netConn_projEE_ampa[633] = new NetCon(&v(0.5), syn_projEE_ampa[633], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 634: cell 7, seg 0 (0.5) [0.5 on Epop[7]] -> cell 74, seg 0 (0.5) [0.5 on Epop[74]], weight: 4.1363508E-4, delay 1.5
        h("Epop[74] syn_projEE_ampa[634] = new ampa(0.5)")
        h("Epop[7] netConn_projEE_ampa[634] = new NetCon(&v(0.5), syn_projEE_ampa[634], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 635: cell 7, seg 0 (0.5) [0.5 on Epop[7]] -> cell 75, seg 0 (0.5) [0.5 on Epop[75]], weight: 4.1363508E-4, delay 1.5
        h("Epop[75] syn_projEE_ampa[635] = new ampa(0.5)")
        h("Epop[7] netConn_projEE_ampa[635] = new NetCon(&v(0.5), syn_projEE_ampa[635], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 636: cell 7, seg 0 (0.5) [0.5 on Epop[7]] -> cell 76, seg 0 (0.5) [0.5 on Epop[76]], weight: 4.1363508E-4, delay 1.5
        h("Epop[76] syn_projEE_ampa[636] = new ampa(0.5)")
        h("Epop[7] netConn_projEE_ampa[636] = new NetCon(&v(0.5), syn_projEE_ampa[636], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 637: cell 7, seg 0 (0.5) [0.5 on Epop[7]] -> cell 77, seg 0 (0.5) [0.5 on Epop[77]], weight: 4.1363508E-4, delay 1.5
        h("Epop[77] syn_projEE_ampa[637] = new ampa(0.5)")
        h("Epop[7] netConn_projEE_ampa[637] = new NetCon(&v(0.5), syn_projEE_ampa[637], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 638: cell 7, seg 0 (0.5) [0.5 on Epop[7]] -> cell 78, seg 0 (0.5) [0.5 on Epop[78]], weight: 4.1363508E-4, delay 1.5
        h("Epop[78] syn_projEE_ampa[638] = new ampa(0.5)")
        h("Epop[7] netConn_projEE_ampa[638] = new NetCon(&v(0.5), syn_projEE_ampa[638], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 639: cell 7, seg 0 (0.5) [0.5 on Epop[7]] -> cell 79, seg 0 (0.5) [0.5 on Epop[79]], weight: 4.1363508E-4, delay 1.5
        h("Epop[79] syn_projEE_ampa[639] = new ampa(0.5)")
        h("Epop[7] netConn_projEE_ampa[639] = new NetCon(&v(0.5), syn_projEE_ampa[639], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 640: cell 8, seg 0 (0.5) [0.5 on Epop[8]] -> cell 0, seg 0 (0.5) [0.5 on Epop[0]], weight: 4.1363508E-4, delay 1.5
        h("Epop[0] syn_projEE_ampa[640] = new ampa(0.5)")
        h("Epop[8] netConn_projEE_ampa[640] = new NetCon(&v(0.5), syn_projEE_ampa[640], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 641: cell 8, seg 0 (0.5) [0.5 on Epop[8]] -> cell 1, seg 0 (0.5) [0.5 on Epop[1]], weight: 4.1363508E-4, delay 1.5
        h("Epop[1] syn_projEE_ampa[641] = new ampa(0.5)")
        h("Epop[8] netConn_projEE_ampa[641] = new NetCon(&v(0.5), syn_projEE_ampa[641], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 642: cell 8, seg 0 (0.5) [0.5 on Epop[8]] -> cell 2, seg 0 (0.5) [0.5 on Epop[2]], weight: 4.1363508E-4, delay 1.5
        h("Epop[2] syn_projEE_ampa[642] = new ampa(0.5)")
        h("Epop[8] netConn_projEE_ampa[642] = new NetCon(&v(0.5), syn_projEE_ampa[642], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 643: cell 8, seg 0 (0.5) [0.5 on Epop[8]] -> cell 3, seg 0 (0.5) [0.5 on Epop[3]], weight: 4.1363508E-4, delay 1.5
        h("Epop[3] syn_projEE_ampa[643] = new ampa(0.5)")
        h("Epop[8] netConn_projEE_ampa[643] = new NetCon(&v(0.5), syn_projEE_ampa[643], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 644: cell 8, seg 0 (0.5) [0.5 on Epop[8]] -> cell 4, seg 0 (0.5) [0.5 on Epop[4]], weight: 4.1363508E-4, delay 1.5
        h("Epop[4] syn_projEE_ampa[644] = new ampa(0.5)")
        h("Epop[8] netConn_projEE_ampa[644] = new NetCon(&v(0.5), syn_projEE_ampa[644], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 645: cell 8, seg 0 (0.5) [0.5 on Epop[8]] -> cell 5, seg 0 (0.5) [0.5 on Epop[5]], weight: 4.1363508E-4, delay 1.5
        h("Epop[5] syn_projEE_ampa[645] = new ampa(0.5)")
        h("Epop[8] netConn_projEE_ampa[645] = new NetCon(&v(0.5), syn_projEE_ampa[645], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 646: cell 8, seg 0 (0.5) [0.5 on Epop[8]] -> cell 6, seg 0 (0.5) [0.5 on Epop[6]], weight: 4.1363508E-4, delay 1.5
        h("Epop[6] syn_projEE_ampa[646] = new ampa(0.5)")
        h("Epop[8] netConn_projEE_ampa[646] = new NetCon(&v(0.5), syn_projEE_ampa[646], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 647: cell 8, seg 0 (0.5) [0.5 on Epop[8]] -> cell 7, seg 0 (0.5) [0.5 on Epop[7]], weight: 4.1363508E-4, delay 1.5
        h("Epop[7] syn_projEE_ampa[647] = new ampa(0.5)")
        h("Epop[8] netConn_projEE_ampa[647] = new NetCon(&v(0.5), syn_projEE_ampa[647], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 648: cell 8, seg 0 (0.5) [0.5 on Epop[8]] -> cell 8, seg 0 (0.5) [0.5 on Epop[8]], weight: 4.1363508E-4, delay 1.5
        h("Epop[8] syn_projEE_ampa[648] = new ampa(0.5)")
        h("Epop[8] netConn_projEE_ampa[648] = new NetCon(&v(0.5), syn_projEE_ampa[648], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 649: cell 8, seg 0 (0.5) [0.5 on Epop[8]] -> cell 9, seg 0 (0.5) [0.5 on Epop[9]], weight: 4.1363508E-4, delay 1.5
        h("Epop[9] syn_projEE_ampa[649] = new ampa(0.5)")
        h("Epop[8] netConn_projEE_ampa[649] = new NetCon(&v(0.5), syn_projEE_ampa[649], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 650: cell 8, seg 0 (0.5) [0.5 on Epop[8]] -> cell 10, seg 0 (0.5) [0.5 on Epop[10]], weight: 4.1363508E-4, delay 1.5
        h("Epop[10] syn_projEE_ampa[650] = new ampa(0.5)")
        h("Epop[8] netConn_projEE_ampa[650] = new NetCon(&v(0.5), syn_projEE_ampa[650], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 651: cell 8, seg 0 (0.5) [0.5 on Epop[8]] -> cell 11, seg 0 (0.5) [0.5 on Epop[11]], weight: 4.1363508E-4, delay 1.5
        h("Epop[11] syn_projEE_ampa[651] = new ampa(0.5)")
        h("Epop[8] netConn_projEE_ampa[651] = new NetCon(&v(0.5), syn_projEE_ampa[651], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 652: cell 8, seg 0 (0.5) [0.5 on Epop[8]] -> cell 12, seg 0 (0.5) [0.5 on Epop[12]], weight: 4.1363508E-4, delay 1.5
        h("Epop[12] syn_projEE_ampa[652] = new ampa(0.5)")
        h("Epop[8] netConn_projEE_ampa[652] = new NetCon(&v(0.5), syn_projEE_ampa[652], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 653: cell 8, seg 0 (0.5) [0.5 on Epop[8]] -> cell 13, seg 0 (0.5) [0.5 on Epop[13]], weight: 4.1363508E-4, delay 1.5
        h("Epop[13] syn_projEE_ampa[653] = new ampa(0.5)")
        h("Epop[8] netConn_projEE_ampa[653] = new NetCon(&v(0.5), syn_projEE_ampa[653], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 654: cell 8, seg 0 (0.5) [0.5 on Epop[8]] -> cell 14, seg 0 (0.5) [0.5 on Epop[14]], weight: 4.1363508E-4, delay 1.5
        h("Epop[14] syn_projEE_ampa[654] = new ampa(0.5)")
        h("Epop[8] netConn_projEE_ampa[654] = new NetCon(&v(0.5), syn_projEE_ampa[654], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 655: cell 8, seg 0 (0.5) [0.5 on Epop[8]] -> cell 15, seg 0 (0.5) [0.5 on Epop[15]], weight: 4.1363508E-4, delay 1.5
        h("Epop[15] syn_projEE_ampa[655] = new ampa(0.5)")
        h("Epop[8] netConn_projEE_ampa[655] = new NetCon(&v(0.5), syn_projEE_ampa[655], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 656: cell 8, seg 0 (0.5) [0.5 on Epop[8]] -> cell 16, seg 0 (0.5) [0.5 on Epop[16]], weight: 4.1363508E-4, delay 1.5
        h("Epop[16] syn_projEE_ampa[656] = new ampa(0.5)")
        h("Epop[8] netConn_projEE_ampa[656] = new NetCon(&v(0.5), syn_projEE_ampa[656], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 657: cell 8, seg 0 (0.5) [0.5 on Epop[8]] -> cell 17, seg 0 (0.5) [0.5 on Epop[17]], weight: 4.1363508E-4, delay 1.5
        h("Epop[17] syn_projEE_ampa[657] = new ampa(0.5)")
        h("Epop[8] netConn_projEE_ampa[657] = new NetCon(&v(0.5), syn_projEE_ampa[657], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 658: cell 8, seg 0 (0.5) [0.5 on Epop[8]] -> cell 18, seg 0 (0.5) [0.5 on Epop[18]], weight: 4.1363508E-4, delay 1.5
        h("Epop[18] syn_projEE_ampa[658] = new ampa(0.5)")
        h("Epop[8] netConn_projEE_ampa[658] = new NetCon(&v(0.5), syn_projEE_ampa[658], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 659: cell 8, seg 0 (0.5) [0.5 on Epop[8]] -> cell 19, seg 0 (0.5) [0.5 on Epop[19]], weight: 4.1363508E-4, delay 1.5
        h("Epop[19] syn_projEE_ampa[659] = new ampa(0.5)")
        h("Epop[8] netConn_projEE_ampa[659] = new NetCon(&v(0.5), syn_projEE_ampa[659], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 660: cell 8, seg 0 (0.5) [0.5 on Epop[8]] -> cell 20, seg 0 (0.5) [0.5 on Epop[20]], weight: 4.1363508E-4, delay 1.5
        h("Epop[20] syn_projEE_ampa[660] = new ampa(0.5)")
        h("Epop[8] netConn_projEE_ampa[660] = new NetCon(&v(0.5), syn_projEE_ampa[660], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 661: cell 8, seg 0 (0.5) [0.5 on Epop[8]] -> cell 21, seg 0 (0.5) [0.5 on Epop[21]], weight: 4.1363508E-4, delay 1.5
        h("Epop[21] syn_projEE_ampa[661] = new ampa(0.5)")
        h("Epop[8] netConn_projEE_ampa[661] = new NetCon(&v(0.5), syn_projEE_ampa[661], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 662: cell 8, seg 0 (0.5) [0.5 on Epop[8]] -> cell 22, seg 0 (0.5) [0.5 on Epop[22]], weight: 4.1363508E-4, delay 1.5
        h("Epop[22] syn_projEE_ampa[662] = new ampa(0.5)")
        h("Epop[8] netConn_projEE_ampa[662] = new NetCon(&v(0.5), syn_projEE_ampa[662], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 663: cell 8, seg 0 (0.5) [0.5 on Epop[8]] -> cell 23, seg 0 (0.5) [0.5 on Epop[23]], weight: 4.1363508E-4, delay 1.5
        h("Epop[23] syn_projEE_ampa[663] = new ampa(0.5)")
        h("Epop[8] netConn_projEE_ampa[663] = new NetCon(&v(0.5), syn_projEE_ampa[663], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 664: cell 8, seg 0 (0.5) [0.5 on Epop[8]] -> cell 24, seg 0 (0.5) [0.5 on Epop[24]], weight: 4.1363508E-4, delay 1.5
        h("Epop[24] syn_projEE_ampa[664] = new ampa(0.5)")
        h("Epop[8] netConn_projEE_ampa[664] = new NetCon(&v(0.5), syn_projEE_ampa[664], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 665: cell 8, seg 0 (0.5) [0.5 on Epop[8]] -> cell 25, seg 0 (0.5) [0.5 on Epop[25]], weight: 4.1363508E-4, delay 1.5
        h("Epop[25] syn_projEE_ampa[665] = new ampa(0.5)")
        h("Epop[8] netConn_projEE_ampa[665] = new NetCon(&v(0.5), syn_projEE_ampa[665], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 666: cell 8, seg 0 (0.5) [0.5 on Epop[8]] -> cell 26, seg 0 (0.5) [0.5 on Epop[26]], weight: 4.1363508E-4, delay 1.5
        h("Epop[26] syn_projEE_ampa[666] = new ampa(0.5)")
        h("Epop[8] netConn_projEE_ampa[666] = new NetCon(&v(0.5), syn_projEE_ampa[666], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 667: cell 8, seg 0 (0.5) [0.5 on Epop[8]] -> cell 27, seg 0 (0.5) [0.5 on Epop[27]], weight: 4.1363508E-4, delay 1.5
        h("Epop[27] syn_projEE_ampa[667] = new ampa(0.5)")
        h("Epop[8] netConn_projEE_ampa[667] = new NetCon(&v(0.5), syn_projEE_ampa[667], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 668: cell 8, seg 0 (0.5) [0.5 on Epop[8]] -> cell 28, seg 0 (0.5) [0.5 on Epop[28]], weight: 4.1363508E-4, delay 1.5
        h("Epop[28] syn_projEE_ampa[668] = new ampa(0.5)")
        h("Epop[8] netConn_projEE_ampa[668] = new NetCon(&v(0.5), syn_projEE_ampa[668], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 669: cell 8, seg 0 (0.5) [0.5 on Epop[8]] -> cell 29, seg 0 (0.5) [0.5 on Epop[29]], weight: 4.1363508E-4, delay 1.5
        h("Epop[29] syn_projEE_ampa[669] = new ampa(0.5)")
        h("Epop[8] netConn_projEE_ampa[669] = new NetCon(&v(0.5), syn_projEE_ampa[669], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 670: cell 8, seg 0 (0.5) [0.5 on Epop[8]] -> cell 30, seg 0 (0.5) [0.5 on Epop[30]], weight: 4.1363508E-4, delay 1.5
        h("Epop[30] syn_projEE_ampa[670] = new ampa(0.5)")
        h("Epop[8] netConn_projEE_ampa[670] = new NetCon(&v(0.5), syn_projEE_ampa[670], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 671: cell 8, seg 0 (0.5) [0.5 on Epop[8]] -> cell 31, seg 0 (0.5) [0.5 on Epop[31]], weight: 4.1363508E-4, delay 1.5
        h("Epop[31] syn_projEE_ampa[671] = new ampa(0.5)")
        h("Epop[8] netConn_projEE_ampa[671] = new NetCon(&v(0.5), syn_projEE_ampa[671], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 672: cell 8, seg 0 (0.5) [0.5 on Epop[8]] -> cell 32, seg 0 (0.5) [0.5 on Epop[32]], weight: 4.1363508E-4, delay 1.5
        h("Epop[32] syn_projEE_ampa[672] = new ampa(0.5)")
        h("Epop[8] netConn_projEE_ampa[672] = new NetCon(&v(0.5), syn_projEE_ampa[672], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 673: cell 8, seg 0 (0.5) [0.5 on Epop[8]] -> cell 33, seg 0 (0.5) [0.5 on Epop[33]], weight: 4.1363508E-4, delay 1.5
        h("Epop[33] syn_projEE_ampa[673] = new ampa(0.5)")
        h("Epop[8] netConn_projEE_ampa[673] = new NetCon(&v(0.5), syn_projEE_ampa[673], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 674: cell 8, seg 0 (0.5) [0.5 on Epop[8]] -> cell 34, seg 0 (0.5) [0.5 on Epop[34]], weight: 4.1363508E-4, delay 1.5
        h("Epop[34] syn_projEE_ampa[674] = new ampa(0.5)")
        h("Epop[8] netConn_projEE_ampa[674] = new NetCon(&v(0.5), syn_projEE_ampa[674], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 675: cell 8, seg 0 (0.5) [0.5 on Epop[8]] -> cell 35, seg 0 (0.5) [0.5 on Epop[35]], weight: 4.1363508E-4, delay 1.5
        h("Epop[35] syn_projEE_ampa[675] = new ampa(0.5)")
        h("Epop[8] netConn_projEE_ampa[675] = new NetCon(&v(0.5), syn_projEE_ampa[675], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 676: cell 8, seg 0 (0.5) [0.5 on Epop[8]] -> cell 36, seg 0 (0.5) [0.5 on Epop[36]], weight: 4.1363508E-4, delay 1.5
        h("Epop[36] syn_projEE_ampa[676] = new ampa(0.5)")
        h("Epop[8] netConn_projEE_ampa[676] = new NetCon(&v(0.5), syn_projEE_ampa[676], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 677: cell 8, seg 0 (0.5) [0.5 on Epop[8]] -> cell 37, seg 0 (0.5) [0.5 on Epop[37]], weight: 4.1363508E-4, delay 1.5
        h("Epop[37] syn_projEE_ampa[677] = new ampa(0.5)")
        h("Epop[8] netConn_projEE_ampa[677] = new NetCon(&v(0.5), syn_projEE_ampa[677], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 678: cell 8, seg 0 (0.5) [0.5 on Epop[8]] -> cell 38, seg 0 (0.5) [0.5 on Epop[38]], weight: 4.1363508E-4, delay 1.5
        h("Epop[38] syn_projEE_ampa[678] = new ampa(0.5)")
        h("Epop[8] netConn_projEE_ampa[678] = new NetCon(&v(0.5), syn_projEE_ampa[678], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 679: cell 8, seg 0 (0.5) [0.5 on Epop[8]] -> cell 39, seg 0 (0.5) [0.5 on Epop[39]], weight: 4.1363508E-4, delay 1.5
        h("Epop[39] syn_projEE_ampa[679] = new ampa(0.5)")
        h("Epop[8] netConn_projEE_ampa[679] = new NetCon(&v(0.5), syn_projEE_ampa[679], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 680: cell 8, seg 0 (0.5) [0.5 on Epop[8]] -> cell 40, seg 0 (0.5) [0.5 on Epop[40]], weight: 4.1363508E-4, delay 1.5
        h("Epop[40] syn_projEE_ampa[680] = new ampa(0.5)")
        h("Epop[8] netConn_projEE_ampa[680] = new NetCon(&v(0.5), syn_projEE_ampa[680], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 681: cell 8, seg 0 (0.5) [0.5 on Epop[8]] -> cell 41, seg 0 (0.5) [0.5 on Epop[41]], weight: 4.1363508E-4, delay 1.5
        h("Epop[41] syn_projEE_ampa[681] = new ampa(0.5)")
        h("Epop[8] netConn_projEE_ampa[681] = new NetCon(&v(0.5), syn_projEE_ampa[681], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 682: cell 8, seg 0 (0.5) [0.5 on Epop[8]] -> cell 42, seg 0 (0.5) [0.5 on Epop[42]], weight: 4.1363508E-4, delay 1.5
        h("Epop[42] syn_projEE_ampa[682] = new ampa(0.5)")
        h("Epop[8] netConn_projEE_ampa[682] = new NetCon(&v(0.5), syn_projEE_ampa[682], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 683: cell 8, seg 0 (0.5) [0.5 on Epop[8]] -> cell 43, seg 0 (0.5) [0.5 on Epop[43]], weight: 4.1363508E-4, delay 1.5
        h("Epop[43] syn_projEE_ampa[683] = new ampa(0.5)")
        h("Epop[8] netConn_projEE_ampa[683] = new NetCon(&v(0.5), syn_projEE_ampa[683], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 684: cell 8, seg 0 (0.5) [0.5 on Epop[8]] -> cell 44, seg 0 (0.5) [0.5 on Epop[44]], weight: 4.1363508E-4, delay 1.5
        h("Epop[44] syn_projEE_ampa[684] = new ampa(0.5)")
        h("Epop[8] netConn_projEE_ampa[684] = new NetCon(&v(0.5), syn_projEE_ampa[684], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 685: cell 8, seg 0 (0.5) [0.5 on Epop[8]] -> cell 45, seg 0 (0.5) [0.5 on Epop[45]], weight: 4.1363508E-4, delay 1.5
        h("Epop[45] syn_projEE_ampa[685] = new ampa(0.5)")
        h("Epop[8] netConn_projEE_ampa[685] = new NetCon(&v(0.5), syn_projEE_ampa[685], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 686: cell 8, seg 0 (0.5) [0.5 on Epop[8]] -> cell 46, seg 0 (0.5) [0.5 on Epop[46]], weight: 4.1363508E-4, delay 1.5
        h("Epop[46] syn_projEE_ampa[686] = new ampa(0.5)")
        h("Epop[8] netConn_projEE_ampa[686] = new NetCon(&v(0.5), syn_projEE_ampa[686], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 687: cell 8, seg 0 (0.5) [0.5 on Epop[8]] -> cell 47, seg 0 (0.5) [0.5 on Epop[47]], weight: 4.1363508E-4, delay 1.5
        h("Epop[47] syn_projEE_ampa[687] = new ampa(0.5)")
        h("Epop[8] netConn_projEE_ampa[687] = new NetCon(&v(0.5), syn_projEE_ampa[687], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 688: cell 8, seg 0 (0.5) [0.5 on Epop[8]] -> cell 48, seg 0 (0.5) [0.5 on Epop[48]], weight: 4.1363508E-4, delay 1.5
        h("Epop[48] syn_projEE_ampa[688] = new ampa(0.5)")
        h("Epop[8] netConn_projEE_ampa[688] = new NetCon(&v(0.5), syn_projEE_ampa[688], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 689: cell 8, seg 0 (0.5) [0.5 on Epop[8]] -> cell 49, seg 0 (0.5) [0.5 on Epop[49]], weight: 4.1363508E-4, delay 1.5
        h("Epop[49] syn_projEE_ampa[689] = new ampa(0.5)")
        h("Epop[8] netConn_projEE_ampa[689] = new NetCon(&v(0.5), syn_projEE_ampa[689], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 690: cell 8, seg 0 (0.5) [0.5 on Epop[8]] -> cell 50, seg 0 (0.5) [0.5 on Epop[50]], weight: 4.1363508E-4, delay 1.5
        h("Epop[50] syn_projEE_ampa[690] = new ampa(0.5)")
        h("Epop[8] netConn_projEE_ampa[690] = new NetCon(&v(0.5), syn_projEE_ampa[690], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 691: cell 8, seg 0 (0.5) [0.5 on Epop[8]] -> cell 51, seg 0 (0.5) [0.5 on Epop[51]], weight: 4.1363508E-4, delay 1.5
        h("Epop[51] syn_projEE_ampa[691] = new ampa(0.5)")
        h("Epop[8] netConn_projEE_ampa[691] = new NetCon(&v(0.5), syn_projEE_ampa[691], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 692: cell 8, seg 0 (0.5) [0.5 on Epop[8]] -> cell 52, seg 0 (0.5) [0.5 on Epop[52]], weight: 4.1363508E-4, delay 1.5
        h("Epop[52] syn_projEE_ampa[692] = new ampa(0.5)")
        h("Epop[8] netConn_projEE_ampa[692] = new NetCon(&v(0.5), syn_projEE_ampa[692], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 693: cell 8, seg 0 (0.5) [0.5 on Epop[8]] -> cell 53, seg 0 (0.5) [0.5 on Epop[53]], weight: 4.1363508E-4, delay 1.5
        h("Epop[53] syn_projEE_ampa[693] = new ampa(0.5)")
        h("Epop[8] netConn_projEE_ampa[693] = new NetCon(&v(0.5), syn_projEE_ampa[693], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 694: cell 8, seg 0 (0.5) [0.5 on Epop[8]] -> cell 54, seg 0 (0.5) [0.5 on Epop[54]], weight: 4.1363508E-4, delay 1.5
        h("Epop[54] syn_projEE_ampa[694] = new ampa(0.5)")
        h("Epop[8] netConn_projEE_ampa[694] = new NetCon(&v(0.5), syn_projEE_ampa[694], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 695: cell 8, seg 0 (0.5) [0.5 on Epop[8]] -> cell 55, seg 0 (0.5) [0.5 on Epop[55]], weight: 4.1363508E-4, delay 1.5
        h("Epop[55] syn_projEE_ampa[695] = new ampa(0.5)")
        h("Epop[8] netConn_projEE_ampa[695] = new NetCon(&v(0.5), syn_projEE_ampa[695], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 696: cell 8, seg 0 (0.5) [0.5 on Epop[8]] -> cell 56, seg 0 (0.5) [0.5 on Epop[56]], weight: 4.1363508E-4, delay 1.5
        h("Epop[56] syn_projEE_ampa[696] = new ampa(0.5)")
        h("Epop[8] netConn_projEE_ampa[696] = new NetCon(&v(0.5), syn_projEE_ampa[696], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 697: cell 8, seg 0 (0.5) [0.5 on Epop[8]] -> cell 57, seg 0 (0.5) [0.5 on Epop[57]], weight: 4.1363508E-4, delay 1.5
        h("Epop[57] syn_projEE_ampa[697] = new ampa(0.5)")
        h("Epop[8] netConn_projEE_ampa[697] = new NetCon(&v(0.5), syn_projEE_ampa[697], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 698: cell 8, seg 0 (0.5) [0.5 on Epop[8]] -> cell 58, seg 0 (0.5) [0.5 on Epop[58]], weight: 4.1363508E-4, delay 1.5
        h("Epop[58] syn_projEE_ampa[698] = new ampa(0.5)")
        h("Epop[8] netConn_projEE_ampa[698] = new NetCon(&v(0.5), syn_projEE_ampa[698], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 699: cell 8, seg 0 (0.5) [0.5 on Epop[8]] -> cell 59, seg 0 (0.5) [0.5 on Epop[59]], weight: 4.1363508E-4, delay 1.5
        h("Epop[59] syn_projEE_ampa[699] = new ampa(0.5)")
        h("Epop[8] netConn_projEE_ampa[699] = new NetCon(&v(0.5), syn_projEE_ampa[699], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 700: cell 8, seg 0 (0.5) [0.5 on Epop[8]] -> cell 60, seg 0 (0.5) [0.5 on Epop[60]], weight: 4.1363508E-4, delay 1.5
        h("Epop[60] syn_projEE_ampa[700] = new ampa(0.5)")
        h("Epop[8] netConn_projEE_ampa[700] = new NetCon(&v(0.5), syn_projEE_ampa[700], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 701: cell 8, seg 0 (0.5) [0.5 on Epop[8]] -> cell 61, seg 0 (0.5) [0.5 on Epop[61]], weight: 4.1363508E-4, delay 1.5
        h("Epop[61] syn_projEE_ampa[701] = new ampa(0.5)")
        h("Epop[8] netConn_projEE_ampa[701] = new NetCon(&v(0.5), syn_projEE_ampa[701], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 702: cell 8, seg 0 (0.5) [0.5 on Epop[8]] -> cell 62, seg 0 (0.5) [0.5 on Epop[62]], weight: 4.1363508E-4, delay 1.5
        h("Epop[62] syn_projEE_ampa[702] = new ampa(0.5)")
        h("Epop[8] netConn_projEE_ampa[702] = new NetCon(&v(0.5), syn_projEE_ampa[702], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 703: cell 8, seg 0 (0.5) [0.5 on Epop[8]] -> cell 63, seg 0 (0.5) [0.5 on Epop[63]], weight: 4.1363508E-4, delay 1.5
        h("Epop[63] syn_projEE_ampa[703] = new ampa(0.5)")
        h("Epop[8] netConn_projEE_ampa[703] = new NetCon(&v(0.5), syn_projEE_ampa[703], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 704: cell 8, seg 0 (0.5) [0.5 on Epop[8]] -> cell 64, seg 0 (0.5) [0.5 on Epop[64]], weight: 4.1363508E-4, delay 1.5
        h("Epop[64] syn_projEE_ampa[704] = new ampa(0.5)")
        h("Epop[8] netConn_projEE_ampa[704] = new NetCon(&v(0.5), syn_projEE_ampa[704], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 705: cell 8, seg 0 (0.5) [0.5 on Epop[8]] -> cell 65, seg 0 (0.5) [0.5 on Epop[65]], weight: 4.1363508E-4, delay 1.5
        h("Epop[65] syn_projEE_ampa[705] = new ampa(0.5)")
        h("Epop[8] netConn_projEE_ampa[705] = new NetCon(&v(0.5), syn_projEE_ampa[705], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 706: cell 8, seg 0 (0.5) [0.5 on Epop[8]] -> cell 66, seg 0 (0.5) [0.5 on Epop[66]], weight: 4.1363508E-4, delay 1.5
        h("Epop[66] syn_projEE_ampa[706] = new ampa(0.5)")
        h("Epop[8] netConn_projEE_ampa[706] = new NetCon(&v(0.5), syn_projEE_ampa[706], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 707: cell 8, seg 0 (0.5) [0.5 on Epop[8]] -> cell 67, seg 0 (0.5) [0.5 on Epop[67]], weight: 4.1363508E-4, delay 1.5
        h("Epop[67] syn_projEE_ampa[707] = new ampa(0.5)")
        h("Epop[8] netConn_projEE_ampa[707] = new NetCon(&v(0.5), syn_projEE_ampa[707], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 708: cell 8, seg 0 (0.5) [0.5 on Epop[8]] -> cell 68, seg 0 (0.5) [0.5 on Epop[68]], weight: 4.1363508E-4, delay 1.5
        h("Epop[68] syn_projEE_ampa[708] = new ampa(0.5)")
        h("Epop[8] netConn_projEE_ampa[708] = new NetCon(&v(0.5), syn_projEE_ampa[708], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 709: cell 8, seg 0 (0.5) [0.5 on Epop[8]] -> cell 69, seg 0 (0.5) [0.5 on Epop[69]], weight: 4.1363508E-4, delay 1.5
        h("Epop[69] syn_projEE_ampa[709] = new ampa(0.5)")
        h("Epop[8] netConn_projEE_ampa[709] = new NetCon(&v(0.5), syn_projEE_ampa[709], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 710: cell 8, seg 0 (0.5) [0.5 on Epop[8]] -> cell 70, seg 0 (0.5) [0.5 on Epop[70]], weight: 4.1363508E-4, delay 1.5
        h("Epop[70] syn_projEE_ampa[710] = new ampa(0.5)")
        h("Epop[8] netConn_projEE_ampa[710] = new NetCon(&v(0.5), syn_projEE_ampa[710], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 711: cell 8, seg 0 (0.5) [0.5 on Epop[8]] -> cell 71, seg 0 (0.5) [0.5 on Epop[71]], weight: 4.1363508E-4, delay 1.5
        h("Epop[71] syn_projEE_ampa[711] = new ampa(0.5)")
        h("Epop[8] netConn_projEE_ampa[711] = new NetCon(&v(0.5), syn_projEE_ampa[711], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 712: cell 8, seg 0 (0.5) [0.5 on Epop[8]] -> cell 72, seg 0 (0.5) [0.5 on Epop[72]], weight: 4.1363508E-4, delay 1.5
        h("Epop[72] syn_projEE_ampa[712] = new ampa(0.5)")
        h("Epop[8] netConn_projEE_ampa[712] = new NetCon(&v(0.5), syn_projEE_ampa[712], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 713: cell 8, seg 0 (0.5) [0.5 on Epop[8]] -> cell 73, seg 0 (0.5) [0.5 on Epop[73]], weight: 4.1363508E-4, delay 1.5
        h("Epop[73] syn_projEE_ampa[713] = new ampa(0.5)")
        h("Epop[8] netConn_projEE_ampa[713] = new NetCon(&v(0.5), syn_projEE_ampa[713], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 714: cell 8, seg 0 (0.5) [0.5 on Epop[8]] -> cell 74, seg 0 (0.5) [0.5 on Epop[74]], weight: 4.1363508E-4, delay 1.5
        h("Epop[74] syn_projEE_ampa[714] = new ampa(0.5)")
        h("Epop[8] netConn_projEE_ampa[714] = new NetCon(&v(0.5), syn_projEE_ampa[714], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 715: cell 8, seg 0 (0.5) [0.5 on Epop[8]] -> cell 75, seg 0 (0.5) [0.5 on Epop[75]], weight: 4.1363508E-4, delay 1.5
        h("Epop[75] syn_projEE_ampa[715] = new ampa(0.5)")
        h("Epop[8] netConn_projEE_ampa[715] = new NetCon(&v(0.5), syn_projEE_ampa[715], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 716: cell 8, seg 0 (0.5) [0.5 on Epop[8]] -> cell 76, seg 0 (0.5) [0.5 on Epop[76]], weight: 4.1363508E-4, delay 1.5
        h("Epop[76] syn_projEE_ampa[716] = new ampa(0.5)")
        h("Epop[8] netConn_projEE_ampa[716] = new NetCon(&v(0.5), syn_projEE_ampa[716], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 717: cell 8, seg 0 (0.5) [0.5 on Epop[8]] -> cell 77, seg 0 (0.5) [0.5 on Epop[77]], weight: 4.1363508E-4, delay 1.5
        h("Epop[77] syn_projEE_ampa[717] = new ampa(0.5)")
        h("Epop[8] netConn_projEE_ampa[717] = new NetCon(&v(0.5), syn_projEE_ampa[717], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 718: cell 8, seg 0 (0.5) [0.5 on Epop[8]] -> cell 78, seg 0 (0.5) [0.5 on Epop[78]], weight: 4.1363508E-4, delay 1.5
        h("Epop[78] syn_projEE_ampa[718] = new ampa(0.5)")
        h("Epop[8] netConn_projEE_ampa[718] = new NetCon(&v(0.5), syn_projEE_ampa[718], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 719: cell 8, seg 0 (0.5) [0.5 on Epop[8]] -> cell 79, seg 0 (0.5) [0.5 on Epop[79]], weight: 4.1363508E-4, delay 1.5
        h("Epop[79] syn_projEE_ampa[719] = new ampa(0.5)")
        h("Epop[8] netConn_projEE_ampa[719] = new NetCon(&v(0.5), syn_projEE_ampa[719], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 720: cell 9, seg 0 (0.5) [0.5 on Epop[9]] -> cell 0, seg 0 (0.5) [0.5 on Epop[0]], weight: 4.1363508E-4, delay 1.5
        h("Epop[0] syn_projEE_ampa[720] = new ampa(0.5)")
        h("Epop[9] netConn_projEE_ampa[720] = new NetCon(&v(0.5), syn_projEE_ampa[720], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 721: cell 9, seg 0 (0.5) [0.5 on Epop[9]] -> cell 1, seg 0 (0.5) [0.5 on Epop[1]], weight: 4.1363508E-4, delay 1.5
        h("Epop[1] syn_projEE_ampa[721] = new ampa(0.5)")
        h("Epop[9] netConn_projEE_ampa[721] = new NetCon(&v(0.5), syn_projEE_ampa[721], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 722: cell 9, seg 0 (0.5) [0.5 on Epop[9]] -> cell 2, seg 0 (0.5) [0.5 on Epop[2]], weight: 4.1363508E-4, delay 1.5
        h("Epop[2] syn_projEE_ampa[722] = new ampa(0.5)")
        h("Epop[9] netConn_projEE_ampa[722] = new NetCon(&v(0.5), syn_projEE_ampa[722], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 723: cell 9, seg 0 (0.5) [0.5 on Epop[9]] -> cell 3, seg 0 (0.5) [0.5 on Epop[3]], weight: 4.1363508E-4, delay 1.5
        h("Epop[3] syn_projEE_ampa[723] = new ampa(0.5)")
        h("Epop[9] netConn_projEE_ampa[723] = new NetCon(&v(0.5), syn_projEE_ampa[723], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 724: cell 9, seg 0 (0.5) [0.5 on Epop[9]] -> cell 4, seg 0 (0.5) [0.5 on Epop[4]], weight: 4.1363508E-4, delay 1.5
        h("Epop[4] syn_projEE_ampa[724] = new ampa(0.5)")
        h("Epop[9] netConn_projEE_ampa[724] = new NetCon(&v(0.5), syn_projEE_ampa[724], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 725: cell 9, seg 0 (0.5) [0.5 on Epop[9]] -> cell 5, seg 0 (0.5) [0.5 on Epop[5]], weight: 4.1363508E-4, delay 1.5
        h("Epop[5] syn_projEE_ampa[725] = new ampa(0.5)")
        h("Epop[9] netConn_projEE_ampa[725] = new NetCon(&v(0.5), syn_projEE_ampa[725], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 726: cell 9, seg 0 (0.5) [0.5 on Epop[9]] -> cell 6, seg 0 (0.5) [0.5 on Epop[6]], weight: 4.1363508E-4, delay 1.5
        h("Epop[6] syn_projEE_ampa[726] = new ampa(0.5)")
        h("Epop[9] netConn_projEE_ampa[726] = new NetCon(&v(0.5), syn_projEE_ampa[726], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 727: cell 9, seg 0 (0.5) [0.5 on Epop[9]] -> cell 7, seg 0 (0.5) [0.5 on Epop[7]], weight: 4.1363508E-4, delay 1.5
        h("Epop[7] syn_projEE_ampa[727] = new ampa(0.5)")
        h("Epop[9] netConn_projEE_ampa[727] = new NetCon(&v(0.5), syn_projEE_ampa[727], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 728: cell 9, seg 0 (0.5) [0.5 on Epop[9]] -> cell 8, seg 0 (0.5) [0.5 on Epop[8]], weight: 4.1363508E-4, delay 1.5
        h("Epop[8] syn_projEE_ampa[728] = new ampa(0.5)")
        h("Epop[9] netConn_projEE_ampa[728] = new NetCon(&v(0.5), syn_projEE_ampa[728], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 729: cell 9, seg 0 (0.5) [0.5 on Epop[9]] -> cell 9, seg 0 (0.5) [0.5 on Epop[9]], weight: 4.1363508E-4, delay 1.5
        h("Epop[9] syn_projEE_ampa[729] = new ampa(0.5)")
        h("Epop[9] netConn_projEE_ampa[729] = new NetCon(&v(0.5), syn_projEE_ampa[729], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 730: cell 9, seg 0 (0.5) [0.5 on Epop[9]] -> cell 10, seg 0 (0.5) [0.5 on Epop[10]], weight: 4.1363508E-4, delay 1.5
        h("Epop[10] syn_projEE_ampa[730] = new ampa(0.5)")
        h("Epop[9] netConn_projEE_ampa[730] = new NetCon(&v(0.5), syn_projEE_ampa[730], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 731: cell 9, seg 0 (0.5) [0.5 on Epop[9]] -> cell 11, seg 0 (0.5) [0.5 on Epop[11]], weight: 4.1363508E-4, delay 1.5
        h("Epop[11] syn_projEE_ampa[731] = new ampa(0.5)")
        h("Epop[9] netConn_projEE_ampa[731] = new NetCon(&v(0.5), syn_projEE_ampa[731], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 732: cell 9, seg 0 (0.5) [0.5 on Epop[9]] -> cell 12, seg 0 (0.5) [0.5 on Epop[12]], weight: 4.1363508E-4, delay 1.5
        h("Epop[12] syn_projEE_ampa[732] = new ampa(0.5)")
        h("Epop[9] netConn_projEE_ampa[732] = new NetCon(&v(0.5), syn_projEE_ampa[732], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 733: cell 9, seg 0 (0.5) [0.5 on Epop[9]] -> cell 13, seg 0 (0.5) [0.5 on Epop[13]], weight: 4.1363508E-4, delay 1.5
        h("Epop[13] syn_projEE_ampa[733] = new ampa(0.5)")
        h("Epop[9] netConn_projEE_ampa[733] = new NetCon(&v(0.5), syn_projEE_ampa[733], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 734: cell 9, seg 0 (0.5) [0.5 on Epop[9]] -> cell 14, seg 0 (0.5) [0.5 on Epop[14]], weight: 4.1363508E-4, delay 1.5
        h("Epop[14] syn_projEE_ampa[734] = new ampa(0.5)")
        h("Epop[9] netConn_projEE_ampa[734] = new NetCon(&v(0.5), syn_projEE_ampa[734], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 735: cell 9, seg 0 (0.5) [0.5 on Epop[9]] -> cell 15, seg 0 (0.5) [0.5 on Epop[15]], weight: 4.1363508E-4, delay 1.5
        h("Epop[15] syn_projEE_ampa[735] = new ampa(0.5)")
        h("Epop[9] netConn_projEE_ampa[735] = new NetCon(&v(0.5), syn_projEE_ampa[735], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 736: cell 9, seg 0 (0.5) [0.5 on Epop[9]] -> cell 16, seg 0 (0.5) [0.5 on Epop[16]], weight: 4.1363508E-4, delay 1.5
        h("Epop[16] syn_projEE_ampa[736] = new ampa(0.5)")
        h("Epop[9] netConn_projEE_ampa[736] = new NetCon(&v(0.5), syn_projEE_ampa[736], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 737: cell 9, seg 0 (0.5) [0.5 on Epop[9]] -> cell 17, seg 0 (0.5) [0.5 on Epop[17]], weight: 4.1363508E-4, delay 1.5
        h("Epop[17] syn_projEE_ampa[737] = new ampa(0.5)")
        h("Epop[9] netConn_projEE_ampa[737] = new NetCon(&v(0.5), syn_projEE_ampa[737], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 738: cell 9, seg 0 (0.5) [0.5 on Epop[9]] -> cell 18, seg 0 (0.5) [0.5 on Epop[18]], weight: 4.1363508E-4, delay 1.5
        h("Epop[18] syn_projEE_ampa[738] = new ampa(0.5)")
        h("Epop[9] netConn_projEE_ampa[738] = new NetCon(&v(0.5), syn_projEE_ampa[738], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 739: cell 9, seg 0 (0.5) [0.5 on Epop[9]] -> cell 19, seg 0 (0.5) [0.5 on Epop[19]], weight: 4.1363508E-4, delay 1.5
        h("Epop[19] syn_projEE_ampa[739] = new ampa(0.5)")
        h("Epop[9] netConn_projEE_ampa[739] = new NetCon(&v(0.5), syn_projEE_ampa[739], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 740: cell 9, seg 0 (0.5) [0.5 on Epop[9]] -> cell 20, seg 0 (0.5) [0.5 on Epop[20]], weight: 4.1363508E-4, delay 1.5
        h("Epop[20] syn_projEE_ampa[740] = new ampa(0.5)")
        h("Epop[9] netConn_projEE_ampa[740] = new NetCon(&v(0.5), syn_projEE_ampa[740], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 741: cell 9, seg 0 (0.5) [0.5 on Epop[9]] -> cell 21, seg 0 (0.5) [0.5 on Epop[21]], weight: 4.1363508E-4, delay 1.5
        h("Epop[21] syn_projEE_ampa[741] = new ampa(0.5)")
        h("Epop[9] netConn_projEE_ampa[741] = new NetCon(&v(0.5), syn_projEE_ampa[741], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 742: cell 9, seg 0 (0.5) [0.5 on Epop[9]] -> cell 22, seg 0 (0.5) [0.5 on Epop[22]], weight: 4.1363508E-4, delay 1.5
        h("Epop[22] syn_projEE_ampa[742] = new ampa(0.5)")
        h("Epop[9] netConn_projEE_ampa[742] = new NetCon(&v(0.5), syn_projEE_ampa[742], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 743: cell 9, seg 0 (0.5) [0.5 on Epop[9]] -> cell 23, seg 0 (0.5) [0.5 on Epop[23]], weight: 4.1363508E-4, delay 1.5
        h("Epop[23] syn_projEE_ampa[743] = new ampa(0.5)")
        h("Epop[9] netConn_projEE_ampa[743] = new NetCon(&v(0.5), syn_projEE_ampa[743], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 744: cell 9, seg 0 (0.5) [0.5 on Epop[9]] -> cell 24, seg 0 (0.5) [0.5 on Epop[24]], weight: 4.1363508E-4, delay 1.5
        h("Epop[24] syn_projEE_ampa[744] = new ampa(0.5)")
        h("Epop[9] netConn_projEE_ampa[744] = new NetCon(&v(0.5), syn_projEE_ampa[744], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 745: cell 9, seg 0 (0.5) [0.5 on Epop[9]] -> cell 25, seg 0 (0.5) [0.5 on Epop[25]], weight: 4.1363508E-4, delay 1.5
        h("Epop[25] syn_projEE_ampa[745] = new ampa(0.5)")
        h("Epop[9] netConn_projEE_ampa[745] = new NetCon(&v(0.5), syn_projEE_ampa[745], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 746: cell 9, seg 0 (0.5) [0.5 on Epop[9]] -> cell 26, seg 0 (0.5) [0.5 on Epop[26]], weight: 4.1363508E-4, delay 1.5
        h("Epop[26] syn_projEE_ampa[746] = new ampa(0.5)")
        h("Epop[9] netConn_projEE_ampa[746] = new NetCon(&v(0.5), syn_projEE_ampa[746], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 747: cell 9, seg 0 (0.5) [0.5 on Epop[9]] -> cell 27, seg 0 (0.5) [0.5 on Epop[27]], weight: 4.1363508E-4, delay 1.5
        h("Epop[27] syn_projEE_ampa[747] = new ampa(0.5)")
        h("Epop[9] netConn_projEE_ampa[747] = new NetCon(&v(0.5), syn_projEE_ampa[747], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 748: cell 9, seg 0 (0.5) [0.5 on Epop[9]] -> cell 28, seg 0 (0.5) [0.5 on Epop[28]], weight: 4.1363508E-4, delay 1.5
        h("Epop[28] syn_projEE_ampa[748] = new ampa(0.5)")
        h("Epop[9] netConn_projEE_ampa[748] = new NetCon(&v(0.5), syn_projEE_ampa[748], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 749: cell 9, seg 0 (0.5) [0.5 on Epop[9]] -> cell 29, seg 0 (0.5) [0.5 on Epop[29]], weight: 4.1363508E-4, delay 1.5
        h("Epop[29] syn_projEE_ampa[749] = new ampa(0.5)")
        h("Epop[9] netConn_projEE_ampa[749] = new NetCon(&v(0.5), syn_projEE_ampa[749], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 750: cell 9, seg 0 (0.5) [0.5 on Epop[9]] -> cell 30, seg 0 (0.5) [0.5 on Epop[30]], weight: 4.1363508E-4, delay 1.5
        h("Epop[30] syn_projEE_ampa[750] = new ampa(0.5)")
        h("Epop[9] netConn_projEE_ampa[750] = new NetCon(&v(0.5), syn_projEE_ampa[750], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 751: cell 9, seg 0 (0.5) [0.5 on Epop[9]] -> cell 31, seg 0 (0.5) [0.5 on Epop[31]], weight: 4.1363508E-4, delay 1.5
        h("Epop[31] syn_projEE_ampa[751] = new ampa(0.5)")
        h("Epop[9] netConn_projEE_ampa[751] = new NetCon(&v(0.5), syn_projEE_ampa[751], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 752: cell 9, seg 0 (0.5) [0.5 on Epop[9]] -> cell 32, seg 0 (0.5) [0.5 on Epop[32]], weight: 4.1363508E-4, delay 1.5
        h("Epop[32] syn_projEE_ampa[752] = new ampa(0.5)")
        h("Epop[9] netConn_projEE_ampa[752] = new NetCon(&v(0.5), syn_projEE_ampa[752], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 753: cell 9, seg 0 (0.5) [0.5 on Epop[9]] -> cell 33, seg 0 (0.5) [0.5 on Epop[33]], weight: 4.1363508E-4, delay 1.5
        h("Epop[33] syn_projEE_ampa[753] = new ampa(0.5)")
        h("Epop[9] netConn_projEE_ampa[753] = new NetCon(&v(0.5), syn_projEE_ampa[753], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 754: cell 9, seg 0 (0.5) [0.5 on Epop[9]] -> cell 34, seg 0 (0.5) [0.5 on Epop[34]], weight: 4.1363508E-4, delay 1.5
        h("Epop[34] syn_projEE_ampa[754] = new ampa(0.5)")
        h("Epop[9] netConn_projEE_ampa[754] = new NetCon(&v(0.5), syn_projEE_ampa[754], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 755: cell 9, seg 0 (0.5) [0.5 on Epop[9]] -> cell 35, seg 0 (0.5) [0.5 on Epop[35]], weight: 4.1363508E-4, delay 1.5
        h("Epop[35] syn_projEE_ampa[755] = new ampa(0.5)")
        h("Epop[9] netConn_projEE_ampa[755] = new NetCon(&v(0.5), syn_projEE_ampa[755], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 756: cell 9, seg 0 (0.5) [0.5 on Epop[9]] -> cell 36, seg 0 (0.5) [0.5 on Epop[36]], weight: 4.1363508E-4, delay 1.5
        h("Epop[36] syn_projEE_ampa[756] = new ampa(0.5)")
        h("Epop[9] netConn_projEE_ampa[756] = new NetCon(&v(0.5), syn_projEE_ampa[756], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 757: cell 9, seg 0 (0.5) [0.5 on Epop[9]] -> cell 37, seg 0 (0.5) [0.5 on Epop[37]], weight: 4.1363508E-4, delay 1.5
        h("Epop[37] syn_projEE_ampa[757] = new ampa(0.5)")
        h("Epop[9] netConn_projEE_ampa[757] = new NetCon(&v(0.5), syn_projEE_ampa[757], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 758: cell 9, seg 0 (0.5) [0.5 on Epop[9]] -> cell 38, seg 0 (0.5) [0.5 on Epop[38]], weight: 4.1363508E-4, delay 1.5
        h("Epop[38] syn_projEE_ampa[758] = new ampa(0.5)")
        h("Epop[9] netConn_projEE_ampa[758] = new NetCon(&v(0.5), syn_projEE_ampa[758], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 759: cell 9, seg 0 (0.5) [0.5 on Epop[9]] -> cell 39, seg 0 (0.5) [0.5 on Epop[39]], weight: 4.1363508E-4, delay 1.5
        h("Epop[39] syn_projEE_ampa[759] = new ampa(0.5)")
        h("Epop[9] netConn_projEE_ampa[759] = new NetCon(&v(0.5), syn_projEE_ampa[759], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 760: cell 9, seg 0 (0.5) [0.5 on Epop[9]] -> cell 40, seg 0 (0.5) [0.5 on Epop[40]], weight: 4.1363508E-4, delay 1.5
        h("Epop[40] syn_projEE_ampa[760] = new ampa(0.5)")
        h("Epop[9] netConn_projEE_ampa[760] = new NetCon(&v(0.5), syn_projEE_ampa[760], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 761: cell 9, seg 0 (0.5) [0.5 on Epop[9]] -> cell 41, seg 0 (0.5) [0.5 on Epop[41]], weight: 4.1363508E-4, delay 1.5
        h("Epop[41] syn_projEE_ampa[761] = new ampa(0.5)")
        h("Epop[9] netConn_projEE_ampa[761] = new NetCon(&v(0.5), syn_projEE_ampa[761], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 762: cell 9, seg 0 (0.5) [0.5 on Epop[9]] -> cell 42, seg 0 (0.5) [0.5 on Epop[42]], weight: 4.1363508E-4, delay 1.5
        h("Epop[42] syn_projEE_ampa[762] = new ampa(0.5)")
        h("Epop[9] netConn_projEE_ampa[762] = new NetCon(&v(0.5), syn_projEE_ampa[762], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 763: cell 9, seg 0 (0.5) [0.5 on Epop[9]] -> cell 43, seg 0 (0.5) [0.5 on Epop[43]], weight: 4.1363508E-4, delay 1.5
        h("Epop[43] syn_projEE_ampa[763] = new ampa(0.5)")
        h("Epop[9] netConn_projEE_ampa[763] = new NetCon(&v(0.5), syn_projEE_ampa[763], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 764: cell 9, seg 0 (0.5) [0.5 on Epop[9]] -> cell 44, seg 0 (0.5) [0.5 on Epop[44]], weight: 4.1363508E-4, delay 1.5
        h("Epop[44] syn_projEE_ampa[764] = new ampa(0.5)")
        h("Epop[9] netConn_projEE_ampa[764] = new NetCon(&v(0.5), syn_projEE_ampa[764], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 765: cell 9, seg 0 (0.5) [0.5 on Epop[9]] -> cell 45, seg 0 (0.5) [0.5 on Epop[45]], weight: 4.1363508E-4, delay 1.5
        h("Epop[45] syn_projEE_ampa[765] = new ampa(0.5)")
        h("Epop[9] netConn_projEE_ampa[765] = new NetCon(&v(0.5), syn_projEE_ampa[765], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 766: cell 9, seg 0 (0.5) [0.5 on Epop[9]] -> cell 46, seg 0 (0.5) [0.5 on Epop[46]], weight: 4.1363508E-4, delay 1.5
        h("Epop[46] syn_projEE_ampa[766] = new ampa(0.5)")
        h("Epop[9] netConn_projEE_ampa[766] = new NetCon(&v(0.5), syn_projEE_ampa[766], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 767: cell 9, seg 0 (0.5) [0.5 on Epop[9]] -> cell 47, seg 0 (0.5) [0.5 on Epop[47]], weight: 4.1363508E-4, delay 1.5
        h("Epop[47] syn_projEE_ampa[767] = new ampa(0.5)")
        h("Epop[9] netConn_projEE_ampa[767] = new NetCon(&v(0.5), syn_projEE_ampa[767], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 768: cell 9, seg 0 (0.5) [0.5 on Epop[9]] -> cell 48, seg 0 (0.5) [0.5 on Epop[48]], weight: 4.1363508E-4, delay 1.5
        h("Epop[48] syn_projEE_ampa[768] = new ampa(0.5)")
        h("Epop[9] netConn_projEE_ampa[768] = new NetCon(&v(0.5), syn_projEE_ampa[768], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 769: cell 9, seg 0 (0.5) [0.5 on Epop[9]] -> cell 49, seg 0 (0.5) [0.5 on Epop[49]], weight: 4.1363508E-4, delay 1.5
        h("Epop[49] syn_projEE_ampa[769] = new ampa(0.5)")
        h("Epop[9] netConn_projEE_ampa[769] = new NetCon(&v(0.5), syn_projEE_ampa[769], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 770: cell 9, seg 0 (0.5) [0.5 on Epop[9]] -> cell 50, seg 0 (0.5) [0.5 on Epop[50]], weight: 4.1363508E-4, delay 1.5
        h("Epop[50] syn_projEE_ampa[770] = new ampa(0.5)")
        h("Epop[9] netConn_projEE_ampa[770] = new NetCon(&v(0.5), syn_projEE_ampa[770], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 771: cell 9, seg 0 (0.5) [0.5 on Epop[9]] -> cell 51, seg 0 (0.5) [0.5 on Epop[51]], weight: 4.1363508E-4, delay 1.5
        h("Epop[51] syn_projEE_ampa[771] = new ampa(0.5)")
        h("Epop[9] netConn_projEE_ampa[771] = new NetCon(&v(0.5), syn_projEE_ampa[771], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 772: cell 9, seg 0 (0.5) [0.5 on Epop[9]] -> cell 52, seg 0 (0.5) [0.5 on Epop[52]], weight: 4.1363508E-4, delay 1.5
        h("Epop[52] syn_projEE_ampa[772] = new ampa(0.5)")
        h("Epop[9] netConn_projEE_ampa[772] = new NetCon(&v(0.5), syn_projEE_ampa[772], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 773: cell 9, seg 0 (0.5) [0.5 on Epop[9]] -> cell 53, seg 0 (0.5) [0.5 on Epop[53]], weight: 4.1363508E-4, delay 1.5
        h("Epop[53] syn_projEE_ampa[773] = new ampa(0.5)")
        h("Epop[9] netConn_projEE_ampa[773] = new NetCon(&v(0.5), syn_projEE_ampa[773], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 774: cell 9, seg 0 (0.5) [0.5 on Epop[9]] -> cell 54, seg 0 (0.5) [0.5 on Epop[54]], weight: 4.1363508E-4, delay 1.5
        h("Epop[54] syn_projEE_ampa[774] = new ampa(0.5)")
        h("Epop[9] netConn_projEE_ampa[774] = new NetCon(&v(0.5), syn_projEE_ampa[774], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 775: cell 9, seg 0 (0.5) [0.5 on Epop[9]] -> cell 55, seg 0 (0.5) [0.5 on Epop[55]], weight: 4.1363508E-4, delay 1.5
        h("Epop[55] syn_projEE_ampa[775] = new ampa(0.5)")
        h("Epop[9] netConn_projEE_ampa[775] = new NetCon(&v(0.5), syn_projEE_ampa[775], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 776: cell 9, seg 0 (0.5) [0.5 on Epop[9]] -> cell 56, seg 0 (0.5) [0.5 on Epop[56]], weight: 4.1363508E-4, delay 1.5
        h("Epop[56] syn_projEE_ampa[776] = new ampa(0.5)")
        h("Epop[9] netConn_projEE_ampa[776] = new NetCon(&v(0.5), syn_projEE_ampa[776], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 777: cell 9, seg 0 (0.5) [0.5 on Epop[9]] -> cell 57, seg 0 (0.5) [0.5 on Epop[57]], weight: 4.1363508E-4, delay 1.5
        h("Epop[57] syn_projEE_ampa[777] = new ampa(0.5)")
        h("Epop[9] netConn_projEE_ampa[777] = new NetCon(&v(0.5), syn_projEE_ampa[777], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 778: cell 9, seg 0 (0.5) [0.5 on Epop[9]] -> cell 58, seg 0 (0.5) [0.5 on Epop[58]], weight: 4.1363508E-4, delay 1.5
        h("Epop[58] syn_projEE_ampa[778] = new ampa(0.5)")
        h("Epop[9] netConn_projEE_ampa[778] = new NetCon(&v(0.5), syn_projEE_ampa[778], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 779: cell 9, seg 0 (0.5) [0.5 on Epop[9]] -> cell 59, seg 0 (0.5) [0.5 on Epop[59]], weight: 4.1363508E-4, delay 1.5
        h("Epop[59] syn_projEE_ampa[779] = new ampa(0.5)")
        h("Epop[9] netConn_projEE_ampa[779] = new NetCon(&v(0.5), syn_projEE_ampa[779], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 780: cell 9, seg 0 (0.5) [0.5 on Epop[9]] -> cell 60, seg 0 (0.5) [0.5 on Epop[60]], weight: 4.1363508E-4, delay 1.5
        h("Epop[60] syn_projEE_ampa[780] = new ampa(0.5)")
        h("Epop[9] netConn_projEE_ampa[780] = new NetCon(&v(0.5), syn_projEE_ampa[780], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 781: cell 9, seg 0 (0.5) [0.5 on Epop[9]] -> cell 61, seg 0 (0.5) [0.5 on Epop[61]], weight: 4.1363508E-4, delay 1.5
        h("Epop[61] syn_projEE_ampa[781] = new ampa(0.5)")
        h("Epop[9] netConn_projEE_ampa[781] = new NetCon(&v(0.5), syn_projEE_ampa[781], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 782: cell 9, seg 0 (0.5) [0.5 on Epop[9]] -> cell 62, seg 0 (0.5) [0.5 on Epop[62]], weight: 4.1363508E-4, delay 1.5
        h("Epop[62] syn_projEE_ampa[782] = new ampa(0.5)")
        h("Epop[9] netConn_projEE_ampa[782] = new NetCon(&v(0.5), syn_projEE_ampa[782], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 783: cell 9, seg 0 (0.5) [0.5 on Epop[9]] -> cell 63, seg 0 (0.5) [0.5 on Epop[63]], weight: 4.1363508E-4, delay 1.5
        h("Epop[63] syn_projEE_ampa[783] = new ampa(0.5)")
        h("Epop[9] netConn_projEE_ampa[783] = new NetCon(&v(0.5), syn_projEE_ampa[783], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 784: cell 9, seg 0 (0.5) [0.5 on Epop[9]] -> cell 64, seg 0 (0.5) [0.5 on Epop[64]], weight: 4.1363508E-4, delay 1.5
        h("Epop[64] syn_projEE_ampa[784] = new ampa(0.5)")
        h("Epop[9] netConn_projEE_ampa[784] = new NetCon(&v(0.5), syn_projEE_ampa[784], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 785: cell 9, seg 0 (0.5) [0.5 on Epop[9]] -> cell 65, seg 0 (0.5) [0.5 on Epop[65]], weight: 4.1363508E-4, delay 1.5
        h("Epop[65] syn_projEE_ampa[785] = new ampa(0.5)")
        h("Epop[9] netConn_projEE_ampa[785] = new NetCon(&v(0.5), syn_projEE_ampa[785], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 786: cell 9, seg 0 (0.5) [0.5 on Epop[9]] -> cell 66, seg 0 (0.5) [0.5 on Epop[66]], weight: 4.1363508E-4, delay 1.5
        h("Epop[66] syn_projEE_ampa[786] = new ampa(0.5)")
        h("Epop[9] netConn_projEE_ampa[786] = new NetCon(&v(0.5), syn_projEE_ampa[786], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 787: cell 9, seg 0 (0.5) [0.5 on Epop[9]] -> cell 67, seg 0 (0.5) [0.5 on Epop[67]], weight: 4.1363508E-4, delay 1.5
        h("Epop[67] syn_projEE_ampa[787] = new ampa(0.5)")
        h("Epop[9] netConn_projEE_ampa[787] = new NetCon(&v(0.5), syn_projEE_ampa[787], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 788: cell 9, seg 0 (0.5) [0.5 on Epop[9]] -> cell 68, seg 0 (0.5) [0.5 on Epop[68]], weight: 4.1363508E-4, delay 1.5
        h("Epop[68] syn_projEE_ampa[788] = new ampa(0.5)")
        h("Epop[9] netConn_projEE_ampa[788] = new NetCon(&v(0.5), syn_projEE_ampa[788], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 789: cell 9, seg 0 (0.5) [0.5 on Epop[9]] -> cell 69, seg 0 (0.5) [0.5 on Epop[69]], weight: 4.1363508E-4, delay 1.5
        h("Epop[69] syn_projEE_ampa[789] = new ampa(0.5)")
        h("Epop[9] netConn_projEE_ampa[789] = new NetCon(&v(0.5), syn_projEE_ampa[789], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 790: cell 9, seg 0 (0.5) [0.5 on Epop[9]] -> cell 70, seg 0 (0.5) [0.5 on Epop[70]], weight: 4.1363508E-4, delay 1.5
        h("Epop[70] syn_projEE_ampa[790] = new ampa(0.5)")
        h("Epop[9] netConn_projEE_ampa[790] = new NetCon(&v(0.5), syn_projEE_ampa[790], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 791: cell 9, seg 0 (0.5) [0.5 on Epop[9]] -> cell 71, seg 0 (0.5) [0.5 on Epop[71]], weight: 4.1363508E-4, delay 1.5
        h("Epop[71] syn_projEE_ampa[791] = new ampa(0.5)")
        h("Epop[9] netConn_projEE_ampa[791] = new NetCon(&v(0.5), syn_projEE_ampa[791], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 792: cell 9, seg 0 (0.5) [0.5 on Epop[9]] -> cell 72, seg 0 (0.5) [0.5 on Epop[72]], weight: 4.1363508E-4, delay 1.5
        h("Epop[72] syn_projEE_ampa[792] = new ampa(0.5)")
        h("Epop[9] netConn_projEE_ampa[792] = new NetCon(&v(0.5), syn_projEE_ampa[792], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 793: cell 9, seg 0 (0.5) [0.5 on Epop[9]] -> cell 73, seg 0 (0.5) [0.5 on Epop[73]], weight: 4.1363508E-4, delay 1.5
        h("Epop[73] syn_projEE_ampa[793] = new ampa(0.5)")
        h("Epop[9] netConn_projEE_ampa[793] = new NetCon(&v(0.5), syn_projEE_ampa[793], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 794: cell 9, seg 0 (0.5) [0.5 on Epop[9]] -> cell 74, seg 0 (0.5) [0.5 on Epop[74]], weight: 4.1363508E-4, delay 1.5
        h("Epop[74] syn_projEE_ampa[794] = new ampa(0.5)")
        h("Epop[9] netConn_projEE_ampa[794] = new NetCon(&v(0.5), syn_projEE_ampa[794], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 795: cell 9, seg 0 (0.5) [0.5 on Epop[9]] -> cell 75, seg 0 (0.5) [0.5 on Epop[75]], weight: 4.1363508E-4, delay 1.5
        h("Epop[75] syn_projEE_ampa[795] = new ampa(0.5)")
        h("Epop[9] netConn_projEE_ampa[795] = new NetCon(&v(0.5), syn_projEE_ampa[795], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 796: cell 9, seg 0 (0.5) [0.5 on Epop[9]] -> cell 76, seg 0 (0.5) [0.5 on Epop[76]], weight: 4.1363508E-4, delay 1.5
        h("Epop[76] syn_projEE_ampa[796] = new ampa(0.5)")
        h("Epop[9] netConn_projEE_ampa[796] = new NetCon(&v(0.5), syn_projEE_ampa[796], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 797: cell 9, seg 0 (0.5) [0.5 on Epop[9]] -> cell 77, seg 0 (0.5) [0.5 on Epop[77]], weight: 4.1363508E-4, delay 1.5
        h("Epop[77] syn_projEE_ampa[797] = new ampa(0.5)")
        h("Epop[9] netConn_projEE_ampa[797] = new NetCon(&v(0.5), syn_projEE_ampa[797], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 798: cell 9, seg 0 (0.5) [0.5 on Epop[9]] -> cell 78, seg 0 (0.5) [0.5 on Epop[78]], weight: 4.1363508E-4, delay 1.5
        h("Epop[78] syn_projEE_ampa[798] = new ampa(0.5)")
        h("Epop[9] netConn_projEE_ampa[798] = new NetCon(&v(0.5), syn_projEE_ampa[798], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 799: cell 9, seg 0 (0.5) [0.5 on Epop[9]] -> cell 79, seg 0 (0.5) [0.5 on Epop[79]], weight: 4.1363508E-4, delay 1.5
        h("Epop[79] syn_projEE_ampa[799] = new ampa(0.5)")
        h("Epop[9] netConn_projEE_ampa[799] = new NetCon(&v(0.5), syn_projEE_ampa[799], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 800: cell 10, seg 0 (0.5) [0.5 on Epop[10]] -> cell 0, seg 0 (0.5) [0.5 on Epop[0]], weight: 4.1363508E-4, delay 1.5
        h("Epop[0] syn_projEE_ampa[800] = new ampa(0.5)")
        h("Epop[10] netConn_projEE_ampa[800] = new NetCon(&v(0.5), syn_projEE_ampa[800], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 801: cell 10, seg 0 (0.5) [0.5 on Epop[10]] -> cell 1, seg 0 (0.5) [0.5 on Epop[1]], weight: 4.1363508E-4, delay 1.5
        h("Epop[1] syn_projEE_ampa[801] = new ampa(0.5)")
        h("Epop[10] netConn_projEE_ampa[801] = new NetCon(&v(0.5), syn_projEE_ampa[801], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 802: cell 10, seg 0 (0.5) [0.5 on Epop[10]] -> cell 2, seg 0 (0.5) [0.5 on Epop[2]], weight: 4.1363508E-4, delay 1.5
        h("Epop[2] syn_projEE_ampa[802] = new ampa(0.5)")
        h("Epop[10] netConn_projEE_ampa[802] = new NetCon(&v(0.5), syn_projEE_ampa[802], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 803: cell 10, seg 0 (0.5) [0.5 on Epop[10]] -> cell 3, seg 0 (0.5) [0.5 on Epop[3]], weight: 4.1363508E-4, delay 1.5
        h("Epop[3] syn_projEE_ampa[803] = new ampa(0.5)")
        h("Epop[10] netConn_projEE_ampa[803] = new NetCon(&v(0.5), syn_projEE_ampa[803], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 804: cell 10, seg 0 (0.5) [0.5 on Epop[10]] -> cell 4, seg 0 (0.5) [0.5 on Epop[4]], weight: 4.1363508E-4, delay 1.5
        h("Epop[4] syn_projEE_ampa[804] = new ampa(0.5)")
        h("Epop[10] netConn_projEE_ampa[804] = new NetCon(&v(0.5), syn_projEE_ampa[804], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 805: cell 10, seg 0 (0.5) [0.5 on Epop[10]] -> cell 5, seg 0 (0.5) [0.5 on Epop[5]], weight: 4.1363508E-4, delay 1.5
        h("Epop[5] syn_projEE_ampa[805] = new ampa(0.5)")
        h("Epop[10] netConn_projEE_ampa[805] = new NetCon(&v(0.5), syn_projEE_ampa[805], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 806: cell 10, seg 0 (0.5) [0.5 on Epop[10]] -> cell 6, seg 0 (0.5) [0.5 on Epop[6]], weight: 4.1363508E-4, delay 1.5
        h("Epop[6] syn_projEE_ampa[806] = new ampa(0.5)")
        h("Epop[10] netConn_projEE_ampa[806] = new NetCon(&v(0.5), syn_projEE_ampa[806], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 807: cell 10, seg 0 (0.5) [0.5 on Epop[10]] -> cell 7, seg 0 (0.5) [0.5 on Epop[7]], weight: 4.1363508E-4, delay 1.5
        h("Epop[7] syn_projEE_ampa[807] = new ampa(0.5)")
        h("Epop[10] netConn_projEE_ampa[807] = new NetCon(&v(0.5), syn_projEE_ampa[807], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 808: cell 10, seg 0 (0.5) [0.5 on Epop[10]] -> cell 8, seg 0 (0.5) [0.5 on Epop[8]], weight: 4.1363508E-4, delay 1.5
        h("Epop[8] syn_projEE_ampa[808] = new ampa(0.5)")
        h("Epop[10] netConn_projEE_ampa[808] = new NetCon(&v(0.5), syn_projEE_ampa[808], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 809: cell 10, seg 0 (0.5) [0.5 on Epop[10]] -> cell 9, seg 0 (0.5) [0.5 on Epop[9]], weight: 4.1363508E-4, delay 1.5
        h("Epop[9] syn_projEE_ampa[809] = new ampa(0.5)")
        h("Epop[10] netConn_projEE_ampa[809] = new NetCon(&v(0.5), syn_projEE_ampa[809], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 810: cell 10, seg 0 (0.5) [0.5 on Epop[10]] -> cell 10, seg 0 (0.5) [0.5 on Epop[10]], weight: 4.1363508E-4, delay 1.5
        h("Epop[10] syn_projEE_ampa[810] = new ampa(0.5)")
        h("Epop[10] netConn_projEE_ampa[810] = new NetCon(&v(0.5), syn_projEE_ampa[810], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 811: cell 10, seg 0 (0.5) [0.5 on Epop[10]] -> cell 11, seg 0 (0.5) [0.5 on Epop[11]], weight: 4.1363508E-4, delay 1.5
        h("Epop[11] syn_projEE_ampa[811] = new ampa(0.5)")
        h("Epop[10] netConn_projEE_ampa[811] = new NetCon(&v(0.5), syn_projEE_ampa[811], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 812: cell 10, seg 0 (0.5) [0.5 on Epop[10]] -> cell 12, seg 0 (0.5) [0.5 on Epop[12]], weight: 4.1363508E-4, delay 1.5
        h("Epop[12] syn_projEE_ampa[812] = new ampa(0.5)")
        h("Epop[10] netConn_projEE_ampa[812] = new NetCon(&v(0.5), syn_projEE_ampa[812], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 813: cell 10, seg 0 (0.5) [0.5 on Epop[10]] -> cell 13, seg 0 (0.5) [0.5 on Epop[13]], weight: 4.1363508E-4, delay 1.5
        h("Epop[13] syn_projEE_ampa[813] = new ampa(0.5)")
        h("Epop[10] netConn_projEE_ampa[813] = new NetCon(&v(0.5), syn_projEE_ampa[813], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 814: cell 10, seg 0 (0.5) [0.5 on Epop[10]] -> cell 14, seg 0 (0.5) [0.5 on Epop[14]], weight: 4.1363508E-4, delay 1.5
        h("Epop[14] syn_projEE_ampa[814] = new ampa(0.5)")
        h("Epop[10] netConn_projEE_ampa[814] = new NetCon(&v(0.5), syn_projEE_ampa[814], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 815: cell 10, seg 0 (0.5) [0.5 on Epop[10]] -> cell 15, seg 0 (0.5) [0.5 on Epop[15]], weight: 4.1363508E-4, delay 1.5
        h("Epop[15] syn_projEE_ampa[815] = new ampa(0.5)")
        h("Epop[10] netConn_projEE_ampa[815] = new NetCon(&v(0.5), syn_projEE_ampa[815], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 816: cell 10, seg 0 (0.5) [0.5 on Epop[10]] -> cell 16, seg 0 (0.5) [0.5 on Epop[16]], weight: 4.1363508E-4, delay 1.5
        h("Epop[16] syn_projEE_ampa[816] = new ampa(0.5)")
        h("Epop[10] netConn_projEE_ampa[816] = new NetCon(&v(0.5), syn_projEE_ampa[816], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 817: cell 10, seg 0 (0.5) [0.5 on Epop[10]] -> cell 17, seg 0 (0.5) [0.5 on Epop[17]], weight: 4.1363508E-4, delay 1.5
        h("Epop[17] syn_projEE_ampa[817] = new ampa(0.5)")
        h("Epop[10] netConn_projEE_ampa[817] = new NetCon(&v(0.5), syn_projEE_ampa[817], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 818: cell 10, seg 0 (0.5) [0.5 on Epop[10]] -> cell 18, seg 0 (0.5) [0.5 on Epop[18]], weight: 4.1363508E-4, delay 1.5
        h("Epop[18] syn_projEE_ampa[818] = new ampa(0.5)")
        h("Epop[10] netConn_projEE_ampa[818] = new NetCon(&v(0.5), syn_projEE_ampa[818], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 819: cell 10, seg 0 (0.5) [0.5 on Epop[10]] -> cell 19, seg 0 (0.5) [0.5 on Epop[19]], weight: 4.1363508E-4, delay 1.5
        h("Epop[19] syn_projEE_ampa[819] = new ampa(0.5)")
        h("Epop[10] netConn_projEE_ampa[819] = new NetCon(&v(0.5), syn_projEE_ampa[819], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 820: cell 10, seg 0 (0.5) [0.5 on Epop[10]] -> cell 20, seg 0 (0.5) [0.5 on Epop[20]], weight: 4.1363508E-4, delay 1.5
        h("Epop[20] syn_projEE_ampa[820] = new ampa(0.5)")
        h("Epop[10] netConn_projEE_ampa[820] = new NetCon(&v(0.5), syn_projEE_ampa[820], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 821: cell 10, seg 0 (0.5) [0.5 on Epop[10]] -> cell 21, seg 0 (0.5) [0.5 on Epop[21]], weight: 4.1363508E-4, delay 1.5
        h("Epop[21] syn_projEE_ampa[821] = new ampa(0.5)")
        h("Epop[10] netConn_projEE_ampa[821] = new NetCon(&v(0.5), syn_projEE_ampa[821], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 822: cell 10, seg 0 (0.5) [0.5 on Epop[10]] -> cell 22, seg 0 (0.5) [0.5 on Epop[22]], weight: 4.1363508E-4, delay 1.5
        h("Epop[22] syn_projEE_ampa[822] = new ampa(0.5)")
        h("Epop[10] netConn_projEE_ampa[822] = new NetCon(&v(0.5), syn_projEE_ampa[822], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 823: cell 10, seg 0 (0.5) [0.5 on Epop[10]] -> cell 23, seg 0 (0.5) [0.5 on Epop[23]], weight: 4.1363508E-4, delay 1.5
        h("Epop[23] syn_projEE_ampa[823] = new ampa(0.5)")
        h("Epop[10] netConn_projEE_ampa[823] = new NetCon(&v(0.5), syn_projEE_ampa[823], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 824: cell 10, seg 0 (0.5) [0.5 on Epop[10]] -> cell 24, seg 0 (0.5) [0.5 on Epop[24]], weight: 4.1363508E-4, delay 1.5
        h("Epop[24] syn_projEE_ampa[824] = new ampa(0.5)")
        h("Epop[10] netConn_projEE_ampa[824] = new NetCon(&v(0.5), syn_projEE_ampa[824], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 825: cell 10, seg 0 (0.5) [0.5 on Epop[10]] -> cell 25, seg 0 (0.5) [0.5 on Epop[25]], weight: 4.1363508E-4, delay 1.5
        h("Epop[25] syn_projEE_ampa[825] = new ampa(0.5)")
        h("Epop[10] netConn_projEE_ampa[825] = new NetCon(&v(0.5), syn_projEE_ampa[825], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 826: cell 10, seg 0 (0.5) [0.5 on Epop[10]] -> cell 26, seg 0 (0.5) [0.5 on Epop[26]], weight: 4.1363508E-4, delay 1.5
        h("Epop[26] syn_projEE_ampa[826] = new ampa(0.5)")
        h("Epop[10] netConn_projEE_ampa[826] = new NetCon(&v(0.5), syn_projEE_ampa[826], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 827: cell 10, seg 0 (0.5) [0.5 on Epop[10]] -> cell 27, seg 0 (0.5) [0.5 on Epop[27]], weight: 4.1363508E-4, delay 1.5
        h("Epop[27] syn_projEE_ampa[827] = new ampa(0.5)")
        h("Epop[10] netConn_projEE_ampa[827] = new NetCon(&v(0.5), syn_projEE_ampa[827], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 828: cell 10, seg 0 (0.5) [0.5 on Epop[10]] -> cell 28, seg 0 (0.5) [0.5 on Epop[28]], weight: 4.1363508E-4, delay 1.5
        h("Epop[28] syn_projEE_ampa[828] = new ampa(0.5)")
        h("Epop[10] netConn_projEE_ampa[828] = new NetCon(&v(0.5), syn_projEE_ampa[828], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 829: cell 10, seg 0 (0.5) [0.5 on Epop[10]] -> cell 29, seg 0 (0.5) [0.5 on Epop[29]], weight: 4.1363508E-4, delay 1.5
        h("Epop[29] syn_projEE_ampa[829] = new ampa(0.5)")
        h("Epop[10] netConn_projEE_ampa[829] = new NetCon(&v(0.5), syn_projEE_ampa[829], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 830: cell 10, seg 0 (0.5) [0.5 on Epop[10]] -> cell 30, seg 0 (0.5) [0.5 on Epop[30]], weight: 4.1363508E-4, delay 1.5
        h("Epop[30] syn_projEE_ampa[830] = new ampa(0.5)")
        h("Epop[10] netConn_projEE_ampa[830] = new NetCon(&v(0.5), syn_projEE_ampa[830], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 831: cell 10, seg 0 (0.5) [0.5 on Epop[10]] -> cell 31, seg 0 (0.5) [0.5 on Epop[31]], weight: 4.1363508E-4, delay 1.5
        h("Epop[31] syn_projEE_ampa[831] = new ampa(0.5)")
        h("Epop[10] netConn_projEE_ampa[831] = new NetCon(&v(0.5), syn_projEE_ampa[831], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 832: cell 10, seg 0 (0.5) [0.5 on Epop[10]] -> cell 32, seg 0 (0.5) [0.5 on Epop[32]], weight: 4.1363508E-4, delay 1.5
        h("Epop[32] syn_projEE_ampa[832] = new ampa(0.5)")
        h("Epop[10] netConn_projEE_ampa[832] = new NetCon(&v(0.5), syn_projEE_ampa[832], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 833: cell 10, seg 0 (0.5) [0.5 on Epop[10]] -> cell 33, seg 0 (0.5) [0.5 on Epop[33]], weight: 4.1363508E-4, delay 1.5
        h("Epop[33] syn_projEE_ampa[833] = new ampa(0.5)")
        h("Epop[10] netConn_projEE_ampa[833] = new NetCon(&v(0.5), syn_projEE_ampa[833], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 834: cell 10, seg 0 (0.5) [0.5 on Epop[10]] -> cell 34, seg 0 (0.5) [0.5 on Epop[34]], weight: 4.1363508E-4, delay 1.5
        h("Epop[34] syn_projEE_ampa[834] = new ampa(0.5)")
        h("Epop[10] netConn_projEE_ampa[834] = new NetCon(&v(0.5), syn_projEE_ampa[834], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 835: cell 10, seg 0 (0.5) [0.5 on Epop[10]] -> cell 35, seg 0 (0.5) [0.5 on Epop[35]], weight: 4.1363508E-4, delay 1.5
        h("Epop[35] syn_projEE_ampa[835] = new ampa(0.5)")
        h("Epop[10] netConn_projEE_ampa[835] = new NetCon(&v(0.5), syn_projEE_ampa[835], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 836: cell 10, seg 0 (0.5) [0.5 on Epop[10]] -> cell 36, seg 0 (0.5) [0.5 on Epop[36]], weight: 4.1363508E-4, delay 1.5
        h("Epop[36] syn_projEE_ampa[836] = new ampa(0.5)")
        h("Epop[10] netConn_projEE_ampa[836] = new NetCon(&v(0.5), syn_projEE_ampa[836], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 837: cell 10, seg 0 (0.5) [0.5 on Epop[10]] -> cell 37, seg 0 (0.5) [0.5 on Epop[37]], weight: 4.1363508E-4, delay 1.5
        h("Epop[37] syn_projEE_ampa[837] = new ampa(0.5)")
        h("Epop[10] netConn_projEE_ampa[837] = new NetCon(&v(0.5), syn_projEE_ampa[837], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 838: cell 10, seg 0 (0.5) [0.5 on Epop[10]] -> cell 38, seg 0 (0.5) [0.5 on Epop[38]], weight: 4.1363508E-4, delay 1.5
        h("Epop[38] syn_projEE_ampa[838] = new ampa(0.5)")
        h("Epop[10] netConn_projEE_ampa[838] = new NetCon(&v(0.5), syn_projEE_ampa[838], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 839: cell 10, seg 0 (0.5) [0.5 on Epop[10]] -> cell 39, seg 0 (0.5) [0.5 on Epop[39]], weight: 4.1363508E-4, delay 1.5
        h("Epop[39] syn_projEE_ampa[839] = new ampa(0.5)")
        h("Epop[10] netConn_projEE_ampa[839] = new NetCon(&v(0.5), syn_projEE_ampa[839], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 840: cell 10, seg 0 (0.5) [0.5 on Epop[10]] -> cell 40, seg 0 (0.5) [0.5 on Epop[40]], weight: 4.1363508E-4, delay 1.5
        h("Epop[40] syn_projEE_ampa[840] = new ampa(0.5)")
        h("Epop[10] netConn_projEE_ampa[840] = new NetCon(&v(0.5), syn_projEE_ampa[840], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 841: cell 10, seg 0 (0.5) [0.5 on Epop[10]] -> cell 41, seg 0 (0.5) [0.5 on Epop[41]], weight: 4.1363508E-4, delay 1.5
        h("Epop[41] syn_projEE_ampa[841] = new ampa(0.5)")
        h("Epop[10] netConn_projEE_ampa[841] = new NetCon(&v(0.5), syn_projEE_ampa[841], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 842: cell 10, seg 0 (0.5) [0.5 on Epop[10]] -> cell 42, seg 0 (0.5) [0.5 on Epop[42]], weight: 4.1363508E-4, delay 1.5
        h("Epop[42] syn_projEE_ampa[842] = new ampa(0.5)")
        h("Epop[10] netConn_projEE_ampa[842] = new NetCon(&v(0.5), syn_projEE_ampa[842], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 843: cell 10, seg 0 (0.5) [0.5 on Epop[10]] -> cell 43, seg 0 (0.5) [0.5 on Epop[43]], weight: 4.1363508E-4, delay 1.5
        h("Epop[43] syn_projEE_ampa[843] = new ampa(0.5)")
        h("Epop[10] netConn_projEE_ampa[843] = new NetCon(&v(0.5), syn_projEE_ampa[843], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 844: cell 10, seg 0 (0.5) [0.5 on Epop[10]] -> cell 44, seg 0 (0.5) [0.5 on Epop[44]], weight: 4.1363508E-4, delay 1.5
        h("Epop[44] syn_projEE_ampa[844] = new ampa(0.5)")
        h("Epop[10] netConn_projEE_ampa[844] = new NetCon(&v(0.5), syn_projEE_ampa[844], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 845: cell 10, seg 0 (0.5) [0.5 on Epop[10]] -> cell 45, seg 0 (0.5) [0.5 on Epop[45]], weight: 4.1363508E-4, delay 1.5
        h("Epop[45] syn_projEE_ampa[845] = new ampa(0.5)")
        h("Epop[10] netConn_projEE_ampa[845] = new NetCon(&v(0.5), syn_projEE_ampa[845], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 846: cell 10, seg 0 (0.5) [0.5 on Epop[10]] -> cell 46, seg 0 (0.5) [0.5 on Epop[46]], weight: 4.1363508E-4, delay 1.5
        h("Epop[46] syn_projEE_ampa[846] = new ampa(0.5)")
        h("Epop[10] netConn_projEE_ampa[846] = new NetCon(&v(0.5), syn_projEE_ampa[846], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 847: cell 10, seg 0 (0.5) [0.5 on Epop[10]] -> cell 47, seg 0 (0.5) [0.5 on Epop[47]], weight: 4.1363508E-4, delay 1.5
        h("Epop[47] syn_projEE_ampa[847] = new ampa(0.5)")
        h("Epop[10] netConn_projEE_ampa[847] = new NetCon(&v(0.5), syn_projEE_ampa[847], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 848: cell 10, seg 0 (0.5) [0.5 on Epop[10]] -> cell 48, seg 0 (0.5) [0.5 on Epop[48]], weight: 4.1363508E-4, delay 1.5
        h("Epop[48] syn_projEE_ampa[848] = new ampa(0.5)")
        h("Epop[10] netConn_projEE_ampa[848] = new NetCon(&v(0.5), syn_projEE_ampa[848], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 849: cell 10, seg 0 (0.5) [0.5 on Epop[10]] -> cell 49, seg 0 (0.5) [0.5 on Epop[49]], weight: 4.1363508E-4, delay 1.5
        h("Epop[49] syn_projEE_ampa[849] = new ampa(0.5)")
        h("Epop[10] netConn_projEE_ampa[849] = new NetCon(&v(0.5), syn_projEE_ampa[849], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 850: cell 10, seg 0 (0.5) [0.5 on Epop[10]] -> cell 50, seg 0 (0.5) [0.5 on Epop[50]], weight: 4.1363508E-4, delay 1.5
        h("Epop[50] syn_projEE_ampa[850] = new ampa(0.5)")
        h("Epop[10] netConn_projEE_ampa[850] = new NetCon(&v(0.5), syn_projEE_ampa[850], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 851: cell 10, seg 0 (0.5) [0.5 on Epop[10]] -> cell 51, seg 0 (0.5) [0.5 on Epop[51]], weight: 4.1363508E-4, delay 1.5
        h("Epop[51] syn_projEE_ampa[851] = new ampa(0.5)")
        h("Epop[10] netConn_projEE_ampa[851] = new NetCon(&v(0.5), syn_projEE_ampa[851], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 852: cell 10, seg 0 (0.5) [0.5 on Epop[10]] -> cell 52, seg 0 (0.5) [0.5 on Epop[52]], weight: 4.1363508E-4, delay 1.5
        h("Epop[52] syn_projEE_ampa[852] = new ampa(0.5)")
        h("Epop[10] netConn_projEE_ampa[852] = new NetCon(&v(0.5), syn_projEE_ampa[852], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 853: cell 10, seg 0 (0.5) [0.5 on Epop[10]] -> cell 53, seg 0 (0.5) [0.5 on Epop[53]], weight: 4.1363508E-4, delay 1.5
        h("Epop[53] syn_projEE_ampa[853] = new ampa(0.5)")
        h("Epop[10] netConn_projEE_ampa[853] = new NetCon(&v(0.5), syn_projEE_ampa[853], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 854: cell 10, seg 0 (0.5) [0.5 on Epop[10]] -> cell 54, seg 0 (0.5) [0.5 on Epop[54]], weight: 4.1363508E-4, delay 1.5
        h("Epop[54] syn_projEE_ampa[854] = new ampa(0.5)")
        h("Epop[10] netConn_projEE_ampa[854] = new NetCon(&v(0.5), syn_projEE_ampa[854], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 855: cell 10, seg 0 (0.5) [0.5 on Epop[10]] -> cell 55, seg 0 (0.5) [0.5 on Epop[55]], weight: 4.1363508E-4, delay 1.5
        h("Epop[55] syn_projEE_ampa[855] = new ampa(0.5)")
        h("Epop[10] netConn_projEE_ampa[855] = new NetCon(&v(0.5), syn_projEE_ampa[855], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 856: cell 10, seg 0 (0.5) [0.5 on Epop[10]] -> cell 56, seg 0 (0.5) [0.5 on Epop[56]], weight: 4.1363508E-4, delay 1.5
        h("Epop[56] syn_projEE_ampa[856] = new ampa(0.5)")
        h("Epop[10] netConn_projEE_ampa[856] = new NetCon(&v(0.5), syn_projEE_ampa[856], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 857: cell 10, seg 0 (0.5) [0.5 on Epop[10]] -> cell 57, seg 0 (0.5) [0.5 on Epop[57]], weight: 4.1363508E-4, delay 1.5
        h("Epop[57] syn_projEE_ampa[857] = new ampa(0.5)")
        h("Epop[10] netConn_projEE_ampa[857] = new NetCon(&v(0.5), syn_projEE_ampa[857], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 858: cell 10, seg 0 (0.5) [0.5 on Epop[10]] -> cell 58, seg 0 (0.5) [0.5 on Epop[58]], weight: 4.1363508E-4, delay 1.5
        h("Epop[58] syn_projEE_ampa[858] = new ampa(0.5)")
        h("Epop[10] netConn_projEE_ampa[858] = new NetCon(&v(0.5), syn_projEE_ampa[858], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 859: cell 10, seg 0 (0.5) [0.5 on Epop[10]] -> cell 59, seg 0 (0.5) [0.5 on Epop[59]], weight: 4.1363508E-4, delay 1.5
        h("Epop[59] syn_projEE_ampa[859] = new ampa(0.5)")
        h("Epop[10] netConn_projEE_ampa[859] = new NetCon(&v(0.5), syn_projEE_ampa[859], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 860: cell 10, seg 0 (0.5) [0.5 on Epop[10]] -> cell 60, seg 0 (0.5) [0.5 on Epop[60]], weight: 4.1363508E-4, delay 1.5
        h("Epop[60] syn_projEE_ampa[860] = new ampa(0.5)")
        h("Epop[10] netConn_projEE_ampa[860] = new NetCon(&v(0.5), syn_projEE_ampa[860], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 861: cell 10, seg 0 (0.5) [0.5 on Epop[10]] -> cell 61, seg 0 (0.5) [0.5 on Epop[61]], weight: 4.1363508E-4, delay 1.5
        h("Epop[61] syn_projEE_ampa[861] = new ampa(0.5)")
        h("Epop[10] netConn_projEE_ampa[861] = new NetCon(&v(0.5), syn_projEE_ampa[861], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 862: cell 10, seg 0 (0.5) [0.5 on Epop[10]] -> cell 62, seg 0 (0.5) [0.5 on Epop[62]], weight: 4.1363508E-4, delay 1.5
        h("Epop[62] syn_projEE_ampa[862] = new ampa(0.5)")
        h("Epop[10] netConn_projEE_ampa[862] = new NetCon(&v(0.5), syn_projEE_ampa[862], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 863: cell 10, seg 0 (0.5) [0.5 on Epop[10]] -> cell 63, seg 0 (0.5) [0.5 on Epop[63]], weight: 4.1363508E-4, delay 1.5
        h("Epop[63] syn_projEE_ampa[863] = new ampa(0.5)")
        h("Epop[10] netConn_projEE_ampa[863] = new NetCon(&v(0.5), syn_projEE_ampa[863], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 864: cell 10, seg 0 (0.5) [0.5 on Epop[10]] -> cell 64, seg 0 (0.5) [0.5 on Epop[64]], weight: 4.1363508E-4, delay 1.5
        h("Epop[64] syn_projEE_ampa[864] = new ampa(0.5)")
        h("Epop[10] netConn_projEE_ampa[864] = new NetCon(&v(0.5), syn_projEE_ampa[864], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 865: cell 10, seg 0 (0.5) [0.5 on Epop[10]] -> cell 65, seg 0 (0.5) [0.5 on Epop[65]], weight: 4.1363508E-4, delay 1.5
        h("Epop[65] syn_projEE_ampa[865] = new ampa(0.5)")
        h("Epop[10] netConn_projEE_ampa[865] = new NetCon(&v(0.5), syn_projEE_ampa[865], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 866: cell 10, seg 0 (0.5) [0.5 on Epop[10]] -> cell 66, seg 0 (0.5) [0.5 on Epop[66]], weight: 4.1363508E-4, delay 1.5
        h("Epop[66] syn_projEE_ampa[866] = new ampa(0.5)")
        h("Epop[10] netConn_projEE_ampa[866] = new NetCon(&v(0.5), syn_projEE_ampa[866], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 867: cell 10, seg 0 (0.5) [0.5 on Epop[10]] -> cell 67, seg 0 (0.5) [0.5 on Epop[67]], weight: 4.1363508E-4, delay 1.5
        h("Epop[67] syn_projEE_ampa[867] = new ampa(0.5)")
        h("Epop[10] netConn_projEE_ampa[867] = new NetCon(&v(0.5), syn_projEE_ampa[867], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 868: cell 10, seg 0 (0.5) [0.5 on Epop[10]] -> cell 68, seg 0 (0.5) [0.5 on Epop[68]], weight: 4.1363508E-4, delay 1.5
        h("Epop[68] syn_projEE_ampa[868] = new ampa(0.5)")
        h("Epop[10] netConn_projEE_ampa[868] = new NetCon(&v(0.5), syn_projEE_ampa[868], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 869: cell 10, seg 0 (0.5) [0.5 on Epop[10]] -> cell 69, seg 0 (0.5) [0.5 on Epop[69]], weight: 4.1363508E-4, delay 1.5
        h("Epop[69] syn_projEE_ampa[869] = new ampa(0.5)")
        h("Epop[10] netConn_projEE_ampa[869] = new NetCon(&v(0.5), syn_projEE_ampa[869], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 870: cell 10, seg 0 (0.5) [0.5 on Epop[10]] -> cell 70, seg 0 (0.5) [0.5 on Epop[70]], weight: 4.1363508E-4, delay 1.5
        h("Epop[70] syn_projEE_ampa[870] = new ampa(0.5)")
        h("Epop[10] netConn_projEE_ampa[870] = new NetCon(&v(0.5), syn_projEE_ampa[870], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 871: cell 10, seg 0 (0.5) [0.5 on Epop[10]] -> cell 71, seg 0 (0.5) [0.5 on Epop[71]], weight: 4.1363508E-4, delay 1.5
        h("Epop[71] syn_projEE_ampa[871] = new ampa(0.5)")
        h("Epop[10] netConn_projEE_ampa[871] = new NetCon(&v(0.5), syn_projEE_ampa[871], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 872: cell 10, seg 0 (0.5) [0.5 on Epop[10]] -> cell 72, seg 0 (0.5) [0.5 on Epop[72]], weight: 4.1363508E-4, delay 1.5
        h("Epop[72] syn_projEE_ampa[872] = new ampa(0.5)")
        h("Epop[10] netConn_projEE_ampa[872] = new NetCon(&v(0.5), syn_projEE_ampa[872], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 873: cell 10, seg 0 (0.5) [0.5 on Epop[10]] -> cell 73, seg 0 (0.5) [0.5 on Epop[73]], weight: 4.1363508E-4, delay 1.5
        h("Epop[73] syn_projEE_ampa[873] = new ampa(0.5)")
        h("Epop[10] netConn_projEE_ampa[873] = new NetCon(&v(0.5), syn_projEE_ampa[873], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 874: cell 10, seg 0 (0.5) [0.5 on Epop[10]] -> cell 74, seg 0 (0.5) [0.5 on Epop[74]], weight: 4.1363508E-4, delay 1.5
        h("Epop[74] syn_projEE_ampa[874] = new ampa(0.5)")
        h("Epop[10] netConn_projEE_ampa[874] = new NetCon(&v(0.5), syn_projEE_ampa[874], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 875: cell 10, seg 0 (0.5) [0.5 on Epop[10]] -> cell 75, seg 0 (0.5) [0.5 on Epop[75]], weight: 4.1363508E-4, delay 1.5
        h("Epop[75] syn_projEE_ampa[875] = new ampa(0.5)")
        h("Epop[10] netConn_projEE_ampa[875] = new NetCon(&v(0.5), syn_projEE_ampa[875], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 876: cell 10, seg 0 (0.5) [0.5 on Epop[10]] -> cell 76, seg 0 (0.5) [0.5 on Epop[76]], weight: 4.1363508E-4, delay 1.5
        h("Epop[76] syn_projEE_ampa[876] = new ampa(0.5)")
        h("Epop[10] netConn_projEE_ampa[876] = new NetCon(&v(0.5), syn_projEE_ampa[876], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 877: cell 10, seg 0 (0.5) [0.5 on Epop[10]] -> cell 77, seg 0 (0.5) [0.5 on Epop[77]], weight: 4.1363508E-4, delay 1.5
        h("Epop[77] syn_projEE_ampa[877] = new ampa(0.5)")
        h("Epop[10] netConn_projEE_ampa[877] = new NetCon(&v(0.5), syn_projEE_ampa[877], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 878: cell 10, seg 0 (0.5) [0.5 on Epop[10]] -> cell 78, seg 0 (0.5) [0.5 on Epop[78]], weight: 4.1363508E-4, delay 1.5
        h("Epop[78] syn_projEE_ampa[878] = new ampa(0.5)")
        h("Epop[10] netConn_projEE_ampa[878] = new NetCon(&v(0.5), syn_projEE_ampa[878], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 879: cell 10, seg 0 (0.5) [0.5 on Epop[10]] -> cell 79, seg 0 (0.5) [0.5 on Epop[79]], weight: 4.1363508E-4, delay 1.5
        h("Epop[79] syn_projEE_ampa[879] = new ampa(0.5)")
        h("Epop[10] netConn_projEE_ampa[879] = new NetCon(&v(0.5), syn_projEE_ampa[879], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 880: cell 11, seg 0 (0.5) [0.5 on Epop[11]] -> cell 0, seg 0 (0.5) [0.5 on Epop[0]], weight: 4.1363508E-4, delay 1.5
        h("Epop[0] syn_projEE_ampa[880] = new ampa(0.5)")
        h("Epop[11] netConn_projEE_ampa[880] = new NetCon(&v(0.5), syn_projEE_ampa[880], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 881: cell 11, seg 0 (0.5) [0.5 on Epop[11]] -> cell 1, seg 0 (0.5) [0.5 on Epop[1]], weight: 4.1363508E-4, delay 1.5
        h("Epop[1] syn_projEE_ampa[881] = new ampa(0.5)")
        h("Epop[11] netConn_projEE_ampa[881] = new NetCon(&v(0.5), syn_projEE_ampa[881], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 882: cell 11, seg 0 (0.5) [0.5 on Epop[11]] -> cell 2, seg 0 (0.5) [0.5 on Epop[2]], weight: 4.1363508E-4, delay 1.5
        h("Epop[2] syn_projEE_ampa[882] = new ampa(0.5)")
        h("Epop[11] netConn_projEE_ampa[882] = new NetCon(&v(0.5), syn_projEE_ampa[882], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 883: cell 11, seg 0 (0.5) [0.5 on Epop[11]] -> cell 3, seg 0 (0.5) [0.5 on Epop[3]], weight: 4.1363508E-4, delay 1.5
        h("Epop[3] syn_projEE_ampa[883] = new ampa(0.5)")
        h("Epop[11] netConn_projEE_ampa[883] = new NetCon(&v(0.5), syn_projEE_ampa[883], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 884: cell 11, seg 0 (0.5) [0.5 on Epop[11]] -> cell 4, seg 0 (0.5) [0.5 on Epop[4]], weight: 4.1363508E-4, delay 1.5
        h("Epop[4] syn_projEE_ampa[884] = new ampa(0.5)")
        h("Epop[11] netConn_projEE_ampa[884] = new NetCon(&v(0.5), syn_projEE_ampa[884], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 885: cell 11, seg 0 (0.5) [0.5 on Epop[11]] -> cell 5, seg 0 (0.5) [0.5 on Epop[5]], weight: 4.1363508E-4, delay 1.5
        h("Epop[5] syn_projEE_ampa[885] = new ampa(0.5)")
        h("Epop[11] netConn_projEE_ampa[885] = new NetCon(&v(0.5), syn_projEE_ampa[885], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 886: cell 11, seg 0 (0.5) [0.5 on Epop[11]] -> cell 6, seg 0 (0.5) [0.5 on Epop[6]], weight: 4.1363508E-4, delay 1.5
        h("Epop[6] syn_projEE_ampa[886] = new ampa(0.5)")
        h("Epop[11] netConn_projEE_ampa[886] = new NetCon(&v(0.5), syn_projEE_ampa[886], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 887: cell 11, seg 0 (0.5) [0.5 on Epop[11]] -> cell 7, seg 0 (0.5) [0.5 on Epop[7]], weight: 4.1363508E-4, delay 1.5
        h("Epop[7] syn_projEE_ampa[887] = new ampa(0.5)")
        h("Epop[11] netConn_projEE_ampa[887] = new NetCon(&v(0.5), syn_projEE_ampa[887], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 888: cell 11, seg 0 (0.5) [0.5 on Epop[11]] -> cell 8, seg 0 (0.5) [0.5 on Epop[8]], weight: 4.1363508E-4, delay 1.5
        h("Epop[8] syn_projEE_ampa[888] = new ampa(0.5)")
        h("Epop[11] netConn_projEE_ampa[888] = new NetCon(&v(0.5), syn_projEE_ampa[888], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 889: cell 11, seg 0 (0.5) [0.5 on Epop[11]] -> cell 9, seg 0 (0.5) [0.5 on Epop[9]], weight: 4.1363508E-4, delay 1.5
        h("Epop[9] syn_projEE_ampa[889] = new ampa(0.5)")
        h("Epop[11] netConn_projEE_ampa[889] = new NetCon(&v(0.5), syn_projEE_ampa[889], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 890: cell 11, seg 0 (0.5) [0.5 on Epop[11]] -> cell 10, seg 0 (0.5) [0.5 on Epop[10]], weight: 4.1363508E-4, delay 1.5
        h("Epop[10] syn_projEE_ampa[890] = new ampa(0.5)")
        h("Epop[11] netConn_projEE_ampa[890] = new NetCon(&v(0.5), syn_projEE_ampa[890], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 891: cell 11, seg 0 (0.5) [0.5 on Epop[11]] -> cell 11, seg 0 (0.5) [0.5 on Epop[11]], weight: 4.1363508E-4, delay 1.5
        h("Epop[11] syn_projEE_ampa[891] = new ampa(0.5)")
        h("Epop[11] netConn_projEE_ampa[891] = new NetCon(&v(0.5), syn_projEE_ampa[891], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 892: cell 11, seg 0 (0.5) [0.5 on Epop[11]] -> cell 12, seg 0 (0.5) [0.5 on Epop[12]], weight: 4.1363508E-4, delay 1.5
        h("Epop[12] syn_projEE_ampa[892] = new ampa(0.5)")
        h("Epop[11] netConn_projEE_ampa[892] = new NetCon(&v(0.5), syn_projEE_ampa[892], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 893: cell 11, seg 0 (0.5) [0.5 on Epop[11]] -> cell 13, seg 0 (0.5) [0.5 on Epop[13]], weight: 4.1363508E-4, delay 1.5
        h("Epop[13] syn_projEE_ampa[893] = new ampa(0.5)")
        h("Epop[11] netConn_projEE_ampa[893] = new NetCon(&v(0.5), syn_projEE_ampa[893], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 894: cell 11, seg 0 (0.5) [0.5 on Epop[11]] -> cell 14, seg 0 (0.5) [0.5 on Epop[14]], weight: 4.1363508E-4, delay 1.5
        h("Epop[14] syn_projEE_ampa[894] = new ampa(0.5)")
        h("Epop[11] netConn_projEE_ampa[894] = new NetCon(&v(0.5), syn_projEE_ampa[894], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 895: cell 11, seg 0 (0.5) [0.5 on Epop[11]] -> cell 15, seg 0 (0.5) [0.5 on Epop[15]], weight: 4.1363508E-4, delay 1.5
        h("Epop[15] syn_projEE_ampa[895] = new ampa(0.5)")
        h("Epop[11] netConn_projEE_ampa[895] = new NetCon(&v(0.5), syn_projEE_ampa[895], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 896: cell 11, seg 0 (0.5) [0.5 on Epop[11]] -> cell 16, seg 0 (0.5) [0.5 on Epop[16]], weight: 4.1363508E-4, delay 1.5
        h("Epop[16] syn_projEE_ampa[896] = new ampa(0.5)")
        h("Epop[11] netConn_projEE_ampa[896] = new NetCon(&v(0.5), syn_projEE_ampa[896], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 897: cell 11, seg 0 (0.5) [0.5 on Epop[11]] -> cell 17, seg 0 (0.5) [0.5 on Epop[17]], weight: 4.1363508E-4, delay 1.5
        h("Epop[17] syn_projEE_ampa[897] = new ampa(0.5)")
        h("Epop[11] netConn_projEE_ampa[897] = new NetCon(&v(0.5), syn_projEE_ampa[897], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 898: cell 11, seg 0 (0.5) [0.5 on Epop[11]] -> cell 18, seg 0 (0.5) [0.5 on Epop[18]], weight: 4.1363508E-4, delay 1.5
        h("Epop[18] syn_projEE_ampa[898] = new ampa(0.5)")
        h("Epop[11] netConn_projEE_ampa[898] = new NetCon(&v(0.5), syn_projEE_ampa[898], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 899: cell 11, seg 0 (0.5) [0.5 on Epop[11]] -> cell 19, seg 0 (0.5) [0.5 on Epop[19]], weight: 4.1363508E-4, delay 1.5
        h("Epop[19] syn_projEE_ampa[899] = new ampa(0.5)")
        h("Epop[11] netConn_projEE_ampa[899] = new NetCon(&v(0.5), syn_projEE_ampa[899], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 900: cell 11, seg 0 (0.5) [0.5 on Epop[11]] -> cell 20, seg 0 (0.5) [0.5 on Epop[20]], weight: 4.1363508E-4, delay 1.5
        h("Epop[20] syn_projEE_ampa[900] = new ampa(0.5)")
        h("Epop[11] netConn_projEE_ampa[900] = new NetCon(&v(0.5), syn_projEE_ampa[900], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 901: cell 11, seg 0 (0.5) [0.5 on Epop[11]] -> cell 21, seg 0 (0.5) [0.5 on Epop[21]], weight: 4.1363508E-4, delay 1.5
        h("Epop[21] syn_projEE_ampa[901] = new ampa(0.5)")
        h("Epop[11] netConn_projEE_ampa[901] = new NetCon(&v(0.5), syn_projEE_ampa[901], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 902: cell 11, seg 0 (0.5) [0.5 on Epop[11]] -> cell 22, seg 0 (0.5) [0.5 on Epop[22]], weight: 4.1363508E-4, delay 1.5
        h("Epop[22] syn_projEE_ampa[902] = new ampa(0.5)")
        h("Epop[11] netConn_projEE_ampa[902] = new NetCon(&v(0.5), syn_projEE_ampa[902], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 903: cell 11, seg 0 (0.5) [0.5 on Epop[11]] -> cell 23, seg 0 (0.5) [0.5 on Epop[23]], weight: 4.1363508E-4, delay 1.5
        h("Epop[23] syn_projEE_ampa[903] = new ampa(0.5)")
        h("Epop[11] netConn_projEE_ampa[903] = new NetCon(&v(0.5), syn_projEE_ampa[903], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 904: cell 11, seg 0 (0.5) [0.5 on Epop[11]] -> cell 24, seg 0 (0.5) [0.5 on Epop[24]], weight: 4.1363508E-4, delay 1.5
        h("Epop[24] syn_projEE_ampa[904] = new ampa(0.5)")
        h("Epop[11] netConn_projEE_ampa[904] = new NetCon(&v(0.5), syn_projEE_ampa[904], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 905: cell 11, seg 0 (0.5) [0.5 on Epop[11]] -> cell 25, seg 0 (0.5) [0.5 on Epop[25]], weight: 4.1363508E-4, delay 1.5
        h("Epop[25] syn_projEE_ampa[905] = new ampa(0.5)")
        h("Epop[11] netConn_projEE_ampa[905] = new NetCon(&v(0.5), syn_projEE_ampa[905], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 906: cell 11, seg 0 (0.5) [0.5 on Epop[11]] -> cell 26, seg 0 (0.5) [0.5 on Epop[26]], weight: 4.1363508E-4, delay 1.5
        h("Epop[26] syn_projEE_ampa[906] = new ampa(0.5)")
        h("Epop[11] netConn_projEE_ampa[906] = new NetCon(&v(0.5), syn_projEE_ampa[906], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 907: cell 11, seg 0 (0.5) [0.5 on Epop[11]] -> cell 27, seg 0 (0.5) [0.5 on Epop[27]], weight: 4.1363508E-4, delay 1.5
        h("Epop[27] syn_projEE_ampa[907] = new ampa(0.5)")
        h("Epop[11] netConn_projEE_ampa[907] = new NetCon(&v(0.5), syn_projEE_ampa[907], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 908: cell 11, seg 0 (0.5) [0.5 on Epop[11]] -> cell 28, seg 0 (0.5) [0.5 on Epop[28]], weight: 4.1363508E-4, delay 1.5
        h("Epop[28] syn_projEE_ampa[908] = new ampa(0.5)")
        h("Epop[11] netConn_projEE_ampa[908] = new NetCon(&v(0.5), syn_projEE_ampa[908], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 909: cell 11, seg 0 (0.5) [0.5 on Epop[11]] -> cell 29, seg 0 (0.5) [0.5 on Epop[29]], weight: 4.1363508E-4, delay 1.5
        h("Epop[29] syn_projEE_ampa[909] = new ampa(0.5)")
        h("Epop[11] netConn_projEE_ampa[909] = new NetCon(&v(0.5), syn_projEE_ampa[909], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 910: cell 11, seg 0 (0.5) [0.5 on Epop[11]] -> cell 30, seg 0 (0.5) [0.5 on Epop[30]], weight: 4.1363508E-4, delay 1.5
        h("Epop[30] syn_projEE_ampa[910] = new ampa(0.5)")
        h("Epop[11] netConn_projEE_ampa[910] = new NetCon(&v(0.5), syn_projEE_ampa[910], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 911: cell 11, seg 0 (0.5) [0.5 on Epop[11]] -> cell 31, seg 0 (0.5) [0.5 on Epop[31]], weight: 4.1363508E-4, delay 1.5
        h("Epop[31] syn_projEE_ampa[911] = new ampa(0.5)")
        h("Epop[11] netConn_projEE_ampa[911] = new NetCon(&v(0.5), syn_projEE_ampa[911], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 912: cell 11, seg 0 (0.5) [0.5 on Epop[11]] -> cell 32, seg 0 (0.5) [0.5 on Epop[32]], weight: 4.1363508E-4, delay 1.5
        h("Epop[32] syn_projEE_ampa[912] = new ampa(0.5)")
        h("Epop[11] netConn_projEE_ampa[912] = new NetCon(&v(0.5), syn_projEE_ampa[912], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 913: cell 11, seg 0 (0.5) [0.5 on Epop[11]] -> cell 33, seg 0 (0.5) [0.5 on Epop[33]], weight: 4.1363508E-4, delay 1.5
        h("Epop[33] syn_projEE_ampa[913] = new ampa(0.5)")
        h("Epop[11] netConn_projEE_ampa[913] = new NetCon(&v(0.5), syn_projEE_ampa[913], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 914: cell 11, seg 0 (0.5) [0.5 on Epop[11]] -> cell 34, seg 0 (0.5) [0.5 on Epop[34]], weight: 4.1363508E-4, delay 1.5
        h("Epop[34] syn_projEE_ampa[914] = new ampa(0.5)")
        h("Epop[11] netConn_projEE_ampa[914] = new NetCon(&v(0.5), syn_projEE_ampa[914], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 915: cell 11, seg 0 (0.5) [0.5 on Epop[11]] -> cell 35, seg 0 (0.5) [0.5 on Epop[35]], weight: 4.1363508E-4, delay 1.5
        h("Epop[35] syn_projEE_ampa[915] = new ampa(0.5)")
        h("Epop[11] netConn_projEE_ampa[915] = new NetCon(&v(0.5), syn_projEE_ampa[915], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 916: cell 11, seg 0 (0.5) [0.5 on Epop[11]] -> cell 36, seg 0 (0.5) [0.5 on Epop[36]], weight: 4.1363508E-4, delay 1.5
        h("Epop[36] syn_projEE_ampa[916] = new ampa(0.5)")
        h("Epop[11] netConn_projEE_ampa[916] = new NetCon(&v(0.5), syn_projEE_ampa[916], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 917: cell 11, seg 0 (0.5) [0.5 on Epop[11]] -> cell 37, seg 0 (0.5) [0.5 on Epop[37]], weight: 4.1363508E-4, delay 1.5
        h("Epop[37] syn_projEE_ampa[917] = new ampa(0.5)")
        h("Epop[11] netConn_projEE_ampa[917] = new NetCon(&v(0.5), syn_projEE_ampa[917], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 918: cell 11, seg 0 (0.5) [0.5 on Epop[11]] -> cell 38, seg 0 (0.5) [0.5 on Epop[38]], weight: 4.1363508E-4, delay 1.5
        h("Epop[38] syn_projEE_ampa[918] = new ampa(0.5)")
        h("Epop[11] netConn_projEE_ampa[918] = new NetCon(&v(0.5), syn_projEE_ampa[918], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 919: cell 11, seg 0 (0.5) [0.5 on Epop[11]] -> cell 39, seg 0 (0.5) [0.5 on Epop[39]], weight: 4.1363508E-4, delay 1.5
        h("Epop[39] syn_projEE_ampa[919] = new ampa(0.5)")
        h("Epop[11] netConn_projEE_ampa[919] = new NetCon(&v(0.5), syn_projEE_ampa[919], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 920: cell 11, seg 0 (0.5) [0.5 on Epop[11]] -> cell 40, seg 0 (0.5) [0.5 on Epop[40]], weight: 4.1363508E-4, delay 1.5
        h("Epop[40] syn_projEE_ampa[920] = new ampa(0.5)")
        h("Epop[11] netConn_projEE_ampa[920] = new NetCon(&v(0.5), syn_projEE_ampa[920], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 921: cell 11, seg 0 (0.5) [0.5 on Epop[11]] -> cell 41, seg 0 (0.5) [0.5 on Epop[41]], weight: 4.1363508E-4, delay 1.5
        h("Epop[41] syn_projEE_ampa[921] = new ampa(0.5)")
        h("Epop[11] netConn_projEE_ampa[921] = new NetCon(&v(0.5), syn_projEE_ampa[921], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 922: cell 11, seg 0 (0.5) [0.5 on Epop[11]] -> cell 42, seg 0 (0.5) [0.5 on Epop[42]], weight: 4.1363508E-4, delay 1.5
        h("Epop[42] syn_projEE_ampa[922] = new ampa(0.5)")
        h("Epop[11] netConn_projEE_ampa[922] = new NetCon(&v(0.5), syn_projEE_ampa[922], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 923: cell 11, seg 0 (0.5) [0.5 on Epop[11]] -> cell 43, seg 0 (0.5) [0.5 on Epop[43]], weight: 4.1363508E-4, delay 1.5
        h("Epop[43] syn_projEE_ampa[923] = new ampa(0.5)")
        h("Epop[11] netConn_projEE_ampa[923] = new NetCon(&v(0.5), syn_projEE_ampa[923], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 924: cell 11, seg 0 (0.5) [0.5 on Epop[11]] -> cell 44, seg 0 (0.5) [0.5 on Epop[44]], weight: 4.1363508E-4, delay 1.5
        h("Epop[44] syn_projEE_ampa[924] = new ampa(0.5)")
        h("Epop[11] netConn_projEE_ampa[924] = new NetCon(&v(0.5), syn_projEE_ampa[924], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 925: cell 11, seg 0 (0.5) [0.5 on Epop[11]] -> cell 45, seg 0 (0.5) [0.5 on Epop[45]], weight: 4.1363508E-4, delay 1.5
        h("Epop[45] syn_projEE_ampa[925] = new ampa(0.5)")
        h("Epop[11] netConn_projEE_ampa[925] = new NetCon(&v(0.5), syn_projEE_ampa[925], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 926: cell 11, seg 0 (0.5) [0.5 on Epop[11]] -> cell 46, seg 0 (0.5) [0.5 on Epop[46]], weight: 4.1363508E-4, delay 1.5
        h("Epop[46] syn_projEE_ampa[926] = new ampa(0.5)")
        h("Epop[11] netConn_projEE_ampa[926] = new NetCon(&v(0.5), syn_projEE_ampa[926], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 927: cell 11, seg 0 (0.5) [0.5 on Epop[11]] -> cell 47, seg 0 (0.5) [0.5 on Epop[47]], weight: 4.1363508E-4, delay 1.5
        h("Epop[47] syn_projEE_ampa[927] = new ampa(0.5)")
        h("Epop[11] netConn_projEE_ampa[927] = new NetCon(&v(0.5), syn_projEE_ampa[927], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 928: cell 11, seg 0 (0.5) [0.5 on Epop[11]] -> cell 48, seg 0 (0.5) [0.5 on Epop[48]], weight: 4.1363508E-4, delay 1.5
        h("Epop[48] syn_projEE_ampa[928] = new ampa(0.5)")
        h("Epop[11] netConn_projEE_ampa[928] = new NetCon(&v(0.5), syn_projEE_ampa[928], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 929: cell 11, seg 0 (0.5) [0.5 on Epop[11]] -> cell 49, seg 0 (0.5) [0.5 on Epop[49]], weight: 4.1363508E-4, delay 1.5
        h("Epop[49] syn_projEE_ampa[929] = new ampa(0.5)")
        h("Epop[11] netConn_projEE_ampa[929] = new NetCon(&v(0.5), syn_projEE_ampa[929], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 930: cell 11, seg 0 (0.5) [0.5 on Epop[11]] -> cell 50, seg 0 (0.5) [0.5 on Epop[50]], weight: 4.1363508E-4, delay 1.5
        h("Epop[50] syn_projEE_ampa[930] = new ampa(0.5)")
        h("Epop[11] netConn_projEE_ampa[930] = new NetCon(&v(0.5), syn_projEE_ampa[930], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 931: cell 11, seg 0 (0.5) [0.5 on Epop[11]] -> cell 51, seg 0 (0.5) [0.5 on Epop[51]], weight: 4.1363508E-4, delay 1.5
        h("Epop[51] syn_projEE_ampa[931] = new ampa(0.5)")
        h("Epop[11] netConn_projEE_ampa[931] = new NetCon(&v(0.5), syn_projEE_ampa[931], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 932: cell 11, seg 0 (0.5) [0.5 on Epop[11]] -> cell 52, seg 0 (0.5) [0.5 on Epop[52]], weight: 4.1363508E-4, delay 1.5
        h("Epop[52] syn_projEE_ampa[932] = new ampa(0.5)")
        h("Epop[11] netConn_projEE_ampa[932] = new NetCon(&v(0.5), syn_projEE_ampa[932], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 933: cell 11, seg 0 (0.5) [0.5 on Epop[11]] -> cell 53, seg 0 (0.5) [0.5 on Epop[53]], weight: 4.1363508E-4, delay 1.5
        h("Epop[53] syn_projEE_ampa[933] = new ampa(0.5)")
        h("Epop[11] netConn_projEE_ampa[933] = new NetCon(&v(0.5), syn_projEE_ampa[933], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 934: cell 11, seg 0 (0.5) [0.5 on Epop[11]] -> cell 54, seg 0 (0.5) [0.5 on Epop[54]], weight: 4.1363508E-4, delay 1.5
        h("Epop[54] syn_projEE_ampa[934] = new ampa(0.5)")
        h("Epop[11] netConn_projEE_ampa[934] = new NetCon(&v(0.5), syn_projEE_ampa[934], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 935: cell 11, seg 0 (0.5) [0.5 on Epop[11]] -> cell 55, seg 0 (0.5) [0.5 on Epop[55]], weight: 4.1363508E-4, delay 1.5
        h("Epop[55] syn_projEE_ampa[935] = new ampa(0.5)")
        h("Epop[11] netConn_projEE_ampa[935] = new NetCon(&v(0.5), syn_projEE_ampa[935], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 936: cell 11, seg 0 (0.5) [0.5 on Epop[11]] -> cell 56, seg 0 (0.5) [0.5 on Epop[56]], weight: 4.1363508E-4, delay 1.5
        h("Epop[56] syn_projEE_ampa[936] = new ampa(0.5)")
        h("Epop[11] netConn_projEE_ampa[936] = new NetCon(&v(0.5), syn_projEE_ampa[936], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 937: cell 11, seg 0 (0.5) [0.5 on Epop[11]] -> cell 57, seg 0 (0.5) [0.5 on Epop[57]], weight: 4.1363508E-4, delay 1.5
        h("Epop[57] syn_projEE_ampa[937] = new ampa(0.5)")
        h("Epop[11] netConn_projEE_ampa[937] = new NetCon(&v(0.5), syn_projEE_ampa[937], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 938: cell 11, seg 0 (0.5) [0.5 on Epop[11]] -> cell 58, seg 0 (0.5) [0.5 on Epop[58]], weight: 4.1363508E-4, delay 1.5
        h("Epop[58] syn_projEE_ampa[938] = new ampa(0.5)")
        h("Epop[11] netConn_projEE_ampa[938] = new NetCon(&v(0.5), syn_projEE_ampa[938], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 939: cell 11, seg 0 (0.5) [0.5 on Epop[11]] -> cell 59, seg 0 (0.5) [0.5 on Epop[59]], weight: 4.1363508E-4, delay 1.5
        h("Epop[59] syn_projEE_ampa[939] = new ampa(0.5)")
        h("Epop[11] netConn_projEE_ampa[939] = new NetCon(&v(0.5), syn_projEE_ampa[939], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 940: cell 11, seg 0 (0.5) [0.5 on Epop[11]] -> cell 60, seg 0 (0.5) [0.5 on Epop[60]], weight: 4.1363508E-4, delay 1.5
        h("Epop[60] syn_projEE_ampa[940] = new ampa(0.5)")
        h("Epop[11] netConn_projEE_ampa[940] = new NetCon(&v(0.5), syn_projEE_ampa[940], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 941: cell 11, seg 0 (0.5) [0.5 on Epop[11]] -> cell 61, seg 0 (0.5) [0.5 on Epop[61]], weight: 4.1363508E-4, delay 1.5
        h("Epop[61] syn_projEE_ampa[941] = new ampa(0.5)")
        h("Epop[11] netConn_projEE_ampa[941] = new NetCon(&v(0.5), syn_projEE_ampa[941], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 942: cell 11, seg 0 (0.5) [0.5 on Epop[11]] -> cell 62, seg 0 (0.5) [0.5 on Epop[62]], weight: 4.1363508E-4, delay 1.5
        h("Epop[62] syn_projEE_ampa[942] = new ampa(0.5)")
        h("Epop[11] netConn_projEE_ampa[942] = new NetCon(&v(0.5), syn_projEE_ampa[942], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 943: cell 11, seg 0 (0.5) [0.5 on Epop[11]] -> cell 63, seg 0 (0.5) [0.5 on Epop[63]], weight: 4.1363508E-4, delay 1.5
        h("Epop[63] syn_projEE_ampa[943] = new ampa(0.5)")
        h("Epop[11] netConn_projEE_ampa[943] = new NetCon(&v(0.5), syn_projEE_ampa[943], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 944: cell 11, seg 0 (0.5) [0.5 on Epop[11]] -> cell 64, seg 0 (0.5) [0.5 on Epop[64]], weight: 4.1363508E-4, delay 1.5
        h("Epop[64] syn_projEE_ampa[944] = new ampa(0.5)")
        h("Epop[11] netConn_projEE_ampa[944] = new NetCon(&v(0.5), syn_projEE_ampa[944], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 945: cell 11, seg 0 (0.5) [0.5 on Epop[11]] -> cell 65, seg 0 (0.5) [0.5 on Epop[65]], weight: 4.1363508E-4, delay 1.5
        h("Epop[65] syn_projEE_ampa[945] = new ampa(0.5)")
        h("Epop[11] netConn_projEE_ampa[945] = new NetCon(&v(0.5), syn_projEE_ampa[945], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 946: cell 11, seg 0 (0.5) [0.5 on Epop[11]] -> cell 66, seg 0 (0.5) [0.5 on Epop[66]], weight: 4.1363508E-4, delay 1.5
        h("Epop[66] syn_projEE_ampa[946] = new ampa(0.5)")
        h("Epop[11] netConn_projEE_ampa[946] = new NetCon(&v(0.5), syn_projEE_ampa[946], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 947: cell 11, seg 0 (0.5) [0.5 on Epop[11]] -> cell 67, seg 0 (0.5) [0.5 on Epop[67]], weight: 4.1363508E-4, delay 1.5
        h("Epop[67] syn_projEE_ampa[947] = new ampa(0.5)")
        h("Epop[11] netConn_projEE_ampa[947] = new NetCon(&v(0.5), syn_projEE_ampa[947], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 948: cell 11, seg 0 (0.5) [0.5 on Epop[11]] -> cell 68, seg 0 (0.5) [0.5 on Epop[68]], weight: 4.1363508E-4, delay 1.5
        h("Epop[68] syn_projEE_ampa[948] = new ampa(0.5)")
        h("Epop[11] netConn_projEE_ampa[948] = new NetCon(&v(0.5), syn_projEE_ampa[948], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 949: cell 11, seg 0 (0.5) [0.5 on Epop[11]] -> cell 69, seg 0 (0.5) [0.5 on Epop[69]], weight: 4.1363508E-4, delay 1.5
        h("Epop[69] syn_projEE_ampa[949] = new ampa(0.5)")
        h("Epop[11] netConn_projEE_ampa[949] = new NetCon(&v(0.5), syn_projEE_ampa[949], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 950: cell 11, seg 0 (0.5) [0.5 on Epop[11]] -> cell 70, seg 0 (0.5) [0.5 on Epop[70]], weight: 4.1363508E-4, delay 1.5
        h("Epop[70] syn_projEE_ampa[950] = new ampa(0.5)")
        h("Epop[11] netConn_projEE_ampa[950] = new NetCon(&v(0.5), syn_projEE_ampa[950], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 951: cell 11, seg 0 (0.5) [0.5 on Epop[11]] -> cell 71, seg 0 (0.5) [0.5 on Epop[71]], weight: 4.1363508E-4, delay 1.5
        h("Epop[71] syn_projEE_ampa[951] = new ampa(0.5)")
        h("Epop[11] netConn_projEE_ampa[951] = new NetCon(&v(0.5), syn_projEE_ampa[951], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 952: cell 11, seg 0 (0.5) [0.5 on Epop[11]] -> cell 72, seg 0 (0.5) [0.5 on Epop[72]], weight: 4.1363508E-4, delay 1.5
        h("Epop[72] syn_projEE_ampa[952] = new ampa(0.5)")
        h("Epop[11] netConn_projEE_ampa[952] = new NetCon(&v(0.5), syn_projEE_ampa[952], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 953: cell 11, seg 0 (0.5) [0.5 on Epop[11]] -> cell 73, seg 0 (0.5) [0.5 on Epop[73]], weight: 4.1363508E-4, delay 1.5
        h("Epop[73] syn_projEE_ampa[953] = new ampa(0.5)")
        h("Epop[11] netConn_projEE_ampa[953] = new NetCon(&v(0.5), syn_projEE_ampa[953], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 954: cell 11, seg 0 (0.5) [0.5 on Epop[11]] -> cell 74, seg 0 (0.5) [0.5 on Epop[74]], weight: 4.1363508E-4, delay 1.5
        h("Epop[74] syn_projEE_ampa[954] = new ampa(0.5)")
        h("Epop[11] netConn_projEE_ampa[954] = new NetCon(&v(0.5), syn_projEE_ampa[954], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 955: cell 11, seg 0 (0.5) [0.5 on Epop[11]] -> cell 75, seg 0 (0.5) [0.5 on Epop[75]], weight: 4.1363508E-4, delay 1.5
        h("Epop[75] syn_projEE_ampa[955] = new ampa(0.5)")
        h("Epop[11] netConn_projEE_ampa[955] = new NetCon(&v(0.5), syn_projEE_ampa[955], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 956: cell 11, seg 0 (0.5) [0.5 on Epop[11]] -> cell 76, seg 0 (0.5) [0.5 on Epop[76]], weight: 4.1363508E-4, delay 1.5
        h("Epop[76] syn_projEE_ampa[956] = new ampa(0.5)")
        h("Epop[11] netConn_projEE_ampa[956] = new NetCon(&v(0.5), syn_projEE_ampa[956], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 957: cell 11, seg 0 (0.5) [0.5 on Epop[11]] -> cell 77, seg 0 (0.5) [0.5 on Epop[77]], weight: 4.1363508E-4, delay 1.5
        h("Epop[77] syn_projEE_ampa[957] = new ampa(0.5)")
        h("Epop[11] netConn_projEE_ampa[957] = new NetCon(&v(0.5), syn_projEE_ampa[957], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 958: cell 11, seg 0 (0.5) [0.5 on Epop[11]] -> cell 78, seg 0 (0.5) [0.5 on Epop[78]], weight: 4.1363508E-4, delay 1.5
        h("Epop[78] syn_projEE_ampa[958] = new ampa(0.5)")
        h("Epop[11] netConn_projEE_ampa[958] = new NetCon(&v(0.5), syn_projEE_ampa[958], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 959: cell 11, seg 0 (0.5) [0.5 on Epop[11]] -> cell 79, seg 0 (0.5) [0.5 on Epop[79]], weight: 4.1363508E-4, delay 1.5
        h("Epop[79] syn_projEE_ampa[959] = new ampa(0.5)")
        h("Epop[11] netConn_projEE_ampa[959] = new NetCon(&v(0.5), syn_projEE_ampa[959], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 960: cell 12, seg 0 (0.5) [0.5 on Epop[12]] -> cell 0, seg 0 (0.5) [0.5 on Epop[0]], weight: 4.1363508E-4, delay 1.5
        h("Epop[0] syn_projEE_ampa[960] = new ampa(0.5)")
        h("Epop[12] netConn_projEE_ampa[960] = new NetCon(&v(0.5), syn_projEE_ampa[960], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 961: cell 12, seg 0 (0.5) [0.5 on Epop[12]] -> cell 1, seg 0 (0.5) [0.5 on Epop[1]], weight: 4.1363508E-4, delay 1.5
        h("Epop[1] syn_projEE_ampa[961] = new ampa(0.5)")
        h("Epop[12] netConn_projEE_ampa[961] = new NetCon(&v(0.5), syn_projEE_ampa[961], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 962: cell 12, seg 0 (0.5) [0.5 on Epop[12]] -> cell 2, seg 0 (0.5) [0.5 on Epop[2]], weight: 4.1363508E-4, delay 1.5
        h("Epop[2] syn_projEE_ampa[962] = new ampa(0.5)")
        h("Epop[12] netConn_projEE_ampa[962] = new NetCon(&v(0.5), syn_projEE_ampa[962], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 963: cell 12, seg 0 (0.5) [0.5 on Epop[12]] -> cell 3, seg 0 (0.5) [0.5 on Epop[3]], weight: 4.1363508E-4, delay 1.5
        h("Epop[3] syn_projEE_ampa[963] = new ampa(0.5)")
        h("Epop[12] netConn_projEE_ampa[963] = new NetCon(&v(0.5), syn_projEE_ampa[963], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 964: cell 12, seg 0 (0.5) [0.5 on Epop[12]] -> cell 4, seg 0 (0.5) [0.5 on Epop[4]], weight: 4.1363508E-4, delay 1.5
        h("Epop[4] syn_projEE_ampa[964] = new ampa(0.5)")
        h("Epop[12] netConn_projEE_ampa[964] = new NetCon(&v(0.5), syn_projEE_ampa[964], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 965: cell 12, seg 0 (0.5) [0.5 on Epop[12]] -> cell 5, seg 0 (0.5) [0.5 on Epop[5]], weight: 4.1363508E-4, delay 1.5
        h("Epop[5] syn_projEE_ampa[965] = new ampa(0.5)")
        h("Epop[12] netConn_projEE_ampa[965] = new NetCon(&v(0.5), syn_projEE_ampa[965], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 966: cell 12, seg 0 (0.5) [0.5 on Epop[12]] -> cell 6, seg 0 (0.5) [0.5 on Epop[6]], weight: 4.1363508E-4, delay 1.5
        h("Epop[6] syn_projEE_ampa[966] = new ampa(0.5)")
        h("Epop[12] netConn_projEE_ampa[966] = new NetCon(&v(0.5), syn_projEE_ampa[966], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 967: cell 12, seg 0 (0.5) [0.5 on Epop[12]] -> cell 7, seg 0 (0.5) [0.5 on Epop[7]], weight: 4.1363508E-4, delay 1.5
        h("Epop[7] syn_projEE_ampa[967] = new ampa(0.5)")
        h("Epop[12] netConn_projEE_ampa[967] = new NetCon(&v(0.5), syn_projEE_ampa[967], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 968: cell 12, seg 0 (0.5) [0.5 on Epop[12]] -> cell 8, seg 0 (0.5) [0.5 on Epop[8]], weight: 4.1363508E-4, delay 1.5
        h("Epop[8] syn_projEE_ampa[968] = new ampa(0.5)")
        h("Epop[12] netConn_projEE_ampa[968] = new NetCon(&v(0.5), syn_projEE_ampa[968], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 969: cell 12, seg 0 (0.5) [0.5 on Epop[12]] -> cell 9, seg 0 (0.5) [0.5 on Epop[9]], weight: 4.1363508E-4, delay 1.5
        h("Epop[9] syn_projEE_ampa[969] = new ampa(0.5)")
        h("Epop[12] netConn_projEE_ampa[969] = new NetCon(&v(0.5), syn_projEE_ampa[969], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 970: cell 12, seg 0 (0.5) [0.5 on Epop[12]] -> cell 10, seg 0 (0.5) [0.5 on Epop[10]], weight: 4.1363508E-4, delay 1.5
        h("Epop[10] syn_projEE_ampa[970] = new ampa(0.5)")
        h("Epop[12] netConn_projEE_ampa[970] = new NetCon(&v(0.5), syn_projEE_ampa[970], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 971: cell 12, seg 0 (0.5) [0.5 on Epop[12]] -> cell 11, seg 0 (0.5) [0.5 on Epop[11]], weight: 4.1363508E-4, delay 1.5
        h("Epop[11] syn_projEE_ampa[971] = new ampa(0.5)")
        h("Epop[12] netConn_projEE_ampa[971] = new NetCon(&v(0.5), syn_projEE_ampa[971], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 972: cell 12, seg 0 (0.5) [0.5 on Epop[12]] -> cell 12, seg 0 (0.5) [0.5 on Epop[12]], weight: 4.1363508E-4, delay 1.5
        h("Epop[12] syn_projEE_ampa[972] = new ampa(0.5)")
        h("Epop[12] netConn_projEE_ampa[972] = new NetCon(&v(0.5), syn_projEE_ampa[972], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 973: cell 12, seg 0 (0.5) [0.5 on Epop[12]] -> cell 13, seg 0 (0.5) [0.5 on Epop[13]], weight: 4.1363508E-4, delay 1.5
        h("Epop[13] syn_projEE_ampa[973] = new ampa(0.5)")
        h("Epop[12] netConn_projEE_ampa[973] = new NetCon(&v(0.5), syn_projEE_ampa[973], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 974: cell 12, seg 0 (0.5) [0.5 on Epop[12]] -> cell 14, seg 0 (0.5) [0.5 on Epop[14]], weight: 4.1363508E-4, delay 1.5
        h("Epop[14] syn_projEE_ampa[974] = new ampa(0.5)")
        h("Epop[12] netConn_projEE_ampa[974] = new NetCon(&v(0.5), syn_projEE_ampa[974], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 975: cell 12, seg 0 (0.5) [0.5 on Epop[12]] -> cell 15, seg 0 (0.5) [0.5 on Epop[15]], weight: 4.1363508E-4, delay 1.5
        h("Epop[15] syn_projEE_ampa[975] = new ampa(0.5)")
        h("Epop[12] netConn_projEE_ampa[975] = new NetCon(&v(0.5), syn_projEE_ampa[975], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 976: cell 12, seg 0 (0.5) [0.5 on Epop[12]] -> cell 16, seg 0 (0.5) [0.5 on Epop[16]], weight: 4.1363508E-4, delay 1.5
        h("Epop[16] syn_projEE_ampa[976] = new ampa(0.5)")
        h("Epop[12] netConn_projEE_ampa[976] = new NetCon(&v(0.5), syn_projEE_ampa[976], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 977: cell 12, seg 0 (0.5) [0.5 on Epop[12]] -> cell 17, seg 0 (0.5) [0.5 on Epop[17]], weight: 4.1363508E-4, delay 1.5
        h("Epop[17] syn_projEE_ampa[977] = new ampa(0.5)")
        h("Epop[12] netConn_projEE_ampa[977] = new NetCon(&v(0.5), syn_projEE_ampa[977], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 978: cell 12, seg 0 (0.5) [0.5 on Epop[12]] -> cell 18, seg 0 (0.5) [0.5 on Epop[18]], weight: 4.1363508E-4, delay 1.5
        h("Epop[18] syn_projEE_ampa[978] = new ampa(0.5)")
        h("Epop[12] netConn_projEE_ampa[978] = new NetCon(&v(0.5), syn_projEE_ampa[978], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 979: cell 12, seg 0 (0.5) [0.5 on Epop[12]] -> cell 19, seg 0 (0.5) [0.5 on Epop[19]], weight: 4.1363508E-4, delay 1.5
        h("Epop[19] syn_projEE_ampa[979] = new ampa(0.5)")
        h("Epop[12] netConn_projEE_ampa[979] = new NetCon(&v(0.5), syn_projEE_ampa[979], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 980: cell 12, seg 0 (0.5) [0.5 on Epop[12]] -> cell 20, seg 0 (0.5) [0.5 on Epop[20]], weight: 4.1363508E-4, delay 1.5
        h("Epop[20] syn_projEE_ampa[980] = new ampa(0.5)")
        h("Epop[12] netConn_projEE_ampa[980] = new NetCon(&v(0.5), syn_projEE_ampa[980], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 981: cell 12, seg 0 (0.5) [0.5 on Epop[12]] -> cell 21, seg 0 (0.5) [0.5 on Epop[21]], weight: 4.1363508E-4, delay 1.5
        h("Epop[21] syn_projEE_ampa[981] = new ampa(0.5)")
        h("Epop[12] netConn_projEE_ampa[981] = new NetCon(&v(0.5), syn_projEE_ampa[981], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 982: cell 12, seg 0 (0.5) [0.5 on Epop[12]] -> cell 22, seg 0 (0.5) [0.5 on Epop[22]], weight: 4.1363508E-4, delay 1.5
        h("Epop[22] syn_projEE_ampa[982] = new ampa(0.5)")
        h("Epop[12] netConn_projEE_ampa[982] = new NetCon(&v(0.5), syn_projEE_ampa[982], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 983: cell 12, seg 0 (0.5) [0.5 on Epop[12]] -> cell 23, seg 0 (0.5) [0.5 on Epop[23]], weight: 4.1363508E-4, delay 1.5
        h("Epop[23] syn_projEE_ampa[983] = new ampa(0.5)")
        h("Epop[12] netConn_projEE_ampa[983] = new NetCon(&v(0.5), syn_projEE_ampa[983], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 984: cell 12, seg 0 (0.5) [0.5 on Epop[12]] -> cell 24, seg 0 (0.5) [0.5 on Epop[24]], weight: 4.1363508E-4, delay 1.5
        h("Epop[24] syn_projEE_ampa[984] = new ampa(0.5)")
        h("Epop[12] netConn_projEE_ampa[984] = new NetCon(&v(0.5), syn_projEE_ampa[984], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 985: cell 12, seg 0 (0.5) [0.5 on Epop[12]] -> cell 25, seg 0 (0.5) [0.5 on Epop[25]], weight: 4.1363508E-4, delay 1.5
        h("Epop[25] syn_projEE_ampa[985] = new ampa(0.5)")
        h("Epop[12] netConn_projEE_ampa[985] = new NetCon(&v(0.5), syn_projEE_ampa[985], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 986: cell 12, seg 0 (0.5) [0.5 on Epop[12]] -> cell 26, seg 0 (0.5) [0.5 on Epop[26]], weight: 4.1363508E-4, delay 1.5
        h("Epop[26] syn_projEE_ampa[986] = new ampa(0.5)")
        h("Epop[12] netConn_projEE_ampa[986] = new NetCon(&v(0.5), syn_projEE_ampa[986], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 987: cell 12, seg 0 (0.5) [0.5 on Epop[12]] -> cell 27, seg 0 (0.5) [0.5 on Epop[27]], weight: 4.1363508E-4, delay 1.5
        h("Epop[27] syn_projEE_ampa[987] = new ampa(0.5)")
        h("Epop[12] netConn_projEE_ampa[987] = new NetCon(&v(0.5), syn_projEE_ampa[987], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 988: cell 12, seg 0 (0.5) [0.5 on Epop[12]] -> cell 28, seg 0 (0.5) [0.5 on Epop[28]], weight: 4.1363508E-4, delay 1.5
        h("Epop[28] syn_projEE_ampa[988] = new ampa(0.5)")
        h("Epop[12] netConn_projEE_ampa[988] = new NetCon(&v(0.5), syn_projEE_ampa[988], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 989: cell 12, seg 0 (0.5) [0.5 on Epop[12]] -> cell 29, seg 0 (0.5) [0.5 on Epop[29]], weight: 4.1363508E-4, delay 1.5
        h("Epop[29] syn_projEE_ampa[989] = new ampa(0.5)")
        h("Epop[12] netConn_projEE_ampa[989] = new NetCon(&v(0.5), syn_projEE_ampa[989], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 990: cell 12, seg 0 (0.5) [0.5 on Epop[12]] -> cell 30, seg 0 (0.5) [0.5 on Epop[30]], weight: 4.1363508E-4, delay 1.5
        h("Epop[30] syn_projEE_ampa[990] = new ampa(0.5)")
        h("Epop[12] netConn_projEE_ampa[990] = new NetCon(&v(0.5), syn_projEE_ampa[990], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 991: cell 12, seg 0 (0.5) [0.5 on Epop[12]] -> cell 31, seg 0 (0.5) [0.5 on Epop[31]], weight: 4.1363508E-4, delay 1.5
        h("Epop[31] syn_projEE_ampa[991] = new ampa(0.5)")
        h("Epop[12] netConn_projEE_ampa[991] = new NetCon(&v(0.5), syn_projEE_ampa[991], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 992: cell 12, seg 0 (0.5) [0.5 on Epop[12]] -> cell 32, seg 0 (0.5) [0.5 on Epop[32]], weight: 4.1363508E-4, delay 1.5
        h("Epop[32] syn_projEE_ampa[992] = new ampa(0.5)")
        h("Epop[12] netConn_projEE_ampa[992] = new NetCon(&v(0.5), syn_projEE_ampa[992], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 993: cell 12, seg 0 (0.5) [0.5 on Epop[12]] -> cell 33, seg 0 (0.5) [0.5 on Epop[33]], weight: 4.1363508E-4, delay 1.5
        h("Epop[33] syn_projEE_ampa[993] = new ampa(0.5)")
        h("Epop[12] netConn_projEE_ampa[993] = new NetCon(&v(0.5), syn_projEE_ampa[993], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 994: cell 12, seg 0 (0.5) [0.5 on Epop[12]] -> cell 34, seg 0 (0.5) [0.5 on Epop[34]], weight: 4.1363508E-4, delay 1.5
        h("Epop[34] syn_projEE_ampa[994] = new ampa(0.5)")
        h("Epop[12] netConn_projEE_ampa[994] = new NetCon(&v(0.5), syn_projEE_ampa[994], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 995: cell 12, seg 0 (0.5) [0.5 on Epop[12]] -> cell 35, seg 0 (0.5) [0.5 on Epop[35]], weight: 4.1363508E-4, delay 1.5
        h("Epop[35] syn_projEE_ampa[995] = new ampa(0.5)")
        h("Epop[12] netConn_projEE_ampa[995] = new NetCon(&v(0.5), syn_projEE_ampa[995], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 996: cell 12, seg 0 (0.5) [0.5 on Epop[12]] -> cell 36, seg 0 (0.5) [0.5 on Epop[36]], weight: 4.1363508E-4, delay 1.5
        h("Epop[36] syn_projEE_ampa[996] = new ampa(0.5)")
        h("Epop[12] netConn_projEE_ampa[996] = new NetCon(&v(0.5), syn_projEE_ampa[996], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 997: cell 12, seg 0 (0.5) [0.5 on Epop[12]] -> cell 37, seg 0 (0.5) [0.5 on Epop[37]], weight: 4.1363508E-4, delay 1.5
        h("Epop[37] syn_projEE_ampa[997] = new ampa(0.5)")
        h("Epop[12] netConn_projEE_ampa[997] = new NetCon(&v(0.5), syn_projEE_ampa[997], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 998: cell 12, seg 0 (0.5) [0.5 on Epop[12]] -> cell 38, seg 0 (0.5) [0.5 on Epop[38]], weight: 4.1363508E-4, delay 1.5
        h("Epop[38] syn_projEE_ampa[998] = new ampa(0.5)")
        h("Epop[12] netConn_projEE_ampa[998] = new NetCon(&v(0.5), syn_projEE_ampa[998], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 999: cell 12, seg 0 (0.5) [0.5 on Epop[12]] -> cell 39, seg 0 (0.5) [0.5 on Epop[39]], weight: 4.1363508E-4, delay 1.5
        h("Epop[39] syn_projEE_ampa[999] = new ampa(0.5)")
        h("Epop[12] netConn_projEE_ampa[999] = new NetCon(&v(0.5), syn_projEE_ampa[999], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1000: cell 12, seg 0 (0.5) [0.5 on Epop[12]] -> cell 40, seg 0 (0.5) [0.5 on Epop[40]], weight: 4.1363508E-4, delay 1.5
        h("Epop[40] syn_projEE_ampa[1000] = new ampa(0.5)")
        h("Epop[12] netConn_projEE_ampa[1000] = new NetCon(&v(0.5), syn_projEE_ampa[1000], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1001: cell 12, seg 0 (0.5) [0.5 on Epop[12]] -> cell 41, seg 0 (0.5) [0.5 on Epop[41]], weight: 4.1363508E-4, delay 1.5
        h("Epop[41] syn_projEE_ampa[1001] = new ampa(0.5)")
        h("Epop[12] netConn_projEE_ampa[1001] = new NetCon(&v(0.5), syn_projEE_ampa[1001], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1002: cell 12, seg 0 (0.5) [0.5 on Epop[12]] -> cell 42, seg 0 (0.5) [0.5 on Epop[42]], weight: 4.1363508E-4, delay 1.5
        h("Epop[42] syn_projEE_ampa[1002] = new ampa(0.5)")
        h("Epop[12] netConn_projEE_ampa[1002] = new NetCon(&v(0.5), syn_projEE_ampa[1002], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1003: cell 12, seg 0 (0.5) [0.5 on Epop[12]] -> cell 43, seg 0 (0.5) [0.5 on Epop[43]], weight: 4.1363508E-4, delay 1.5
        h("Epop[43] syn_projEE_ampa[1003] = new ampa(0.5)")
        h("Epop[12] netConn_projEE_ampa[1003] = new NetCon(&v(0.5), syn_projEE_ampa[1003], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1004: cell 12, seg 0 (0.5) [0.5 on Epop[12]] -> cell 44, seg 0 (0.5) [0.5 on Epop[44]], weight: 4.1363508E-4, delay 1.5
        h("Epop[44] syn_projEE_ampa[1004] = new ampa(0.5)")
        h("Epop[12] netConn_projEE_ampa[1004] = new NetCon(&v(0.5), syn_projEE_ampa[1004], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1005: cell 12, seg 0 (0.5) [0.5 on Epop[12]] -> cell 45, seg 0 (0.5) [0.5 on Epop[45]], weight: 4.1363508E-4, delay 1.5
        h("Epop[45] syn_projEE_ampa[1005] = new ampa(0.5)")
        h("Epop[12] netConn_projEE_ampa[1005] = new NetCon(&v(0.5), syn_projEE_ampa[1005], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1006: cell 12, seg 0 (0.5) [0.5 on Epop[12]] -> cell 46, seg 0 (0.5) [0.5 on Epop[46]], weight: 4.1363508E-4, delay 1.5
        h("Epop[46] syn_projEE_ampa[1006] = new ampa(0.5)")
        h("Epop[12] netConn_projEE_ampa[1006] = new NetCon(&v(0.5), syn_projEE_ampa[1006], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1007: cell 12, seg 0 (0.5) [0.5 on Epop[12]] -> cell 47, seg 0 (0.5) [0.5 on Epop[47]], weight: 4.1363508E-4, delay 1.5
        h("Epop[47] syn_projEE_ampa[1007] = new ampa(0.5)")
        h("Epop[12] netConn_projEE_ampa[1007] = new NetCon(&v(0.5), syn_projEE_ampa[1007], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1008: cell 12, seg 0 (0.5) [0.5 on Epop[12]] -> cell 48, seg 0 (0.5) [0.5 on Epop[48]], weight: 4.1363508E-4, delay 1.5
        h("Epop[48] syn_projEE_ampa[1008] = new ampa(0.5)")
        h("Epop[12] netConn_projEE_ampa[1008] = new NetCon(&v(0.5), syn_projEE_ampa[1008], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1009: cell 12, seg 0 (0.5) [0.5 on Epop[12]] -> cell 49, seg 0 (0.5) [0.5 on Epop[49]], weight: 4.1363508E-4, delay 1.5
        h("Epop[49] syn_projEE_ampa[1009] = new ampa(0.5)")
        h("Epop[12] netConn_projEE_ampa[1009] = new NetCon(&v(0.5), syn_projEE_ampa[1009], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1010: cell 12, seg 0 (0.5) [0.5 on Epop[12]] -> cell 50, seg 0 (0.5) [0.5 on Epop[50]], weight: 4.1363508E-4, delay 1.5
        h("Epop[50] syn_projEE_ampa[1010] = new ampa(0.5)")
        h("Epop[12] netConn_projEE_ampa[1010] = new NetCon(&v(0.5), syn_projEE_ampa[1010], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1011: cell 12, seg 0 (0.5) [0.5 on Epop[12]] -> cell 51, seg 0 (0.5) [0.5 on Epop[51]], weight: 4.1363508E-4, delay 1.5
        h("Epop[51] syn_projEE_ampa[1011] = new ampa(0.5)")
        h("Epop[12] netConn_projEE_ampa[1011] = new NetCon(&v(0.5), syn_projEE_ampa[1011], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1012: cell 12, seg 0 (0.5) [0.5 on Epop[12]] -> cell 52, seg 0 (0.5) [0.5 on Epop[52]], weight: 4.1363508E-4, delay 1.5
        h("Epop[52] syn_projEE_ampa[1012] = new ampa(0.5)")
        h("Epop[12] netConn_projEE_ampa[1012] = new NetCon(&v(0.5), syn_projEE_ampa[1012], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1013: cell 12, seg 0 (0.5) [0.5 on Epop[12]] -> cell 53, seg 0 (0.5) [0.5 on Epop[53]], weight: 4.1363508E-4, delay 1.5
        h("Epop[53] syn_projEE_ampa[1013] = new ampa(0.5)")
        h("Epop[12] netConn_projEE_ampa[1013] = new NetCon(&v(0.5), syn_projEE_ampa[1013], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1014: cell 12, seg 0 (0.5) [0.5 on Epop[12]] -> cell 54, seg 0 (0.5) [0.5 on Epop[54]], weight: 4.1363508E-4, delay 1.5
        h("Epop[54] syn_projEE_ampa[1014] = new ampa(0.5)")
        h("Epop[12] netConn_projEE_ampa[1014] = new NetCon(&v(0.5), syn_projEE_ampa[1014], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1015: cell 12, seg 0 (0.5) [0.5 on Epop[12]] -> cell 55, seg 0 (0.5) [0.5 on Epop[55]], weight: 4.1363508E-4, delay 1.5
        h("Epop[55] syn_projEE_ampa[1015] = new ampa(0.5)")
        h("Epop[12] netConn_projEE_ampa[1015] = new NetCon(&v(0.5), syn_projEE_ampa[1015], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1016: cell 12, seg 0 (0.5) [0.5 on Epop[12]] -> cell 56, seg 0 (0.5) [0.5 on Epop[56]], weight: 4.1363508E-4, delay 1.5
        h("Epop[56] syn_projEE_ampa[1016] = new ampa(0.5)")
        h("Epop[12] netConn_projEE_ampa[1016] = new NetCon(&v(0.5), syn_projEE_ampa[1016], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1017: cell 12, seg 0 (0.5) [0.5 on Epop[12]] -> cell 57, seg 0 (0.5) [0.5 on Epop[57]], weight: 4.1363508E-4, delay 1.5
        h("Epop[57] syn_projEE_ampa[1017] = new ampa(0.5)")
        h("Epop[12] netConn_projEE_ampa[1017] = new NetCon(&v(0.5), syn_projEE_ampa[1017], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1018: cell 12, seg 0 (0.5) [0.5 on Epop[12]] -> cell 58, seg 0 (0.5) [0.5 on Epop[58]], weight: 4.1363508E-4, delay 1.5
        h("Epop[58] syn_projEE_ampa[1018] = new ampa(0.5)")
        h("Epop[12] netConn_projEE_ampa[1018] = new NetCon(&v(0.5), syn_projEE_ampa[1018], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1019: cell 12, seg 0 (0.5) [0.5 on Epop[12]] -> cell 59, seg 0 (0.5) [0.5 on Epop[59]], weight: 4.1363508E-4, delay 1.5
        h("Epop[59] syn_projEE_ampa[1019] = new ampa(0.5)")
        h("Epop[12] netConn_projEE_ampa[1019] = new NetCon(&v(0.5), syn_projEE_ampa[1019], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1020: cell 12, seg 0 (0.5) [0.5 on Epop[12]] -> cell 60, seg 0 (0.5) [0.5 on Epop[60]], weight: 4.1363508E-4, delay 1.5
        h("Epop[60] syn_projEE_ampa[1020] = new ampa(0.5)")
        h("Epop[12] netConn_projEE_ampa[1020] = new NetCon(&v(0.5), syn_projEE_ampa[1020], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1021: cell 12, seg 0 (0.5) [0.5 on Epop[12]] -> cell 61, seg 0 (0.5) [0.5 on Epop[61]], weight: 4.1363508E-4, delay 1.5
        h("Epop[61] syn_projEE_ampa[1021] = new ampa(0.5)")
        h("Epop[12] netConn_projEE_ampa[1021] = new NetCon(&v(0.5), syn_projEE_ampa[1021], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1022: cell 12, seg 0 (0.5) [0.5 on Epop[12]] -> cell 62, seg 0 (0.5) [0.5 on Epop[62]], weight: 4.1363508E-4, delay 1.5
        h("Epop[62] syn_projEE_ampa[1022] = new ampa(0.5)")
        h("Epop[12] netConn_projEE_ampa[1022] = new NetCon(&v(0.5), syn_projEE_ampa[1022], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1023: cell 12, seg 0 (0.5) [0.5 on Epop[12]] -> cell 63, seg 0 (0.5) [0.5 on Epop[63]], weight: 4.1363508E-4, delay 1.5
        h("Epop[63] syn_projEE_ampa[1023] = new ampa(0.5)")
        h("Epop[12] netConn_projEE_ampa[1023] = new NetCon(&v(0.5), syn_projEE_ampa[1023], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1024: cell 12, seg 0 (0.5) [0.5 on Epop[12]] -> cell 64, seg 0 (0.5) [0.5 on Epop[64]], weight: 4.1363508E-4, delay 1.5
        h("Epop[64] syn_projEE_ampa[1024] = new ampa(0.5)")
        h("Epop[12] netConn_projEE_ampa[1024] = new NetCon(&v(0.5), syn_projEE_ampa[1024], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1025: cell 12, seg 0 (0.5) [0.5 on Epop[12]] -> cell 65, seg 0 (0.5) [0.5 on Epop[65]], weight: 4.1363508E-4, delay 1.5
        h("Epop[65] syn_projEE_ampa[1025] = new ampa(0.5)")
        h("Epop[12] netConn_projEE_ampa[1025] = new NetCon(&v(0.5), syn_projEE_ampa[1025], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1026: cell 12, seg 0 (0.5) [0.5 on Epop[12]] -> cell 66, seg 0 (0.5) [0.5 on Epop[66]], weight: 4.1363508E-4, delay 1.5
        h("Epop[66] syn_projEE_ampa[1026] = new ampa(0.5)")
        h("Epop[12] netConn_projEE_ampa[1026] = new NetCon(&v(0.5), syn_projEE_ampa[1026], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1027: cell 12, seg 0 (0.5) [0.5 on Epop[12]] -> cell 67, seg 0 (0.5) [0.5 on Epop[67]], weight: 4.1363508E-4, delay 1.5
        h("Epop[67] syn_projEE_ampa[1027] = new ampa(0.5)")
        h("Epop[12] netConn_projEE_ampa[1027] = new NetCon(&v(0.5), syn_projEE_ampa[1027], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1028: cell 12, seg 0 (0.5) [0.5 on Epop[12]] -> cell 68, seg 0 (0.5) [0.5 on Epop[68]], weight: 4.1363508E-4, delay 1.5
        h("Epop[68] syn_projEE_ampa[1028] = new ampa(0.5)")
        h("Epop[12] netConn_projEE_ampa[1028] = new NetCon(&v(0.5), syn_projEE_ampa[1028], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1029: cell 12, seg 0 (0.5) [0.5 on Epop[12]] -> cell 69, seg 0 (0.5) [0.5 on Epop[69]], weight: 4.1363508E-4, delay 1.5
        h("Epop[69] syn_projEE_ampa[1029] = new ampa(0.5)")
        h("Epop[12] netConn_projEE_ampa[1029] = new NetCon(&v(0.5), syn_projEE_ampa[1029], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1030: cell 12, seg 0 (0.5) [0.5 on Epop[12]] -> cell 70, seg 0 (0.5) [0.5 on Epop[70]], weight: 4.1363508E-4, delay 1.5
        h("Epop[70] syn_projEE_ampa[1030] = new ampa(0.5)")
        h("Epop[12] netConn_projEE_ampa[1030] = new NetCon(&v(0.5), syn_projEE_ampa[1030], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1031: cell 12, seg 0 (0.5) [0.5 on Epop[12]] -> cell 71, seg 0 (0.5) [0.5 on Epop[71]], weight: 4.1363508E-4, delay 1.5
        h("Epop[71] syn_projEE_ampa[1031] = new ampa(0.5)")
        h("Epop[12] netConn_projEE_ampa[1031] = new NetCon(&v(0.5), syn_projEE_ampa[1031], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1032: cell 12, seg 0 (0.5) [0.5 on Epop[12]] -> cell 72, seg 0 (0.5) [0.5 on Epop[72]], weight: 4.1363508E-4, delay 1.5
        h("Epop[72] syn_projEE_ampa[1032] = new ampa(0.5)")
        h("Epop[12] netConn_projEE_ampa[1032] = new NetCon(&v(0.5), syn_projEE_ampa[1032], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1033: cell 12, seg 0 (0.5) [0.5 on Epop[12]] -> cell 73, seg 0 (0.5) [0.5 on Epop[73]], weight: 4.1363508E-4, delay 1.5
        h("Epop[73] syn_projEE_ampa[1033] = new ampa(0.5)")
        h("Epop[12] netConn_projEE_ampa[1033] = new NetCon(&v(0.5), syn_projEE_ampa[1033], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1034: cell 12, seg 0 (0.5) [0.5 on Epop[12]] -> cell 74, seg 0 (0.5) [0.5 on Epop[74]], weight: 4.1363508E-4, delay 1.5
        h("Epop[74] syn_projEE_ampa[1034] = new ampa(0.5)")
        h("Epop[12] netConn_projEE_ampa[1034] = new NetCon(&v(0.5), syn_projEE_ampa[1034], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1035: cell 12, seg 0 (0.5) [0.5 on Epop[12]] -> cell 75, seg 0 (0.5) [0.5 on Epop[75]], weight: 4.1363508E-4, delay 1.5
        h("Epop[75] syn_projEE_ampa[1035] = new ampa(0.5)")
        h("Epop[12] netConn_projEE_ampa[1035] = new NetCon(&v(0.5), syn_projEE_ampa[1035], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1036: cell 12, seg 0 (0.5) [0.5 on Epop[12]] -> cell 76, seg 0 (0.5) [0.5 on Epop[76]], weight: 4.1363508E-4, delay 1.5
        h("Epop[76] syn_projEE_ampa[1036] = new ampa(0.5)")
        h("Epop[12] netConn_projEE_ampa[1036] = new NetCon(&v(0.5), syn_projEE_ampa[1036], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1037: cell 12, seg 0 (0.5) [0.5 on Epop[12]] -> cell 77, seg 0 (0.5) [0.5 on Epop[77]], weight: 4.1363508E-4, delay 1.5
        h("Epop[77] syn_projEE_ampa[1037] = new ampa(0.5)")
        h("Epop[12] netConn_projEE_ampa[1037] = new NetCon(&v(0.5), syn_projEE_ampa[1037], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1038: cell 12, seg 0 (0.5) [0.5 on Epop[12]] -> cell 78, seg 0 (0.5) [0.5 on Epop[78]], weight: 4.1363508E-4, delay 1.5
        h("Epop[78] syn_projEE_ampa[1038] = new ampa(0.5)")
        h("Epop[12] netConn_projEE_ampa[1038] = new NetCon(&v(0.5), syn_projEE_ampa[1038], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1039: cell 12, seg 0 (0.5) [0.5 on Epop[12]] -> cell 79, seg 0 (0.5) [0.5 on Epop[79]], weight: 4.1363508E-4, delay 1.5
        h("Epop[79] syn_projEE_ampa[1039] = new ampa(0.5)")
        h("Epop[12] netConn_projEE_ampa[1039] = new NetCon(&v(0.5), syn_projEE_ampa[1039], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1040: cell 13, seg 0 (0.5) [0.5 on Epop[13]] -> cell 0, seg 0 (0.5) [0.5 on Epop[0]], weight: 4.1363508E-4, delay 1.5
        h("Epop[0] syn_projEE_ampa[1040] = new ampa(0.5)")
        h("Epop[13] netConn_projEE_ampa[1040] = new NetCon(&v(0.5), syn_projEE_ampa[1040], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1041: cell 13, seg 0 (0.5) [0.5 on Epop[13]] -> cell 1, seg 0 (0.5) [0.5 on Epop[1]], weight: 4.1363508E-4, delay 1.5
        h("Epop[1] syn_projEE_ampa[1041] = new ampa(0.5)")
        h("Epop[13] netConn_projEE_ampa[1041] = new NetCon(&v(0.5), syn_projEE_ampa[1041], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1042: cell 13, seg 0 (0.5) [0.5 on Epop[13]] -> cell 2, seg 0 (0.5) [0.5 on Epop[2]], weight: 4.1363508E-4, delay 1.5
        h("Epop[2] syn_projEE_ampa[1042] = new ampa(0.5)")
        h("Epop[13] netConn_projEE_ampa[1042] = new NetCon(&v(0.5), syn_projEE_ampa[1042], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1043: cell 13, seg 0 (0.5) [0.5 on Epop[13]] -> cell 3, seg 0 (0.5) [0.5 on Epop[3]], weight: 4.1363508E-4, delay 1.5
        h("Epop[3] syn_projEE_ampa[1043] = new ampa(0.5)")
        h("Epop[13] netConn_projEE_ampa[1043] = new NetCon(&v(0.5), syn_projEE_ampa[1043], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1044: cell 13, seg 0 (0.5) [0.5 on Epop[13]] -> cell 4, seg 0 (0.5) [0.5 on Epop[4]], weight: 4.1363508E-4, delay 1.5
        h("Epop[4] syn_projEE_ampa[1044] = new ampa(0.5)")
        h("Epop[13] netConn_projEE_ampa[1044] = new NetCon(&v(0.5), syn_projEE_ampa[1044], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1045: cell 13, seg 0 (0.5) [0.5 on Epop[13]] -> cell 5, seg 0 (0.5) [0.5 on Epop[5]], weight: 4.1363508E-4, delay 1.5
        h("Epop[5] syn_projEE_ampa[1045] = new ampa(0.5)")
        h("Epop[13] netConn_projEE_ampa[1045] = new NetCon(&v(0.5), syn_projEE_ampa[1045], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1046: cell 13, seg 0 (0.5) [0.5 on Epop[13]] -> cell 6, seg 0 (0.5) [0.5 on Epop[6]], weight: 4.1363508E-4, delay 1.5
        h("Epop[6] syn_projEE_ampa[1046] = new ampa(0.5)")
        h("Epop[13] netConn_projEE_ampa[1046] = new NetCon(&v(0.5), syn_projEE_ampa[1046], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1047: cell 13, seg 0 (0.5) [0.5 on Epop[13]] -> cell 7, seg 0 (0.5) [0.5 on Epop[7]], weight: 4.1363508E-4, delay 1.5
        h("Epop[7] syn_projEE_ampa[1047] = new ampa(0.5)")
        h("Epop[13] netConn_projEE_ampa[1047] = new NetCon(&v(0.5), syn_projEE_ampa[1047], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1048: cell 13, seg 0 (0.5) [0.5 on Epop[13]] -> cell 8, seg 0 (0.5) [0.5 on Epop[8]], weight: 4.1363508E-4, delay 1.5
        h("Epop[8] syn_projEE_ampa[1048] = new ampa(0.5)")
        h("Epop[13] netConn_projEE_ampa[1048] = new NetCon(&v(0.5), syn_projEE_ampa[1048], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1049: cell 13, seg 0 (0.5) [0.5 on Epop[13]] -> cell 9, seg 0 (0.5) [0.5 on Epop[9]], weight: 4.1363508E-4, delay 1.5
        h("Epop[9] syn_projEE_ampa[1049] = new ampa(0.5)")
        h("Epop[13] netConn_projEE_ampa[1049] = new NetCon(&v(0.5), syn_projEE_ampa[1049], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1050: cell 13, seg 0 (0.5) [0.5 on Epop[13]] -> cell 10, seg 0 (0.5) [0.5 on Epop[10]], weight: 4.1363508E-4, delay 1.5
        h("Epop[10] syn_projEE_ampa[1050] = new ampa(0.5)")
        h("Epop[13] netConn_projEE_ampa[1050] = new NetCon(&v(0.5), syn_projEE_ampa[1050], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1051: cell 13, seg 0 (0.5) [0.5 on Epop[13]] -> cell 11, seg 0 (0.5) [0.5 on Epop[11]], weight: 4.1363508E-4, delay 1.5
        h("Epop[11] syn_projEE_ampa[1051] = new ampa(0.5)")
        h("Epop[13] netConn_projEE_ampa[1051] = new NetCon(&v(0.5), syn_projEE_ampa[1051], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1052: cell 13, seg 0 (0.5) [0.5 on Epop[13]] -> cell 12, seg 0 (0.5) [0.5 on Epop[12]], weight: 4.1363508E-4, delay 1.5
        h("Epop[12] syn_projEE_ampa[1052] = new ampa(0.5)")
        h("Epop[13] netConn_projEE_ampa[1052] = new NetCon(&v(0.5), syn_projEE_ampa[1052], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1053: cell 13, seg 0 (0.5) [0.5 on Epop[13]] -> cell 13, seg 0 (0.5) [0.5 on Epop[13]], weight: 4.1363508E-4, delay 1.5
        h("Epop[13] syn_projEE_ampa[1053] = new ampa(0.5)")
        h("Epop[13] netConn_projEE_ampa[1053] = new NetCon(&v(0.5), syn_projEE_ampa[1053], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1054: cell 13, seg 0 (0.5) [0.5 on Epop[13]] -> cell 14, seg 0 (0.5) [0.5 on Epop[14]], weight: 4.1363508E-4, delay 1.5
        h("Epop[14] syn_projEE_ampa[1054] = new ampa(0.5)")
        h("Epop[13] netConn_projEE_ampa[1054] = new NetCon(&v(0.5), syn_projEE_ampa[1054], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1055: cell 13, seg 0 (0.5) [0.5 on Epop[13]] -> cell 15, seg 0 (0.5) [0.5 on Epop[15]], weight: 4.1363508E-4, delay 1.5
        h("Epop[15] syn_projEE_ampa[1055] = new ampa(0.5)")
        h("Epop[13] netConn_projEE_ampa[1055] = new NetCon(&v(0.5), syn_projEE_ampa[1055], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1056: cell 13, seg 0 (0.5) [0.5 on Epop[13]] -> cell 16, seg 0 (0.5) [0.5 on Epop[16]], weight: 4.1363508E-4, delay 1.5
        h("Epop[16] syn_projEE_ampa[1056] = new ampa(0.5)")
        h("Epop[13] netConn_projEE_ampa[1056] = new NetCon(&v(0.5), syn_projEE_ampa[1056], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1057: cell 13, seg 0 (0.5) [0.5 on Epop[13]] -> cell 17, seg 0 (0.5) [0.5 on Epop[17]], weight: 4.1363508E-4, delay 1.5
        h("Epop[17] syn_projEE_ampa[1057] = new ampa(0.5)")
        h("Epop[13] netConn_projEE_ampa[1057] = new NetCon(&v(0.5), syn_projEE_ampa[1057], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1058: cell 13, seg 0 (0.5) [0.5 on Epop[13]] -> cell 18, seg 0 (0.5) [0.5 on Epop[18]], weight: 4.1363508E-4, delay 1.5
        h("Epop[18] syn_projEE_ampa[1058] = new ampa(0.5)")
        h("Epop[13] netConn_projEE_ampa[1058] = new NetCon(&v(0.5), syn_projEE_ampa[1058], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1059: cell 13, seg 0 (0.5) [0.5 on Epop[13]] -> cell 19, seg 0 (0.5) [0.5 on Epop[19]], weight: 4.1363508E-4, delay 1.5
        h("Epop[19] syn_projEE_ampa[1059] = new ampa(0.5)")
        h("Epop[13] netConn_projEE_ampa[1059] = new NetCon(&v(0.5), syn_projEE_ampa[1059], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1060: cell 13, seg 0 (0.5) [0.5 on Epop[13]] -> cell 20, seg 0 (0.5) [0.5 on Epop[20]], weight: 4.1363508E-4, delay 1.5
        h("Epop[20] syn_projEE_ampa[1060] = new ampa(0.5)")
        h("Epop[13] netConn_projEE_ampa[1060] = new NetCon(&v(0.5), syn_projEE_ampa[1060], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1061: cell 13, seg 0 (0.5) [0.5 on Epop[13]] -> cell 21, seg 0 (0.5) [0.5 on Epop[21]], weight: 4.1363508E-4, delay 1.5
        h("Epop[21] syn_projEE_ampa[1061] = new ampa(0.5)")
        h("Epop[13] netConn_projEE_ampa[1061] = new NetCon(&v(0.5), syn_projEE_ampa[1061], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1062: cell 13, seg 0 (0.5) [0.5 on Epop[13]] -> cell 22, seg 0 (0.5) [0.5 on Epop[22]], weight: 4.1363508E-4, delay 1.5
        h("Epop[22] syn_projEE_ampa[1062] = new ampa(0.5)")
        h("Epop[13] netConn_projEE_ampa[1062] = new NetCon(&v(0.5), syn_projEE_ampa[1062], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1063: cell 13, seg 0 (0.5) [0.5 on Epop[13]] -> cell 23, seg 0 (0.5) [0.5 on Epop[23]], weight: 4.1363508E-4, delay 1.5
        h("Epop[23] syn_projEE_ampa[1063] = new ampa(0.5)")
        h("Epop[13] netConn_projEE_ampa[1063] = new NetCon(&v(0.5), syn_projEE_ampa[1063], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1064: cell 13, seg 0 (0.5) [0.5 on Epop[13]] -> cell 24, seg 0 (0.5) [0.5 on Epop[24]], weight: 4.1363508E-4, delay 1.5
        h("Epop[24] syn_projEE_ampa[1064] = new ampa(0.5)")
        h("Epop[13] netConn_projEE_ampa[1064] = new NetCon(&v(0.5), syn_projEE_ampa[1064], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1065: cell 13, seg 0 (0.5) [0.5 on Epop[13]] -> cell 25, seg 0 (0.5) [0.5 on Epop[25]], weight: 4.1363508E-4, delay 1.5
        h("Epop[25] syn_projEE_ampa[1065] = new ampa(0.5)")
        h("Epop[13] netConn_projEE_ampa[1065] = new NetCon(&v(0.5), syn_projEE_ampa[1065], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1066: cell 13, seg 0 (0.5) [0.5 on Epop[13]] -> cell 26, seg 0 (0.5) [0.5 on Epop[26]], weight: 4.1363508E-4, delay 1.5
        h("Epop[26] syn_projEE_ampa[1066] = new ampa(0.5)")
        h("Epop[13] netConn_projEE_ampa[1066] = new NetCon(&v(0.5), syn_projEE_ampa[1066], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1067: cell 13, seg 0 (0.5) [0.5 on Epop[13]] -> cell 27, seg 0 (0.5) [0.5 on Epop[27]], weight: 4.1363508E-4, delay 1.5
        h("Epop[27] syn_projEE_ampa[1067] = new ampa(0.5)")
        h("Epop[13] netConn_projEE_ampa[1067] = new NetCon(&v(0.5), syn_projEE_ampa[1067], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1068: cell 13, seg 0 (0.5) [0.5 on Epop[13]] -> cell 28, seg 0 (0.5) [0.5 on Epop[28]], weight: 4.1363508E-4, delay 1.5
        h("Epop[28] syn_projEE_ampa[1068] = new ampa(0.5)")
        h("Epop[13] netConn_projEE_ampa[1068] = new NetCon(&v(0.5), syn_projEE_ampa[1068], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1069: cell 13, seg 0 (0.5) [0.5 on Epop[13]] -> cell 29, seg 0 (0.5) [0.5 on Epop[29]], weight: 4.1363508E-4, delay 1.5
        h("Epop[29] syn_projEE_ampa[1069] = new ampa(0.5)")
        h("Epop[13] netConn_projEE_ampa[1069] = new NetCon(&v(0.5), syn_projEE_ampa[1069], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1070: cell 13, seg 0 (0.5) [0.5 on Epop[13]] -> cell 30, seg 0 (0.5) [0.5 on Epop[30]], weight: 4.1363508E-4, delay 1.5
        h("Epop[30] syn_projEE_ampa[1070] = new ampa(0.5)")
        h("Epop[13] netConn_projEE_ampa[1070] = new NetCon(&v(0.5), syn_projEE_ampa[1070], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1071: cell 13, seg 0 (0.5) [0.5 on Epop[13]] -> cell 31, seg 0 (0.5) [0.5 on Epop[31]], weight: 4.1363508E-4, delay 1.5
        h("Epop[31] syn_projEE_ampa[1071] = new ampa(0.5)")
        h("Epop[13] netConn_projEE_ampa[1071] = new NetCon(&v(0.5), syn_projEE_ampa[1071], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1072: cell 13, seg 0 (0.5) [0.5 on Epop[13]] -> cell 32, seg 0 (0.5) [0.5 on Epop[32]], weight: 4.1363508E-4, delay 1.5
        h("Epop[32] syn_projEE_ampa[1072] = new ampa(0.5)")
        h("Epop[13] netConn_projEE_ampa[1072] = new NetCon(&v(0.5), syn_projEE_ampa[1072], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1073: cell 13, seg 0 (0.5) [0.5 on Epop[13]] -> cell 33, seg 0 (0.5) [0.5 on Epop[33]], weight: 4.1363508E-4, delay 1.5
        h("Epop[33] syn_projEE_ampa[1073] = new ampa(0.5)")
        h("Epop[13] netConn_projEE_ampa[1073] = new NetCon(&v(0.5), syn_projEE_ampa[1073], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1074: cell 13, seg 0 (0.5) [0.5 on Epop[13]] -> cell 34, seg 0 (0.5) [0.5 on Epop[34]], weight: 4.1363508E-4, delay 1.5
        h("Epop[34] syn_projEE_ampa[1074] = new ampa(0.5)")
        h("Epop[13] netConn_projEE_ampa[1074] = new NetCon(&v(0.5), syn_projEE_ampa[1074], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1075: cell 13, seg 0 (0.5) [0.5 on Epop[13]] -> cell 35, seg 0 (0.5) [0.5 on Epop[35]], weight: 4.1363508E-4, delay 1.5
        h("Epop[35] syn_projEE_ampa[1075] = new ampa(0.5)")
        h("Epop[13] netConn_projEE_ampa[1075] = new NetCon(&v(0.5), syn_projEE_ampa[1075], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1076: cell 13, seg 0 (0.5) [0.5 on Epop[13]] -> cell 36, seg 0 (0.5) [0.5 on Epop[36]], weight: 4.1363508E-4, delay 1.5
        h("Epop[36] syn_projEE_ampa[1076] = new ampa(0.5)")
        h("Epop[13] netConn_projEE_ampa[1076] = new NetCon(&v(0.5), syn_projEE_ampa[1076], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1077: cell 13, seg 0 (0.5) [0.5 on Epop[13]] -> cell 37, seg 0 (0.5) [0.5 on Epop[37]], weight: 4.1363508E-4, delay 1.5
        h("Epop[37] syn_projEE_ampa[1077] = new ampa(0.5)")
        h("Epop[13] netConn_projEE_ampa[1077] = new NetCon(&v(0.5), syn_projEE_ampa[1077], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1078: cell 13, seg 0 (0.5) [0.5 on Epop[13]] -> cell 38, seg 0 (0.5) [0.5 on Epop[38]], weight: 4.1363508E-4, delay 1.5
        h("Epop[38] syn_projEE_ampa[1078] = new ampa(0.5)")
        h("Epop[13] netConn_projEE_ampa[1078] = new NetCon(&v(0.5), syn_projEE_ampa[1078], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1079: cell 13, seg 0 (0.5) [0.5 on Epop[13]] -> cell 39, seg 0 (0.5) [0.5 on Epop[39]], weight: 4.1363508E-4, delay 1.5
        h("Epop[39] syn_projEE_ampa[1079] = new ampa(0.5)")
        h("Epop[13] netConn_projEE_ampa[1079] = new NetCon(&v(0.5), syn_projEE_ampa[1079], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1080: cell 13, seg 0 (0.5) [0.5 on Epop[13]] -> cell 40, seg 0 (0.5) [0.5 on Epop[40]], weight: 4.1363508E-4, delay 1.5
        h("Epop[40] syn_projEE_ampa[1080] = new ampa(0.5)")
        h("Epop[13] netConn_projEE_ampa[1080] = new NetCon(&v(0.5), syn_projEE_ampa[1080], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1081: cell 13, seg 0 (0.5) [0.5 on Epop[13]] -> cell 41, seg 0 (0.5) [0.5 on Epop[41]], weight: 4.1363508E-4, delay 1.5
        h("Epop[41] syn_projEE_ampa[1081] = new ampa(0.5)")
        h("Epop[13] netConn_projEE_ampa[1081] = new NetCon(&v(0.5), syn_projEE_ampa[1081], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1082: cell 13, seg 0 (0.5) [0.5 on Epop[13]] -> cell 42, seg 0 (0.5) [0.5 on Epop[42]], weight: 4.1363508E-4, delay 1.5
        h("Epop[42] syn_projEE_ampa[1082] = new ampa(0.5)")
        h("Epop[13] netConn_projEE_ampa[1082] = new NetCon(&v(0.5), syn_projEE_ampa[1082], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1083: cell 13, seg 0 (0.5) [0.5 on Epop[13]] -> cell 43, seg 0 (0.5) [0.5 on Epop[43]], weight: 4.1363508E-4, delay 1.5
        h("Epop[43] syn_projEE_ampa[1083] = new ampa(0.5)")
        h("Epop[13] netConn_projEE_ampa[1083] = new NetCon(&v(0.5), syn_projEE_ampa[1083], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1084: cell 13, seg 0 (0.5) [0.5 on Epop[13]] -> cell 44, seg 0 (0.5) [0.5 on Epop[44]], weight: 4.1363508E-4, delay 1.5
        h("Epop[44] syn_projEE_ampa[1084] = new ampa(0.5)")
        h("Epop[13] netConn_projEE_ampa[1084] = new NetCon(&v(0.5), syn_projEE_ampa[1084], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1085: cell 13, seg 0 (0.5) [0.5 on Epop[13]] -> cell 45, seg 0 (0.5) [0.5 on Epop[45]], weight: 4.1363508E-4, delay 1.5
        h("Epop[45] syn_projEE_ampa[1085] = new ampa(0.5)")
        h("Epop[13] netConn_projEE_ampa[1085] = new NetCon(&v(0.5), syn_projEE_ampa[1085], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1086: cell 13, seg 0 (0.5) [0.5 on Epop[13]] -> cell 46, seg 0 (0.5) [0.5 on Epop[46]], weight: 4.1363508E-4, delay 1.5
        h("Epop[46] syn_projEE_ampa[1086] = new ampa(0.5)")
        h("Epop[13] netConn_projEE_ampa[1086] = new NetCon(&v(0.5), syn_projEE_ampa[1086], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1087: cell 13, seg 0 (0.5) [0.5 on Epop[13]] -> cell 47, seg 0 (0.5) [0.5 on Epop[47]], weight: 4.1363508E-4, delay 1.5
        h("Epop[47] syn_projEE_ampa[1087] = new ampa(0.5)")
        h("Epop[13] netConn_projEE_ampa[1087] = new NetCon(&v(0.5), syn_projEE_ampa[1087], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1088: cell 13, seg 0 (0.5) [0.5 on Epop[13]] -> cell 48, seg 0 (0.5) [0.5 on Epop[48]], weight: 4.1363508E-4, delay 1.5
        h("Epop[48] syn_projEE_ampa[1088] = new ampa(0.5)")
        h("Epop[13] netConn_projEE_ampa[1088] = new NetCon(&v(0.5), syn_projEE_ampa[1088], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1089: cell 13, seg 0 (0.5) [0.5 on Epop[13]] -> cell 49, seg 0 (0.5) [0.5 on Epop[49]], weight: 4.1363508E-4, delay 1.5
        h("Epop[49] syn_projEE_ampa[1089] = new ampa(0.5)")
        h("Epop[13] netConn_projEE_ampa[1089] = new NetCon(&v(0.5), syn_projEE_ampa[1089], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1090: cell 13, seg 0 (0.5) [0.5 on Epop[13]] -> cell 50, seg 0 (0.5) [0.5 on Epop[50]], weight: 4.1363508E-4, delay 1.5
        h("Epop[50] syn_projEE_ampa[1090] = new ampa(0.5)")
        h("Epop[13] netConn_projEE_ampa[1090] = new NetCon(&v(0.5), syn_projEE_ampa[1090], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1091: cell 13, seg 0 (0.5) [0.5 on Epop[13]] -> cell 51, seg 0 (0.5) [0.5 on Epop[51]], weight: 4.1363508E-4, delay 1.5
        h("Epop[51] syn_projEE_ampa[1091] = new ampa(0.5)")
        h("Epop[13] netConn_projEE_ampa[1091] = new NetCon(&v(0.5), syn_projEE_ampa[1091], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1092: cell 13, seg 0 (0.5) [0.5 on Epop[13]] -> cell 52, seg 0 (0.5) [0.5 on Epop[52]], weight: 4.1363508E-4, delay 1.5
        h("Epop[52] syn_projEE_ampa[1092] = new ampa(0.5)")
        h("Epop[13] netConn_projEE_ampa[1092] = new NetCon(&v(0.5), syn_projEE_ampa[1092], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1093: cell 13, seg 0 (0.5) [0.5 on Epop[13]] -> cell 53, seg 0 (0.5) [0.5 on Epop[53]], weight: 4.1363508E-4, delay 1.5
        h("Epop[53] syn_projEE_ampa[1093] = new ampa(0.5)")
        h("Epop[13] netConn_projEE_ampa[1093] = new NetCon(&v(0.5), syn_projEE_ampa[1093], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1094: cell 13, seg 0 (0.5) [0.5 on Epop[13]] -> cell 54, seg 0 (0.5) [0.5 on Epop[54]], weight: 4.1363508E-4, delay 1.5
        h("Epop[54] syn_projEE_ampa[1094] = new ampa(0.5)")
        h("Epop[13] netConn_projEE_ampa[1094] = new NetCon(&v(0.5), syn_projEE_ampa[1094], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1095: cell 13, seg 0 (0.5) [0.5 on Epop[13]] -> cell 55, seg 0 (0.5) [0.5 on Epop[55]], weight: 4.1363508E-4, delay 1.5
        h("Epop[55] syn_projEE_ampa[1095] = new ampa(0.5)")
        h("Epop[13] netConn_projEE_ampa[1095] = new NetCon(&v(0.5), syn_projEE_ampa[1095], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1096: cell 13, seg 0 (0.5) [0.5 on Epop[13]] -> cell 56, seg 0 (0.5) [0.5 on Epop[56]], weight: 4.1363508E-4, delay 1.5
        h("Epop[56] syn_projEE_ampa[1096] = new ampa(0.5)")
        h("Epop[13] netConn_projEE_ampa[1096] = new NetCon(&v(0.5), syn_projEE_ampa[1096], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1097: cell 13, seg 0 (0.5) [0.5 on Epop[13]] -> cell 57, seg 0 (0.5) [0.5 on Epop[57]], weight: 4.1363508E-4, delay 1.5
        h("Epop[57] syn_projEE_ampa[1097] = new ampa(0.5)")
        h("Epop[13] netConn_projEE_ampa[1097] = new NetCon(&v(0.5), syn_projEE_ampa[1097], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1098: cell 13, seg 0 (0.5) [0.5 on Epop[13]] -> cell 58, seg 0 (0.5) [0.5 on Epop[58]], weight: 4.1363508E-4, delay 1.5
        h("Epop[58] syn_projEE_ampa[1098] = new ampa(0.5)")
        h("Epop[13] netConn_projEE_ampa[1098] = new NetCon(&v(0.5), syn_projEE_ampa[1098], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1099: cell 13, seg 0 (0.5) [0.5 on Epop[13]] -> cell 59, seg 0 (0.5) [0.5 on Epop[59]], weight: 4.1363508E-4, delay 1.5
        h("Epop[59] syn_projEE_ampa[1099] = new ampa(0.5)")
        h("Epop[13] netConn_projEE_ampa[1099] = new NetCon(&v(0.5), syn_projEE_ampa[1099], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1100: cell 13, seg 0 (0.5) [0.5 on Epop[13]] -> cell 60, seg 0 (0.5) [0.5 on Epop[60]], weight: 4.1363508E-4, delay 1.5
        h("Epop[60] syn_projEE_ampa[1100] = new ampa(0.5)")
        h("Epop[13] netConn_projEE_ampa[1100] = new NetCon(&v(0.5), syn_projEE_ampa[1100], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1101: cell 13, seg 0 (0.5) [0.5 on Epop[13]] -> cell 61, seg 0 (0.5) [0.5 on Epop[61]], weight: 4.1363508E-4, delay 1.5
        h("Epop[61] syn_projEE_ampa[1101] = new ampa(0.5)")
        h("Epop[13] netConn_projEE_ampa[1101] = new NetCon(&v(0.5), syn_projEE_ampa[1101], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1102: cell 13, seg 0 (0.5) [0.5 on Epop[13]] -> cell 62, seg 0 (0.5) [0.5 on Epop[62]], weight: 4.1363508E-4, delay 1.5
        h("Epop[62] syn_projEE_ampa[1102] = new ampa(0.5)")
        h("Epop[13] netConn_projEE_ampa[1102] = new NetCon(&v(0.5), syn_projEE_ampa[1102], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1103: cell 13, seg 0 (0.5) [0.5 on Epop[13]] -> cell 63, seg 0 (0.5) [0.5 on Epop[63]], weight: 4.1363508E-4, delay 1.5
        h("Epop[63] syn_projEE_ampa[1103] = new ampa(0.5)")
        h("Epop[13] netConn_projEE_ampa[1103] = new NetCon(&v(0.5), syn_projEE_ampa[1103], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1104: cell 13, seg 0 (0.5) [0.5 on Epop[13]] -> cell 64, seg 0 (0.5) [0.5 on Epop[64]], weight: 4.1363508E-4, delay 1.5
        h("Epop[64] syn_projEE_ampa[1104] = new ampa(0.5)")
        h("Epop[13] netConn_projEE_ampa[1104] = new NetCon(&v(0.5), syn_projEE_ampa[1104], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1105: cell 13, seg 0 (0.5) [0.5 on Epop[13]] -> cell 65, seg 0 (0.5) [0.5 on Epop[65]], weight: 4.1363508E-4, delay 1.5
        h("Epop[65] syn_projEE_ampa[1105] = new ampa(0.5)")
        h("Epop[13] netConn_projEE_ampa[1105] = new NetCon(&v(0.5), syn_projEE_ampa[1105], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1106: cell 13, seg 0 (0.5) [0.5 on Epop[13]] -> cell 66, seg 0 (0.5) [0.5 on Epop[66]], weight: 4.1363508E-4, delay 1.5
        h("Epop[66] syn_projEE_ampa[1106] = new ampa(0.5)")
        h("Epop[13] netConn_projEE_ampa[1106] = new NetCon(&v(0.5), syn_projEE_ampa[1106], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1107: cell 13, seg 0 (0.5) [0.5 on Epop[13]] -> cell 67, seg 0 (0.5) [0.5 on Epop[67]], weight: 4.1363508E-4, delay 1.5
        h("Epop[67] syn_projEE_ampa[1107] = new ampa(0.5)")
        h("Epop[13] netConn_projEE_ampa[1107] = new NetCon(&v(0.5), syn_projEE_ampa[1107], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1108: cell 13, seg 0 (0.5) [0.5 on Epop[13]] -> cell 68, seg 0 (0.5) [0.5 on Epop[68]], weight: 4.1363508E-4, delay 1.5
        h("Epop[68] syn_projEE_ampa[1108] = new ampa(0.5)")
        h("Epop[13] netConn_projEE_ampa[1108] = new NetCon(&v(0.5), syn_projEE_ampa[1108], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1109: cell 13, seg 0 (0.5) [0.5 on Epop[13]] -> cell 69, seg 0 (0.5) [0.5 on Epop[69]], weight: 4.1363508E-4, delay 1.5
        h("Epop[69] syn_projEE_ampa[1109] = new ampa(0.5)")
        h("Epop[13] netConn_projEE_ampa[1109] = new NetCon(&v(0.5), syn_projEE_ampa[1109], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1110: cell 13, seg 0 (0.5) [0.5 on Epop[13]] -> cell 70, seg 0 (0.5) [0.5 on Epop[70]], weight: 4.1363508E-4, delay 1.5
        h("Epop[70] syn_projEE_ampa[1110] = new ampa(0.5)")
        h("Epop[13] netConn_projEE_ampa[1110] = new NetCon(&v(0.5), syn_projEE_ampa[1110], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1111: cell 13, seg 0 (0.5) [0.5 on Epop[13]] -> cell 71, seg 0 (0.5) [0.5 on Epop[71]], weight: 4.1363508E-4, delay 1.5
        h("Epop[71] syn_projEE_ampa[1111] = new ampa(0.5)")
        h("Epop[13] netConn_projEE_ampa[1111] = new NetCon(&v(0.5), syn_projEE_ampa[1111], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1112: cell 13, seg 0 (0.5) [0.5 on Epop[13]] -> cell 72, seg 0 (0.5) [0.5 on Epop[72]], weight: 4.1363508E-4, delay 1.5
        h("Epop[72] syn_projEE_ampa[1112] = new ampa(0.5)")
        h("Epop[13] netConn_projEE_ampa[1112] = new NetCon(&v(0.5), syn_projEE_ampa[1112], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1113: cell 13, seg 0 (0.5) [0.5 on Epop[13]] -> cell 73, seg 0 (0.5) [0.5 on Epop[73]], weight: 4.1363508E-4, delay 1.5
        h("Epop[73] syn_projEE_ampa[1113] = new ampa(0.5)")
        h("Epop[13] netConn_projEE_ampa[1113] = new NetCon(&v(0.5), syn_projEE_ampa[1113], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1114: cell 13, seg 0 (0.5) [0.5 on Epop[13]] -> cell 74, seg 0 (0.5) [0.5 on Epop[74]], weight: 4.1363508E-4, delay 1.5
        h("Epop[74] syn_projEE_ampa[1114] = new ampa(0.5)")
        h("Epop[13] netConn_projEE_ampa[1114] = new NetCon(&v(0.5), syn_projEE_ampa[1114], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1115: cell 13, seg 0 (0.5) [0.5 on Epop[13]] -> cell 75, seg 0 (0.5) [0.5 on Epop[75]], weight: 4.1363508E-4, delay 1.5
        h("Epop[75] syn_projEE_ampa[1115] = new ampa(0.5)")
        h("Epop[13] netConn_projEE_ampa[1115] = new NetCon(&v(0.5), syn_projEE_ampa[1115], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1116: cell 13, seg 0 (0.5) [0.5 on Epop[13]] -> cell 76, seg 0 (0.5) [0.5 on Epop[76]], weight: 4.1363508E-4, delay 1.5
        h("Epop[76] syn_projEE_ampa[1116] = new ampa(0.5)")
        h("Epop[13] netConn_projEE_ampa[1116] = new NetCon(&v(0.5), syn_projEE_ampa[1116], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1117: cell 13, seg 0 (0.5) [0.5 on Epop[13]] -> cell 77, seg 0 (0.5) [0.5 on Epop[77]], weight: 4.1363508E-4, delay 1.5
        h("Epop[77] syn_projEE_ampa[1117] = new ampa(0.5)")
        h("Epop[13] netConn_projEE_ampa[1117] = new NetCon(&v(0.5), syn_projEE_ampa[1117], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1118: cell 13, seg 0 (0.5) [0.5 on Epop[13]] -> cell 78, seg 0 (0.5) [0.5 on Epop[78]], weight: 4.1363508E-4, delay 1.5
        h("Epop[78] syn_projEE_ampa[1118] = new ampa(0.5)")
        h("Epop[13] netConn_projEE_ampa[1118] = new NetCon(&v(0.5), syn_projEE_ampa[1118], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1119: cell 13, seg 0 (0.5) [0.5 on Epop[13]] -> cell 79, seg 0 (0.5) [0.5 on Epop[79]], weight: 4.1363508E-4, delay 1.5
        h("Epop[79] syn_projEE_ampa[1119] = new ampa(0.5)")
        h("Epop[13] netConn_projEE_ampa[1119] = new NetCon(&v(0.5), syn_projEE_ampa[1119], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1120: cell 14, seg 0 (0.5) [0.5 on Epop[14]] -> cell 0, seg 0 (0.5) [0.5 on Epop[0]], weight: 4.1363508E-4, delay 1.5
        h("Epop[0] syn_projEE_ampa[1120] = new ampa(0.5)")
        h("Epop[14] netConn_projEE_ampa[1120] = new NetCon(&v(0.5), syn_projEE_ampa[1120], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1121: cell 14, seg 0 (0.5) [0.5 on Epop[14]] -> cell 1, seg 0 (0.5) [0.5 on Epop[1]], weight: 4.1363508E-4, delay 1.5
        h("Epop[1] syn_projEE_ampa[1121] = new ampa(0.5)")
        h("Epop[14] netConn_projEE_ampa[1121] = new NetCon(&v(0.5), syn_projEE_ampa[1121], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1122: cell 14, seg 0 (0.5) [0.5 on Epop[14]] -> cell 2, seg 0 (0.5) [0.5 on Epop[2]], weight: 4.1363508E-4, delay 1.5
        h("Epop[2] syn_projEE_ampa[1122] = new ampa(0.5)")
        h("Epop[14] netConn_projEE_ampa[1122] = new NetCon(&v(0.5), syn_projEE_ampa[1122], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1123: cell 14, seg 0 (0.5) [0.5 on Epop[14]] -> cell 3, seg 0 (0.5) [0.5 on Epop[3]], weight: 4.1363508E-4, delay 1.5
        h("Epop[3] syn_projEE_ampa[1123] = new ampa(0.5)")
        h("Epop[14] netConn_projEE_ampa[1123] = new NetCon(&v(0.5), syn_projEE_ampa[1123], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1124: cell 14, seg 0 (0.5) [0.5 on Epop[14]] -> cell 4, seg 0 (0.5) [0.5 on Epop[4]], weight: 4.1363508E-4, delay 1.5
        h("Epop[4] syn_projEE_ampa[1124] = new ampa(0.5)")
        h("Epop[14] netConn_projEE_ampa[1124] = new NetCon(&v(0.5), syn_projEE_ampa[1124], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1125: cell 14, seg 0 (0.5) [0.5 on Epop[14]] -> cell 5, seg 0 (0.5) [0.5 on Epop[5]], weight: 4.1363508E-4, delay 1.5
        h("Epop[5] syn_projEE_ampa[1125] = new ampa(0.5)")
        h("Epop[14] netConn_projEE_ampa[1125] = new NetCon(&v(0.5), syn_projEE_ampa[1125], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1126: cell 14, seg 0 (0.5) [0.5 on Epop[14]] -> cell 6, seg 0 (0.5) [0.5 on Epop[6]], weight: 4.1363508E-4, delay 1.5
        h("Epop[6] syn_projEE_ampa[1126] = new ampa(0.5)")
        h("Epop[14] netConn_projEE_ampa[1126] = new NetCon(&v(0.5), syn_projEE_ampa[1126], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1127: cell 14, seg 0 (0.5) [0.5 on Epop[14]] -> cell 7, seg 0 (0.5) [0.5 on Epop[7]], weight: 4.1363508E-4, delay 1.5
        h("Epop[7] syn_projEE_ampa[1127] = new ampa(0.5)")
        h("Epop[14] netConn_projEE_ampa[1127] = new NetCon(&v(0.5), syn_projEE_ampa[1127], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1128: cell 14, seg 0 (0.5) [0.5 on Epop[14]] -> cell 8, seg 0 (0.5) [0.5 on Epop[8]], weight: 4.1363508E-4, delay 1.5
        h("Epop[8] syn_projEE_ampa[1128] = new ampa(0.5)")
        h("Epop[14] netConn_projEE_ampa[1128] = new NetCon(&v(0.5), syn_projEE_ampa[1128], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1129: cell 14, seg 0 (0.5) [0.5 on Epop[14]] -> cell 9, seg 0 (0.5) [0.5 on Epop[9]], weight: 4.1363508E-4, delay 1.5
        h("Epop[9] syn_projEE_ampa[1129] = new ampa(0.5)")
        h("Epop[14] netConn_projEE_ampa[1129] = new NetCon(&v(0.5), syn_projEE_ampa[1129], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1130: cell 14, seg 0 (0.5) [0.5 on Epop[14]] -> cell 10, seg 0 (0.5) [0.5 on Epop[10]], weight: 4.1363508E-4, delay 1.5
        h("Epop[10] syn_projEE_ampa[1130] = new ampa(0.5)")
        h("Epop[14] netConn_projEE_ampa[1130] = new NetCon(&v(0.5), syn_projEE_ampa[1130], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1131: cell 14, seg 0 (0.5) [0.5 on Epop[14]] -> cell 11, seg 0 (0.5) [0.5 on Epop[11]], weight: 4.1363508E-4, delay 1.5
        h("Epop[11] syn_projEE_ampa[1131] = new ampa(0.5)")
        h("Epop[14] netConn_projEE_ampa[1131] = new NetCon(&v(0.5), syn_projEE_ampa[1131], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1132: cell 14, seg 0 (0.5) [0.5 on Epop[14]] -> cell 12, seg 0 (0.5) [0.5 on Epop[12]], weight: 4.1363508E-4, delay 1.5
        h("Epop[12] syn_projEE_ampa[1132] = new ampa(0.5)")
        h("Epop[14] netConn_projEE_ampa[1132] = new NetCon(&v(0.5), syn_projEE_ampa[1132], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1133: cell 14, seg 0 (0.5) [0.5 on Epop[14]] -> cell 13, seg 0 (0.5) [0.5 on Epop[13]], weight: 4.1363508E-4, delay 1.5
        h("Epop[13] syn_projEE_ampa[1133] = new ampa(0.5)")
        h("Epop[14] netConn_projEE_ampa[1133] = new NetCon(&v(0.5), syn_projEE_ampa[1133], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1134: cell 14, seg 0 (0.5) [0.5 on Epop[14]] -> cell 14, seg 0 (0.5) [0.5 on Epop[14]], weight: 4.1363508E-4, delay 1.5
        h("Epop[14] syn_projEE_ampa[1134] = new ampa(0.5)")
        h("Epop[14] netConn_projEE_ampa[1134] = new NetCon(&v(0.5), syn_projEE_ampa[1134], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1135: cell 14, seg 0 (0.5) [0.5 on Epop[14]] -> cell 15, seg 0 (0.5) [0.5 on Epop[15]], weight: 4.1363508E-4, delay 1.5
        h("Epop[15] syn_projEE_ampa[1135] = new ampa(0.5)")
        h("Epop[14] netConn_projEE_ampa[1135] = new NetCon(&v(0.5), syn_projEE_ampa[1135], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1136: cell 14, seg 0 (0.5) [0.5 on Epop[14]] -> cell 16, seg 0 (0.5) [0.5 on Epop[16]], weight: 4.1363508E-4, delay 1.5
        h("Epop[16] syn_projEE_ampa[1136] = new ampa(0.5)")
        h("Epop[14] netConn_projEE_ampa[1136] = new NetCon(&v(0.5), syn_projEE_ampa[1136], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1137: cell 14, seg 0 (0.5) [0.5 on Epop[14]] -> cell 17, seg 0 (0.5) [0.5 on Epop[17]], weight: 4.1363508E-4, delay 1.5
        h("Epop[17] syn_projEE_ampa[1137] = new ampa(0.5)")
        h("Epop[14] netConn_projEE_ampa[1137] = new NetCon(&v(0.5), syn_projEE_ampa[1137], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1138: cell 14, seg 0 (0.5) [0.5 on Epop[14]] -> cell 18, seg 0 (0.5) [0.5 on Epop[18]], weight: 4.1363508E-4, delay 1.5
        h("Epop[18] syn_projEE_ampa[1138] = new ampa(0.5)")
        h("Epop[14] netConn_projEE_ampa[1138] = new NetCon(&v(0.5), syn_projEE_ampa[1138], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1139: cell 14, seg 0 (0.5) [0.5 on Epop[14]] -> cell 19, seg 0 (0.5) [0.5 on Epop[19]], weight: 4.1363508E-4, delay 1.5
        h("Epop[19] syn_projEE_ampa[1139] = new ampa(0.5)")
        h("Epop[14] netConn_projEE_ampa[1139] = new NetCon(&v(0.5), syn_projEE_ampa[1139], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1140: cell 14, seg 0 (0.5) [0.5 on Epop[14]] -> cell 20, seg 0 (0.5) [0.5 on Epop[20]], weight: 4.1363508E-4, delay 1.5
        h("Epop[20] syn_projEE_ampa[1140] = new ampa(0.5)")
        h("Epop[14] netConn_projEE_ampa[1140] = new NetCon(&v(0.5), syn_projEE_ampa[1140], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1141: cell 14, seg 0 (0.5) [0.5 on Epop[14]] -> cell 21, seg 0 (0.5) [0.5 on Epop[21]], weight: 4.1363508E-4, delay 1.5
        h("Epop[21] syn_projEE_ampa[1141] = new ampa(0.5)")
        h("Epop[14] netConn_projEE_ampa[1141] = new NetCon(&v(0.5), syn_projEE_ampa[1141], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1142: cell 14, seg 0 (0.5) [0.5 on Epop[14]] -> cell 22, seg 0 (0.5) [0.5 on Epop[22]], weight: 4.1363508E-4, delay 1.5
        h("Epop[22] syn_projEE_ampa[1142] = new ampa(0.5)")
        h("Epop[14] netConn_projEE_ampa[1142] = new NetCon(&v(0.5), syn_projEE_ampa[1142], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1143: cell 14, seg 0 (0.5) [0.5 on Epop[14]] -> cell 23, seg 0 (0.5) [0.5 on Epop[23]], weight: 4.1363508E-4, delay 1.5
        h("Epop[23] syn_projEE_ampa[1143] = new ampa(0.5)")
        h("Epop[14] netConn_projEE_ampa[1143] = new NetCon(&v(0.5), syn_projEE_ampa[1143], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1144: cell 14, seg 0 (0.5) [0.5 on Epop[14]] -> cell 24, seg 0 (0.5) [0.5 on Epop[24]], weight: 4.1363508E-4, delay 1.5
        h("Epop[24] syn_projEE_ampa[1144] = new ampa(0.5)")
        h("Epop[14] netConn_projEE_ampa[1144] = new NetCon(&v(0.5), syn_projEE_ampa[1144], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1145: cell 14, seg 0 (0.5) [0.5 on Epop[14]] -> cell 25, seg 0 (0.5) [0.5 on Epop[25]], weight: 4.1363508E-4, delay 1.5
        h("Epop[25] syn_projEE_ampa[1145] = new ampa(0.5)")
        h("Epop[14] netConn_projEE_ampa[1145] = new NetCon(&v(0.5), syn_projEE_ampa[1145], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1146: cell 14, seg 0 (0.5) [0.5 on Epop[14]] -> cell 26, seg 0 (0.5) [0.5 on Epop[26]], weight: 4.1363508E-4, delay 1.5
        h("Epop[26] syn_projEE_ampa[1146] = new ampa(0.5)")
        h("Epop[14] netConn_projEE_ampa[1146] = new NetCon(&v(0.5), syn_projEE_ampa[1146], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1147: cell 14, seg 0 (0.5) [0.5 on Epop[14]] -> cell 27, seg 0 (0.5) [0.5 on Epop[27]], weight: 4.1363508E-4, delay 1.5
        h("Epop[27] syn_projEE_ampa[1147] = new ampa(0.5)")
        h("Epop[14] netConn_projEE_ampa[1147] = new NetCon(&v(0.5), syn_projEE_ampa[1147], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1148: cell 14, seg 0 (0.5) [0.5 on Epop[14]] -> cell 28, seg 0 (0.5) [0.5 on Epop[28]], weight: 4.1363508E-4, delay 1.5
        h("Epop[28] syn_projEE_ampa[1148] = new ampa(0.5)")
        h("Epop[14] netConn_projEE_ampa[1148] = new NetCon(&v(0.5), syn_projEE_ampa[1148], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1149: cell 14, seg 0 (0.5) [0.5 on Epop[14]] -> cell 29, seg 0 (0.5) [0.5 on Epop[29]], weight: 4.1363508E-4, delay 1.5
        h("Epop[29] syn_projEE_ampa[1149] = new ampa(0.5)")
        h("Epop[14] netConn_projEE_ampa[1149] = new NetCon(&v(0.5), syn_projEE_ampa[1149], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1150: cell 14, seg 0 (0.5) [0.5 on Epop[14]] -> cell 30, seg 0 (0.5) [0.5 on Epop[30]], weight: 4.1363508E-4, delay 1.5
        h("Epop[30] syn_projEE_ampa[1150] = new ampa(0.5)")
        h("Epop[14] netConn_projEE_ampa[1150] = new NetCon(&v(0.5), syn_projEE_ampa[1150], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1151: cell 14, seg 0 (0.5) [0.5 on Epop[14]] -> cell 31, seg 0 (0.5) [0.5 on Epop[31]], weight: 4.1363508E-4, delay 1.5
        h("Epop[31] syn_projEE_ampa[1151] = new ampa(0.5)")
        h("Epop[14] netConn_projEE_ampa[1151] = new NetCon(&v(0.5), syn_projEE_ampa[1151], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1152: cell 14, seg 0 (0.5) [0.5 on Epop[14]] -> cell 32, seg 0 (0.5) [0.5 on Epop[32]], weight: 4.1363508E-4, delay 1.5
        h("Epop[32] syn_projEE_ampa[1152] = new ampa(0.5)")
        h("Epop[14] netConn_projEE_ampa[1152] = new NetCon(&v(0.5), syn_projEE_ampa[1152], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1153: cell 14, seg 0 (0.5) [0.5 on Epop[14]] -> cell 33, seg 0 (0.5) [0.5 on Epop[33]], weight: 4.1363508E-4, delay 1.5
        h("Epop[33] syn_projEE_ampa[1153] = new ampa(0.5)")
        h("Epop[14] netConn_projEE_ampa[1153] = new NetCon(&v(0.5), syn_projEE_ampa[1153], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1154: cell 14, seg 0 (0.5) [0.5 on Epop[14]] -> cell 34, seg 0 (0.5) [0.5 on Epop[34]], weight: 4.1363508E-4, delay 1.5
        h("Epop[34] syn_projEE_ampa[1154] = new ampa(0.5)")
        h("Epop[14] netConn_projEE_ampa[1154] = new NetCon(&v(0.5), syn_projEE_ampa[1154], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1155: cell 14, seg 0 (0.5) [0.5 on Epop[14]] -> cell 35, seg 0 (0.5) [0.5 on Epop[35]], weight: 4.1363508E-4, delay 1.5
        h("Epop[35] syn_projEE_ampa[1155] = new ampa(0.5)")
        h("Epop[14] netConn_projEE_ampa[1155] = new NetCon(&v(0.5), syn_projEE_ampa[1155], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1156: cell 14, seg 0 (0.5) [0.5 on Epop[14]] -> cell 36, seg 0 (0.5) [0.5 on Epop[36]], weight: 4.1363508E-4, delay 1.5
        h("Epop[36] syn_projEE_ampa[1156] = new ampa(0.5)")
        h("Epop[14] netConn_projEE_ampa[1156] = new NetCon(&v(0.5), syn_projEE_ampa[1156], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1157: cell 14, seg 0 (0.5) [0.5 on Epop[14]] -> cell 37, seg 0 (0.5) [0.5 on Epop[37]], weight: 4.1363508E-4, delay 1.5
        h("Epop[37] syn_projEE_ampa[1157] = new ampa(0.5)")
        h("Epop[14] netConn_projEE_ampa[1157] = new NetCon(&v(0.5), syn_projEE_ampa[1157], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1158: cell 14, seg 0 (0.5) [0.5 on Epop[14]] -> cell 38, seg 0 (0.5) [0.5 on Epop[38]], weight: 4.1363508E-4, delay 1.5
        h("Epop[38] syn_projEE_ampa[1158] = new ampa(0.5)")
        h("Epop[14] netConn_projEE_ampa[1158] = new NetCon(&v(0.5), syn_projEE_ampa[1158], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1159: cell 14, seg 0 (0.5) [0.5 on Epop[14]] -> cell 39, seg 0 (0.5) [0.5 on Epop[39]], weight: 4.1363508E-4, delay 1.5
        h("Epop[39] syn_projEE_ampa[1159] = new ampa(0.5)")
        h("Epop[14] netConn_projEE_ampa[1159] = new NetCon(&v(0.5), syn_projEE_ampa[1159], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1160: cell 14, seg 0 (0.5) [0.5 on Epop[14]] -> cell 40, seg 0 (0.5) [0.5 on Epop[40]], weight: 4.1363508E-4, delay 1.5
        h("Epop[40] syn_projEE_ampa[1160] = new ampa(0.5)")
        h("Epop[14] netConn_projEE_ampa[1160] = new NetCon(&v(0.5), syn_projEE_ampa[1160], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1161: cell 14, seg 0 (0.5) [0.5 on Epop[14]] -> cell 41, seg 0 (0.5) [0.5 on Epop[41]], weight: 4.1363508E-4, delay 1.5
        h("Epop[41] syn_projEE_ampa[1161] = new ampa(0.5)")
        h("Epop[14] netConn_projEE_ampa[1161] = new NetCon(&v(0.5), syn_projEE_ampa[1161], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1162: cell 14, seg 0 (0.5) [0.5 on Epop[14]] -> cell 42, seg 0 (0.5) [0.5 on Epop[42]], weight: 4.1363508E-4, delay 1.5
        h("Epop[42] syn_projEE_ampa[1162] = new ampa(0.5)")
        h("Epop[14] netConn_projEE_ampa[1162] = new NetCon(&v(0.5), syn_projEE_ampa[1162], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1163: cell 14, seg 0 (0.5) [0.5 on Epop[14]] -> cell 43, seg 0 (0.5) [0.5 on Epop[43]], weight: 4.1363508E-4, delay 1.5
        h("Epop[43] syn_projEE_ampa[1163] = new ampa(0.5)")
        h("Epop[14] netConn_projEE_ampa[1163] = new NetCon(&v(0.5), syn_projEE_ampa[1163], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1164: cell 14, seg 0 (0.5) [0.5 on Epop[14]] -> cell 44, seg 0 (0.5) [0.5 on Epop[44]], weight: 4.1363508E-4, delay 1.5
        h("Epop[44] syn_projEE_ampa[1164] = new ampa(0.5)")
        h("Epop[14] netConn_projEE_ampa[1164] = new NetCon(&v(0.5), syn_projEE_ampa[1164], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1165: cell 14, seg 0 (0.5) [0.5 on Epop[14]] -> cell 45, seg 0 (0.5) [0.5 on Epop[45]], weight: 4.1363508E-4, delay 1.5
        h("Epop[45] syn_projEE_ampa[1165] = new ampa(0.5)")
        h("Epop[14] netConn_projEE_ampa[1165] = new NetCon(&v(0.5), syn_projEE_ampa[1165], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1166: cell 14, seg 0 (0.5) [0.5 on Epop[14]] -> cell 46, seg 0 (0.5) [0.5 on Epop[46]], weight: 4.1363508E-4, delay 1.5
        h("Epop[46] syn_projEE_ampa[1166] = new ampa(0.5)")
        h("Epop[14] netConn_projEE_ampa[1166] = new NetCon(&v(0.5), syn_projEE_ampa[1166], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1167: cell 14, seg 0 (0.5) [0.5 on Epop[14]] -> cell 47, seg 0 (0.5) [0.5 on Epop[47]], weight: 4.1363508E-4, delay 1.5
        h("Epop[47] syn_projEE_ampa[1167] = new ampa(0.5)")
        h("Epop[14] netConn_projEE_ampa[1167] = new NetCon(&v(0.5), syn_projEE_ampa[1167], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1168: cell 14, seg 0 (0.5) [0.5 on Epop[14]] -> cell 48, seg 0 (0.5) [0.5 on Epop[48]], weight: 4.1363508E-4, delay 1.5
        h("Epop[48] syn_projEE_ampa[1168] = new ampa(0.5)")
        h("Epop[14] netConn_projEE_ampa[1168] = new NetCon(&v(0.5), syn_projEE_ampa[1168], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1169: cell 14, seg 0 (0.5) [0.5 on Epop[14]] -> cell 49, seg 0 (0.5) [0.5 on Epop[49]], weight: 4.1363508E-4, delay 1.5
        h("Epop[49] syn_projEE_ampa[1169] = new ampa(0.5)")
        h("Epop[14] netConn_projEE_ampa[1169] = new NetCon(&v(0.5), syn_projEE_ampa[1169], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1170: cell 14, seg 0 (0.5) [0.5 on Epop[14]] -> cell 50, seg 0 (0.5) [0.5 on Epop[50]], weight: 4.1363508E-4, delay 1.5
        h("Epop[50] syn_projEE_ampa[1170] = new ampa(0.5)")
        h("Epop[14] netConn_projEE_ampa[1170] = new NetCon(&v(0.5), syn_projEE_ampa[1170], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1171: cell 14, seg 0 (0.5) [0.5 on Epop[14]] -> cell 51, seg 0 (0.5) [0.5 on Epop[51]], weight: 4.1363508E-4, delay 1.5
        h("Epop[51] syn_projEE_ampa[1171] = new ampa(0.5)")
        h("Epop[14] netConn_projEE_ampa[1171] = new NetCon(&v(0.5), syn_projEE_ampa[1171], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1172: cell 14, seg 0 (0.5) [0.5 on Epop[14]] -> cell 52, seg 0 (0.5) [0.5 on Epop[52]], weight: 4.1363508E-4, delay 1.5
        h("Epop[52] syn_projEE_ampa[1172] = new ampa(0.5)")
        h("Epop[14] netConn_projEE_ampa[1172] = new NetCon(&v(0.5), syn_projEE_ampa[1172], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1173: cell 14, seg 0 (0.5) [0.5 on Epop[14]] -> cell 53, seg 0 (0.5) [0.5 on Epop[53]], weight: 4.1363508E-4, delay 1.5
        h("Epop[53] syn_projEE_ampa[1173] = new ampa(0.5)")
        h("Epop[14] netConn_projEE_ampa[1173] = new NetCon(&v(0.5), syn_projEE_ampa[1173], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1174: cell 14, seg 0 (0.5) [0.5 on Epop[14]] -> cell 54, seg 0 (0.5) [0.5 on Epop[54]], weight: 4.1363508E-4, delay 1.5
        h("Epop[54] syn_projEE_ampa[1174] = new ampa(0.5)")
        h("Epop[14] netConn_projEE_ampa[1174] = new NetCon(&v(0.5), syn_projEE_ampa[1174], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1175: cell 14, seg 0 (0.5) [0.5 on Epop[14]] -> cell 55, seg 0 (0.5) [0.5 on Epop[55]], weight: 4.1363508E-4, delay 1.5
        h("Epop[55] syn_projEE_ampa[1175] = new ampa(0.5)")
        h("Epop[14] netConn_projEE_ampa[1175] = new NetCon(&v(0.5), syn_projEE_ampa[1175], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1176: cell 14, seg 0 (0.5) [0.5 on Epop[14]] -> cell 56, seg 0 (0.5) [0.5 on Epop[56]], weight: 4.1363508E-4, delay 1.5
        h("Epop[56] syn_projEE_ampa[1176] = new ampa(0.5)")
        h("Epop[14] netConn_projEE_ampa[1176] = new NetCon(&v(0.5), syn_projEE_ampa[1176], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1177: cell 14, seg 0 (0.5) [0.5 on Epop[14]] -> cell 57, seg 0 (0.5) [0.5 on Epop[57]], weight: 4.1363508E-4, delay 1.5
        h("Epop[57] syn_projEE_ampa[1177] = new ampa(0.5)")
        h("Epop[14] netConn_projEE_ampa[1177] = new NetCon(&v(0.5), syn_projEE_ampa[1177], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1178: cell 14, seg 0 (0.5) [0.5 on Epop[14]] -> cell 58, seg 0 (0.5) [0.5 on Epop[58]], weight: 4.1363508E-4, delay 1.5
        h("Epop[58] syn_projEE_ampa[1178] = new ampa(0.5)")
        h("Epop[14] netConn_projEE_ampa[1178] = new NetCon(&v(0.5), syn_projEE_ampa[1178], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1179: cell 14, seg 0 (0.5) [0.5 on Epop[14]] -> cell 59, seg 0 (0.5) [0.5 on Epop[59]], weight: 4.1363508E-4, delay 1.5
        h("Epop[59] syn_projEE_ampa[1179] = new ampa(0.5)")
        h("Epop[14] netConn_projEE_ampa[1179] = new NetCon(&v(0.5), syn_projEE_ampa[1179], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1180: cell 14, seg 0 (0.5) [0.5 on Epop[14]] -> cell 60, seg 0 (0.5) [0.5 on Epop[60]], weight: 4.1363508E-4, delay 1.5
        h("Epop[60] syn_projEE_ampa[1180] = new ampa(0.5)")
        h("Epop[14] netConn_projEE_ampa[1180] = new NetCon(&v(0.5), syn_projEE_ampa[1180], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1181: cell 14, seg 0 (0.5) [0.5 on Epop[14]] -> cell 61, seg 0 (0.5) [0.5 on Epop[61]], weight: 4.1363508E-4, delay 1.5
        h("Epop[61] syn_projEE_ampa[1181] = new ampa(0.5)")
        h("Epop[14] netConn_projEE_ampa[1181] = new NetCon(&v(0.5), syn_projEE_ampa[1181], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1182: cell 14, seg 0 (0.5) [0.5 on Epop[14]] -> cell 62, seg 0 (0.5) [0.5 on Epop[62]], weight: 4.1363508E-4, delay 1.5
        h("Epop[62] syn_projEE_ampa[1182] = new ampa(0.5)")
        h("Epop[14] netConn_projEE_ampa[1182] = new NetCon(&v(0.5), syn_projEE_ampa[1182], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1183: cell 14, seg 0 (0.5) [0.5 on Epop[14]] -> cell 63, seg 0 (0.5) [0.5 on Epop[63]], weight: 4.1363508E-4, delay 1.5
        h("Epop[63] syn_projEE_ampa[1183] = new ampa(0.5)")
        h("Epop[14] netConn_projEE_ampa[1183] = new NetCon(&v(0.5), syn_projEE_ampa[1183], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1184: cell 14, seg 0 (0.5) [0.5 on Epop[14]] -> cell 64, seg 0 (0.5) [0.5 on Epop[64]], weight: 4.1363508E-4, delay 1.5
        h("Epop[64] syn_projEE_ampa[1184] = new ampa(0.5)")
        h("Epop[14] netConn_projEE_ampa[1184] = new NetCon(&v(0.5), syn_projEE_ampa[1184], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1185: cell 14, seg 0 (0.5) [0.5 on Epop[14]] -> cell 65, seg 0 (0.5) [0.5 on Epop[65]], weight: 4.1363508E-4, delay 1.5
        h("Epop[65] syn_projEE_ampa[1185] = new ampa(0.5)")
        h("Epop[14] netConn_projEE_ampa[1185] = new NetCon(&v(0.5), syn_projEE_ampa[1185], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1186: cell 14, seg 0 (0.5) [0.5 on Epop[14]] -> cell 66, seg 0 (0.5) [0.5 on Epop[66]], weight: 4.1363508E-4, delay 1.5
        h("Epop[66] syn_projEE_ampa[1186] = new ampa(0.5)")
        h("Epop[14] netConn_projEE_ampa[1186] = new NetCon(&v(0.5), syn_projEE_ampa[1186], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1187: cell 14, seg 0 (0.5) [0.5 on Epop[14]] -> cell 67, seg 0 (0.5) [0.5 on Epop[67]], weight: 4.1363508E-4, delay 1.5
        h("Epop[67] syn_projEE_ampa[1187] = new ampa(0.5)")
        h("Epop[14] netConn_projEE_ampa[1187] = new NetCon(&v(0.5), syn_projEE_ampa[1187], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1188: cell 14, seg 0 (0.5) [0.5 on Epop[14]] -> cell 68, seg 0 (0.5) [0.5 on Epop[68]], weight: 4.1363508E-4, delay 1.5
        h("Epop[68] syn_projEE_ampa[1188] = new ampa(0.5)")
        h("Epop[14] netConn_projEE_ampa[1188] = new NetCon(&v(0.5), syn_projEE_ampa[1188], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1189: cell 14, seg 0 (0.5) [0.5 on Epop[14]] -> cell 69, seg 0 (0.5) [0.5 on Epop[69]], weight: 4.1363508E-4, delay 1.5
        h("Epop[69] syn_projEE_ampa[1189] = new ampa(0.5)")
        h("Epop[14] netConn_projEE_ampa[1189] = new NetCon(&v(0.5), syn_projEE_ampa[1189], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1190: cell 14, seg 0 (0.5) [0.5 on Epop[14]] -> cell 70, seg 0 (0.5) [0.5 on Epop[70]], weight: 4.1363508E-4, delay 1.5
        h("Epop[70] syn_projEE_ampa[1190] = new ampa(0.5)")
        h("Epop[14] netConn_projEE_ampa[1190] = new NetCon(&v(0.5), syn_projEE_ampa[1190], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1191: cell 14, seg 0 (0.5) [0.5 on Epop[14]] -> cell 71, seg 0 (0.5) [0.5 on Epop[71]], weight: 4.1363508E-4, delay 1.5
        h("Epop[71] syn_projEE_ampa[1191] = new ampa(0.5)")
        h("Epop[14] netConn_projEE_ampa[1191] = new NetCon(&v(0.5), syn_projEE_ampa[1191], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1192: cell 14, seg 0 (0.5) [0.5 on Epop[14]] -> cell 72, seg 0 (0.5) [0.5 on Epop[72]], weight: 4.1363508E-4, delay 1.5
        h("Epop[72] syn_projEE_ampa[1192] = new ampa(0.5)")
        h("Epop[14] netConn_projEE_ampa[1192] = new NetCon(&v(0.5), syn_projEE_ampa[1192], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1193: cell 14, seg 0 (0.5) [0.5 on Epop[14]] -> cell 73, seg 0 (0.5) [0.5 on Epop[73]], weight: 4.1363508E-4, delay 1.5
        h("Epop[73] syn_projEE_ampa[1193] = new ampa(0.5)")
        h("Epop[14] netConn_projEE_ampa[1193] = new NetCon(&v(0.5), syn_projEE_ampa[1193], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1194: cell 14, seg 0 (0.5) [0.5 on Epop[14]] -> cell 74, seg 0 (0.5) [0.5 on Epop[74]], weight: 4.1363508E-4, delay 1.5
        h("Epop[74] syn_projEE_ampa[1194] = new ampa(0.5)")
        h("Epop[14] netConn_projEE_ampa[1194] = new NetCon(&v(0.5), syn_projEE_ampa[1194], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1195: cell 14, seg 0 (0.5) [0.5 on Epop[14]] -> cell 75, seg 0 (0.5) [0.5 on Epop[75]], weight: 4.1363508E-4, delay 1.5
        h("Epop[75] syn_projEE_ampa[1195] = new ampa(0.5)")
        h("Epop[14] netConn_projEE_ampa[1195] = new NetCon(&v(0.5), syn_projEE_ampa[1195], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1196: cell 14, seg 0 (0.5) [0.5 on Epop[14]] -> cell 76, seg 0 (0.5) [0.5 on Epop[76]], weight: 4.1363508E-4, delay 1.5
        h("Epop[76] syn_projEE_ampa[1196] = new ampa(0.5)")
        h("Epop[14] netConn_projEE_ampa[1196] = new NetCon(&v(0.5), syn_projEE_ampa[1196], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1197: cell 14, seg 0 (0.5) [0.5 on Epop[14]] -> cell 77, seg 0 (0.5) [0.5 on Epop[77]], weight: 4.1363508E-4, delay 1.5
        h("Epop[77] syn_projEE_ampa[1197] = new ampa(0.5)")
        h("Epop[14] netConn_projEE_ampa[1197] = new NetCon(&v(0.5), syn_projEE_ampa[1197], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1198: cell 14, seg 0 (0.5) [0.5 on Epop[14]] -> cell 78, seg 0 (0.5) [0.5 on Epop[78]], weight: 4.1363508E-4, delay 1.5
        h("Epop[78] syn_projEE_ampa[1198] = new ampa(0.5)")
        h("Epop[14] netConn_projEE_ampa[1198] = new NetCon(&v(0.5), syn_projEE_ampa[1198], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1199: cell 14, seg 0 (0.5) [0.5 on Epop[14]] -> cell 79, seg 0 (0.5) [0.5 on Epop[79]], weight: 4.1363508E-4, delay 1.5
        h("Epop[79] syn_projEE_ampa[1199] = new ampa(0.5)")
        h("Epop[14] netConn_projEE_ampa[1199] = new NetCon(&v(0.5), syn_projEE_ampa[1199], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1200: cell 15, seg 0 (0.5) [0.5 on Epop[15]] -> cell 0, seg 0 (0.5) [0.5 on Epop[0]], weight: 4.1363508E-4, delay 1.5
        h("Epop[0] syn_projEE_ampa[1200] = new ampa(0.5)")
        h("Epop[15] netConn_projEE_ampa[1200] = new NetCon(&v(0.5), syn_projEE_ampa[1200], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1201: cell 15, seg 0 (0.5) [0.5 on Epop[15]] -> cell 1, seg 0 (0.5) [0.5 on Epop[1]], weight: 4.1363508E-4, delay 1.5
        h("Epop[1] syn_projEE_ampa[1201] = new ampa(0.5)")
        h("Epop[15] netConn_projEE_ampa[1201] = new NetCon(&v(0.5), syn_projEE_ampa[1201], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1202: cell 15, seg 0 (0.5) [0.5 on Epop[15]] -> cell 2, seg 0 (0.5) [0.5 on Epop[2]], weight: 4.1363508E-4, delay 1.5
        h("Epop[2] syn_projEE_ampa[1202] = new ampa(0.5)")
        h("Epop[15] netConn_projEE_ampa[1202] = new NetCon(&v(0.5), syn_projEE_ampa[1202], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1203: cell 15, seg 0 (0.5) [0.5 on Epop[15]] -> cell 3, seg 0 (0.5) [0.5 on Epop[3]], weight: 4.1363508E-4, delay 1.5
        h("Epop[3] syn_projEE_ampa[1203] = new ampa(0.5)")
        h("Epop[15] netConn_projEE_ampa[1203] = new NetCon(&v(0.5), syn_projEE_ampa[1203], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1204: cell 15, seg 0 (0.5) [0.5 on Epop[15]] -> cell 4, seg 0 (0.5) [0.5 on Epop[4]], weight: 4.1363508E-4, delay 1.5
        h("Epop[4] syn_projEE_ampa[1204] = new ampa(0.5)")
        h("Epop[15] netConn_projEE_ampa[1204] = new NetCon(&v(0.5), syn_projEE_ampa[1204], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1205: cell 15, seg 0 (0.5) [0.5 on Epop[15]] -> cell 5, seg 0 (0.5) [0.5 on Epop[5]], weight: 4.1363508E-4, delay 1.5
        h("Epop[5] syn_projEE_ampa[1205] = new ampa(0.5)")
        h("Epop[15] netConn_projEE_ampa[1205] = new NetCon(&v(0.5), syn_projEE_ampa[1205], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1206: cell 15, seg 0 (0.5) [0.5 on Epop[15]] -> cell 6, seg 0 (0.5) [0.5 on Epop[6]], weight: 4.1363508E-4, delay 1.5
        h("Epop[6] syn_projEE_ampa[1206] = new ampa(0.5)")
        h("Epop[15] netConn_projEE_ampa[1206] = new NetCon(&v(0.5), syn_projEE_ampa[1206], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1207: cell 15, seg 0 (0.5) [0.5 on Epop[15]] -> cell 7, seg 0 (0.5) [0.5 on Epop[7]], weight: 4.1363508E-4, delay 1.5
        h("Epop[7] syn_projEE_ampa[1207] = new ampa(0.5)")
        h("Epop[15] netConn_projEE_ampa[1207] = new NetCon(&v(0.5), syn_projEE_ampa[1207], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1208: cell 15, seg 0 (0.5) [0.5 on Epop[15]] -> cell 8, seg 0 (0.5) [0.5 on Epop[8]], weight: 4.1363508E-4, delay 1.5
        h("Epop[8] syn_projEE_ampa[1208] = new ampa(0.5)")
        h("Epop[15] netConn_projEE_ampa[1208] = new NetCon(&v(0.5), syn_projEE_ampa[1208], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1209: cell 15, seg 0 (0.5) [0.5 on Epop[15]] -> cell 9, seg 0 (0.5) [0.5 on Epop[9]], weight: 4.1363508E-4, delay 1.5
        h("Epop[9] syn_projEE_ampa[1209] = new ampa(0.5)")
        h("Epop[15] netConn_projEE_ampa[1209] = new NetCon(&v(0.5), syn_projEE_ampa[1209], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1210: cell 15, seg 0 (0.5) [0.5 on Epop[15]] -> cell 10, seg 0 (0.5) [0.5 on Epop[10]], weight: 4.1363508E-4, delay 1.5
        h("Epop[10] syn_projEE_ampa[1210] = new ampa(0.5)")
        h("Epop[15] netConn_projEE_ampa[1210] = new NetCon(&v(0.5), syn_projEE_ampa[1210], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1211: cell 15, seg 0 (0.5) [0.5 on Epop[15]] -> cell 11, seg 0 (0.5) [0.5 on Epop[11]], weight: 4.1363508E-4, delay 1.5
        h("Epop[11] syn_projEE_ampa[1211] = new ampa(0.5)")
        h("Epop[15] netConn_projEE_ampa[1211] = new NetCon(&v(0.5), syn_projEE_ampa[1211], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1212: cell 15, seg 0 (0.5) [0.5 on Epop[15]] -> cell 12, seg 0 (0.5) [0.5 on Epop[12]], weight: 4.1363508E-4, delay 1.5
        h("Epop[12] syn_projEE_ampa[1212] = new ampa(0.5)")
        h("Epop[15] netConn_projEE_ampa[1212] = new NetCon(&v(0.5), syn_projEE_ampa[1212], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1213: cell 15, seg 0 (0.5) [0.5 on Epop[15]] -> cell 13, seg 0 (0.5) [0.5 on Epop[13]], weight: 4.1363508E-4, delay 1.5
        h("Epop[13] syn_projEE_ampa[1213] = new ampa(0.5)")
        h("Epop[15] netConn_projEE_ampa[1213] = new NetCon(&v(0.5), syn_projEE_ampa[1213], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1214: cell 15, seg 0 (0.5) [0.5 on Epop[15]] -> cell 14, seg 0 (0.5) [0.5 on Epop[14]], weight: 4.1363508E-4, delay 1.5
        h("Epop[14] syn_projEE_ampa[1214] = new ampa(0.5)")
        h("Epop[15] netConn_projEE_ampa[1214] = new NetCon(&v(0.5), syn_projEE_ampa[1214], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1215: cell 15, seg 0 (0.5) [0.5 on Epop[15]] -> cell 15, seg 0 (0.5) [0.5 on Epop[15]], weight: 4.1363508E-4, delay 1.5
        h("Epop[15] syn_projEE_ampa[1215] = new ampa(0.5)")
        h("Epop[15] netConn_projEE_ampa[1215] = new NetCon(&v(0.5), syn_projEE_ampa[1215], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1216: cell 15, seg 0 (0.5) [0.5 on Epop[15]] -> cell 16, seg 0 (0.5) [0.5 on Epop[16]], weight: 4.1363508E-4, delay 1.5
        h("Epop[16] syn_projEE_ampa[1216] = new ampa(0.5)")
        h("Epop[15] netConn_projEE_ampa[1216] = new NetCon(&v(0.5), syn_projEE_ampa[1216], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1217: cell 15, seg 0 (0.5) [0.5 on Epop[15]] -> cell 17, seg 0 (0.5) [0.5 on Epop[17]], weight: 4.1363508E-4, delay 1.5
        h("Epop[17] syn_projEE_ampa[1217] = new ampa(0.5)")
        h("Epop[15] netConn_projEE_ampa[1217] = new NetCon(&v(0.5), syn_projEE_ampa[1217], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1218: cell 15, seg 0 (0.5) [0.5 on Epop[15]] -> cell 18, seg 0 (0.5) [0.5 on Epop[18]], weight: 4.1363508E-4, delay 1.5
        h("Epop[18] syn_projEE_ampa[1218] = new ampa(0.5)")
        h("Epop[15] netConn_projEE_ampa[1218] = new NetCon(&v(0.5), syn_projEE_ampa[1218], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1219: cell 15, seg 0 (0.5) [0.5 on Epop[15]] -> cell 19, seg 0 (0.5) [0.5 on Epop[19]], weight: 4.1363508E-4, delay 1.5
        h("Epop[19] syn_projEE_ampa[1219] = new ampa(0.5)")
        h("Epop[15] netConn_projEE_ampa[1219] = new NetCon(&v(0.5), syn_projEE_ampa[1219], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1220: cell 15, seg 0 (0.5) [0.5 on Epop[15]] -> cell 20, seg 0 (0.5) [0.5 on Epop[20]], weight: 4.1363508E-4, delay 1.5
        h("Epop[20] syn_projEE_ampa[1220] = new ampa(0.5)")
        h("Epop[15] netConn_projEE_ampa[1220] = new NetCon(&v(0.5), syn_projEE_ampa[1220], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1221: cell 15, seg 0 (0.5) [0.5 on Epop[15]] -> cell 21, seg 0 (0.5) [0.5 on Epop[21]], weight: 4.1363508E-4, delay 1.5
        h("Epop[21] syn_projEE_ampa[1221] = new ampa(0.5)")
        h("Epop[15] netConn_projEE_ampa[1221] = new NetCon(&v(0.5), syn_projEE_ampa[1221], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1222: cell 15, seg 0 (0.5) [0.5 on Epop[15]] -> cell 22, seg 0 (0.5) [0.5 on Epop[22]], weight: 4.1363508E-4, delay 1.5
        h("Epop[22] syn_projEE_ampa[1222] = new ampa(0.5)")
        h("Epop[15] netConn_projEE_ampa[1222] = new NetCon(&v(0.5), syn_projEE_ampa[1222], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1223: cell 15, seg 0 (0.5) [0.5 on Epop[15]] -> cell 23, seg 0 (0.5) [0.5 on Epop[23]], weight: 4.1363508E-4, delay 1.5
        h("Epop[23] syn_projEE_ampa[1223] = new ampa(0.5)")
        h("Epop[15] netConn_projEE_ampa[1223] = new NetCon(&v(0.5), syn_projEE_ampa[1223], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1224: cell 15, seg 0 (0.5) [0.5 on Epop[15]] -> cell 24, seg 0 (0.5) [0.5 on Epop[24]], weight: 4.1363508E-4, delay 1.5
        h("Epop[24] syn_projEE_ampa[1224] = new ampa(0.5)")
        h("Epop[15] netConn_projEE_ampa[1224] = new NetCon(&v(0.5), syn_projEE_ampa[1224], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1225: cell 15, seg 0 (0.5) [0.5 on Epop[15]] -> cell 25, seg 0 (0.5) [0.5 on Epop[25]], weight: 4.1363508E-4, delay 1.5
        h("Epop[25] syn_projEE_ampa[1225] = new ampa(0.5)")
        h("Epop[15] netConn_projEE_ampa[1225] = new NetCon(&v(0.5), syn_projEE_ampa[1225], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1226: cell 15, seg 0 (0.5) [0.5 on Epop[15]] -> cell 26, seg 0 (0.5) [0.5 on Epop[26]], weight: 4.1363508E-4, delay 1.5
        h("Epop[26] syn_projEE_ampa[1226] = new ampa(0.5)")
        h("Epop[15] netConn_projEE_ampa[1226] = new NetCon(&v(0.5), syn_projEE_ampa[1226], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1227: cell 15, seg 0 (0.5) [0.5 on Epop[15]] -> cell 27, seg 0 (0.5) [0.5 on Epop[27]], weight: 4.1363508E-4, delay 1.5
        h("Epop[27] syn_projEE_ampa[1227] = new ampa(0.5)")
        h("Epop[15] netConn_projEE_ampa[1227] = new NetCon(&v(0.5), syn_projEE_ampa[1227], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1228: cell 15, seg 0 (0.5) [0.5 on Epop[15]] -> cell 28, seg 0 (0.5) [0.5 on Epop[28]], weight: 4.1363508E-4, delay 1.5
        h("Epop[28] syn_projEE_ampa[1228] = new ampa(0.5)")
        h("Epop[15] netConn_projEE_ampa[1228] = new NetCon(&v(0.5), syn_projEE_ampa[1228], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1229: cell 15, seg 0 (0.5) [0.5 on Epop[15]] -> cell 29, seg 0 (0.5) [0.5 on Epop[29]], weight: 4.1363508E-4, delay 1.5
        h("Epop[29] syn_projEE_ampa[1229] = new ampa(0.5)")
        h("Epop[15] netConn_projEE_ampa[1229] = new NetCon(&v(0.5), syn_projEE_ampa[1229], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1230: cell 15, seg 0 (0.5) [0.5 on Epop[15]] -> cell 30, seg 0 (0.5) [0.5 on Epop[30]], weight: 4.1363508E-4, delay 1.5
        h("Epop[30] syn_projEE_ampa[1230] = new ampa(0.5)")
        h("Epop[15] netConn_projEE_ampa[1230] = new NetCon(&v(0.5), syn_projEE_ampa[1230], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1231: cell 15, seg 0 (0.5) [0.5 on Epop[15]] -> cell 31, seg 0 (0.5) [0.5 on Epop[31]], weight: 4.1363508E-4, delay 1.5
        h("Epop[31] syn_projEE_ampa[1231] = new ampa(0.5)")
        h("Epop[15] netConn_projEE_ampa[1231] = new NetCon(&v(0.5), syn_projEE_ampa[1231], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1232: cell 15, seg 0 (0.5) [0.5 on Epop[15]] -> cell 32, seg 0 (0.5) [0.5 on Epop[32]], weight: 4.1363508E-4, delay 1.5
        h("Epop[32] syn_projEE_ampa[1232] = new ampa(0.5)")
        h("Epop[15] netConn_projEE_ampa[1232] = new NetCon(&v(0.5), syn_projEE_ampa[1232], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1233: cell 15, seg 0 (0.5) [0.5 on Epop[15]] -> cell 33, seg 0 (0.5) [0.5 on Epop[33]], weight: 4.1363508E-4, delay 1.5
        h("Epop[33] syn_projEE_ampa[1233] = new ampa(0.5)")
        h("Epop[15] netConn_projEE_ampa[1233] = new NetCon(&v(0.5), syn_projEE_ampa[1233], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1234: cell 15, seg 0 (0.5) [0.5 on Epop[15]] -> cell 34, seg 0 (0.5) [0.5 on Epop[34]], weight: 4.1363508E-4, delay 1.5
        h("Epop[34] syn_projEE_ampa[1234] = new ampa(0.5)")
        h("Epop[15] netConn_projEE_ampa[1234] = new NetCon(&v(0.5), syn_projEE_ampa[1234], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1235: cell 15, seg 0 (0.5) [0.5 on Epop[15]] -> cell 35, seg 0 (0.5) [0.5 on Epop[35]], weight: 4.1363508E-4, delay 1.5
        h("Epop[35] syn_projEE_ampa[1235] = new ampa(0.5)")
        h("Epop[15] netConn_projEE_ampa[1235] = new NetCon(&v(0.5), syn_projEE_ampa[1235], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1236: cell 15, seg 0 (0.5) [0.5 on Epop[15]] -> cell 36, seg 0 (0.5) [0.5 on Epop[36]], weight: 4.1363508E-4, delay 1.5
        h("Epop[36] syn_projEE_ampa[1236] = new ampa(0.5)")
        h("Epop[15] netConn_projEE_ampa[1236] = new NetCon(&v(0.5), syn_projEE_ampa[1236], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1237: cell 15, seg 0 (0.5) [0.5 on Epop[15]] -> cell 37, seg 0 (0.5) [0.5 on Epop[37]], weight: 4.1363508E-4, delay 1.5
        h("Epop[37] syn_projEE_ampa[1237] = new ampa(0.5)")
        h("Epop[15] netConn_projEE_ampa[1237] = new NetCon(&v(0.5), syn_projEE_ampa[1237], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1238: cell 15, seg 0 (0.5) [0.5 on Epop[15]] -> cell 38, seg 0 (0.5) [0.5 on Epop[38]], weight: 4.1363508E-4, delay 1.5
        h("Epop[38] syn_projEE_ampa[1238] = new ampa(0.5)")
        h("Epop[15] netConn_projEE_ampa[1238] = new NetCon(&v(0.5), syn_projEE_ampa[1238], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1239: cell 15, seg 0 (0.5) [0.5 on Epop[15]] -> cell 39, seg 0 (0.5) [0.5 on Epop[39]], weight: 4.1363508E-4, delay 1.5
        h("Epop[39] syn_projEE_ampa[1239] = new ampa(0.5)")
        h("Epop[15] netConn_projEE_ampa[1239] = new NetCon(&v(0.5), syn_projEE_ampa[1239], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1240: cell 15, seg 0 (0.5) [0.5 on Epop[15]] -> cell 40, seg 0 (0.5) [0.5 on Epop[40]], weight: 4.1363508E-4, delay 1.5
        h("Epop[40] syn_projEE_ampa[1240] = new ampa(0.5)")
        h("Epop[15] netConn_projEE_ampa[1240] = new NetCon(&v(0.5), syn_projEE_ampa[1240], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1241: cell 15, seg 0 (0.5) [0.5 on Epop[15]] -> cell 41, seg 0 (0.5) [0.5 on Epop[41]], weight: 4.1363508E-4, delay 1.5
        h("Epop[41] syn_projEE_ampa[1241] = new ampa(0.5)")
        h("Epop[15] netConn_projEE_ampa[1241] = new NetCon(&v(0.5), syn_projEE_ampa[1241], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1242: cell 15, seg 0 (0.5) [0.5 on Epop[15]] -> cell 42, seg 0 (0.5) [0.5 on Epop[42]], weight: 4.1363508E-4, delay 1.5
        h("Epop[42] syn_projEE_ampa[1242] = new ampa(0.5)")
        h("Epop[15] netConn_projEE_ampa[1242] = new NetCon(&v(0.5), syn_projEE_ampa[1242], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1243: cell 15, seg 0 (0.5) [0.5 on Epop[15]] -> cell 43, seg 0 (0.5) [0.5 on Epop[43]], weight: 4.1363508E-4, delay 1.5
        h("Epop[43] syn_projEE_ampa[1243] = new ampa(0.5)")
        h("Epop[15] netConn_projEE_ampa[1243] = new NetCon(&v(0.5), syn_projEE_ampa[1243], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1244: cell 15, seg 0 (0.5) [0.5 on Epop[15]] -> cell 44, seg 0 (0.5) [0.5 on Epop[44]], weight: 4.1363508E-4, delay 1.5
        h("Epop[44] syn_projEE_ampa[1244] = new ampa(0.5)")
        h("Epop[15] netConn_projEE_ampa[1244] = new NetCon(&v(0.5), syn_projEE_ampa[1244], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1245: cell 15, seg 0 (0.5) [0.5 on Epop[15]] -> cell 45, seg 0 (0.5) [0.5 on Epop[45]], weight: 4.1363508E-4, delay 1.5
        h("Epop[45] syn_projEE_ampa[1245] = new ampa(0.5)")
        h("Epop[15] netConn_projEE_ampa[1245] = new NetCon(&v(0.5), syn_projEE_ampa[1245], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1246: cell 15, seg 0 (0.5) [0.5 on Epop[15]] -> cell 46, seg 0 (0.5) [0.5 on Epop[46]], weight: 4.1363508E-4, delay 1.5
        h("Epop[46] syn_projEE_ampa[1246] = new ampa(0.5)")
        h("Epop[15] netConn_projEE_ampa[1246] = new NetCon(&v(0.5), syn_projEE_ampa[1246], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1247: cell 15, seg 0 (0.5) [0.5 on Epop[15]] -> cell 47, seg 0 (0.5) [0.5 on Epop[47]], weight: 4.1363508E-4, delay 1.5
        h("Epop[47] syn_projEE_ampa[1247] = new ampa(0.5)")
        h("Epop[15] netConn_projEE_ampa[1247] = new NetCon(&v(0.5), syn_projEE_ampa[1247], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1248: cell 15, seg 0 (0.5) [0.5 on Epop[15]] -> cell 48, seg 0 (0.5) [0.5 on Epop[48]], weight: 4.1363508E-4, delay 1.5
        h("Epop[48] syn_projEE_ampa[1248] = new ampa(0.5)")
        h("Epop[15] netConn_projEE_ampa[1248] = new NetCon(&v(0.5), syn_projEE_ampa[1248], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1249: cell 15, seg 0 (0.5) [0.5 on Epop[15]] -> cell 49, seg 0 (0.5) [0.5 on Epop[49]], weight: 4.1363508E-4, delay 1.5
        h("Epop[49] syn_projEE_ampa[1249] = new ampa(0.5)")
        h("Epop[15] netConn_projEE_ampa[1249] = new NetCon(&v(0.5), syn_projEE_ampa[1249], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1250: cell 15, seg 0 (0.5) [0.5 on Epop[15]] -> cell 50, seg 0 (0.5) [0.5 on Epop[50]], weight: 4.1363508E-4, delay 1.5
        h("Epop[50] syn_projEE_ampa[1250] = new ampa(0.5)")
        h("Epop[15] netConn_projEE_ampa[1250] = new NetCon(&v(0.5), syn_projEE_ampa[1250], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1251: cell 15, seg 0 (0.5) [0.5 on Epop[15]] -> cell 51, seg 0 (0.5) [0.5 on Epop[51]], weight: 4.1363508E-4, delay 1.5
        h("Epop[51] syn_projEE_ampa[1251] = new ampa(0.5)")
        h("Epop[15] netConn_projEE_ampa[1251] = new NetCon(&v(0.5), syn_projEE_ampa[1251], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1252: cell 15, seg 0 (0.5) [0.5 on Epop[15]] -> cell 52, seg 0 (0.5) [0.5 on Epop[52]], weight: 4.1363508E-4, delay 1.5
        h("Epop[52] syn_projEE_ampa[1252] = new ampa(0.5)")
        h("Epop[15] netConn_projEE_ampa[1252] = new NetCon(&v(0.5), syn_projEE_ampa[1252], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1253: cell 15, seg 0 (0.5) [0.5 on Epop[15]] -> cell 53, seg 0 (0.5) [0.5 on Epop[53]], weight: 4.1363508E-4, delay 1.5
        h("Epop[53] syn_projEE_ampa[1253] = new ampa(0.5)")
        h("Epop[15] netConn_projEE_ampa[1253] = new NetCon(&v(0.5), syn_projEE_ampa[1253], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1254: cell 15, seg 0 (0.5) [0.5 on Epop[15]] -> cell 54, seg 0 (0.5) [0.5 on Epop[54]], weight: 4.1363508E-4, delay 1.5
        h("Epop[54] syn_projEE_ampa[1254] = new ampa(0.5)")
        h("Epop[15] netConn_projEE_ampa[1254] = new NetCon(&v(0.5), syn_projEE_ampa[1254], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1255: cell 15, seg 0 (0.5) [0.5 on Epop[15]] -> cell 55, seg 0 (0.5) [0.5 on Epop[55]], weight: 4.1363508E-4, delay 1.5
        h("Epop[55] syn_projEE_ampa[1255] = new ampa(0.5)")
        h("Epop[15] netConn_projEE_ampa[1255] = new NetCon(&v(0.5), syn_projEE_ampa[1255], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1256: cell 15, seg 0 (0.5) [0.5 on Epop[15]] -> cell 56, seg 0 (0.5) [0.5 on Epop[56]], weight: 4.1363508E-4, delay 1.5
        h("Epop[56] syn_projEE_ampa[1256] = new ampa(0.5)")
        h("Epop[15] netConn_projEE_ampa[1256] = new NetCon(&v(0.5), syn_projEE_ampa[1256], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1257: cell 15, seg 0 (0.5) [0.5 on Epop[15]] -> cell 57, seg 0 (0.5) [0.5 on Epop[57]], weight: 4.1363508E-4, delay 1.5
        h("Epop[57] syn_projEE_ampa[1257] = new ampa(0.5)")
        h("Epop[15] netConn_projEE_ampa[1257] = new NetCon(&v(0.5), syn_projEE_ampa[1257], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1258: cell 15, seg 0 (0.5) [0.5 on Epop[15]] -> cell 58, seg 0 (0.5) [0.5 on Epop[58]], weight: 4.1363508E-4, delay 1.5
        h("Epop[58] syn_projEE_ampa[1258] = new ampa(0.5)")
        h("Epop[15] netConn_projEE_ampa[1258] = new NetCon(&v(0.5), syn_projEE_ampa[1258], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1259: cell 15, seg 0 (0.5) [0.5 on Epop[15]] -> cell 59, seg 0 (0.5) [0.5 on Epop[59]], weight: 4.1363508E-4, delay 1.5
        h("Epop[59] syn_projEE_ampa[1259] = new ampa(0.5)")
        h("Epop[15] netConn_projEE_ampa[1259] = new NetCon(&v(0.5), syn_projEE_ampa[1259], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1260: cell 15, seg 0 (0.5) [0.5 on Epop[15]] -> cell 60, seg 0 (0.5) [0.5 on Epop[60]], weight: 4.1363508E-4, delay 1.5
        h("Epop[60] syn_projEE_ampa[1260] = new ampa(0.5)")
        h("Epop[15] netConn_projEE_ampa[1260] = new NetCon(&v(0.5), syn_projEE_ampa[1260], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1261: cell 15, seg 0 (0.5) [0.5 on Epop[15]] -> cell 61, seg 0 (0.5) [0.5 on Epop[61]], weight: 4.1363508E-4, delay 1.5
        h("Epop[61] syn_projEE_ampa[1261] = new ampa(0.5)")
        h("Epop[15] netConn_projEE_ampa[1261] = new NetCon(&v(0.5), syn_projEE_ampa[1261], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1262: cell 15, seg 0 (0.5) [0.5 on Epop[15]] -> cell 62, seg 0 (0.5) [0.5 on Epop[62]], weight: 4.1363508E-4, delay 1.5
        h("Epop[62] syn_projEE_ampa[1262] = new ampa(0.5)")
        h("Epop[15] netConn_projEE_ampa[1262] = new NetCon(&v(0.5), syn_projEE_ampa[1262], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1263: cell 15, seg 0 (0.5) [0.5 on Epop[15]] -> cell 63, seg 0 (0.5) [0.5 on Epop[63]], weight: 4.1363508E-4, delay 1.5
        h("Epop[63] syn_projEE_ampa[1263] = new ampa(0.5)")
        h("Epop[15] netConn_projEE_ampa[1263] = new NetCon(&v(0.5), syn_projEE_ampa[1263], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1264: cell 15, seg 0 (0.5) [0.5 on Epop[15]] -> cell 64, seg 0 (0.5) [0.5 on Epop[64]], weight: 4.1363508E-4, delay 1.5
        h("Epop[64] syn_projEE_ampa[1264] = new ampa(0.5)")
        h("Epop[15] netConn_projEE_ampa[1264] = new NetCon(&v(0.5), syn_projEE_ampa[1264], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1265: cell 15, seg 0 (0.5) [0.5 on Epop[15]] -> cell 65, seg 0 (0.5) [0.5 on Epop[65]], weight: 4.1363508E-4, delay 1.5
        h("Epop[65] syn_projEE_ampa[1265] = new ampa(0.5)")
        h("Epop[15] netConn_projEE_ampa[1265] = new NetCon(&v(0.5), syn_projEE_ampa[1265], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1266: cell 15, seg 0 (0.5) [0.5 on Epop[15]] -> cell 66, seg 0 (0.5) [0.5 on Epop[66]], weight: 4.1363508E-4, delay 1.5
        h("Epop[66] syn_projEE_ampa[1266] = new ampa(0.5)")
        h("Epop[15] netConn_projEE_ampa[1266] = new NetCon(&v(0.5), syn_projEE_ampa[1266], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1267: cell 15, seg 0 (0.5) [0.5 on Epop[15]] -> cell 67, seg 0 (0.5) [0.5 on Epop[67]], weight: 4.1363508E-4, delay 1.5
        h("Epop[67] syn_projEE_ampa[1267] = new ampa(0.5)")
        h("Epop[15] netConn_projEE_ampa[1267] = new NetCon(&v(0.5), syn_projEE_ampa[1267], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1268: cell 15, seg 0 (0.5) [0.5 on Epop[15]] -> cell 68, seg 0 (0.5) [0.5 on Epop[68]], weight: 4.1363508E-4, delay 1.5
        h("Epop[68] syn_projEE_ampa[1268] = new ampa(0.5)")
        h("Epop[15] netConn_projEE_ampa[1268] = new NetCon(&v(0.5), syn_projEE_ampa[1268], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1269: cell 15, seg 0 (0.5) [0.5 on Epop[15]] -> cell 69, seg 0 (0.5) [0.5 on Epop[69]], weight: 4.1363508E-4, delay 1.5
        h("Epop[69] syn_projEE_ampa[1269] = new ampa(0.5)")
        h("Epop[15] netConn_projEE_ampa[1269] = new NetCon(&v(0.5), syn_projEE_ampa[1269], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1270: cell 15, seg 0 (0.5) [0.5 on Epop[15]] -> cell 70, seg 0 (0.5) [0.5 on Epop[70]], weight: 4.1363508E-4, delay 1.5
        h("Epop[70] syn_projEE_ampa[1270] = new ampa(0.5)")
        h("Epop[15] netConn_projEE_ampa[1270] = new NetCon(&v(0.5), syn_projEE_ampa[1270], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1271: cell 15, seg 0 (0.5) [0.5 on Epop[15]] -> cell 71, seg 0 (0.5) [0.5 on Epop[71]], weight: 4.1363508E-4, delay 1.5
        h("Epop[71] syn_projEE_ampa[1271] = new ampa(0.5)")
        h("Epop[15] netConn_projEE_ampa[1271] = new NetCon(&v(0.5), syn_projEE_ampa[1271], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1272: cell 15, seg 0 (0.5) [0.5 on Epop[15]] -> cell 72, seg 0 (0.5) [0.5 on Epop[72]], weight: 4.1363508E-4, delay 1.5
        h("Epop[72] syn_projEE_ampa[1272] = new ampa(0.5)")
        h("Epop[15] netConn_projEE_ampa[1272] = new NetCon(&v(0.5), syn_projEE_ampa[1272], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1273: cell 15, seg 0 (0.5) [0.5 on Epop[15]] -> cell 73, seg 0 (0.5) [0.5 on Epop[73]], weight: 4.1363508E-4, delay 1.5
        h("Epop[73] syn_projEE_ampa[1273] = new ampa(0.5)")
        h("Epop[15] netConn_projEE_ampa[1273] = new NetCon(&v(0.5), syn_projEE_ampa[1273], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1274: cell 15, seg 0 (0.5) [0.5 on Epop[15]] -> cell 74, seg 0 (0.5) [0.5 on Epop[74]], weight: 4.1363508E-4, delay 1.5
        h("Epop[74] syn_projEE_ampa[1274] = new ampa(0.5)")
        h("Epop[15] netConn_projEE_ampa[1274] = new NetCon(&v(0.5), syn_projEE_ampa[1274], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1275: cell 15, seg 0 (0.5) [0.5 on Epop[15]] -> cell 75, seg 0 (0.5) [0.5 on Epop[75]], weight: 4.1363508E-4, delay 1.5
        h("Epop[75] syn_projEE_ampa[1275] = new ampa(0.5)")
        h("Epop[15] netConn_projEE_ampa[1275] = new NetCon(&v(0.5), syn_projEE_ampa[1275], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1276: cell 15, seg 0 (0.5) [0.5 on Epop[15]] -> cell 76, seg 0 (0.5) [0.5 on Epop[76]], weight: 4.1363508E-4, delay 1.5
        h("Epop[76] syn_projEE_ampa[1276] = new ampa(0.5)")
        h("Epop[15] netConn_projEE_ampa[1276] = new NetCon(&v(0.5), syn_projEE_ampa[1276], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1277: cell 15, seg 0 (0.5) [0.5 on Epop[15]] -> cell 77, seg 0 (0.5) [0.5 on Epop[77]], weight: 4.1363508E-4, delay 1.5
        h("Epop[77] syn_projEE_ampa[1277] = new ampa(0.5)")
        h("Epop[15] netConn_projEE_ampa[1277] = new NetCon(&v(0.5), syn_projEE_ampa[1277], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1278: cell 15, seg 0 (0.5) [0.5 on Epop[15]] -> cell 78, seg 0 (0.5) [0.5 on Epop[78]], weight: 4.1363508E-4, delay 1.5
        h("Epop[78] syn_projEE_ampa[1278] = new ampa(0.5)")
        h("Epop[15] netConn_projEE_ampa[1278] = new NetCon(&v(0.5), syn_projEE_ampa[1278], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1279: cell 15, seg 0 (0.5) [0.5 on Epop[15]] -> cell 79, seg 0 (0.5) [0.5 on Epop[79]], weight: 4.1363508E-4, delay 1.5
        h("Epop[79] syn_projEE_ampa[1279] = new ampa(0.5)")
        h("Epop[15] netConn_projEE_ampa[1279] = new NetCon(&v(0.5), syn_projEE_ampa[1279], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1280: cell 16, seg 0 (0.5) [0.5 on Epop[16]] -> cell 0, seg 0 (0.5) [0.5 on Epop[0]], weight: 4.1363508E-4, delay 1.5
        h("Epop[0] syn_projEE_ampa[1280] = new ampa(0.5)")
        h("Epop[16] netConn_projEE_ampa[1280] = new NetCon(&v(0.5), syn_projEE_ampa[1280], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1281: cell 16, seg 0 (0.5) [0.5 on Epop[16]] -> cell 1, seg 0 (0.5) [0.5 on Epop[1]], weight: 4.1363508E-4, delay 1.5
        h("Epop[1] syn_projEE_ampa[1281] = new ampa(0.5)")
        h("Epop[16] netConn_projEE_ampa[1281] = new NetCon(&v(0.5), syn_projEE_ampa[1281], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1282: cell 16, seg 0 (0.5) [0.5 on Epop[16]] -> cell 2, seg 0 (0.5) [0.5 on Epop[2]], weight: 4.1363508E-4, delay 1.5
        h("Epop[2] syn_projEE_ampa[1282] = new ampa(0.5)")
        h("Epop[16] netConn_projEE_ampa[1282] = new NetCon(&v(0.5), syn_projEE_ampa[1282], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1283: cell 16, seg 0 (0.5) [0.5 on Epop[16]] -> cell 3, seg 0 (0.5) [0.5 on Epop[3]], weight: 4.1363508E-4, delay 1.5
        h("Epop[3] syn_projEE_ampa[1283] = new ampa(0.5)")
        h("Epop[16] netConn_projEE_ampa[1283] = new NetCon(&v(0.5), syn_projEE_ampa[1283], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1284: cell 16, seg 0 (0.5) [0.5 on Epop[16]] -> cell 4, seg 0 (0.5) [0.5 on Epop[4]], weight: 4.1363508E-4, delay 1.5
        h("Epop[4] syn_projEE_ampa[1284] = new ampa(0.5)")
        h("Epop[16] netConn_projEE_ampa[1284] = new NetCon(&v(0.5), syn_projEE_ampa[1284], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1285: cell 16, seg 0 (0.5) [0.5 on Epop[16]] -> cell 5, seg 0 (0.5) [0.5 on Epop[5]], weight: 4.1363508E-4, delay 1.5
        h("Epop[5] syn_projEE_ampa[1285] = new ampa(0.5)")
        h("Epop[16] netConn_projEE_ampa[1285] = new NetCon(&v(0.5), syn_projEE_ampa[1285], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1286: cell 16, seg 0 (0.5) [0.5 on Epop[16]] -> cell 6, seg 0 (0.5) [0.5 on Epop[6]], weight: 4.1363508E-4, delay 1.5
        h("Epop[6] syn_projEE_ampa[1286] = new ampa(0.5)")
        h("Epop[16] netConn_projEE_ampa[1286] = new NetCon(&v(0.5), syn_projEE_ampa[1286], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1287: cell 16, seg 0 (0.5) [0.5 on Epop[16]] -> cell 7, seg 0 (0.5) [0.5 on Epop[7]], weight: 4.1363508E-4, delay 1.5
        h("Epop[7] syn_projEE_ampa[1287] = new ampa(0.5)")
        h("Epop[16] netConn_projEE_ampa[1287] = new NetCon(&v(0.5), syn_projEE_ampa[1287], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1288: cell 16, seg 0 (0.5) [0.5 on Epop[16]] -> cell 8, seg 0 (0.5) [0.5 on Epop[8]], weight: 4.1363508E-4, delay 1.5
        h("Epop[8] syn_projEE_ampa[1288] = new ampa(0.5)")
        h("Epop[16] netConn_projEE_ampa[1288] = new NetCon(&v(0.5), syn_projEE_ampa[1288], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1289: cell 16, seg 0 (0.5) [0.5 on Epop[16]] -> cell 9, seg 0 (0.5) [0.5 on Epop[9]], weight: 4.1363508E-4, delay 1.5
        h("Epop[9] syn_projEE_ampa[1289] = new ampa(0.5)")
        h("Epop[16] netConn_projEE_ampa[1289] = new NetCon(&v(0.5), syn_projEE_ampa[1289], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1290: cell 16, seg 0 (0.5) [0.5 on Epop[16]] -> cell 10, seg 0 (0.5) [0.5 on Epop[10]], weight: 4.1363508E-4, delay 1.5
        h("Epop[10] syn_projEE_ampa[1290] = new ampa(0.5)")
        h("Epop[16] netConn_projEE_ampa[1290] = new NetCon(&v(0.5), syn_projEE_ampa[1290], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1291: cell 16, seg 0 (0.5) [0.5 on Epop[16]] -> cell 11, seg 0 (0.5) [0.5 on Epop[11]], weight: 4.1363508E-4, delay 1.5
        h("Epop[11] syn_projEE_ampa[1291] = new ampa(0.5)")
        h("Epop[16] netConn_projEE_ampa[1291] = new NetCon(&v(0.5), syn_projEE_ampa[1291], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1292: cell 16, seg 0 (0.5) [0.5 on Epop[16]] -> cell 12, seg 0 (0.5) [0.5 on Epop[12]], weight: 4.1363508E-4, delay 1.5
        h("Epop[12] syn_projEE_ampa[1292] = new ampa(0.5)")
        h("Epop[16] netConn_projEE_ampa[1292] = new NetCon(&v(0.5), syn_projEE_ampa[1292], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1293: cell 16, seg 0 (0.5) [0.5 on Epop[16]] -> cell 13, seg 0 (0.5) [0.5 on Epop[13]], weight: 4.1363508E-4, delay 1.5
        h("Epop[13] syn_projEE_ampa[1293] = new ampa(0.5)")
        h("Epop[16] netConn_projEE_ampa[1293] = new NetCon(&v(0.5), syn_projEE_ampa[1293], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1294: cell 16, seg 0 (0.5) [0.5 on Epop[16]] -> cell 14, seg 0 (0.5) [0.5 on Epop[14]], weight: 4.1363508E-4, delay 1.5
        h("Epop[14] syn_projEE_ampa[1294] = new ampa(0.5)")
        h("Epop[16] netConn_projEE_ampa[1294] = new NetCon(&v(0.5), syn_projEE_ampa[1294], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1295: cell 16, seg 0 (0.5) [0.5 on Epop[16]] -> cell 15, seg 0 (0.5) [0.5 on Epop[15]], weight: 4.1363508E-4, delay 1.5
        h("Epop[15] syn_projEE_ampa[1295] = new ampa(0.5)")
        h("Epop[16] netConn_projEE_ampa[1295] = new NetCon(&v(0.5), syn_projEE_ampa[1295], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1296: cell 16, seg 0 (0.5) [0.5 on Epop[16]] -> cell 16, seg 0 (0.5) [0.5 on Epop[16]], weight: 4.1363508E-4, delay 1.5
        h("Epop[16] syn_projEE_ampa[1296] = new ampa(0.5)")
        h("Epop[16] netConn_projEE_ampa[1296] = new NetCon(&v(0.5), syn_projEE_ampa[1296], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1297: cell 16, seg 0 (0.5) [0.5 on Epop[16]] -> cell 17, seg 0 (0.5) [0.5 on Epop[17]], weight: 4.1363508E-4, delay 1.5
        h("Epop[17] syn_projEE_ampa[1297] = new ampa(0.5)")
        h("Epop[16] netConn_projEE_ampa[1297] = new NetCon(&v(0.5), syn_projEE_ampa[1297], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1298: cell 16, seg 0 (0.5) [0.5 on Epop[16]] -> cell 18, seg 0 (0.5) [0.5 on Epop[18]], weight: 4.1363508E-4, delay 1.5
        h("Epop[18] syn_projEE_ampa[1298] = new ampa(0.5)")
        h("Epop[16] netConn_projEE_ampa[1298] = new NetCon(&v(0.5), syn_projEE_ampa[1298], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1299: cell 16, seg 0 (0.5) [0.5 on Epop[16]] -> cell 19, seg 0 (0.5) [0.5 on Epop[19]], weight: 4.1363508E-4, delay 1.5
        h("Epop[19] syn_projEE_ampa[1299] = new ampa(0.5)")
        h("Epop[16] netConn_projEE_ampa[1299] = new NetCon(&v(0.5), syn_projEE_ampa[1299], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1300: cell 16, seg 0 (0.5) [0.5 on Epop[16]] -> cell 20, seg 0 (0.5) [0.5 on Epop[20]], weight: 4.1363508E-4, delay 1.5
        h("Epop[20] syn_projEE_ampa[1300] = new ampa(0.5)")
        h("Epop[16] netConn_projEE_ampa[1300] = new NetCon(&v(0.5), syn_projEE_ampa[1300], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1301: cell 16, seg 0 (0.5) [0.5 on Epop[16]] -> cell 21, seg 0 (0.5) [0.5 on Epop[21]], weight: 4.1363508E-4, delay 1.5
        h("Epop[21] syn_projEE_ampa[1301] = new ampa(0.5)")
        h("Epop[16] netConn_projEE_ampa[1301] = new NetCon(&v(0.5), syn_projEE_ampa[1301], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1302: cell 16, seg 0 (0.5) [0.5 on Epop[16]] -> cell 22, seg 0 (0.5) [0.5 on Epop[22]], weight: 4.1363508E-4, delay 1.5
        h("Epop[22] syn_projEE_ampa[1302] = new ampa(0.5)")
        h("Epop[16] netConn_projEE_ampa[1302] = new NetCon(&v(0.5), syn_projEE_ampa[1302], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1303: cell 16, seg 0 (0.5) [0.5 on Epop[16]] -> cell 23, seg 0 (0.5) [0.5 on Epop[23]], weight: 4.1363508E-4, delay 1.5
        h("Epop[23] syn_projEE_ampa[1303] = new ampa(0.5)")
        h("Epop[16] netConn_projEE_ampa[1303] = new NetCon(&v(0.5), syn_projEE_ampa[1303], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1304: cell 16, seg 0 (0.5) [0.5 on Epop[16]] -> cell 24, seg 0 (0.5) [0.5 on Epop[24]], weight: 4.1363508E-4, delay 1.5
        h("Epop[24] syn_projEE_ampa[1304] = new ampa(0.5)")
        h("Epop[16] netConn_projEE_ampa[1304] = new NetCon(&v(0.5), syn_projEE_ampa[1304], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1305: cell 16, seg 0 (0.5) [0.5 on Epop[16]] -> cell 25, seg 0 (0.5) [0.5 on Epop[25]], weight: 4.1363508E-4, delay 1.5
        h("Epop[25] syn_projEE_ampa[1305] = new ampa(0.5)")
        h("Epop[16] netConn_projEE_ampa[1305] = new NetCon(&v(0.5), syn_projEE_ampa[1305], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1306: cell 16, seg 0 (0.5) [0.5 on Epop[16]] -> cell 26, seg 0 (0.5) [0.5 on Epop[26]], weight: 4.1363508E-4, delay 1.5
        h("Epop[26] syn_projEE_ampa[1306] = new ampa(0.5)")
        h("Epop[16] netConn_projEE_ampa[1306] = new NetCon(&v(0.5), syn_projEE_ampa[1306], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1307: cell 16, seg 0 (0.5) [0.5 on Epop[16]] -> cell 27, seg 0 (0.5) [0.5 on Epop[27]], weight: 4.1363508E-4, delay 1.5
        h("Epop[27] syn_projEE_ampa[1307] = new ampa(0.5)")
        h("Epop[16] netConn_projEE_ampa[1307] = new NetCon(&v(0.5), syn_projEE_ampa[1307], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1308: cell 16, seg 0 (0.5) [0.5 on Epop[16]] -> cell 28, seg 0 (0.5) [0.5 on Epop[28]], weight: 4.1363508E-4, delay 1.5
        h("Epop[28] syn_projEE_ampa[1308] = new ampa(0.5)")
        h("Epop[16] netConn_projEE_ampa[1308] = new NetCon(&v(0.5), syn_projEE_ampa[1308], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1309: cell 16, seg 0 (0.5) [0.5 on Epop[16]] -> cell 29, seg 0 (0.5) [0.5 on Epop[29]], weight: 4.1363508E-4, delay 1.5
        h("Epop[29] syn_projEE_ampa[1309] = new ampa(0.5)")
        h("Epop[16] netConn_projEE_ampa[1309] = new NetCon(&v(0.5), syn_projEE_ampa[1309], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1310: cell 16, seg 0 (0.5) [0.5 on Epop[16]] -> cell 30, seg 0 (0.5) [0.5 on Epop[30]], weight: 4.1363508E-4, delay 1.5
        h("Epop[30] syn_projEE_ampa[1310] = new ampa(0.5)")
        h("Epop[16] netConn_projEE_ampa[1310] = new NetCon(&v(0.5), syn_projEE_ampa[1310], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1311: cell 16, seg 0 (0.5) [0.5 on Epop[16]] -> cell 31, seg 0 (0.5) [0.5 on Epop[31]], weight: 4.1363508E-4, delay 1.5
        h("Epop[31] syn_projEE_ampa[1311] = new ampa(0.5)")
        h("Epop[16] netConn_projEE_ampa[1311] = new NetCon(&v(0.5), syn_projEE_ampa[1311], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1312: cell 16, seg 0 (0.5) [0.5 on Epop[16]] -> cell 32, seg 0 (0.5) [0.5 on Epop[32]], weight: 4.1363508E-4, delay 1.5
        h("Epop[32] syn_projEE_ampa[1312] = new ampa(0.5)")
        h("Epop[16] netConn_projEE_ampa[1312] = new NetCon(&v(0.5), syn_projEE_ampa[1312], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1313: cell 16, seg 0 (0.5) [0.5 on Epop[16]] -> cell 33, seg 0 (0.5) [0.5 on Epop[33]], weight: 4.1363508E-4, delay 1.5
        h("Epop[33] syn_projEE_ampa[1313] = new ampa(0.5)")
        h("Epop[16] netConn_projEE_ampa[1313] = new NetCon(&v(0.5), syn_projEE_ampa[1313], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1314: cell 16, seg 0 (0.5) [0.5 on Epop[16]] -> cell 34, seg 0 (0.5) [0.5 on Epop[34]], weight: 4.1363508E-4, delay 1.5
        h("Epop[34] syn_projEE_ampa[1314] = new ampa(0.5)")
        h("Epop[16] netConn_projEE_ampa[1314] = new NetCon(&v(0.5), syn_projEE_ampa[1314], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1315: cell 16, seg 0 (0.5) [0.5 on Epop[16]] -> cell 35, seg 0 (0.5) [0.5 on Epop[35]], weight: 4.1363508E-4, delay 1.5
        h("Epop[35] syn_projEE_ampa[1315] = new ampa(0.5)")
        h("Epop[16] netConn_projEE_ampa[1315] = new NetCon(&v(0.5), syn_projEE_ampa[1315], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1316: cell 16, seg 0 (0.5) [0.5 on Epop[16]] -> cell 36, seg 0 (0.5) [0.5 on Epop[36]], weight: 4.1363508E-4, delay 1.5
        h("Epop[36] syn_projEE_ampa[1316] = new ampa(0.5)")
        h("Epop[16] netConn_projEE_ampa[1316] = new NetCon(&v(0.5), syn_projEE_ampa[1316], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1317: cell 16, seg 0 (0.5) [0.5 on Epop[16]] -> cell 37, seg 0 (0.5) [0.5 on Epop[37]], weight: 4.1363508E-4, delay 1.5
        h("Epop[37] syn_projEE_ampa[1317] = new ampa(0.5)")
        h("Epop[16] netConn_projEE_ampa[1317] = new NetCon(&v(0.5), syn_projEE_ampa[1317], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1318: cell 16, seg 0 (0.5) [0.5 on Epop[16]] -> cell 38, seg 0 (0.5) [0.5 on Epop[38]], weight: 4.1363508E-4, delay 1.5
        h("Epop[38] syn_projEE_ampa[1318] = new ampa(0.5)")
        h("Epop[16] netConn_projEE_ampa[1318] = new NetCon(&v(0.5), syn_projEE_ampa[1318], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1319: cell 16, seg 0 (0.5) [0.5 on Epop[16]] -> cell 39, seg 0 (0.5) [0.5 on Epop[39]], weight: 4.1363508E-4, delay 1.5
        h("Epop[39] syn_projEE_ampa[1319] = new ampa(0.5)")
        h("Epop[16] netConn_projEE_ampa[1319] = new NetCon(&v(0.5), syn_projEE_ampa[1319], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1320: cell 16, seg 0 (0.5) [0.5 on Epop[16]] -> cell 40, seg 0 (0.5) [0.5 on Epop[40]], weight: 4.1363508E-4, delay 1.5
        h("Epop[40] syn_projEE_ampa[1320] = new ampa(0.5)")
        h("Epop[16] netConn_projEE_ampa[1320] = new NetCon(&v(0.5), syn_projEE_ampa[1320], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1321: cell 16, seg 0 (0.5) [0.5 on Epop[16]] -> cell 41, seg 0 (0.5) [0.5 on Epop[41]], weight: 4.1363508E-4, delay 1.5
        h("Epop[41] syn_projEE_ampa[1321] = new ampa(0.5)")
        h("Epop[16] netConn_projEE_ampa[1321] = new NetCon(&v(0.5), syn_projEE_ampa[1321], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1322: cell 16, seg 0 (0.5) [0.5 on Epop[16]] -> cell 42, seg 0 (0.5) [0.5 on Epop[42]], weight: 4.1363508E-4, delay 1.5
        h("Epop[42] syn_projEE_ampa[1322] = new ampa(0.5)")
        h("Epop[16] netConn_projEE_ampa[1322] = new NetCon(&v(0.5), syn_projEE_ampa[1322], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1323: cell 16, seg 0 (0.5) [0.5 on Epop[16]] -> cell 43, seg 0 (0.5) [0.5 on Epop[43]], weight: 4.1363508E-4, delay 1.5
        h("Epop[43] syn_projEE_ampa[1323] = new ampa(0.5)")
        h("Epop[16] netConn_projEE_ampa[1323] = new NetCon(&v(0.5), syn_projEE_ampa[1323], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1324: cell 16, seg 0 (0.5) [0.5 on Epop[16]] -> cell 44, seg 0 (0.5) [0.5 on Epop[44]], weight: 4.1363508E-4, delay 1.5
        h("Epop[44] syn_projEE_ampa[1324] = new ampa(0.5)")
        h("Epop[16] netConn_projEE_ampa[1324] = new NetCon(&v(0.5), syn_projEE_ampa[1324], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1325: cell 16, seg 0 (0.5) [0.5 on Epop[16]] -> cell 45, seg 0 (0.5) [0.5 on Epop[45]], weight: 4.1363508E-4, delay 1.5
        h("Epop[45] syn_projEE_ampa[1325] = new ampa(0.5)")
        h("Epop[16] netConn_projEE_ampa[1325] = new NetCon(&v(0.5), syn_projEE_ampa[1325], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1326: cell 16, seg 0 (0.5) [0.5 on Epop[16]] -> cell 46, seg 0 (0.5) [0.5 on Epop[46]], weight: 4.1363508E-4, delay 1.5
        h("Epop[46] syn_projEE_ampa[1326] = new ampa(0.5)")
        h("Epop[16] netConn_projEE_ampa[1326] = new NetCon(&v(0.5), syn_projEE_ampa[1326], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1327: cell 16, seg 0 (0.5) [0.5 on Epop[16]] -> cell 47, seg 0 (0.5) [0.5 on Epop[47]], weight: 4.1363508E-4, delay 1.5
        h("Epop[47] syn_projEE_ampa[1327] = new ampa(0.5)")
        h("Epop[16] netConn_projEE_ampa[1327] = new NetCon(&v(0.5), syn_projEE_ampa[1327], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1328: cell 16, seg 0 (0.5) [0.5 on Epop[16]] -> cell 48, seg 0 (0.5) [0.5 on Epop[48]], weight: 4.1363508E-4, delay 1.5
        h("Epop[48] syn_projEE_ampa[1328] = new ampa(0.5)")
        h("Epop[16] netConn_projEE_ampa[1328] = new NetCon(&v(0.5), syn_projEE_ampa[1328], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1329: cell 16, seg 0 (0.5) [0.5 on Epop[16]] -> cell 49, seg 0 (0.5) [0.5 on Epop[49]], weight: 4.1363508E-4, delay 1.5
        h("Epop[49] syn_projEE_ampa[1329] = new ampa(0.5)")
        h("Epop[16] netConn_projEE_ampa[1329] = new NetCon(&v(0.5), syn_projEE_ampa[1329], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1330: cell 16, seg 0 (0.5) [0.5 on Epop[16]] -> cell 50, seg 0 (0.5) [0.5 on Epop[50]], weight: 4.1363508E-4, delay 1.5
        h("Epop[50] syn_projEE_ampa[1330] = new ampa(0.5)")
        h("Epop[16] netConn_projEE_ampa[1330] = new NetCon(&v(0.5), syn_projEE_ampa[1330], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1331: cell 16, seg 0 (0.5) [0.5 on Epop[16]] -> cell 51, seg 0 (0.5) [0.5 on Epop[51]], weight: 4.1363508E-4, delay 1.5
        h("Epop[51] syn_projEE_ampa[1331] = new ampa(0.5)")
        h("Epop[16] netConn_projEE_ampa[1331] = new NetCon(&v(0.5), syn_projEE_ampa[1331], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1332: cell 16, seg 0 (0.5) [0.5 on Epop[16]] -> cell 52, seg 0 (0.5) [0.5 on Epop[52]], weight: 4.1363508E-4, delay 1.5
        h("Epop[52] syn_projEE_ampa[1332] = new ampa(0.5)")
        h("Epop[16] netConn_projEE_ampa[1332] = new NetCon(&v(0.5), syn_projEE_ampa[1332], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1333: cell 16, seg 0 (0.5) [0.5 on Epop[16]] -> cell 53, seg 0 (0.5) [0.5 on Epop[53]], weight: 4.1363508E-4, delay 1.5
        h("Epop[53] syn_projEE_ampa[1333] = new ampa(0.5)")
        h("Epop[16] netConn_projEE_ampa[1333] = new NetCon(&v(0.5), syn_projEE_ampa[1333], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1334: cell 16, seg 0 (0.5) [0.5 on Epop[16]] -> cell 54, seg 0 (0.5) [0.5 on Epop[54]], weight: 4.1363508E-4, delay 1.5
        h("Epop[54] syn_projEE_ampa[1334] = new ampa(0.5)")
        h("Epop[16] netConn_projEE_ampa[1334] = new NetCon(&v(0.5), syn_projEE_ampa[1334], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1335: cell 16, seg 0 (0.5) [0.5 on Epop[16]] -> cell 55, seg 0 (0.5) [0.5 on Epop[55]], weight: 4.1363508E-4, delay 1.5
        h("Epop[55] syn_projEE_ampa[1335] = new ampa(0.5)")
        h("Epop[16] netConn_projEE_ampa[1335] = new NetCon(&v(0.5), syn_projEE_ampa[1335], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1336: cell 16, seg 0 (0.5) [0.5 on Epop[16]] -> cell 56, seg 0 (0.5) [0.5 on Epop[56]], weight: 4.1363508E-4, delay 1.5
        h("Epop[56] syn_projEE_ampa[1336] = new ampa(0.5)")
        h("Epop[16] netConn_projEE_ampa[1336] = new NetCon(&v(0.5), syn_projEE_ampa[1336], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1337: cell 16, seg 0 (0.5) [0.5 on Epop[16]] -> cell 57, seg 0 (0.5) [0.5 on Epop[57]], weight: 4.1363508E-4, delay 1.5
        h("Epop[57] syn_projEE_ampa[1337] = new ampa(0.5)")
        h("Epop[16] netConn_projEE_ampa[1337] = new NetCon(&v(0.5), syn_projEE_ampa[1337], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1338: cell 16, seg 0 (0.5) [0.5 on Epop[16]] -> cell 58, seg 0 (0.5) [0.5 on Epop[58]], weight: 4.1363508E-4, delay 1.5
        h("Epop[58] syn_projEE_ampa[1338] = new ampa(0.5)")
        h("Epop[16] netConn_projEE_ampa[1338] = new NetCon(&v(0.5), syn_projEE_ampa[1338], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1339: cell 16, seg 0 (0.5) [0.5 on Epop[16]] -> cell 59, seg 0 (0.5) [0.5 on Epop[59]], weight: 4.1363508E-4, delay 1.5
        h("Epop[59] syn_projEE_ampa[1339] = new ampa(0.5)")
        h("Epop[16] netConn_projEE_ampa[1339] = new NetCon(&v(0.5), syn_projEE_ampa[1339], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1340: cell 16, seg 0 (0.5) [0.5 on Epop[16]] -> cell 60, seg 0 (0.5) [0.5 on Epop[60]], weight: 4.1363508E-4, delay 1.5
        h("Epop[60] syn_projEE_ampa[1340] = new ampa(0.5)")
        h("Epop[16] netConn_projEE_ampa[1340] = new NetCon(&v(0.5), syn_projEE_ampa[1340], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1341: cell 16, seg 0 (0.5) [0.5 on Epop[16]] -> cell 61, seg 0 (0.5) [0.5 on Epop[61]], weight: 4.1363508E-4, delay 1.5
        h("Epop[61] syn_projEE_ampa[1341] = new ampa(0.5)")
        h("Epop[16] netConn_projEE_ampa[1341] = new NetCon(&v(0.5), syn_projEE_ampa[1341], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1342: cell 16, seg 0 (0.5) [0.5 on Epop[16]] -> cell 62, seg 0 (0.5) [0.5 on Epop[62]], weight: 4.1363508E-4, delay 1.5
        h("Epop[62] syn_projEE_ampa[1342] = new ampa(0.5)")
        h("Epop[16] netConn_projEE_ampa[1342] = new NetCon(&v(0.5), syn_projEE_ampa[1342], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1343: cell 16, seg 0 (0.5) [0.5 on Epop[16]] -> cell 63, seg 0 (0.5) [0.5 on Epop[63]], weight: 4.1363508E-4, delay 1.5
        h("Epop[63] syn_projEE_ampa[1343] = new ampa(0.5)")
        h("Epop[16] netConn_projEE_ampa[1343] = new NetCon(&v(0.5), syn_projEE_ampa[1343], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1344: cell 16, seg 0 (0.5) [0.5 on Epop[16]] -> cell 64, seg 0 (0.5) [0.5 on Epop[64]], weight: 4.1363508E-4, delay 1.5
        h("Epop[64] syn_projEE_ampa[1344] = new ampa(0.5)")
        h("Epop[16] netConn_projEE_ampa[1344] = new NetCon(&v(0.5), syn_projEE_ampa[1344], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1345: cell 16, seg 0 (0.5) [0.5 on Epop[16]] -> cell 65, seg 0 (0.5) [0.5 on Epop[65]], weight: 4.1363508E-4, delay 1.5
        h("Epop[65] syn_projEE_ampa[1345] = new ampa(0.5)")
        h("Epop[16] netConn_projEE_ampa[1345] = new NetCon(&v(0.5), syn_projEE_ampa[1345], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1346: cell 16, seg 0 (0.5) [0.5 on Epop[16]] -> cell 66, seg 0 (0.5) [0.5 on Epop[66]], weight: 4.1363508E-4, delay 1.5
        h("Epop[66] syn_projEE_ampa[1346] = new ampa(0.5)")
        h("Epop[16] netConn_projEE_ampa[1346] = new NetCon(&v(0.5), syn_projEE_ampa[1346], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1347: cell 16, seg 0 (0.5) [0.5 on Epop[16]] -> cell 67, seg 0 (0.5) [0.5 on Epop[67]], weight: 4.1363508E-4, delay 1.5
        h("Epop[67] syn_projEE_ampa[1347] = new ampa(0.5)")
        h("Epop[16] netConn_projEE_ampa[1347] = new NetCon(&v(0.5), syn_projEE_ampa[1347], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1348: cell 16, seg 0 (0.5) [0.5 on Epop[16]] -> cell 68, seg 0 (0.5) [0.5 on Epop[68]], weight: 4.1363508E-4, delay 1.5
        h("Epop[68] syn_projEE_ampa[1348] = new ampa(0.5)")
        h("Epop[16] netConn_projEE_ampa[1348] = new NetCon(&v(0.5), syn_projEE_ampa[1348], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1349: cell 16, seg 0 (0.5) [0.5 on Epop[16]] -> cell 69, seg 0 (0.5) [0.5 on Epop[69]], weight: 4.1363508E-4, delay 1.5
        h("Epop[69] syn_projEE_ampa[1349] = new ampa(0.5)")
        h("Epop[16] netConn_projEE_ampa[1349] = new NetCon(&v(0.5), syn_projEE_ampa[1349], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1350: cell 16, seg 0 (0.5) [0.5 on Epop[16]] -> cell 70, seg 0 (0.5) [0.5 on Epop[70]], weight: 4.1363508E-4, delay 1.5
        h("Epop[70] syn_projEE_ampa[1350] = new ampa(0.5)")
        h("Epop[16] netConn_projEE_ampa[1350] = new NetCon(&v(0.5), syn_projEE_ampa[1350], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1351: cell 16, seg 0 (0.5) [0.5 on Epop[16]] -> cell 71, seg 0 (0.5) [0.5 on Epop[71]], weight: 4.1363508E-4, delay 1.5
        h("Epop[71] syn_projEE_ampa[1351] = new ampa(0.5)")
        h("Epop[16] netConn_projEE_ampa[1351] = new NetCon(&v(0.5), syn_projEE_ampa[1351], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1352: cell 16, seg 0 (0.5) [0.5 on Epop[16]] -> cell 72, seg 0 (0.5) [0.5 on Epop[72]], weight: 4.1363508E-4, delay 1.5
        h("Epop[72] syn_projEE_ampa[1352] = new ampa(0.5)")
        h("Epop[16] netConn_projEE_ampa[1352] = new NetCon(&v(0.5), syn_projEE_ampa[1352], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1353: cell 16, seg 0 (0.5) [0.5 on Epop[16]] -> cell 73, seg 0 (0.5) [0.5 on Epop[73]], weight: 4.1363508E-4, delay 1.5
        h("Epop[73] syn_projEE_ampa[1353] = new ampa(0.5)")
        h("Epop[16] netConn_projEE_ampa[1353] = new NetCon(&v(0.5), syn_projEE_ampa[1353], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1354: cell 16, seg 0 (0.5) [0.5 on Epop[16]] -> cell 74, seg 0 (0.5) [0.5 on Epop[74]], weight: 4.1363508E-4, delay 1.5
        h("Epop[74] syn_projEE_ampa[1354] = new ampa(0.5)")
        h("Epop[16] netConn_projEE_ampa[1354] = new NetCon(&v(0.5), syn_projEE_ampa[1354], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1355: cell 16, seg 0 (0.5) [0.5 on Epop[16]] -> cell 75, seg 0 (0.5) [0.5 on Epop[75]], weight: 4.1363508E-4, delay 1.5
        h("Epop[75] syn_projEE_ampa[1355] = new ampa(0.5)")
        h("Epop[16] netConn_projEE_ampa[1355] = new NetCon(&v(0.5), syn_projEE_ampa[1355], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1356: cell 16, seg 0 (0.5) [0.5 on Epop[16]] -> cell 76, seg 0 (0.5) [0.5 on Epop[76]], weight: 4.1363508E-4, delay 1.5
        h("Epop[76] syn_projEE_ampa[1356] = new ampa(0.5)")
        h("Epop[16] netConn_projEE_ampa[1356] = new NetCon(&v(0.5), syn_projEE_ampa[1356], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1357: cell 16, seg 0 (0.5) [0.5 on Epop[16]] -> cell 77, seg 0 (0.5) [0.5 on Epop[77]], weight: 4.1363508E-4, delay 1.5
        h("Epop[77] syn_projEE_ampa[1357] = new ampa(0.5)")
        h("Epop[16] netConn_projEE_ampa[1357] = new NetCon(&v(0.5), syn_projEE_ampa[1357], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1358: cell 16, seg 0 (0.5) [0.5 on Epop[16]] -> cell 78, seg 0 (0.5) [0.5 on Epop[78]], weight: 4.1363508E-4, delay 1.5
        h("Epop[78] syn_projEE_ampa[1358] = new ampa(0.5)")
        h("Epop[16] netConn_projEE_ampa[1358] = new NetCon(&v(0.5), syn_projEE_ampa[1358], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1359: cell 16, seg 0 (0.5) [0.5 on Epop[16]] -> cell 79, seg 0 (0.5) [0.5 on Epop[79]], weight: 4.1363508E-4, delay 1.5
        h("Epop[79] syn_projEE_ampa[1359] = new ampa(0.5)")
        h("Epop[16] netConn_projEE_ampa[1359] = new NetCon(&v(0.5), syn_projEE_ampa[1359], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1360: cell 17, seg 0 (0.5) [0.5 on Epop[17]] -> cell 0, seg 0 (0.5) [0.5 on Epop[0]], weight: 4.1363508E-4, delay 1.5
        h("Epop[0] syn_projEE_ampa[1360] = new ampa(0.5)")
        h("Epop[17] netConn_projEE_ampa[1360] = new NetCon(&v(0.5), syn_projEE_ampa[1360], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1361: cell 17, seg 0 (0.5) [0.5 on Epop[17]] -> cell 1, seg 0 (0.5) [0.5 on Epop[1]], weight: 4.1363508E-4, delay 1.5
        h("Epop[1] syn_projEE_ampa[1361] = new ampa(0.5)")
        h("Epop[17] netConn_projEE_ampa[1361] = new NetCon(&v(0.5), syn_projEE_ampa[1361], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1362: cell 17, seg 0 (0.5) [0.5 on Epop[17]] -> cell 2, seg 0 (0.5) [0.5 on Epop[2]], weight: 4.1363508E-4, delay 1.5
        h("Epop[2] syn_projEE_ampa[1362] = new ampa(0.5)")
        h("Epop[17] netConn_projEE_ampa[1362] = new NetCon(&v(0.5), syn_projEE_ampa[1362], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1363: cell 17, seg 0 (0.5) [0.5 on Epop[17]] -> cell 3, seg 0 (0.5) [0.5 on Epop[3]], weight: 4.1363508E-4, delay 1.5
        h("Epop[3] syn_projEE_ampa[1363] = new ampa(0.5)")
        h("Epop[17] netConn_projEE_ampa[1363] = new NetCon(&v(0.5), syn_projEE_ampa[1363], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1364: cell 17, seg 0 (0.5) [0.5 on Epop[17]] -> cell 4, seg 0 (0.5) [0.5 on Epop[4]], weight: 4.1363508E-4, delay 1.5
        h("Epop[4] syn_projEE_ampa[1364] = new ampa(0.5)")
        h("Epop[17] netConn_projEE_ampa[1364] = new NetCon(&v(0.5), syn_projEE_ampa[1364], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1365: cell 17, seg 0 (0.5) [0.5 on Epop[17]] -> cell 5, seg 0 (0.5) [0.5 on Epop[5]], weight: 4.1363508E-4, delay 1.5
        h("Epop[5] syn_projEE_ampa[1365] = new ampa(0.5)")
        h("Epop[17] netConn_projEE_ampa[1365] = new NetCon(&v(0.5), syn_projEE_ampa[1365], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1366: cell 17, seg 0 (0.5) [0.5 on Epop[17]] -> cell 6, seg 0 (0.5) [0.5 on Epop[6]], weight: 4.1363508E-4, delay 1.5
        h("Epop[6] syn_projEE_ampa[1366] = new ampa(0.5)")
        h("Epop[17] netConn_projEE_ampa[1366] = new NetCon(&v(0.5), syn_projEE_ampa[1366], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1367: cell 17, seg 0 (0.5) [0.5 on Epop[17]] -> cell 7, seg 0 (0.5) [0.5 on Epop[7]], weight: 4.1363508E-4, delay 1.5
        h("Epop[7] syn_projEE_ampa[1367] = new ampa(0.5)")
        h("Epop[17] netConn_projEE_ampa[1367] = new NetCon(&v(0.5), syn_projEE_ampa[1367], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1368: cell 17, seg 0 (0.5) [0.5 on Epop[17]] -> cell 8, seg 0 (0.5) [0.5 on Epop[8]], weight: 4.1363508E-4, delay 1.5
        h("Epop[8] syn_projEE_ampa[1368] = new ampa(0.5)")
        h("Epop[17] netConn_projEE_ampa[1368] = new NetCon(&v(0.5), syn_projEE_ampa[1368], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1369: cell 17, seg 0 (0.5) [0.5 on Epop[17]] -> cell 9, seg 0 (0.5) [0.5 on Epop[9]], weight: 4.1363508E-4, delay 1.5
        h("Epop[9] syn_projEE_ampa[1369] = new ampa(0.5)")
        h("Epop[17] netConn_projEE_ampa[1369] = new NetCon(&v(0.5), syn_projEE_ampa[1369], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1370: cell 17, seg 0 (0.5) [0.5 on Epop[17]] -> cell 10, seg 0 (0.5) [0.5 on Epop[10]], weight: 4.1363508E-4, delay 1.5
        h("Epop[10] syn_projEE_ampa[1370] = new ampa(0.5)")
        h("Epop[17] netConn_projEE_ampa[1370] = new NetCon(&v(0.5), syn_projEE_ampa[1370], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1371: cell 17, seg 0 (0.5) [0.5 on Epop[17]] -> cell 11, seg 0 (0.5) [0.5 on Epop[11]], weight: 4.1363508E-4, delay 1.5
        h("Epop[11] syn_projEE_ampa[1371] = new ampa(0.5)")
        h("Epop[17] netConn_projEE_ampa[1371] = new NetCon(&v(0.5), syn_projEE_ampa[1371], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1372: cell 17, seg 0 (0.5) [0.5 on Epop[17]] -> cell 12, seg 0 (0.5) [0.5 on Epop[12]], weight: 4.1363508E-4, delay 1.5
        h("Epop[12] syn_projEE_ampa[1372] = new ampa(0.5)")
        h("Epop[17] netConn_projEE_ampa[1372] = new NetCon(&v(0.5), syn_projEE_ampa[1372], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1373: cell 17, seg 0 (0.5) [0.5 on Epop[17]] -> cell 13, seg 0 (0.5) [0.5 on Epop[13]], weight: 4.1363508E-4, delay 1.5
        h("Epop[13] syn_projEE_ampa[1373] = new ampa(0.5)")
        h("Epop[17] netConn_projEE_ampa[1373] = new NetCon(&v(0.5), syn_projEE_ampa[1373], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1374: cell 17, seg 0 (0.5) [0.5 on Epop[17]] -> cell 14, seg 0 (0.5) [0.5 on Epop[14]], weight: 4.1363508E-4, delay 1.5
        h("Epop[14] syn_projEE_ampa[1374] = new ampa(0.5)")
        h("Epop[17] netConn_projEE_ampa[1374] = new NetCon(&v(0.5), syn_projEE_ampa[1374], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1375: cell 17, seg 0 (0.5) [0.5 on Epop[17]] -> cell 15, seg 0 (0.5) [0.5 on Epop[15]], weight: 4.1363508E-4, delay 1.5
        h("Epop[15] syn_projEE_ampa[1375] = new ampa(0.5)")
        h("Epop[17] netConn_projEE_ampa[1375] = new NetCon(&v(0.5), syn_projEE_ampa[1375], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1376: cell 17, seg 0 (0.5) [0.5 on Epop[17]] -> cell 16, seg 0 (0.5) [0.5 on Epop[16]], weight: 4.1363508E-4, delay 1.5
        h("Epop[16] syn_projEE_ampa[1376] = new ampa(0.5)")
        h("Epop[17] netConn_projEE_ampa[1376] = new NetCon(&v(0.5), syn_projEE_ampa[1376], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1377: cell 17, seg 0 (0.5) [0.5 on Epop[17]] -> cell 17, seg 0 (0.5) [0.5 on Epop[17]], weight: 4.1363508E-4, delay 1.5
        h("Epop[17] syn_projEE_ampa[1377] = new ampa(0.5)")
        h("Epop[17] netConn_projEE_ampa[1377] = new NetCon(&v(0.5), syn_projEE_ampa[1377], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1378: cell 17, seg 0 (0.5) [0.5 on Epop[17]] -> cell 18, seg 0 (0.5) [0.5 on Epop[18]], weight: 4.1363508E-4, delay 1.5
        h("Epop[18] syn_projEE_ampa[1378] = new ampa(0.5)")
        h("Epop[17] netConn_projEE_ampa[1378] = new NetCon(&v(0.5), syn_projEE_ampa[1378], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1379: cell 17, seg 0 (0.5) [0.5 on Epop[17]] -> cell 19, seg 0 (0.5) [0.5 on Epop[19]], weight: 4.1363508E-4, delay 1.5
        h("Epop[19] syn_projEE_ampa[1379] = new ampa(0.5)")
        h("Epop[17] netConn_projEE_ampa[1379] = new NetCon(&v(0.5), syn_projEE_ampa[1379], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1380: cell 17, seg 0 (0.5) [0.5 on Epop[17]] -> cell 20, seg 0 (0.5) [0.5 on Epop[20]], weight: 4.1363508E-4, delay 1.5
        h("Epop[20] syn_projEE_ampa[1380] = new ampa(0.5)")
        h("Epop[17] netConn_projEE_ampa[1380] = new NetCon(&v(0.5), syn_projEE_ampa[1380], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1381: cell 17, seg 0 (0.5) [0.5 on Epop[17]] -> cell 21, seg 0 (0.5) [0.5 on Epop[21]], weight: 4.1363508E-4, delay 1.5
        h("Epop[21] syn_projEE_ampa[1381] = new ampa(0.5)")
        h("Epop[17] netConn_projEE_ampa[1381] = new NetCon(&v(0.5), syn_projEE_ampa[1381], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1382: cell 17, seg 0 (0.5) [0.5 on Epop[17]] -> cell 22, seg 0 (0.5) [0.5 on Epop[22]], weight: 4.1363508E-4, delay 1.5
        h("Epop[22] syn_projEE_ampa[1382] = new ampa(0.5)")
        h("Epop[17] netConn_projEE_ampa[1382] = new NetCon(&v(0.5), syn_projEE_ampa[1382], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1383: cell 17, seg 0 (0.5) [0.5 on Epop[17]] -> cell 23, seg 0 (0.5) [0.5 on Epop[23]], weight: 4.1363508E-4, delay 1.5
        h("Epop[23] syn_projEE_ampa[1383] = new ampa(0.5)")
        h("Epop[17] netConn_projEE_ampa[1383] = new NetCon(&v(0.5), syn_projEE_ampa[1383], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1384: cell 17, seg 0 (0.5) [0.5 on Epop[17]] -> cell 24, seg 0 (0.5) [0.5 on Epop[24]], weight: 4.1363508E-4, delay 1.5
        h("Epop[24] syn_projEE_ampa[1384] = new ampa(0.5)")
        h("Epop[17] netConn_projEE_ampa[1384] = new NetCon(&v(0.5), syn_projEE_ampa[1384], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1385: cell 17, seg 0 (0.5) [0.5 on Epop[17]] -> cell 25, seg 0 (0.5) [0.5 on Epop[25]], weight: 4.1363508E-4, delay 1.5
        h("Epop[25] syn_projEE_ampa[1385] = new ampa(0.5)")
        h("Epop[17] netConn_projEE_ampa[1385] = new NetCon(&v(0.5), syn_projEE_ampa[1385], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1386: cell 17, seg 0 (0.5) [0.5 on Epop[17]] -> cell 26, seg 0 (0.5) [0.5 on Epop[26]], weight: 4.1363508E-4, delay 1.5
        h("Epop[26] syn_projEE_ampa[1386] = new ampa(0.5)")
        h("Epop[17] netConn_projEE_ampa[1386] = new NetCon(&v(0.5), syn_projEE_ampa[1386], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1387: cell 17, seg 0 (0.5) [0.5 on Epop[17]] -> cell 27, seg 0 (0.5) [0.5 on Epop[27]], weight: 4.1363508E-4, delay 1.5
        h("Epop[27] syn_projEE_ampa[1387] = new ampa(0.5)")
        h("Epop[17] netConn_projEE_ampa[1387] = new NetCon(&v(0.5), syn_projEE_ampa[1387], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1388: cell 17, seg 0 (0.5) [0.5 on Epop[17]] -> cell 28, seg 0 (0.5) [0.5 on Epop[28]], weight: 4.1363508E-4, delay 1.5
        h("Epop[28] syn_projEE_ampa[1388] = new ampa(0.5)")
        h("Epop[17] netConn_projEE_ampa[1388] = new NetCon(&v(0.5), syn_projEE_ampa[1388], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1389: cell 17, seg 0 (0.5) [0.5 on Epop[17]] -> cell 29, seg 0 (0.5) [0.5 on Epop[29]], weight: 4.1363508E-4, delay 1.5
        h("Epop[29] syn_projEE_ampa[1389] = new ampa(0.5)")
        h("Epop[17] netConn_projEE_ampa[1389] = new NetCon(&v(0.5), syn_projEE_ampa[1389], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1390: cell 17, seg 0 (0.5) [0.5 on Epop[17]] -> cell 30, seg 0 (0.5) [0.5 on Epop[30]], weight: 4.1363508E-4, delay 1.5
        h("Epop[30] syn_projEE_ampa[1390] = new ampa(0.5)")
        h("Epop[17] netConn_projEE_ampa[1390] = new NetCon(&v(0.5), syn_projEE_ampa[1390], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1391: cell 17, seg 0 (0.5) [0.5 on Epop[17]] -> cell 31, seg 0 (0.5) [0.5 on Epop[31]], weight: 4.1363508E-4, delay 1.5
        h("Epop[31] syn_projEE_ampa[1391] = new ampa(0.5)")
        h("Epop[17] netConn_projEE_ampa[1391] = new NetCon(&v(0.5), syn_projEE_ampa[1391], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1392: cell 17, seg 0 (0.5) [0.5 on Epop[17]] -> cell 32, seg 0 (0.5) [0.5 on Epop[32]], weight: 4.1363508E-4, delay 1.5
        h("Epop[32] syn_projEE_ampa[1392] = new ampa(0.5)")
        h("Epop[17] netConn_projEE_ampa[1392] = new NetCon(&v(0.5), syn_projEE_ampa[1392], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1393: cell 17, seg 0 (0.5) [0.5 on Epop[17]] -> cell 33, seg 0 (0.5) [0.5 on Epop[33]], weight: 4.1363508E-4, delay 1.5
        h("Epop[33] syn_projEE_ampa[1393] = new ampa(0.5)")
        h("Epop[17] netConn_projEE_ampa[1393] = new NetCon(&v(0.5), syn_projEE_ampa[1393], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1394: cell 17, seg 0 (0.5) [0.5 on Epop[17]] -> cell 34, seg 0 (0.5) [0.5 on Epop[34]], weight: 4.1363508E-4, delay 1.5
        h("Epop[34] syn_projEE_ampa[1394] = new ampa(0.5)")
        h("Epop[17] netConn_projEE_ampa[1394] = new NetCon(&v(0.5), syn_projEE_ampa[1394], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1395: cell 17, seg 0 (0.5) [0.5 on Epop[17]] -> cell 35, seg 0 (0.5) [0.5 on Epop[35]], weight: 4.1363508E-4, delay 1.5
        h("Epop[35] syn_projEE_ampa[1395] = new ampa(0.5)")
        h("Epop[17] netConn_projEE_ampa[1395] = new NetCon(&v(0.5), syn_projEE_ampa[1395], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1396: cell 17, seg 0 (0.5) [0.5 on Epop[17]] -> cell 36, seg 0 (0.5) [0.5 on Epop[36]], weight: 4.1363508E-4, delay 1.5
        h("Epop[36] syn_projEE_ampa[1396] = new ampa(0.5)")
        h("Epop[17] netConn_projEE_ampa[1396] = new NetCon(&v(0.5), syn_projEE_ampa[1396], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1397: cell 17, seg 0 (0.5) [0.5 on Epop[17]] -> cell 37, seg 0 (0.5) [0.5 on Epop[37]], weight: 4.1363508E-4, delay 1.5
        h("Epop[37] syn_projEE_ampa[1397] = new ampa(0.5)")
        h("Epop[17] netConn_projEE_ampa[1397] = new NetCon(&v(0.5), syn_projEE_ampa[1397], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1398: cell 17, seg 0 (0.5) [0.5 on Epop[17]] -> cell 38, seg 0 (0.5) [0.5 on Epop[38]], weight: 4.1363508E-4, delay 1.5
        h("Epop[38] syn_projEE_ampa[1398] = new ampa(0.5)")
        h("Epop[17] netConn_projEE_ampa[1398] = new NetCon(&v(0.5), syn_projEE_ampa[1398], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1399: cell 17, seg 0 (0.5) [0.5 on Epop[17]] -> cell 39, seg 0 (0.5) [0.5 on Epop[39]], weight: 4.1363508E-4, delay 1.5
        h("Epop[39] syn_projEE_ampa[1399] = new ampa(0.5)")
        h("Epop[17] netConn_projEE_ampa[1399] = new NetCon(&v(0.5), syn_projEE_ampa[1399], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1400: cell 17, seg 0 (0.5) [0.5 on Epop[17]] -> cell 40, seg 0 (0.5) [0.5 on Epop[40]], weight: 4.1363508E-4, delay 1.5
        h("Epop[40] syn_projEE_ampa[1400] = new ampa(0.5)")
        h("Epop[17] netConn_projEE_ampa[1400] = new NetCon(&v(0.5), syn_projEE_ampa[1400], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1401: cell 17, seg 0 (0.5) [0.5 on Epop[17]] -> cell 41, seg 0 (0.5) [0.5 on Epop[41]], weight: 4.1363508E-4, delay 1.5
        h("Epop[41] syn_projEE_ampa[1401] = new ampa(0.5)")
        h("Epop[17] netConn_projEE_ampa[1401] = new NetCon(&v(0.5), syn_projEE_ampa[1401], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1402: cell 17, seg 0 (0.5) [0.5 on Epop[17]] -> cell 42, seg 0 (0.5) [0.5 on Epop[42]], weight: 4.1363508E-4, delay 1.5
        h("Epop[42] syn_projEE_ampa[1402] = new ampa(0.5)")
        h("Epop[17] netConn_projEE_ampa[1402] = new NetCon(&v(0.5), syn_projEE_ampa[1402], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1403: cell 17, seg 0 (0.5) [0.5 on Epop[17]] -> cell 43, seg 0 (0.5) [0.5 on Epop[43]], weight: 4.1363508E-4, delay 1.5
        h("Epop[43] syn_projEE_ampa[1403] = new ampa(0.5)")
        h("Epop[17] netConn_projEE_ampa[1403] = new NetCon(&v(0.5), syn_projEE_ampa[1403], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1404: cell 17, seg 0 (0.5) [0.5 on Epop[17]] -> cell 44, seg 0 (0.5) [0.5 on Epop[44]], weight: 4.1363508E-4, delay 1.5
        h("Epop[44] syn_projEE_ampa[1404] = new ampa(0.5)")
        h("Epop[17] netConn_projEE_ampa[1404] = new NetCon(&v(0.5), syn_projEE_ampa[1404], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1405: cell 17, seg 0 (0.5) [0.5 on Epop[17]] -> cell 45, seg 0 (0.5) [0.5 on Epop[45]], weight: 4.1363508E-4, delay 1.5
        h("Epop[45] syn_projEE_ampa[1405] = new ampa(0.5)")
        h("Epop[17] netConn_projEE_ampa[1405] = new NetCon(&v(0.5), syn_projEE_ampa[1405], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1406: cell 17, seg 0 (0.5) [0.5 on Epop[17]] -> cell 46, seg 0 (0.5) [0.5 on Epop[46]], weight: 4.1363508E-4, delay 1.5
        h("Epop[46] syn_projEE_ampa[1406] = new ampa(0.5)")
        h("Epop[17] netConn_projEE_ampa[1406] = new NetCon(&v(0.5), syn_projEE_ampa[1406], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1407: cell 17, seg 0 (0.5) [0.5 on Epop[17]] -> cell 47, seg 0 (0.5) [0.5 on Epop[47]], weight: 4.1363508E-4, delay 1.5
        h("Epop[47] syn_projEE_ampa[1407] = new ampa(0.5)")
        h("Epop[17] netConn_projEE_ampa[1407] = new NetCon(&v(0.5), syn_projEE_ampa[1407], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1408: cell 17, seg 0 (0.5) [0.5 on Epop[17]] -> cell 48, seg 0 (0.5) [0.5 on Epop[48]], weight: 4.1363508E-4, delay 1.5
        h("Epop[48] syn_projEE_ampa[1408] = new ampa(0.5)")
        h("Epop[17] netConn_projEE_ampa[1408] = new NetCon(&v(0.5), syn_projEE_ampa[1408], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1409: cell 17, seg 0 (0.5) [0.5 on Epop[17]] -> cell 49, seg 0 (0.5) [0.5 on Epop[49]], weight: 4.1363508E-4, delay 1.5
        h("Epop[49] syn_projEE_ampa[1409] = new ampa(0.5)")
        h("Epop[17] netConn_projEE_ampa[1409] = new NetCon(&v(0.5), syn_projEE_ampa[1409], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1410: cell 17, seg 0 (0.5) [0.5 on Epop[17]] -> cell 50, seg 0 (0.5) [0.5 on Epop[50]], weight: 4.1363508E-4, delay 1.5
        h("Epop[50] syn_projEE_ampa[1410] = new ampa(0.5)")
        h("Epop[17] netConn_projEE_ampa[1410] = new NetCon(&v(0.5), syn_projEE_ampa[1410], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1411: cell 17, seg 0 (0.5) [0.5 on Epop[17]] -> cell 51, seg 0 (0.5) [0.5 on Epop[51]], weight: 4.1363508E-4, delay 1.5
        h("Epop[51] syn_projEE_ampa[1411] = new ampa(0.5)")
        h("Epop[17] netConn_projEE_ampa[1411] = new NetCon(&v(0.5), syn_projEE_ampa[1411], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1412: cell 17, seg 0 (0.5) [0.5 on Epop[17]] -> cell 52, seg 0 (0.5) [0.5 on Epop[52]], weight: 4.1363508E-4, delay 1.5
        h("Epop[52] syn_projEE_ampa[1412] = new ampa(0.5)")
        h("Epop[17] netConn_projEE_ampa[1412] = new NetCon(&v(0.5), syn_projEE_ampa[1412], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1413: cell 17, seg 0 (0.5) [0.5 on Epop[17]] -> cell 53, seg 0 (0.5) [0.5 on Epop[53]], weight: 4.1363508E-4, delay 1.5
        h("Epop[53] syn_projEE_ampa[1413] = new ampa(0.5)")
        h("Epop[17] netConn_projEE_ampa[1413] = new NetCon(&v(0.5), syn_projEE_ampa[1413], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1414: cell 17, seg 0 (0.5) [0.5 on Epop[17]] -> cell 54, seg 0 (0.5) [0.5 on Epop[54]], weight: 4.1363508E-4, delay 1.5
        h("Epop[54] syn_projEE_ampa[1414] = new ampa(0.5)")
        h("Epop[17] netConn_projEE_ampa[1414] = new NetCon(&v(0.5), syn_projEE_ampa[1414], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1415: cell 17, seg 0 (0.5) [0.5 on Epop[17]] -> cell 55, seg 0 (0.5) [0.5 on Epop[55]], weight: 4.1363508E-4, delay 1.5
        h("Epop[55] syn_projEE_ampa[1415] = new ampa(0.5)")
        h("Epop[17] netConn_projEE_ampa[1415] = new NetCon(&v(0.5), syn_projEE_ampa[1415], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1416: cell 17, seg 0 (0.5) [0.5 on Epop[17]] -> cell 56, seg 0 (0.5) [0.5 on Epop[56]], weight: 4.1363508E-4, delay 1.5
        h("Epop[56] syn_projEE_ampa[1416] = new ampa(0.5)")
        h("Epop[17] netConn_projEE_ampa[1416] = new NetCon(&v(0.5), syn_projEE_ampa[1416], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1417: cell 17, seg 0 (0.5) [0.5 on Epop[17]] -> cell 57, seg 0 (0.5) [0.5 on Epop[57]], weight: 4.1363508E-4, delay 1.5
        h("Epop[57] syn_projEE_ampa[1417] = new ampa(0.5)")
        h("Epop[17] netConn_projEE_ampa[1417] = new NetCon(&v(0.5), syn_projEE_ampa[1417], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1418: cell 17, seg 0 (0.5) [0.5 on Epop[17]] -> cell 58, seg 0 (0.5) [0.5 on Epop[58]], weight: 4.1363508E-4, delay 1.5
        h("Epop[58] syn_projEE_ampa[1418] = new ampa(0.5)")
        h("Epop[17] netConn_projEE_ampa[1418] = new NetCon(&v(0.5), syn_projEE_ampa[1418], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1419: cell 17, seg 0 (0.5) [0.5 on Epop[17]] -> cell 59, seg 0 (0.5) [0.5 on Epop[59]], weight: 4.1363508E-4, delay 1.5
        h("Epop[59] syn_projEE_ampa[1419] = new ampa(0.5)")
        h("Epop[17] netConn_projEE_ampa[1419] = new NetCon(&v(0.5), syn_projEE_ampa[1419], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1420: cell 17, seg 0 (0.5) [0.5 on Epop[17]] -> cell 60, seg 0 (0.5) [0.5 on Epop[60]], weight: 4.1363508E-4, delay 1.5
        h("Epop[60] syn_projEE_ampa[1420] = new ampa(0.5)")
        h("Epop[17] netConn_projEE_ampa[1420] = new NetCon(&v(0.5), syn_projEE_ampa[1420], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1421: cell 17, seg 0 (0.5) [0.5 on Epop[17]] -> cell 61, seg 0 (0.5) [0.5 on Epop[61]], weight: 4.1363508E-4, delay 1.5
        h("Epop[61] syn_projEE_ampa[1421] = new ampa(0.5)")
        h("Epop[17] netConn_projEE_ampa[1421] = new NetCon(&v(0.5), syn_projEE_ampa[1421], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1422: cell 17, seg 0 (0.5) [0.5 on Epop[17]] -> cell 62, seg 0 (0.5) [0.5 on Epop[62]], weight: 4.1363508E-4, delay 1.5
        h("Epop[62] syn_projEE_ampa[1422] = new ampa(0.5)")
        h("Epop[17] netConn_projEE_ampa[1422] = new NetCon(&v(0.5), syn_projEE_ampa[1422], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1423: cell 17, seg 0 (0.5) [0.5 on Epop[17]] -> cell 63, seg 0 (0.5) [0.5 on Epop[63]], weight: 4.1363508E-4, delay 1.5
        h("Epop[63] syn_projEE_ampa[1423] = new ampa(0.5)")
        h("Epop[17] netConn_projEE_ampa[1423] = new NetCon(&v(0.5), syn_projEE_ampa[1423], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1424: cell 17, seg 0 (0.5) [0.5 on Epop[17]] -> cell 64, seg 0 (0.5) [0.5 on Epop[64]], weight: 4.1363508E-4, delay 1.5
        h("Epop[64] syn_projEE_ampa[1424] = new ampa(0.5)")
        h("Epop[17] netConn_projEE_ampa[1424] = new NetCon(&v(0.5), syn_projEE_ampa[1424], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1425: cell 17, seg 0 (0.5) [0.5 on Epop[17]] -> cell 65, seg 0 (0.5) [0.5 on Epop[65]], weight: 4.1363508E-4, delay 1.5
        h("Epop[65] syn_projEE_ampa[1425] = new ampa(0.5)")
        h("Epop[17] netConn_projEE_ampa[1425] = new NetCon(&v(0.5), syn_projEE_ampa[1425], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1426: cell 17, seg 0 (0.5) [0.5 on Epop[17]] -> cell 66, seg 0 (0.5) [0.5 on Epop[66]], weight: 4.1363508E-4, delay 1.5
        h("Epop[66] syn_projEE_ampa[1426] = new ampa(0.5)")
        h("Epop[17] netConn_projEE_ampa[1426] = new NetCon(&v(0.5), syn_projEE_ampa[1426], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1427: cell 17, seg 0 (0.5) [0.5 on Epop[17]] -> cell 67, seg 0 (0.5) [0.5 on Epop[67]], weight: 4.1363508E-4, delay 1.5
        h("Epop[67] syn_projEE_ampa[1427] = new ampa(0.5)")
        h("Epop[17] netConn_projEE_ampa[1427] = new NetCon(&v(0.5), syn_projEE_ampa[1427], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1428: cell 17, seg 0 (0.5) [0.5 on Epop[17]] -> cell 68, seg 0 (0.5) [0.5 on Epop[68]], weight: 4.1363508E-4, delay 1.5
        h("Epop[68] syn_projEE_ampa[1428] = new ampa(0.5)")
        h("Epop[17] netConn_projEE_ampa[1428] = new NetCon(&v(0.5), syn_projEE_ampa[1428], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1429: cell 17, seg 0 (0.5) [0.5 on Epop[17]] -> cell 69, seg 0 (0.5) [0.5 on Epop[69]], weight: 4.1363508E-4, delay 1.5
        h("Epop[69] syn_projEE_ampa[1429] = new ampa(0.5)")
        h("Epop[17] netConn_projEE_ampa[1429] = new NetCon(&v(0.5), syn_projEE_ampa[1429], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1430: cell 17, seg 0 (0.5) [0.5 on Epop[17]] -> cell 70, seg 0 (0.5) [0.5 on Epop[70]], weight: 4.1363508E-4, delay 1.5
        h("Epop[70] syn_projEE_ampa[1430] = new ampa(0.5)")
        h("Epop[17] netConn_projEE_ampa[1430] = new NetCon(&v(0.5), syn_projEE_ampa[1430], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1431: cell 17, seg 0 (0.5) [0.5 on Epop[17]] -> cell 71, seg 0 (0.5) [0.5 on Epop[71]], weight: 4.1363508E-4, delay 1.5
        h("Epop[71] syn_projEE_ampa[1431] = new ampa(0.5)")
        h("Epop[17] netConn_projEE_ampa[1431] = new NetCon(&v(0.5), syn_projEE_ampa[1431], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1432: cell 17, seg 0 (0.5) [0.5 on Epop[17]] -> cell 72, seg 0 (0.5) [0.5 on Epop[72]], weight: 4.1363508E-4, delay 1.5
        h("Epop[72] syn_projEE_ampa[1432] = new ampa(0.5)")
        h("Epop[17] netConn_projEE_ampa[1432] = new NetCon(&v(0.5), syn_projEE_ampa[1432], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1433: cell 17, seg 0 (0.5) [0.5 on Epop[17]] -> cell 73, seg 0 (0.5) [0.5 on Epop[73]], weight: 4.1363508E-4, delay 1.5
        h("Epop[73] syn_projEE_ampa[1433] = new ampa(0.5)")
        h("Epop[17] netConn_projEE_ampa[1433] = new NetCon(&v(0.5), syn_projEE_ampa[1433], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1434: cell 17, seg 0 (0.5) [0.5 on Epop[17]] -> cell 74, seg 0 (0.5) [0.5 on Epop[74]], weight: 4.1363508E-4, delay 1.5
        h("Epop[74] syn_projEE_ampa[1434] = new ampa(0.5)")
        h("Epop[17] netConn_projEE_ampa[1434] = new NetCon(&v(0.5), syn_projEE_ampa[1434], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1435: cell 17, seg 0 (0.5) [0.5 on Epop[17]] -> cell 75, seg 0 (0.5) [0.5 on Epop[75]], weight: 4.1363508E-4, delay 1.5
        h("Epop[75] syn_projEE_ampa[1435] = new ampa(0.5)")
        h("Epop[17] netConn_projEE_ampa[1435] = new NetCon(&v(0.5), syn_projEE_ampa[1435], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1436: cell 17, seg 0 (0.5) [0.5 on Epop[17]] -> cell 76, seg 0 (0.5) [0.5 on Epop[76]], weight: 4.1363508E-4, delay 1.5
        h("Epop[76] syn_projEE_ampa[1436] = new ampa(0.5)")
        h("Epop[17] netConn_projEE_ampa[1436] = new NetCon(&v(0.5), syn_projEE_ampa[1436], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1437: cell 17, seg 0 (0.5) [0.5 on Epop[17]] -> cell 77, seg 0 (0.5) [0.5 on Epop[77]], weight: 4.1363508E-4, delay 1.5
        h("Epop[77] syn_projEE_ampa[1437] = new ampa(0.5)")
        h("Epop[17] netConn_projEE_ampa[1437] = new NetCon(&v(0.5), syn_projEE_ampa[1437], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1438: cell 17, seg 0 (0.5) [0.5 on Epop[17]] -> cell 78, seg 0 (0.5) [0.5 on Epop[78]], weight: 4.1363508E-4, delay 1.5
        h("Epop[78] syn_projEE_ampa[1438] = new ampa(0.5)")
        h("Epop[17] netConn_projEE_ampa[1438] = new NetCon(&v(0.5), syn_projEE_ampa[1438], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1439: cell 17, seg 0 (0.5) [0.5 on Epop[17]] -> cell 79, seg 0 (0.5) [0.5 on Epop[79]], weight: 4.1363508E-4, delay 1.5
        h("Epop[79] syn_projEE_ampa[1439] = new ampa(0.5)")
        h("Epop[17] netConn_projEE_ampa[1439] = new NetCon(&v(0.5), syn_projEE_ampa[1439], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1440: cell 18, seg 0 (0.5) [0.5 on Epop[18]] -> cell 0, seg 0 (0.5) [0.5 on Epop[0]], weight: 4.1363508E-4, delay 1.5
        h("Epop[0] syn_projEE_ampa[1440] = new ampa(0.5)")
        h("Epop[18] netConn_projEE_ampa[1440] = new NetCon(&v(0.5), syn_projEE_ampa[1440], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1441: cell 18, seg 0 (0.5) [0.5 on Epop[18]] -> cell 1, seg 0 (0.5) [0.5 on Epop[1]], weight: 4.1363508E-4, delay 1.5
        h("Epop[1] syn_projEE_ampa[1441] = new ampa(0.5)")
        h("Epop[18] netConn_projEE_ampa[1441] = new NetCon(&v(0.5), syn_projEE_ampa[1441], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1442: cell 18, seg 0 (0.5) [0.5 on Epop[18]] -> cell 2, seg 0 (0.5) [0.5 on Epop[2]], weight: 4.1363508E-4, delay 1.5
        h("Epop[2] syn_projEE_ampa[1442] = new ampa(0.5)")
        h("Epop[18] netConn_projEE_ampa[1442] = new NetCon(&v(0.5), syn_projEE_ampa[1442], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1443: cell 18, seg 0 (0.5) [0.5 on Epop[18]] -> cell 3, seg 0 (0.5) [0.5 on Epop[3]], weight: 4.1363508E-4, delay 1.5
        h("Epop[3] syn_projEE_ampa[1443] = new ampa(0.5)")
        h("Epop[18] netConn_projEE_ampa[1443] = new NetCon(&v(0.5), syn_projEE_ampa[1443], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1444: cell 18, seg 0 (0.5) [0.5 on Epop[18]] -> cell 4, seg 0 (0.5) [0.5 on Epop[4]], weight: 4.1363508E-4, delay 1.5
        h("Epop[4] syn_projEE_ampa[1444] = new ampa(0.5)")
        h("Epop[18] netConn_projEE_ampa[1444] = new NetCon(&v(0.5), syn_projEE_ampa[1444], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1445: cell 18, seg 0 (0.5) [0.5 on Epop[18]] -> cell 5, seg 0 (0.5) [0.5 on Epop[5]], weight: 4.1363508E-4, delay 1.5
        h("Epop[5] syn_projEE_ampa[1445] = new ampa(0.5)")
        h("Epop[18] netConn_projEE_ampa[1445] = new NetCon(&v(0.5), syn_projEE_ampa[1445], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1446: cell 18, seg 0 (0.5) [0.5 on Epop[18]] -> cell 6, seg 0 (0.5) [0.5 on Epop[6]], weight: 4.1363508E-4, delay 1.5
        h("Epop[6] syn_projEE_ampa[1446] = new ampa(0.5)")
        h("Epop[18] netConn_projEE_ampa[1446] = new NetCon(&v(0.5), syn_projEE_ampa[1446], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1447: cell 18, seg 0 (0.5) [0.5 on Epop[18]] -> cell 7, seg 0 (0.5) [0.5 on Epop[7]], weight: 4.1363508E-4, delay 1.5
        h("Epop[7] syn_projEE_ampa[1447] = new ampa(0.5)")
        h("Epop[18] netConn_projEE_ampa[1447] = new NetCon(&v(0.5), syn_projEE_ampa[1447], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1448: cell 18, seg 0 (0.5) [0.5 on Epop[18]] -> cell 8, seg 0 (0.5) [0.5 on Epop[8]], weight: 4.1363508E-4, delay 1.5
        h("Epop[8] syn_projEE_ampa[1448] = new ampa(0.5)")
        h("Epop[18] netConn_projEE_ampa[1448] = new NetCon(&v(0.5), syn_projEE_ampa[1448], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1449: cell 18, seg 0 (0.5) [0.5 on Epop[18]] -> cell 9, seg 0 (0.5) [0.5 on Epop[9]], weight: 4.1363508E-4, delay 1.5
        h("Epop[9] syn_projEE_ampa[1449] = new ampa(0.5)")
        h("Epop[18] netConn_projEE_ampa[1449] = new NetCon(&v(0.5), syn_projEE_ampa[1449], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1450: cell 18, seg 0 (0.5) [0.5 on Epop[18]] -> cell 10, seg 0 (0.5) [0.5 on Epop[10]], weight: 4.1363508E-4, delay 1.5
        h("Epop[10] syn_projEE_ampa[1450] = new ampa(0.5)")
        h("Epop[18] netConn_projEE_ampa[1450] = new NetCon(&v(0.5), syn_projEE_ampa[1450], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1451: cell 18, seg 0 (0.5) [0.5 on Epop[18]] -> cell 11, seg 0 (0.5) [0.5 on Epop[11]], weight: 4.1363508E-4, delay 1.5
        h("Epop[11] syn_projEE_ampa[1451] = new ampa(0.5)")
        h("Epop[18] netConn_projEE_ampa[1451] = new NetCon(&v(0.5), syn_projEE_ampa[1451], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1452: cell 18, seg 0 (0.5) [0.5 on Epop[18]] -> cell 12, seg 0 (0.5) [0.5 on Epop[12]], weight: 4.1363508E-4, delay 1.5
        h("Epop[12] syn_projEE_ampa[1452] = new ampa(0.5)")
        h("Epop[18] netConn_projEE_ampa[1452] = new NetCon(&v(0.5), syn_projEE_ampa[1452], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1453: cell 18, seg 0 (0.5) [0.5 on Epop[18]] -> cell 13, seg 0 (0.5) [0.5 on Epop[13]], weight: 4.1363508E-4, delay 1.5
        h("Epop[13] syn_projEE_ampa[1453] = new ampa(0.5)")
        h("Epop[18] netConn_projEE_ampa[1453] = new NetCon(&v(0.5), syn_projEE_ampa[1453], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1454: cell 18, seg 0 (0.5) [0.5 on Epop[18]] -> cell 14, seg 0 (0.5) [0.5 on Epop[14]], weight: 4.1363508E-4, delay 1.5
        h("Epop[14] syn_projEE_ampa[1454] = new ampa(0.5)")
        h("Epop[18] netConn_projEE_ampa[1454] = new NetCon(&v(0.5), syn_projEE_ampa[1454], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1455: cell 18, seg 0 (0.5) [0.5 on Epop[18]] -> cell 15, seg 0 (0.5) [0.5 on Epop[15]], weight: 4.1363508E-4, delay 1.5
        h("Epop[15] syn_projEE_ampa[1455] = new ampa(0.5)")
        h("Epop[18] netConn_projEE_ampa[1455] = new NetCon(&v(0.5), syn_projEE_ampa[1455], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1456: cell 18, seg 0 (0.5) [0.5 on Epop[18]] -> cell 16, seg 0 (0.5) [0.5 on Epop[16]], weight: 4.1363508E-4, delay 1.5
        h("Epop[16] syn_projEE_ampa[1456] = new ampa(0.5)")
        h("Epop[18] netConn_projEE_ampa[1456] = new NetCon(&v(0.5), syn_projEE_ampa[1456], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1457: cell 18, seg 0 (0.5) [0.5 on Epop[18]] -> cell 17, seg 0 (0.5) [0.5 on Epop[17]], weight: 4.1363508E-4, delay 1.5
        h("Epop[17] syn_projEE_ampa[1457] = new ampa(0.5)")
        h("Epop[18] netConn_projEE_ampa[1457] = new NetCon(&v(0.5), syn_projEE_ampa[1457], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1458: cell 18, seg 0 (0.5) [0.5 on Epop[18]] -> cell 18, seg 0 (0.5) [0.5 on Epop[18]], weight: 4.1363508E-4, delay 1.5
        h("Epop[18] syn_projEE_ampa[1458] = new ampa(0.5)")
        h("Epop[18] netConn_projEE_ampa[1458] = new NetCon(&v(0.5), syn_projEE_ampa[1458], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1459: cell 18, seg 0 (0.5) [0.5 on Epop[18]] -> cell 19, seg 0 (0.5) [0.5 on Epop[19]], weight: 4.1363508E-4, delay 1.5
        h("Epop[19] syn_projEE_ampa[1459] = new ampa(0.5)")
        h("Epop[18] netConn_projEE_ampa[1459] = new NetCon(&v(0.5), syn_projEE_ampa[1459], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1460: cell 18, seg 0 (0.5) [0.5 on Epop[18]] -> cell 20, seg 0 (0.5) [0.5 on Epop[20]], weight: 4.1363508E-4, delay 1.5
        h("Epop[20] syn_projEE_ampa[1460] = new ampa(0.5)")
        h("Epop[18] netConn_projEE_ampa[1460] = new NetCon(&v(0.5), syn_projEE_ampa[1460], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1461: cell 18, seg 0 (0.5) [0.5 on Epop[18]] -> cell 21, seg 0 (0.5) [0.5 on Epop[21]], weight: 4.1363508E-4, delay 1.5
        h("Epop[21] syn_projEE_ampa[1461] = new ampa(0.5)")
        h("Epop[18] netConn_projEE_ampa[1461] = new NetCon(&v(0.5), syn_projEE_ampa[1461], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1462: cell 18, seg 0 (0.5) [0.5 on Epop[18]] -> cell 22, seg 0 (0.5) [0.5 on Epop[22]], weight: 4.1363508E-4, delay 1.5
        h("Epop[22] syn_projEE_ampa[1462] = new ampa(0.5)")
        h("Epop[18] netConn_projEE_ampa[1462] = new NetCon(&v(0.5), syn_projEE_ampa[1462], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1463: cell 18, seg 0 (0.5) [0.5 on Epop[18]] -> cell 23, seg 0 (0.5) [0.5 on Epop[23]], weight: 4.1363508E-4, delay 1.5
        h("Epop[23] syn_projEE_ampa[1463] = new ampa(0.5)")
        h("Epop[18] netConn_projEE_ampa[1463] = new NetCon(&v(0.5), syn_projEE_ampa[1463], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1464: cell 18, seg 0 (0.5) [0.5 on Epop[18]] -> cell 24, seg 0 (0.5) [0.5 on Epop[24]], weight: 4.1363508E-4, delay 1.5
        h("Epop[24] syn_projEE_ampa[1464] = new ampa(0.5)")
        h("Epop[18] netConn_projEE_ampa[1464] = new NetCon(&v(0.5), syn_projEE_ampa[1464], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1465: cell 18, seg 0 (0.5) [0.5 on Epop[18]] -> cell 25, seg 0 (0.5) [0.5 on Epop[25]], weight: 4.1363508E-4, delay 1.5
        h("Epop[25] syn_projEE_ampa[1465] = new ampa(0.5)")
        h("Epop[18] netConn_projEE_ampa[1465] = new NetCon(&v(0.5), syn_projEE_ampa[1465], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1466: cell 18, seg 0 (0.5) [0.5 on Epop[18]] -> cell 26, seg 0 (0.5) [0.5 on Epop[26]], weight: 4.1363508E-4, delay 1.5
        h("Epop[26] syn_projEE_ampa[1466] = new ampa(0.5)")
        h("Epop[18] netConn_projEE_ampa[1466] = new NetCon(&v(0.5), syn_projEE_ampa[1466], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1467: cell 18, seg 0 (0.5) [0.5 on Epop[18]] -> cell 27, seg 0 (0.5) [0.5 on Epop[27]], weight: 4.1363508E-4, delay 1.5
        h("Epop[27] syn_projEE_ampa[1467] = new ampa(0.5)")
        h("Epop[18] netConn_projEE_ampa[1467] = new NetCon(&v(0.5), syn_projEE_ampa[1467], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1468: cell 18, seg 0 (0.5) [0.5 on Epop[18]] -> cell 28, seg 0 (0.5) [0.5 on Epop[28]], weight: 4.1363508E-4, delay 1.5
        h("Epop[28] syn_projEE_ampa[1468] = new ampa(0.5)")
        h("Epop[18] netConn_projEE_ampa[1468] = new NetCon(&v(0.5), syn_projEE_ampa[1468], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1469: cell 18, seg 0 (0.5) [0.5 on Epop[18]] -> cell 29, seg 0 (0.5) [0.5 on Epop[29]], weight: 4.1363508E-4, delay 1.5
        h("Epop[29] syn_projEE_ampa[1469] = new ampa(0.5)")
        h("Epop[18] netConn_projEE_ampa[1469] = new NetCon(&v(0.5), syn_projEE_ampa[1469], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1470: cell 18, seg 0 (0.5) [0.5 on Epop[18]] -> cell 30, seg 0 (0.5) [0.5 on Epop[30]], weight: 4.1363508E-4, delay 1.5
        h("Epop[30] syn_projEE_ampa[1470] = new ampa(0.5)")
        h("Epop[18] netConn_projEE_ampa[1470] = new NetCon(&v(0.5), syn_projEE_ampa[1470], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1471: cell 18, seg 0 (0.5) [0.5 on Epop[18]] -> cell 31, seg 0 (0.5) [0.5 on Epop[31]], weight: 4.1363508E-4, delay 1.5
        h("Epop[31] syn_projEE_ampa[1471] = new ampa(0.5)")
        h("Epop[18] netConn_projEE_ampa[1471] = new NetCon(&v(0.5), syn_projEE_ampa[1471], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1472: cell 18, seg 0 (0.5) [0.5 on Epop[18]] -> cell 32, seg 0 (0.5) [0.5 on Epop[32]], weight: 4.1363508E-4, delay 1.5
        h("Epop[32] syn_projEE_ampa[1472] = new ampa(0.5)")
        h("Epop[18] netConn_projEE_ampa[1472] = new NetCon(&v(0.5), syn_projEE_ampa[1472], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1473: cell 18, seg 0 (0.5) [0.5 on Epop[18]] -> cell 33, seg 0 (0.5) [0.5 on Epop[33]], weight: 4.1363508E-4, delay 1.5
        h("Epop[33] syn_projEE_ampa[1473] = new ampa(0.5)")
        h("Epop[18] netConn_projEE_ampa[1473] = new NetCon(&v(0.5), syn_projEE_ampa[1473], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1474: cell 18, seg 0 (0.5) [0.5 on Epop[18]] -> cell 34, seg 0 (0.5) [0.5 on Epop[34]], weight: 4.1363508E-4, delay 1.5
        h("Epop[34] syn_projEE_ampa[1474] = new ampa(0.5)")
        h("Epop[18] netConn_projEE_ampa[1474] = new NetCon(&v(0.5), syn_projEE_ampa[1474], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1475: cell 18, seg 0 (0.5) [0.5 on Epop[18]] -> cell 35, seg 0 (0.5) [0.5 on Epop[35]], weight: 4.1363508E-4, delay 1.5
        h("Epop[35] syn_projEE_ampa[1475] = new ampa(0.5)")
        h("Epop[18] netConn_projEE_ampa[1475] = new NetCon(&v(0.5), syn_projEE_ampa[1475], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1476: cell 18, seg 0 (0.5) [0.5 on Epop[18]] -> cell 36, seg 0 (0.5) [0.5 on Epop[36]], weight: 4.1363508E-4, delay 1.5
        h("Epop[36] syn_projEE_ampa[1476] = new ampa(0.5)")
        h("Epop[18] netConn_projEE_ampa[1476] = new NetCon(&v(0.5), syn_projEE_ampa[1476], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1477: cell 18, seg 0 (0.5) [0.5 on Epop[18]] -> cell 37, seg 0 (0.5) [0.5 on Epop[37]], weight: 4.1363508E-4, delay 1.5
        h("Epop[37] syn_projEE_ampa[1477] = new ampa(0.5)")
        h("Epop[18] netConn_projEE_ampa[1477] = new NetCon(&v(0.5), syn_projEE_ampa[1477], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1478: cell 18, seg 0 (0.5) [0.5 on Epop[18]] -> cell 38, seg 0 (0.5) [0.5 on Epop[38]], weight: 4.1363508E-4, delay 1.5
        h("Epop[38] syn_projEE_ampa[1478] = new ampa(0.5)")
        h("Epop[18] netConn_projEE_ampa[1478] = new NetCon(&v(0.5), syn_projEE_ampa[1478], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1479: cell 18, seg 0 (0.5) [0.5 on Epop[18]] -> cell 39, seg 0 (0.5) [0.5 on Epop[39]], weight: 4.1363508E-4, delay 1.5
        h("Epop[39] syn_projEE_ampa[1479] = new ampa(0.5)")
        h("Epop[18] netConn_projEE_ampa[1479] = new NetCon(&v(0.5), syn_projEE_ampa[1479], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1480: cell 18, seg 0 (0.5) [0.5 on Epop[18]] -> cell 40, seg 0 (0.5) [0.5 on Epop[40]], weight: 4.1363508E-4, delay 1.5
        h("Epop[40] syn_projEE_ampa[1480] = new ampa(0.5)")
        h("Epop[18] netConn_projEE_ampa[1480] = new NetCon(&v(0.5), syn_projEE_ampa[1480], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1481: cell 18, seg 0 (0.5) [0.5 on Epop[18]] -> cell 41, seg 0 (0.5) [0.5 on Epop[41]], weight: 4.1363508E-4, delay 1.5
        h("Epop[41] syn_projEE_ampa[1481] = new ampa(0.5)")
        h("Epop[18] netConn_projEE_ampa[1481] = new NetCon(&v(0.5), syn_projEE_ampa[1481], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1482: cell 18, seg 0 (0.5) [0.5 on Epop[18]] -> cell 42, seg 0 (0.5) [0.5 on Epop[42]], weight: 4.1363508E-4, delay 1.5
        h("Epop[42] syn_projEE_ampa[1482] = new ampa(0.5)")
        h("Epop[18] netConn_projEE_ampa[1482] = new NetCon(&v(0.5), syn_projEE_ampa[1482], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1483: cell 18, seg 0 (0.5) [0.5 on Epop[18]] -> cell 43, seg 0 (0.5) [0.5 on Epop[43]], weight: 4.1363508E-4, delay 1.5
        h("Epop[43] syn_projEE_ampa[1483] = new ampa(0.5)")
        h("Epop[18] netConn_projEE_ampa[1483] = new NetCon(&v(0.5), syn_projEE_ampa[1483], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1484: cell 18, seg 0 (0.5) [0.5 on Epop[18]] -> cell 44, seg 0 (0.5) [0.5 on Epop[44]], weight: 4.1363508E-4, delay 1.5
        h("Epop[44] syn_projEE_ampa[1484] = new ampa(0.5)")
        h("Epop[18] netConn_projEE_ampa[1484] = new NetCon(&v(0.5), syn_projEE_ampa[1484], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1485: cell 18, seg 0 (0.5) [0.5 on Epop[18]] -> cell 45, seg 0 (0.5) [0.5 on Epop[45]], weight: 4.1363508E-4, delay 1.5
        h("Epop[45] syn_projEE_ampa[1485] = new ampa(0.5)")
        h("Epop[18] netConn_projEE_ampa[1485] = new NetCon(&v(0.5), syn_projEE_ampa[1485], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1486: cell 18, seg 0 (0.5) [0.5 on Epop[18]] -> cell 46, seg 0 (0.5) [0.5 on Epop[46]], weight: 4.1363508E-4, delay 1.5
        h("Epop[46] syn_projEE_ampa[1486] = new ampa(0.5)")
        h("Epop[18] netConn_projEE_ampa[1486] = new NetCon(&v(0.5), syn_projEE_ampa[1486], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1487: cell 18, seg 0 (0.5) [0.5 on Epop[18]] -> cell 47, seg 0 (0.5) [0.5 on Epop[47]], weight: 4.1363508E-4, delay 1.5
        h("Epop[47] syn_projEE_ampa[1487] = new ampa(0.5)")
        h("Epop[18] netConn_projEE_ampa[1487] = new NetCon(&v(0.5), syn_projEE_ampa[1487], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1488: cell 18, seg 0 (0.5) [0.5 on Epop[18]] -> cell 48, seg 0 (0.5) [0.5 on Epop[48]], weight: 4.1363508E-4, delay 1.5
        h("Epop[48] syn_projEE_ampa[1488] = new ampa(0.5)")
        h("Epop[18] netConn_projEE_ampa[1488] = new NetCon(&v(0.5), syn_projEE_ampa[1488], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1489: cell 18, seg 0 (0.5) [0.5 on Epop[18]] -> cell 49, seg 0 (0.5) [0.5 on Epop[49]], weight: 4.1363508E-4, delay 1.5
        h("Epop[49] syn_projEE_ampa[1489] = new ampa(0.5)")
        h("Epop[18] netConn_projEE_ampa[1489] = new NetCon(&v(0.5), syn_projEE_ampa[1489], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1490: cell 18, seg 0 (0.5) [0.5 on Epop[18]] -> cell 50, seg 0 (0.5) [0.5 on Epop[50]], weight: 4.1363508E-4, delay 1.5
        h("Epop[50] syn_projEE_ampa[1490] = new ampa(0.5)")
        h("Epop[18] netConn_projEE_ampa[1490] = new NetCon(&v(0.5), syn_projEE_ampa[1490], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1491: cell 18, seg 0 (0.5) [0.5 on Epop[18]] -> cell 51, seg 0 (0.5) [0.5 on Epop[51]], weight: 4.1363508E-4, delay 1.5
        h("Epop[51] syn_projEE_ampa[1491] = new ampa(0.5)")
        h("Epop[18] netConn_projEE_ampa[1491] = new NetCon(&v(0.5), syn_projEE_ampa[1491], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1492: cell 18, seg 0 (0.5) [0.5 on Epop[18]] -> cell 52, seg 0 (0.5) [0.5 on Epop[52]], weight: 4.1363508E-4, delay 1.5
        h("Epop[52] syn_projEE_ampa[1492] = new ampa(0.5)")
        h("Epop[18] netConn_projEE_ampa[1492] = new NetCon(&v(0.5), syn_projEE_ampa[1492], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1493: cell 18, seg 0 (0.5) [0.5 on Epop[18]] -> cell 53, seg 0 (0.5) [0.5 on Epop[53]], weight: 4.1363508E-4, delay 1.5
        h("Epop[53] syn_projEE_ampa[1493] = new ampa(0.5)")
        h("Epop[18] netConn_projEE_ampa[1493] = new NetCon(&v(0.5), syn_projEE_ampa[1493], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1494: cell 18, seg 0 (0.5) [0.5 on Epop[18]] -> cell 54, seg 0 (0.5) [0.5 on Epop[54]], weight: 4.1363508E-4, delay 1.5
        h("Epop[54] syn_projEE_ampa[1494] = new ampa(0.5)")
        h("Epop[18] netConn_projEE_ampa[1494] = new NetCon(&v(0.5), syn_projEE_ampa[1494], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1495: cell 18, seg 0 (0.5) [0.5 on Epop[18]] -> cell 55, seg 0 (0.5) [0.5 on Epop[55]], weight: 4.1363508E-4, delay 1.5
        h("Epop[55] syn_projEE_ampa[1495] = new ampa(0.5)")
        h("Epop[18] netConn_projEE_ampa[1495] = new NetCon(&v(0.5), syn_projEE_ampa[1495], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1496: cell 18, seg 0 (0.5) [0.5 on Epop[18]] -> cell 56, seg 0 (0.5) [0.5 on Epop[56]], weight: 4.1363508E-4, delay 1.5
        h("Epop[56] syn_projEE_ampa[1496] = new ampa(0.5)")
        h("Epop[18] netConn_projEE_ampa[1496] = new NetCon(&v(0.5), syn_projEE_ampa[1496], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1497: cell 18, seg 0 (0.5) [0.5 on Epop[18]] -> cell 57, seg 0 (0.5) [0.5 on Epop[57]], weight: 4.1363508E-4, delay 1.5
        h("Epop[57] syn_projEE_ampa[1497] = new ampa(0.5)")
        h("Epop[18] netConn_projEE_ampa[1497] = new NetCon(&v(0.5), syn_projEE_ampa[1497], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1498: cell 18, seg 0 (0.5) [0.5 on Epop[18]] -> cell 58, seg 0 (0.5) [0.5 on Epop[58]], weight: 4.1363508E-4, delay 1.5
        h("Epop[58] syn_projEE_ampa[1498] = new ampa(0.5)")
        h("Epop[18] netConn_projEE_ampa[1498] = new NetCon(&v(0.5), syn_projEE_ampa[1498], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1499: cell 18, seg 0 (0.5) [0.5 on Epop[18]] -> cell 59, seg 0 (0.5) [0.5 on Epop[59]], weight: 4.1363508E-4, delay 1.5
        h("Epop[59] syn_projEE_ampa[1499] = new ampa(0.5)")
        h("Epop[18] netConn_projEE_ampa[1499] = new NetCon(&v(0.5), syn_projEE_ampa[1499], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1500: cell 18, seg 0 (0.5) [0.5 on Epop[18]] -> cell 60, seg 0 (0.5) [0.5 on Epop[60]], weight: 4.1363508E-4, delay 1.5
        h("Epop[60] syn_projEE_ampa[1500] = new ampa(0.5)")
        h("Epop[18] netConn_projEE_ampa[1500] = new NetCon(&v(0.5), syn_projEE_ampa[1500], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1501: cell 18, seg 0 (0.5) [0.5 on Epop[18]] -> cell 61, seg 0 (0.5) [0.5 on Epop[61]], weight: 4.1363508E-4, delay 1.5
        h("Epop[61] syn_projEE_ampa[1501] = new ampa(0.5)")
        h("Epop[18] netConn_projEE_ampa[1501] = new NetCon(&v(0.5), syn_projEE_ampa[1501], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1502: cell 18, seg 0 (0.5) [0.5 on Epop[18]] -> cell 62, seg 0 (0.5) [0.5 on Epop[62]], weight: 4.1363508E-4, delay 1.5
        h("Epop[62] syn_projEE_ampa[1502] = new ampa(0.5)")
        h("Epop[18] netConn_projEE_ampa[1502] = new NetCon(&v(0.5), syn_projEE_ampa[1502], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1503: cell 18, seg 0 (0.5) [0.5 on Epop[18]] -> cell 63, seg 0 (0.5) [0.5 on Epop[63]], weight: 4.1363508E-4, delay 1.5
        h("Epop[63] syn_projEE_ampa[1503] = new ampa(0.5)")
        h("Epop[18] netConn_projEE_ampa[1503] = new NetCon(&v(0.5), syn_projEE_ampa[1503], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1504: cell 18, seg 0 (0.5) [0.5 on Epop[18]] -> cell 64, seg 0 (0.5) [0.5 on Epop[64]], weight: 4.1363508E-4, delay 1.5
        h("Epop[64] syn_projEE_ampa[1504] = new ampa(0.5)")
        h("Epop[18] netConn_projEE_ampa[1504] = new NetCon(&v(0.5), syn_projEE_ampa[1504], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1505: cell 18, seg 0 (0.5) [0.5 on Epop[18]] -> cell 65, seg 0 (0.5) [0.5 on Epop[65]], weight: 4.1363508E-4, delay 1.5
        h("Epop[65] syn_projEE_ampa[1505] = new ampa(0.5)")
        h("Epop[18] netConn_projEE_ampa[1505] = new NetCon(&v(0.5), syn_projEE_ampa[1505], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1506: cell 18, seg 0 (0.5) [0.5 on Epop[18]] -> cell 66, seg 0 (0.5) [0.5 on Epop[66]], weight: 4.1363508E-4, delay 1.5
        h("Epop[66] syn_projEE_ampa[1506] = new ampa(0.5)")
        h("Epop[18] netConn_projEE_ampa[1506] = new NetCon(&v(0.5), syn_projEE_ampa[1506], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1507: cell 18, seg 0 (0.5) [0.5 on Epop[18]] -> cell 67, seg 0 (0.5) [0.5 on Epop[67]], weight: 4.1363508E-4, delay 1.5
        h("Epop[67] syn_projEE_ampa[1507] = new ampa(0.5)")
        h("Epop[18] netConn_projEE_ampa[1507] = new NetCon(&v(0.5), syn_projEE_ampa[1507], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1508: cell 18, seg 0 (0.5) [0.5 on Epop[18]] -> cell 68, seg 0 (0.5) [0.5 on Epop[68]], weight: 4.1363508E-4, delay 1.5
        h("Epop[68] syn_projEE_ampa[1508] = new ampa(0.5)")
        h("Epop[18] netConn_projEE_ampa[1508] = new NetCon(&v(0.5), syn_projEE_ampa[1508], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1509: cell 18, seg 0 (0.5) [0.5 on Epop[18]] -> cell 69, seg 0 (0.5) [0.5 on Epop[69]], weight: 4.1363508E-4, delay 1.5
        h("Epop[69] syn_projEE_ampa[1509] = new ampa(0.5)")
        h("Epop[18] netConn_projEE_ampa[1509] = new NetCon(&v(0.5), syn_projEE_ampa[1509], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1510: cell 18, seg 0 (0.5) [0.5 on Epop[18]] -> cell 70, seg 0 (0.5) [0.5 on Epop[70]], weight: 4.1363508E-4, delay 1.5
        h("Epop[70] syn_projEE_ampa[1510] = new ampa(0.5)")
        h("Epop[18] netConn_projEE_ampa[1510] = new NetCon(&v(0.5), syn_projEE_ampa[1510], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1511: cell 18, seg 0 (0.5) [0.5 on Epop[18]] -> cell 71, seg 0 (0.5) [0.5 on Epop[71]], weight: 4.1363508E-4, delay 1.5
        h("Epop[71] syn_projEE_ampa[1511] = new ampa(0.5)")
        h("Epop[18] netConn_projEE_ampa[1511] = new NetCon(&v(0.5), syn_projEE_ampa[1511], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1512: cell 18, seg 0 (0.5) [0.5 on Epop[18]] -> cell 72, seg 0 (0.5) [0.5 on Epop[72]], weight: 4.1363508E-4, delay 1.5
        h("Epop[72] syn_projEE_ampa[1512] = new ampa(0.5)")
        h("Epop[18] netConn_projEE_ampa[1512] = new NetCon(&v(0.5), syn_projEE_ampa[1512], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1513: cell 18, seg 0 (0.5) [0.5 on Epop[18]] -> cell 73, seg 0 (0.5) [0.5 on Epop[73]], weight: 4.1363508E-4, delay 1.5
        h("Epop[73] syn_projEE_ampa[1513] = new ampa(0.5)")
        h("Epop[18] netConn_projEE_ampa[1513] = new NetCon(&v(0.5), syn_projEE_ampa[1513], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1514: cell 18, seg 0 (0.5) [0.5 on Epop[18]] -> cell 74, seg 0 (0.5) [0.5 on Epop[74]], weight: 4.1363508E-4, delay 1.5
        h("Epop[74] syn_projEE_ampa[1514] = new ampa(0.5)")
        h("Epop[18] netConn_projEE_ampa[1514] = new NetCon(&v(0.5), syn_projEE_ampa[1514], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1515: cell 18, seg 0 (0.5) [0.5 on Epop[18]] -> cell 75, seg 0 (0.5) [0.5 on Epop[75]], weight: 4.1363508E-4, delay 1.5
        h("Epop[75] syn_projEE_ampa[1515] = new ampa(0.5)")
        h("Epop[18] netConn_projEE_ampa[1515] = new NetCon(&v(0.5), syn_projEE_ampa[1515], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1516: cell 18, seg 0 (0.5) [0.5 on Epop[18]] -> cell 76, seg 0 (0.5) [0.5 on Epop[76]], weight: 4.1363508E-4, delay 1.5
        h("Epop[76] syn_projEE_ampa[1516] = new ampa(0.5)")
        h("Epop[18] netConn_projEE_ampa[1516] = new NetCon(&v(0.5), syn_projEE_ampa[1516], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1517: cell 18, seg 0 (0.5) [0.5 on Epop[18]] -> cell 77, seg 0 (0.5) [0.5 on Epop[77]], weight: 4.1363508E-4, delay 1.5
        h("Epop[77] syn_projEE_ampa[1517] = new ampa(0.5)")
        h("Epop[18] netConn_projEE_ampa[1517] = new NetCon(&v(0.5), syn_projEE_ampa[1517], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1518: cell 18, seg 0 (0.5) [0.5 on Epop[18]] -> cell 78, seg 0 (0.5) [0.5 on Epop[78]], weight: 4.1363508E-4, delay 1.5
        h("Epop[78] syn_projEE_ampa[1518] = new ampa(0.5)")
        h("Epop[18] netConn_projEE_ampa[1518] = new NetCon(&v(0.5), syn_projEE_ampa[1518], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1519: cell 18, seg 0 (0.5) [0.5 on Epop[18]] -> cell 79, seg 0 (0.5) [0.5 on Epop[79]], weight: 4.1363508E-4, delay 1.5
        h("Epop[79] syn_projEE_ampa[1519] = new ampa(0.5)")
        h("Epop[18] netConn_projEE_ampa[1519] = new NetCon(&v(0.5), syn_projEE_ampa[1519], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1520: cell 19, seg 0 (0.5) [0.5 on Epop[19]] -> cell 0, seg 0 (0.5) [0.5 on Epop[0]], weight: 4.1363508E-4, delay 1.5
        h("Epop[0] syn_projEE_ampa[1520] = new ampa(0.5)")
        h("Epop[19] netConn_projEE_ampa[1520] = new NetCon(&v(0.5), syn_projEE_ampa[1520], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1521: cell 19, seg 0 (0.5) [0.5 on Epop[19]] -> cell 1, seg 0 (0.5) [0.5 on Epop[1]], weight: 4.1363508E-4, delay 1.5
        h("Epop[1] syn_projEE_ampa[1521] = new ampa(0.5)")
        h("Epop[19] netConn_projEE_ampa[1521] = new NetCon(&v(0.5), syn_projEE_ampa[1521], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1522: cell 19, seg 0 (0.5) [0.5 on Epop[19]] -> cell 2, seg 0 (0.5) [0.5 on Epop[2]], weight: 4.1363508E-4, delay 1.5
        h("Epop[2] syn_projEE_ampa[1522] = new ampa(0.5)")
        h("Epop[19] netConn_projEE_ampa[1522] = new NetCon(&v(0.5), syn_projEE_ampa[1522], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1523: cell 19, seg 0 (0.5) [0.5 on Epop[19]] -> cell 3, seg 0 (0.5) [0.5 on Epop[3]], weight: 4.1363508E-4, delay 1.5
        h("Epop[3] syn_projEE_ampa[1523] = new ampa(0.5)")
        h("Epop[19] netConn_projEE_ampa[1523] = new NetCon(&v(0.5), syn_projEE_ampa[1523], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1524: cell 19, seg 0 (0.5) [0.5 on Epop[19]] -> cell 4, seg 0 (0.5) [0.5 on Epop[4]], weight: 4.1363508E-4, delay 1.5
        h("Epop[4] syn_projEE_ampa[1524] = new ampa(0.5)")
        h("Epop[19] netConn_projEE_ampa[1524] = new NetCon(&v(0.5), syn_projEE_ampa[1524], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1525: cell 19, seg 0 (0.5) [0.5 on Epop[19]] -> cell 5, seg 0 (0.5) [0.5 on Epop[5]], weight: 4.1363508E-4, delay 1.5
        h("Epop[5] syn_projEE_ampa[1525] = new ampa(0.5)")
        h("Epop[19] netConn_projEE_ampa[1525] = new NetCon(&v(0.5), syn_projEE_ampa[1525], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1526: cell 19, seg 0 (0.5) [0.5 on Epop[19]] -> cell 6, seg 0 (0.5) [0.5 on Epop[6]], weight: 4.1363508E-4, delay 1.5
        h("Epop[6] syn_projEE_ampa[1526] = new ampa(0.5)")
        h("Epop[19] netConn_projEE_ampa[1526] = new NetCon(&v(0.5), syn_projEE_ampa[1526], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1527: cell 19, seg 0 (0.5) [0.5 on Epop[19]] -> cell 7, seg 0 (0.5) [0.5 on Epop[7]], weight: 4.1363508E-4, delay 1.5
        h("Epop[7] syn_projEE_ampa[1527] = new ampa(0.5)")
        h("Epop[19] netConn_projEE_ampa[1527] = new NetCon(&v(0.5), syn_projEE_ampa[1527], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1528: cell 19, seg 0 (0.5) [0.5 on Epop[19]] -> cell 8, seg 0 (0.5) [0.5 on Epop[8]], weight: 4.1363508E-4, delay 1.5
        h("Epop[8] syn_projEE_ampa[1528] = new ampa(0.5)")
        h("Epop[19] netConn_projEE_ampa[1528] = new NetCon(&v(0.5), syn_projEE_ampa[1528], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1529: cell 19, seg 0 (0.5) [0.5 on Epop[19]] -> cell 9, seg 0 (0.5) [0.5 on Epop[9]], weight: 4.1363508E-4, delay 1.5
        h("Epop[9] syn_projEE_ampa[1529] = new ampa(0.5)")
        h("Epop[19] netConn_projEE_ampa[1529] = new NetCon(&v(0.5), syn_projEE_ampa[1529], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1530: cell 19, seg 0 (0.5) [0.5 on Epop[19]] -> cell 10, seg 0 (0.5) [0.5 on Epop[10]], weight: 4.1363508E-4, delay 1.5
        h("Epop[10] syn_projEE_ampa[1530] = new ampa(0.5)")
        h("Epop[19] netConn_projEE_ampa[1530] = new NetCon(&v(0.5), syn_projEE_ampa[1530], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1531: cell 19, seg 0 (0.5) [0.5 on Epop[19]] -> cell 11, seg 0 (0.5) [0.5 on Epop[11]], weight: 4.1363508E-4, delay 1.5
        h("Epop[11] syn_projEE_ampa[1531] = new ampa(0.5)")
        h("Epop[19] netConn_projEE_ampa[1531] = new NetCon(&v(0.5), syn_projEE_ampa[1531], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1532: cell 19, seg 0 (0.5) [0.5 on Epop[19]] -> cell 12, seg 0 (0.5) [0.5 on Epop[12]], weight: 4.1363508E-4, delay 1.5
        h("Epop[12] syn_projEE_ampa[1532] = new ampa(0.5)")
        h("Epop[19] netConn_projEE_ampa[1532] = new NetCon(&v(0.5), syn_projEE_ampa[1532], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1533: cell 19, seg 0 (0.5) [0.5 on Epop[19]] -> cell 13, seg 0 (0.5) [0.5 on Epop[13]], weight: 4.1363508E-4, delay 1.5
        h("Epop[13] syn_projEE_ampa[1533] = new ampa(0.5)")
        h("Epop[19] netConn_projEE_ampa[1533] = new NetCon(&v(0.5), syn_projEE_ampa[1533], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1534: cell 19, seg 0 (0.5) [0.5 on Epop[19]] -> cell 14, seg 0 (0.5) [0.5 on Epop[14]], weight: 4.1363508E-4, delay 1.5
        h("Epop[14] syn_projEE_ampa[1534] = new ampa(0.5)")
        h("Epop[19] netConn_projEE_ampa[1534] = new NetCon(&v(0.5), syn_projEE_ampa[1534], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1535: cell 19, seg 0 (0.5) [0.5 on Epop[19]] -> cell 15, seg 0 (0.5) [0.5 on Epop[15]], weight: 4.1363508E-4, delay 1.5
        h("Epop[15] syn_projEE_ampa[1535] = new ampa(0.5)")
        h("Epop[19] netConn_projEE_ampa[1535] = new NetCon(&v(0.5), syn_projEE_ampa[1535], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1536: cell 19, seg 0 (0.5) [0.5 on Epop[19]] -> cell 16, seg 0 (0.5) [0.5 on Epop[16]], weight: 4.1363508E-4, delay 1.5
        h("Epop[16] syn_projEE_ampa[1536] = new ampa(0.5)")
        h("Epop[19] netConn_projEE_ampa[1536] = new NetCon(&v(0.5), syn_projEE_ampa[1536], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1537: cell 19, seg 0 (0.5) [0.5 on Epop[19]] -> cell 17, seg 0 (0.5) [0.5 on Epop[17]], weight: 4.1363508E-4, delay 1.5
        h("Epop[17] syn_projEE_ampa[1537] = new ampa(0.5)")
        h("Epop[19] netConn_projEE_ampa[1537] = new NetCon(&v(0.5), syn_projEE_ampa[1537], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1538: cell 19, seg 0 (0.5) [0.5 on Epop[19]] -> cell 18, seg 0 (0.5) [0.5 on Epop[18]], weight: 4.1363508E-4, delay 1.5
        h("Epop[18] syn_projEE_ampa[1538] = new ampa(0.5)")
        h("Epop[19] netConn_projEE_ampa[1538] = new NetCon(&v(0.5), syn_projEE_ampa[1538], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1539: cell 19, seg 0 (0.5) [0.5 on Epop[19]] -> cell 19, seg 0 (0.5) [0.5 on Epop[19]], weight: 4.1363508E-4, delay 1.5
        h("Epop[19] syn_projEE_ampa[1539] = new ampa(0.5)")
        h("Epop[19] netConn_projEE_ampa[1539] = new NetCon(&v(0.5), syn_projEE_ampa[1539], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1540: cell 19, seg 0 (0.5) [0.5 on Epop[19]] -> cell 20, seg 0 (0.5) [0.5 on Epop[20]], weight: 4.1363508E-4, delay 1.5
        h("Epop[20] syn_projEE_ampa[1540] = new ampa(0.5)")
        h("Epop[19] netConn_projEE_ampa[1540] = new NetCon(&v(0.5), syn_projEE_ampa[1540], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1541: cell 19, seg 0 (0.5) [0.5 on Epop[19]] -> cell 21, seg 0 (0.5) [0.5 on Epop[21]], weight: 4.1363508E-4, delay 1.5
        h("Epop[21] syn_projEE_ampa[1541] = new ampa(0.5)")
        h("Epop[19] netConn_projEE_ampa[1541] = new NetCon(&v(0.5), syn_projEE_ampa[1541], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1542: cell 19, seg 0 (0.5) [0.5 on Epop[19]] -> cell 22, seg 0 (0.5) [0.5 on Epop[22]], weight: 4.1363508E-4, delay 1.5
        h("Epop[22] syn_projEE_ampa[1542] = new ampa(0.5)")
        h("Epop[19] netConn_projEE_ampa[1542] = new NetCon(&v(0.5), syn_projEE_ampa[1542], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1543: cell 19, seg 0 (0.5) [0.5 on Epop[19]] -> cell 23, seg 0 (0.5) [0.5 on Epop[23]], weight: 4.1363508E-4, delay 1.5
        h("Epop[23] syn_projEE_ampa[1543] = new ampa(0.5)")
        h("Epop[19] netConn_projEE_ampa[1543] = new NetCon(&v(0.5), syn_projEE_ampa[1543], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1544: cell 19, seg 0 (0.5) [0.5 on Epop[19]] -> cell 24, seg 0 (0.5) [0.5 on Epop[24]], weight: 4.1363508E-4, delay 1.5
        h("Epop[24] syn_projEE_ampa[1544] = new ampa(0.5)")
        h("Epop[19] netConn_projEE_ampa[1544] = new NetCon(&v(0.5), syn_projEE_ampa[1544], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1545: cell 19, seg 0 (0.5) [0.5 on Epop[19]] -> cell 25, seg 0 (0.5) [0.5 on Epop[25]], weight: 4.1363508E-4, delay 1.5
        h("Epop[25] syn_projEE_ampa[1545] = new ampa(0.5)")
        h("Epop[19] netConn_projEE_ampa[1545] = new NetCon(&v(0.5), syn_projEE_ampa[1545], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1546: cell 19, seg 0 (0.5) [0.5 on Epop[19]] -> cell 26, seg 0 (0.5) [0.5 on Epop[26]], weight: 4.1363508E-4, delay 1.5
        h("Epop[26] syn_projEE_ampa[1546] = new ampa(0.5)")
        h("Epop[19] netConn_projEE_ampa[1546] = new NetCon(&v(0.5), syn_projEE_ampa[1546], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1547: cell 19, seg 0 (0.5) [0.5 on Epop[19]] -> cell 27, seg 0 (0.5) [0.5 on Epop[27]], weight: 4.1363508E-4, delay 1.5
        h("Epop[27] syn_projEE_ampa[1547] = new ampa(0.5)")
        h("Epop[19] netConn_projEE_ampa[1547] = new NetCon(&v(0.5), syn_projEE_ampa[1547], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1548: cell 19, seg 0 (0.5) [0.5 on Epop[19]] -> cell 28, seg 0 (0.5) [0.5 on Epop[28]], weight: 4.1363508E-4, delay 1.5
        h("Epop[28] syn_projEE_ampa[1548] = new ampa(0.5)")
        h("Epop[19] netConn_projEE_ampa[1548] = new NetCon(&v(0.5), syn_projEE_ampa[1548], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1549: cell 19, seg 0 (0.5) [0.5 on Epop[19]] -> cell 29, seg 0 (0.5) [0.5 on Epop[29]], weight: 4.1363508E-4, delay 1.5
        h("Epop[29] syn_projEE_ampa[1549] = new ampa(0.5)")
        h("Epop[19] netConn_projEE_ampa[1549] = new NetCon(&v(0.5), syn_projEE_ampa[1549], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1550: cell 19, seg 0 (0.5) [0.5 on Epop[19]] -> cell 30, seg 0 (0.5) [0.5 on Epop[30]], weight: 4.1363508E-4, delay 1.5
        h("Epop[30] syn_projEE_ampa[1550] = new ampa(0.5)")
        h("Epop[19] netConn_projEE_ampa[1550] = new NetCon(&v(0.5), syn_projEE_ampa[1550], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1551: cell 19, seg 0 (0.5) [0.5 on Epop[19]] -> cell 31, seg 0 (0.5) [0.5 on Epop[31]], weight: 4.1363508E-4, delay 1.5
        h("Epop[31] syn_projEE_ampa[1551] = new ampa(0.5)")
        h("Epop[19] netConn_projEE_ampa[1551] = new NetCon(&v(0.5), syn_projEE_ampa[1551], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1552: cell 19, seg 0 (0.5) [0.5 on Epop[19]] -> cell 32, seg 0 (0.5) [0.5 on Epop[32]], weight: 4.1363508E-4, delay 1.5
        h("Epop[32] syn_projEE_ampa[1552] = new ampa(0.5)")
        h("Epop[19] netConn_projEE_ampa[1552] = new NetCon(&v(0.5), syn_projEE_ampa[1552], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1553: cell 19, seg 0 (0.5) [0.5 on Epop[19]] -> cell 33, seg 0 (0.5) [0.5 on Epop[33]], weight: 4.1363508E-4, delay 1.5
        h("Epop[33] syn_projEE_ampa[1553] = new ampa(0.5)")
        h("Epop[19] netConn_projEE_ampa[1553] = new NetCon(&v(0.5), syn_projEE_ampa[1553], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1554: cell 19, seg 0 (0.5) [0.5 on Epop[19]] -> cell 34, seg 0 (0.5) [0.5 on Epop[34]], weight: 4.1363508E-4, delay 1.5
        h("Epop[34] syn_projEE_ampa[1554] = new ampa(0.5)")
        h("Epop[19] netConn_projEE_ampa[1554] = new NetCon(&v(0.5), syn_projEE_ampa[1554], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1555: cell 19, seg 0 (0.5) [0.5 on Epop[19]] -> cell 35, seg 0 (0.5) [0.5 on Epop[35]], weight: 4.1363508E-4, delay 1.5
        h("Epop[35] syn_projEE_ampa[1555] = new ampa(0.5)")
        h("Epop[19] netConn_projEE_ampa[1555] = new NetCon(&v(0.5), syn_projEE_ampa[1555], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1556: cell 19, seg 0 (0.5) [0.5 on Epop[19]] -> cell 36, seg 0 (0.5) [0.5 on Epop[36]], weight: 4.1363508E-4, delay 1.5
        h("Epop[36] syn_projEE_ampa[1556] = new ampa(0.5)")
        h("Epop[19] netConn_projEE_ampa[1556] = new NetCon(&v(0.5), syn_projEE_ampa[1556], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1557: cell 19, seg 0 (0.5) [0.5 on Epop[19]] -> cell 37, seg 0 (0.5) [0.5 on Epop[37]], weight: 4.1363508E-4, delay 1.5
        h("Epop[37] syn_projEE_ampa[1557] = new ampa(0.5)")
        h("Epop[19] netConn_projEE_ampa[1557] = new NetCon(&v(0.5), syn_projEE_ampa[1557], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1558: cell 19, seg 0 (0.5) [0.5 on Epop[19]] -> cell 38, seg 0 (0.5) [0.5 on Epop[38]], weight: 4.1363508E-4, delay 1.5
        h("Epop[38] syn_projEE_ampa[1558] = new ampa(0.5)")
        h("Epop[19] netConn_projEE_ampa[1558] = new NetCon(&v(0.5), syn_projEE_ampa[1558], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1559: cell 19, seg 0 (0.5) [0.5 on Epop[19]] -> cell 39, seg 0 (0.5) [0.5 on Epop[39]], weight: 4.1363508E-4, delay 1.5
        h("Epop[39] syn_projEE_ampa[1559] = new ampa(0.5)")
        h("Epop[19] netConn_projEE_ampa[1559] = new NetCon(&v(0.5), syn_projEE_ampa[1559], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1560: cell 19, seg 0 (0.5) [0.5 on Epop[19]] -> cell 40, seg 0 (0.5) [0.5 on Epop[40]], weight: 4.1363508E-4, delay 1.5
        h("Epop[40] syn_projEE_ampa[1560] = new ampa(0.5)")
        h("Epop[19] netConn_projEE_ampa[1560] = new NetCon(&v(0.5), syn_projEE_ampa[1560], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1561: cell 19, seg 0 (0.5) [0.5 on Epop[19]] -> cell 41, seg 0 (0.5) [0.5 on Epop[41]], weight: 4.1363508E-4, delay 1.5
        h("Epop[41] syn_projEE_ampa[1561] = new ampa(0.5)")
        h("Epop[19] netConn_projEE_ampa[1561] = new NetCon(&v(0.5), syn_projEE_ampa[1561], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1562: cell 19, seg 0 (0.5) [0.5 on Epop[19]] -> cell 42, seg 0 (0.5) [0.5 on Epop[42]], weight: 4.1363508E-4, delay 1.5
        h("Epop[42] syn_projEE_ampa[1562] = new ampa(0.5)")
        h("Epop[19] netConn_projEE_ampa[1562] = new NetCon(&v(0.5), syn_projEE_ampa[1562], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1563: cell 19, seg 0 (0.5) [0.5 on Epop[19]] -> cell 43, seg 0 (0.5) [0.5 on Epop[43]], weight: 4.1363508E-4, delay 1.5
        h("Epop[43] syn_projEE_ampa[1563] = new ampa(0.5)")
        h("Epop[19] netConn_projEE_ampa[1563] = new NetCon(&v(0.5), syn_projEE_ampa[1563], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1564: cell 19, seg 0 (0.5) [0.5 on Epop[19]] -> cell 44, seg 0 (0.5) [0.5 on Epop[44]], weight: 4.1363508E-4, delay 1.5
        h("Epop[44] syn_projEE_ampa[1564] = new ampa(0.5)")
        h("Epop[19] netConn_projEE_ampa[1564] = new NetCon(&v(0.5), syn_projEE_ampa[1564], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1565: cell 19, seg 0 (0.5) [0.5 on Epop[19]] -> cell 45, seg 0 (0.5) [0.5 on Epop[45]], weight: 4.1363508E-4, delay 1.5
        h("Epop[45] syn_projEE_ampa[1565] = new ampa(0.5)")
        h("Epop[19] netConn_projEE_ampa[1565] = new NetCon(&v(0.5), syn_projEE_ampa[1565], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1566: cell 19, seg 0 (0.5) [0.5 on Epop[19]] -> cell 46, seg 0 (0.5) [0.5 on Epop[46]], weight: 4.1363508E-4, delay 1.5
        h("Epop[46] syn_projEE_ampa[1566] = new ampa(0.5)")
        h("Epop[19] netConn_projEE_ampa[1566] = new NetCon(&v(0.5), syn_projEE_ampa[1566], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1567: cell 19, seg 0 (0.5) [0.5 on Epop[19]] -> cell 47, seg 0 (0.5) [0.5 on Epop[47]], weight: 4.1363508E-4, delay 1.5
        h("Epop[47] syn_projEE_ampa[1567] = new ampa(0.5)")
        h("Epop[19] netConn_projEE_ampa[1567] = new NetCon(&v(0.5), syn_projEE_ampa[1567], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1568: cell 19, seg 0 (0.5) [0.5 on Epop[19]] -> cell 48, seg 0 (0.5) [0.5 on Epop[48]], weight: 4.1363508E-4, delay 1.5
        h("Epop[48] syn_projEE_ampa[1568] = new ampa(0.5)")
        h("Epop[19] netConn_projEE_ampa[1568] = new NetCon(&v(0.5), syn_projEE_ampa[1568], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1569: cell 19, seg 0 (0.5) [0.5 on Epop[19]] -> cell 49, seg 0 (0.5) [0.5 on Epop[49]], weight: 4.1363508E-4, delay 1.5
        h("Epop[49] syn_projEE_ampa[1569] = new ampa(0.5)")
        h("Epop[19] netConn_projEE_ampa[1569] = new NetCon(&v(0.5), syn_projEE_ampa[1569], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1570: cell 19, seg 0 (0.5) [0.5 on Epop[19]] -> cell 50, seg 0 (0.5) [0.5 on Epop[50]], weight: 4.1363508E-4, delay 1.5
        h("Epop[50] syn_projEE_ampa[1570] = new ampa(0.5)")
        h("Epop[19] netConn_projEE_ampa[1570] = new NetCon(&v(0.5), syn_projEE_ampa[1570], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1571: cell 19, seg 0 (0.5) [0.5 on Epop[19]] -> cell 51, seg 0 (0.5) [0.5 on Epop[51]], weight: 4.1363508E-4, delay 1.5
        h("Epop[51] syn_projEE_ampa[1571] = new ampa(0.5)")
        h("Epop[19] netConn_projEE_ampa[1571] = new NetCon(&v(0.5), syn_projEE_ampa[1571], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1572: cell 19, seg 0 (0.5) [0.5 on Epop[19]] -> cell 52, seg 0 (0.5) [0.5 on Epop[52]], weight: 4.1363508E-4, delay 1.5
        h("Epop[52] syn_projEE_ampa[1572] = new ampa(0.5)")
        h("Epop[19] netConn_projEE_ampa[1572] = new NetCon(&v(0.5), syn_projEE_ampa[1572], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1573: cell 19, seg 0 (0.5) [0.5 on Epop[19]] -> cell 53, seg 0 (0.5) [0.5 on Epop[53]], weight: 4.1363508E-4, delay 1.5
        h("Epop[53] syn_projEE_ampa[1573] = new ampa(0.5)")
        h("Epop[19] netConn_projEE_ampa[1573] = new NetCon(&v(0.5), syn_projEE_ampa[1573], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1574: cell 19, seg 0 (0.5) [0.5 on Epop[19]] -> cell 54, seg 0 (0.5) [0.5 on Epop[54]], weight: 4.1363508E-4, delay 1.5
        h("Epop[54] syn_projEE_ampa[1574] = new ampa(0.5)")
        h("Epop[19] netConn_projEE_ampa[1574] = new NetCon(&v(0.5), syn_projEE_ampa[1574], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1575: cell 19, seg 0 (0.5) [0.5 on Epop[19]] -> cell 55, seg 0 (0.5) [0.5 on Epop[55]], weight: 4.1363508E-4, delay 1.5
        h("Epop[55] syn_projEE_ampa[1575] = new ampa(0.5)")
        h("Epop[19] netConn_projEE_ampa[1575] = new NetCon(&v(0.5), syn_projEE_ampa[1575], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1576: cell 19, seg 0 (0.5) [0.5 on Epop[19]] -> cell 56, seg 0 (0.5) [0.5 on Epop[56]], weight: 4.1363508E-4, delay 1.5
        h("Epop[56] syn_projEE_ampa[1576] = new ampa(0.5)")
        h("Epop[19] netConn_projEE_ampa[1576] = new NetCon(&v(0.5), syn_projEE_ampa[1576], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1577: cell 19, seg 0 (0.5) [0.5 on Epop[19]] -> cell 57, seg 0 (0.5) [0.5 on Epop[57]], weight: 4.1363508E-4, delay 1.5
        h("Epop[57] syn_projEE_ampa[1577] = new ampa(0.5)")
        h("Epop[19] netConn_projEE_ampa[1577] = new NetCon(&v(0.5), syn_projEE_ampa[1577], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1578: cell 19, seg 0 (0.5) [0.5 on Epop[19]] -> cell 58, seg 0 (0.5) [0.5 on Epop[58]], weight: 4.1363508E-4, delay 1.5
        h("Epop[58] syn_projEE_ampa[1578] = new ampa(0.5)")
        h("Epop[19] netConn_projEE_ampa[1578] = new NetCon(&v(0.5), syn_projEE_ampa[1578], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1579: cell 19, seg 0 (0.5) [0.5 on Epop[19]] -> cell 59, seg 0 (0.5) [0.5 on Epop[59]], weight: 4.1363508E-4, delay 1.5
        h("Epop[59] syn_projEE_ampa[1579] = new ampa(0.5)")
        h("Epop[19] netConn_projEE_ampa[1579] = new NetCon(&v(0.5), syn_projEE_ampa[1579], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1580: cell 19, seg 0 (0.5) [0.5 on Epop[19]] -> cell 60, seg 0 (0.5) [0.5 on Epop[60]], weight: 4.1363508E-4, delay 1.5
        h("Epop[60] syn_projEE_ampa[1580] = new ampa(0.5)")
        h("Epop[19] netConn_projEE_ampa[1580] = new NetCon(&v(0.5), syn_projEE_ampa[1580], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1581: cell 19, seg 0 (0.5) [0.5 on Epop[19]] -> cell 61, seg 0 (0.5) [0.5 on Epop[61]], weight: 4.1363508E-4, delay 1.5
        h("Epop[61] syn_projEE_ampa[1581] = new ampa(0.5)")
        h("Epop[19] netConn_projEE_ampa[1581] = new NetCon(&v(0.5), syn_projEE_ampa[1581], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1582: cell 19, seg 0 (0.5) [0.5 on Epop[19]] -> cell 62, seg 0 (0.5) [0.5 on Epop[62]], weight: 4.1363508E-4, delay 1.5
        h("Epop[62] syn_projEE_ampa[1582] = new ampa(0.5)")
        h("Epop[19] netConn_projEE_ampa[1582] = new NetCon(&v(0.5), syn_projEE_ampa[1582], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1583: cell 19, seg 0 (0.5) [0.5 on Epop[19]] -> cell 63, seg 0 (0.5) [0.5 on Epop[63]], weight: 4.1363508E-4, delay 1.5
        h("Epop[63] syn_projEE_ampa[1583] = new ampa(0.5)")
        h("Epop[19] netConn_projEE_ampa[1583] = new NetCon(&v(0.5), syn_projEE_ampa[1583], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1584: cell 19, seg 0 (0.5) [0.5 on Epop[19]] -> cell 64, seg 0 (0.5) [0.5 on Epop[64]], weight: 4.1363508E-4, delay 1.5
        h("Epop[64] syn_projEE_ampa[1584] = new ampa(0.5)")
        h("Epop[19] netConn_projEE_ampa[1584] = new NetCon(&v(0.5), syn_projEE_ampa[1584], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1585: cell 19, seg 0 (0.5) [0.5 on Epop[19]] -> cell 65, seg 0 (0.5) [0.5 on Epop[65]], weight: 4.1363508E-4, delay 1.5
        h("Epop[65] syn_projEE_ampa[1585] = new ampa(0.5)")
        h("Epop[19] netConn_projEE_ampa[1585] = new NetCon(&v(0.5), syn_projEE_ampa[1585], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1586: cell 19, seg 0 (0.5) [0.5 on Epop[19]] -> cell 66, seg 0 (0.5) [0.5 on Epop[66]], weight: 4.1363508E-4, delay 1.5
        h("Epop[66] syn_projEE_ampa[1586] = new ampa(0.5)")
        h("Epop[19] netConn_projEE_ampa[1586] = new NetCon(&v(0.5), syn_projEE_ampa[1586], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1587: cell 19, seg 0 (0.5) [0.5 on Epop[19]] -> cell 67, seg 0 (0.5) [0.5 on Epop[67]], weight: 4.1363508E-4, delay 1.5
        h("Epop[67] syn_projEE_ampa[1587] = new ampa(0.5)")
        h("Epop[19] netConn_projEE_ampa[1587] = new NetCon(&v(0.5), syn_projEE_ampa[1587], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1588: cell 19, seg 0 (0.5) [0.5 on Epop[19]] -> cell 68, seg 0 (0.5) [0.5 on Epop[68]], weight: 4.1363508E-4, delay 1.5
        h("Epop[68] syn_projEE_ampa[1588] = new ampa(0.5)")
        h("Epop[19] netConn_projEE_ampa[1588] = new NetCon(&v(0.5), syn_projEE_ampa[1588], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1589: cell 19, seg 0 (0.5) [0.5 on Epop[19]] -> cell 69, seg 0 (0.5) [0.5 on Epop[69]], weight: 4.1363508E-4, delay 1.5
        h("Epop[69] syn_projEE_ampa[1589] = new ampa(0.5)")
        h("Epop[19] netConn_projEE_ampa[1589] = new NetCon(&v(0.5), syn_projEE_ampa[1589], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1590: cell 19, seg 0 (0.5) [0.5 on Epop[19]] -> cell 70, seg 0 (0.5) [0.5 on Epop[70]], weight: 4.1363508E-4, delay 1.5
        h("Epop[70] syn_projEE_ampa[1590] = new ampa(0.5)")
        h("Epop[19] netConn_projEE_ampa[1590] = new NetCon(&v(0.5), syn_projEE_ampa[1590], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1591: cell 19, seg 0 (0.5) [0.5 on Epop[19]] -> cell 71, seg 0 (0.5) [0.5 on Epop[71]], weight: 4.1363508E-4, delay 1.5
        h("Epop[71] syn_projEE_ampa[1591] = new ampa(0.5)")
        h("Epop[19] netConn_projEE_ampa[1591] = new NetCon(&v(0.5), syn_projEE_ampa[1591], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1592: cell 19, seg 0 (0.5) [0.5 on Epop[19]] -> cell 72, seg 0 (0.5) [0.5 on Epop[72]], weight: 4.1363508E-4, delay 1.5
        h("Epop[72] syn_projEE_ampa[1592] = new ampa(0.5)")
        h("Epop[19] netConn_projEE_ampa[1592] = new NetCon(&v(0.5), syn_projEE_ampa[1592], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1593: cell 19, seg 0 (0.5) [0.5 on Epop[19]] -> cell 73, seg 0 (0.5) [0.5 on Epop[73]], weight: 4.1363508E-4, delay 1.5
        h("Epop[73] syn_projEE_ampa[1593] = new ampa(0.5)")
        h("Epop[19] netConn_projEE_ampa[1593] = new NetCon(&v(0.5), syn_projEE_ampa[1593], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1594: cell 19, seg 0 (0.5) [0.5 on Epop[19]] -> cell 74, seg 0 (0.5) [0.5 on Epop[74]], weight: 4.1363508E-4, delay 1.5
        h("Epop[74] syn_projEE_ampa[1594] = new ampa(0.5)")
        h("Epop[19] netConn_projEE_ampa[1594] = new NetCon(&v(0.5), syn_projEE_ampa[1594], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1595: cell 19, seg 0 (0.5) [0.5 on Epop[19]] -> cell 75, seg 0 (0.5) [0.5 on Epop[75]], weight: 4.1363508E-4, delay 1.5
        h("Epop[75] syn_projEE_ampa[1595] = new ampa(0.5)")
        h("Epop[19] netConn_projEE_ampa[1595] = new NetCon(&v(0.5), syn_projEE_ampa[1595], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1596: cell 19, seg 0 (0.5) [0.5 on Epop[19]] -> cell 76, seg 0 (0.5) [0.5 on Epop[76]], weight: 4.1363508E-4, delay 1.5
        h("Epop[76] syn_projEE_ampa[1596] = new ampa(0.5)")
        h("Epop[19] netConn_projEE_ampa[1596] = new NetCon(&v(0.5), syn_projEE_ampa[1596], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1597: cell 19, seg 0 (0.5) [0.5 on Epop[19]] -> cell 77, seg 0 (0.5) [0.5 on Epop[77]], weight: 4.1363508E-4, delay 1.5
        h("Epop[77] syn_projEE_ampa[1597] = new ampa(0.5)")
        h("Epop[19] netConn_projEE_ampa[1597] = new NetCon(&v(0.5), syn_projEE_ampa[1597], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1598: cell 19, seg 0 (0.5) [0.5 on Epop[19]] -> cell 78, seg 0 (0.5) [0.5 on Epop[78]], weight: 4.1363508E-4, delay 1.5
        h("Epop[78] syn_projEE_ampa[1598] = new ampa(0.5)")
        h("Epop[19] netConn_projEE_ampa[1598] = new NetCon(&v(0.5), syn_projEE_ampa[1598], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1599: cell 19, seg 0 (0.5) [0.5 on Epop[19]] -> cell 79, seg 0 (0.5) [0.5 on Epop[79]], weight: 4.1363508E-4, delay 1.5
        h("Epop[79] syn_projEE_ampa[1599] = new ampa(0.5)")
        h("Epop[19] netConn_projEE_ampa[1599] = new NetCon(&v(0.5), syn_projEE_ampa[1599], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1600: cell 20, seg 0 (0.5) [0.5 on Epop[20]] -> cell 0, seg 0 (0.5) [0.5 on Epop[0]], weight: 4.1363508E-4, delay 1.5
        h("Epop[0] syn_projEE_ampa[1600] = new ampa(0.5)")
        h("Epop[20] netConn_projEE_ampa[1600] = new NetCon(&v(0.5), syn_projEE_ampa[1600], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1601: cell 20, seg 0 (0.5) [0.5 on Epop[20]] -> cell 1, seg 0 (0.5) [0.5 on Epop[1]], weight: 4.1363508E-4, delay 1.5
        h("Epop[1] syn_projEE_ampa[1601] = new ampa(0.5)")
        h("Epop[20] netConn_projEE_ampa[1601] = new NetCon(&v(0.5), syn_projEE_ampa[1601], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1602: cell 20, seg 0 (0.5) [0.5 on Epop[20]] -> cell 2, seg 0 (0.5) [0.5 on Epop[2]], weight: 4.1363508E-4, delay 1.5
        h("Epop[2] syn_projEE_ampa[1602] = new ampa(0.5)")
        h("Epop[20] netConn_projEE_ampa[1602] = new NetCon(&v(0.5), syn_projEE_ampa[1602], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1603: cell 20, seg 0 (0.5) [0.5 on Epop[20]] -> cell 3, seg 0 (0.5) [0.5 on Epop[3]], weight: 4.1363508E-4, delay 1.5
        h("Epop[3] syn_projEE_ampa[1603] = new ampa(0.5)")
        h("Epop[20] netConn_projEE_ampa[1603] = new NetCon(&v(0.5), syn_projEE_ampa[1603], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1604: cell 20, seg 0 (0.5) [0.5 on Epop[20]] -> cell 4, seg 0 (0.5) [0.5 on Epop[4]], weight: 4.1363508E-4, delay 1.5
        h("Epop[4] syn_projEE_ampa[1604] = new ampa(0.5)")
        h("Epop[20] netConn_projEE_ampa[1604] = new NetCon(&v(0.5), syn_projEE_ampa[1604], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1605: cell 20, seg 0 (0.5) [0.5 on Epop[20]] -> cell 5, seg 0 (0.5) [0.5 on Epop[5]], weight: 4.1363508E-4, delay 1.5
        h("Epop[5] syn_projEE_ampa[1605] = new ampa(0.5)")
        h("Epop[20] netConn_projEE_ampa[1605] = new NetCon(&v(0.5), syn_projEE_ampa[1605], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1606: cell 20, seg 0 (0.5) [0.5 on Epop[20]] -> cell 6, seg 0 (0.5) [0.5 on Epop[6]], weight: 4.1363508E-4, delay 1.5
        h("Epop[6] syn_projEE_ampa[1606] = new ampa(0.5)")
        h("Epop[20] netConn_projEE_ampa[1606] = new NetCon(&v(0.5), syn_projEE_ampa[1606], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1607: cell 20, seg 0 (0.5) [0.5 on Epop[20]] -> cell 7, seg 0 (0.5) [0.5 on Epop[7]], weight: 4.1363508E-4, delay 1.5
        h("Epop[7] syn_projEE_ampa[1607] = new ampa(0.5)")
        h("Epop[20] netConn_projEE_ampa[1607] = new NetCon(&v(0.5), syn_projEE_ampa[1607], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1608: cell 20, seg 0 (0.5) [0.5 on Epop[20]] -> cell 8, seg 0 (0.5) [0.5 on Epop[8]], weight: 4.1363508E-4, delay 1.5
        h("Epop[8] syn_projEE_ampa[1608] = new ampa(0.5)")
        h("Epop[20] netConn_projEE_ampa[1608] = new NetCon(&v(0.5), syn_projEE_ampa[1608], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1609: cell 20, seg 0 (0.5) [0.5 on Epop[20]] -> cell 9, seg 0 (0.5) [0.5 on Epop[9]], weight: 4.1363508E-4, delay 1.5
        h("Epop[9] syn_projEE_ampa[1609] = new ampa(0.5)")
        h("Epop[20] netConn_projEE_ampa[1609] = new NetCon(&v(0.5), syn_projEE_ampa[1609], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1610: cell 20, seg 0 (0.5) [0.5 on Epop[20]] -> cell 10, seg 0 (0.5) [0.5 on Epop[10]], weight: 4.1363508E-4, delay 1.5
        h("Epop[10] syn_projEE_ampa[1610] = new ampa(0.5)")
        h("Epop[20] netConn_projEE_ampa[1610] = new NetCon(&v(0.5), syn_projEE_ampa[1610], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1611: cell 20, seg 0 (0.5) [0.5 on Epop[20]] -> cell 11, seg 0 (0.5) [0.5 on Epop[11]], weight: 4.1363508E-4, delay 1.5
        h("Epop[11] syn_projEE_ampa[1611] = new ampa(0.5)")
        h("Epop[20] netConn_projEE_ampa[1611] = new NetCon(&v(0.5), syn_projEE_ampa[1611], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1612: cell 20, seg 0 (0.5) [0.5 on Epop[20]] -> cell 12, seg 0 (0.5) [0.5 on Epop[12]], weight: 4.1363508E-4, delay 1.5
        h("Epop[12] syn_projEE_ampa[1612] = new ampa(0.5)")
        h("Epop[20] netConn_projEE_ampa[1612] = new NetCon(&v(0.5), syn_projEE_ampa[1612], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1613: cell 20, seg 0 (0.5) [0.5 on Epop[20]] -> cell 13, seg 0 (0.5) [0.5 on Epop[13]], weight: 4.1363508E-4, delay 1.5
        h("Epop[13] syn_projEE_ampa[1613] = new ampa(0.5)")
        h("Epop[20] netConn_projEE_ampa[1613] = new NetCon(&v(0.5), syn_projEE_ampa[1613], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1614: cell 20, seg 0 (0.5) [0.5 on Epop[20]] -> cell 14, seg 0 (0.5) [0.5 on Epop[14]], weight: 4.1363508E-4, delay 1.5
        h("Epop[14] syn_projEE_ampa[1614] = new ampa(0.5)")
        h("Epop[20] netConn_projEE_ampa[1614] = new NetCon(&v(0.5), syn_projEE_ampa[1614], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1615: cell 20, seg 0 (0.5) [0.5 on Epop[20]] -> cell 15, seg 0 (0.5) [0.5 on Epop[15]], weight: 4.1363508E-4, delay 1.5
        h("Epop[15] syn_projEE_ampa[1615] = new ampa(0.5)")
        h("Epop[20] netConn_projEE_ampa[1615] = new NetCon(&v(0.5), syn_projEE_ampa[1615], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1616: cell 20, seg 0 (0.5) [0.5 on Epop[20]] -> cell 16, seg 0 (0.5) [0.5 on Epop[16]], weight: 4.1363508E-4, delay 1.5
        h("Epop[16] syn_projEE_ampa[1616] = new ampa(0.5)")
        h("Epop[20] netConn_projEE_ampa[1616] = new NetCon(&v(0.5), syn_projEE_ampa[1616], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1617: cell 20, seg 0 (0.5) [0.5 on Epop[20]] -> cell 17, seg 0 (0.5) [0.5 on Epop[17]], weight: 4.1363508E-4, delay 1.5
        h("Epop[17] syn_projEE_ampa[1617] = new ampa(0.5)")
        h("Epop[20] netConn_projEE_ampa[1617] = new NetCon(&v(0.5), syn_projEE_ampa[1617], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1618: cell 20, seg 0 (0.5) [0.5 on Epop[20]] -> cell 18, seg 0 (0.5) [0.5 on Epop[18]], weight: 4.1363508E-4, delay 1.5
        h("Epop[18] syn_projEE_ampa[1618] = new ampa(0.5)")
        h("Epop[20] netConn_projEE_ampa[1618] = new NetCon(&v(0.5), syn_projEE_ampa[1618], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1619: cell 20, seg 0 (0.5) [0.5 on Epop[20]] -> cell 19, seg 0 (0.5) [0.5 on Epop[19]], weight: 4.1363508E-4, delay 1.5
        h("Epop[19] syn_projEE_ampa[1619] = new ampa(0.5)")
        h("Epop[20] netConn_projEE_ampa[1619] = new NetCon(&v(0.5), syn_projEE_ampa[1619], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1620: cell 20, seg 0 (0.5) [0.5 on Epop[20]] -> cell 20, seg 0 (0.5) [0.5 on Epop[20]], weight: 4.1363508E-4, delay 1.5
        h("Epop[20] syn_projEE_ampa[1620] = new ampa(0.5)")
        h("Epop[20] netConn_projEE_ampa[1620] = new NetCon(&v(0.5), syn_projEE_ampa[1620], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1621: cell 20, seg 0 (0.5) [0.5 on Epop[20]] -> cell 21, seg 0 (0.5) [0.5 on Epop[21]], weight: 4.1363508E-4, delay 1.5
        h("Epop[21] syn_projEE_ampa[1621] = new ampa(0.5)")
        h("Epop[20] netConn_projEE_ampa[1621] = new NetCon(&v(0.5), syn_projEE_ampa[1621], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1622: cell 20, seg 0 (0.5) [0.5 on Epop[20]] -> cell 22, seg 0 (0.5) [0.5 on Epop[22]], weight: 4.1363508E-4, delay 1.5
        h("Epop[22] syn_projEE_ampa[1622] = new ampa(0.5)")
        h("Epop[20] netConn_projEE_ampa[1622] = new NetCon(&v(0.5), syn_projEE_ampa[1622], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1623: cell 20, seg 0 (0.5) [0.5 on Epop[20]] -> cell 23, seg 0 (0.5) [0.5 on Epop[23]], weight: 4.1363508E-4, delay 1.5
        h("Epop[23] syn_projEE_ampa[1623] = new ampa(0.5)")
        h("Epop[20] netConn_projEE_ampa[1623] = new NetCon(&v(0.5), syn_projEE_ampa[1623], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1624: cell 20, seg 0 (0.5) [0.5 on Epop[20]] -> cell 24, seg 0 (0.5) [0.5 on Epop[24]], weight: 4.1363508E-4, delay 1.5
        h("Epop[24] syn_projEE_ampa[1624] = new ampa(0.5)")
        h("Epop[20] netConn_projEE_ampa[1624] = new NetCon(&v(0.5), syn_projEE_ampa[1624], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1625: cell 20, seg 0 (0.5) [0.5 on Epop[20]] -> cell 25, seg 0 (0.5) [0.5 on Epop[25]], weight: 4.1363508E-4, delay 1.5
        h("Epop[25] syn_projEE_ampa[1625] = new ampa(0.5)")
        h("Epop[20] netConn_projEE_ampa[1625] = new NetCon(&v(0.5), syn_projEE_ampa[1625], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1626: cell 20, seg 0 (0.5) [0.5 on Epop[20]] -> cell 26, seg 0 (0.5) [0.5 on Epop[26]], weight: 4.1363508E-4, delay 1.5
        h("Epop[26] syn_projEE_ampa[1626] = new ampa(0.5)")
        h("Epop[20] netConn_projEE_ampa[1626] = new NetCon(&v(0.5), syn_projEE_ampa[1626], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1627: cell 20, seg 0 (0.5) [0.5 on Epop[20]] -> cell 27, seg 0 (0.5) [0.5 on Epop[27]], weight: 4.1363508E-4, delay 1.5
        h("Epop[27] syn_projEE_ampa[1627] = new ampa(0.5)")
        h("Epop[20] netConn_projEE_ampa[1627] = new NetCon(&v(0.5), syn_projEE_ampa[1627], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1628: cell 20, seg 0 (0.5) [0.5 on Epop[20]] -> cell 28, seg 0 (0.5) [0.5 on Epop[28]], weight: 4.1363508E-4, delay 1.5
        h("Epop[28] syn_projEE_ampa[1628] = new ampa(0.5)")
        h("Epop[20] netConn_projEE_ampa[1628] = new NetCon(&v(0.5), syn_projEE_ampa[1628], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1629: cell 20, seg 0 (0.5) [0.5 on Epop[20]] -> cell 29, seg 0 (0.5) [0.5 on Epop[29]], weight: 4.1363508E-4, delay 1.5
        h("Epop[29] syn_projEE_ampa[1629] = new ampa(0.5)")
        h("Epop[20] netConn_projEE_ampa[1629] = new NetCon(&v(0.5), syn_projEE_ampa[1629], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1630: cell 20, seg 0 (0.5) [0.5 on Epop[20]] -> cell 30, seg 0 (0.5) [0.5 on Epop[30]], weight: 4.1363508E-4, delay 1.5
        h("Epop[30] syn_projEE_ampa[1630] = new ampa(0.5)")
        h("Epop[20] netConn_projEE_ampa[1630] = new NetCon(&v(0.5), syn_projEE_ampa[1630], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1631: cell 20, seg 0 (0.5) [0.5 on Epop[20]] -> cell 31, seg 0 (0.5) [0.5 on Epop[31]], weight: 4.1363508E-4, delay 1.5
        h("Epop[31] syn_projEE_ampa[1631] = new ampa(0.5)")
        h("Epop[20] netConn_projEE_ampa[1631] = new NetCon(&v(0.5), syn_projEE_ampa[1631], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1632: cell 20, seg 0 (0.5) [0.5 on Epop[20]] -> cell 32, seg 0 (0.5) [0.5 on Epop[32]], weight: 4.1363508E-4, delay 1.5
        h("Epop[32] syn_projEE_ampa[1632] = new ampa(0.5)")
        h("Epop[20] netConn_projEE_ampa[1632] = new NetCon(&v(0.5), syn_projEE_ampa[1632], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1633: cell 20, seg 0 (0.5) [0.5 on Epop[20]] -> cell 33, seg 0 (0.5) [0.5 on Epop[33]], weight: 4.1363508E-4, delay 1.5
        h("Epop[33] syn_projEE_ampa[1633] = new ampa(0.5)")
        h("Epop[20] netConn_projEE_ampa[1633] = new NetCon(&v(0.5), syn_projEE_ampa[1633], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1634: cell 20, seg 0 (0.5) [0.5 on Epop[20]] -> cell 34, seg 0 (0.5) [0.5 on Epop[34]], weight: 4.1363508E-4, delay 1.5
        h("Epop[34] syn_projEE_ampa[1634] = new ampa(0.5)")
        h("Epop[20] netConn_projEE_ampa[1634] = new NetCon(&v(0.5), syn_projEE_ampa[1634], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1635: cell 20, seg 0 (0.5) [0.5 on Epop[20]] -> cell 35, seg 0 (0.5) [0.5 on Epop[35]], weight: 4.1363508E-4, delay 1.5
        h("Epop[35] syn_projEE_ampa[1635] = new ampa(0.5)")
        h("Epop[20] netConn_projEE_ampa[1635] = new NetCon(&v(0.5), syn_projEE_ampa[1635], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1636: cell 20, seg 0 (0.5) [0.5 on Epop[20]] -> cell 36, seg 0 (0.5) [0.5 on Epop[36]], weight: 4.1363508E-4, delay 1.5
        h("Epop[36] syn_projEE_ampa[1636] = new ampa(0.5)")
        h("Epop[20] netConn_projEE_ampa[1636] = new NetCon(&v(0.5), syn_projEE_ampa[1636], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1637: cell 20, seg 0 (0.5) [0.5 on Epop[20]] -> cell 37, seg 0 (0.5) [0.5 on Epop[37]], weight: 4.1363508E-4, delay 1.5
        h("Epop[37] syn_projEE_ampa[1637] = new ampa(0.5)")
        h("Epop[20] netConn_projEE_ampa[1637] = new NetCon(&v(0.5), syn_projEE_ampa[1637], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1638: cell 20, seg 0 (0.5) [0.5 on Epop[20]] -> cell 38, seg 0 (0.5) [0.5 on Epop[38]], weight: 4.1363508E-4, delay 1.5
        h("Epop[38] syn_projEE_ampa[1638] = new ampa(0.5)")
        h("Epop[20] netConn_projEE_ampa[1638] = new NetCon(&v(0.5), syn_projEE_ampa[1638], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1639: cell 20, seg 0 (0.5) [0.5 on Epop[20]] -> cell 39, seg 0 (0.5) [0.5 on Epop[39]], weight: 4.1363508E-4, delay 1.5
        h("Epop[39] syn_projEE_ampa[1639] = new ampa(0.5)")
        h("Epop[20] netConn_projEE_ampa[1639] = new NetCon(&v(0.5), syn_projEE_ampa[1639], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1640: cell 20, seg 0 (0.5) [0.5 on Epop[20]] -> cell 40, seg 0 (0.5) [0.5 on Epop[40]], weight: 4.1363508E-4, delay 1.5
        h("Epop[40] syn_projEE_ampa[1640] = new ampa(0.5)")
        h("Epop[20] netConn_projEE_ampa[1640] = new NetCon(&v(0.5), syn_projEE_ampa[1640], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1641: cell 20, seg 0 (0.5) [0.5 on Epop[20]] -> cell 41, seg 0 (0.5) [0.5 on Epop[41]], weight: 4.1363508E-4, delay 1.5
        h("Epop[41] syn_projEE_ampa[1641] = new ampa(0.5)")
        h("Epop[20] netConn_projEE_ampa[1641] = new NetCon(&v(0.5), syn_projEE_ampa[1641], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1642: cell 20, seg 0 (0.5) [0.5 on Epop[20]] -> cell 42, seg 0 (0.5) [0.5 on Epop[42]], weight: 4.1363508E-4, delay 1.5
        h("Epop[42] syn_projEE_ampa[1642] = new ampa(0.5)")
        h("Epop[20] netConn_projEE_ampa[1642] = new NetCon(&v(0.5), syn_projEE_ampa[1642], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1643: cell 20, seg 0 (0.5) [0.5 on Epop[20]] -> cell 43, seg 0 (0.5) [0.5 on Epop[43]], weight: 4.1363508E-4, delay 1.5
        h("Epop[43] syn_projEE_ampa[1643] = new ampa(0.5)")
        h("Epop[20] netConn_projEE_ampa[1643] = new NetCon(&v(0.5), syn_projEE_ampa[1643], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1644: cell 20, seg 0 (0.5) [0.5 on Epop[20]] -> cell 44, seg 0 (0.5) [0.5 on Epop[44]], weight: 4.1363508E-4, delay 1.5
        h("Epop[44] syn_projEE_ampa[1644] = new ampa(0.5)")
        h("Epop[20] netConn_projEE_ampa[1644] = new NetCon(&v(0.5), syn_projEE_ampa[1644], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1645: cell 20, seg 0 (0.5) [0.5 on Epop[20]] -> cell 45, seg 0 (0.5) [0.5 on Epop[45]], weight: 4.1363508E-4, delay 1.5
        h("Epop[45] syn_projEE_ampa[1645] = new ampa(0.5)")
        h("Epop[20] netConn_projEE_ampa[1645] = new NetCon(&v(0.5), syn_projEE_ampa[1645], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1646: cell 20, seg 0 (0.5) [0.5 on Epop[20]] -> cell 46, seg 0 (0.5) [0.5 on Epop[46]], weight: 4.1363508E-4, delay 1.5
        h("Epop[46] syn_projEE_ampa[1646] = new ampa(0.5)")
        h("Epop[20] netConn_projEE_ampa[1646] = new NetCon(&v(0.5), syn_projEE_ampa[1646], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1647: cell 20, seg 0 (0.5) [0.5 on Epop[20]] -> cell 47, seg 0 (0.5) [0.5 on Epop[47]], weight: 4.1363508E-4, delay 1.5
        h("Epop[47] syn_projEE_ampa[1647] = new ampa(0.5)")
        h("Epop[20] netConn_projEE_ampa[1647] = new NetCon(&v(0.5), syn_projEE_ampa[1647], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1648: cell 20, seg 0 (0.5) [0.5 on Epop[20]] -> cell 48, seg 0 (0.5) [0.5 on Epop[48]], weight: 4.1363508E-4, delay 1.5
        h("Epop[48] syn_projEE_ampa[1648] = new ampa(0.5)")
        h("Epop[20] netConn_projEE_ampa[1648] = new NetCon(&v(0.5), syn_projEE_ampa[1648], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1649: cell 20, seg 0 (0.5) [0.5 on Epop[20]] -> cell 49, seg 0 (0.5) [0.5 on Epop[49]], weight: 4.1363508E-4, delay 1.5
        h("Epop[49] syn_projEE_ampa[1649] = new ampa(0.5)")
        h("Epop[20] netConn_projEE_ampa[1649] = new NetCon(&v(0.5), syn_projEE_ampa[1649], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1650: cell 20, seg 0 (0.5) [0.5 on Epop[20]] -> cell 50, seg 0 (0.5) [0.5 on Epop[50]], weight: 4.1363508E-4, delay 1.5
        h("Epop[50] syn_projEE_ampa[1650] = new ampa(0.5)")
        h("Epop[20] netConn_projEE_ampa[1650] = new NetCon(&v(0.5), syn_projEE_ampa[1650], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1651: cell 20, seg 0 (0.5) [0.5 on Epop[20]] -> cell 51, seg 0 (0.5) [0.5 on Epop[51]], weight: 4.1363508E-4, delay 1.5
        h("Epop[51] syn_projEE_ampa[1651] = new ampa(0.5)")
        h("Epop[20] netConn_projEE_ampa[1651] = new NetCon(&v(0.5), syn_projEE_ampa[1651], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1652: cell 20, seg 0 (0.5) [0.5 on Epop[20]] -> cell 52, seg 0 (0.5) [0.5 on Epop[52]], weight: 4.1363508E-4, delay 1.5
        h("Epop[52] syn_projEE_ampa[1652] = new ampa(0.5)")
        h("Epop[20] netConn_projEE_ampa[1652] = new NetCon(&v(0.5), syn_projEE_ampa[1652], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1653: cell 20, seg 0 (0.5) [0.5 on Epop[20]] -> cell 53, seg 0 (0.5) [0.5 on Epop[53]], weight: 4.1363508E-4, delay 1.5
        h("Epop[53] syn_projEE_ampa[1653] = new ampa(0.5)")
        h("Epop[20] netConn_projEE_ampa[1653] = new NetCon(&v(0.5), syn_projEE_ampa[1653], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1654: cell 20, seg 0 (0.5) [0.5 on Epop[20]] -> cell 54, seg 0 (0.5) [0.5 on Epop[54]], weight: 4.1363508E-4, delay 1.5
        h("Epop[54] syn_projEE_ampa[1654] = new ampa(0.5)")
        h("Epop[20] netConn_projEE_ampa[1654] = new NetCon(&v(0.5), syn_projEE_ampa[1654], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1655: cell 20, seg 0 (0.5) [0.5 on Epop[20]] -> cell 55, seg 0 (0.5) [0.5 on Epop[55]], weight: 4.1363508E-4, delay 1.5
        h("Epop[55] syn_projEE_ampa[1655] = new ampa(0.5)")
        h("Epop[20] netConn_projEE_ampa[1655] = new NetCon(&v(0.5), syn_projEE_ampa[1655], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1656: cell 20, seg 0 (0.5) [0.5 on Epop[20]] -> cell 56, seg 0 (0.5) [0.5 on Epop[56]], weight: 4.1363508E-4, delay 1.5
        h("Epop[56] syn_projEE_ampa[1656] = new ampa(0.5)")
        h("Epop[20] netConn_projEE_ampa[1656] = new NetCon(&v(0.5), syn_projEE_ampa[1656], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1657: cell 20, seg 0 (0.5) [0.5 on Epop[20]] -> cell 57, seg 0 (0.5) [0.5 on Epop[57]], weight: 4.1363508E-4, delay 1.5
        h("Epop[57] syn_projEE_ampa[1657] = new ampa(0.5)")
        h("Epop[20] netConn_projEE_ampa[1657] = new NetCon(&v(0.5), syn_projEE_ampa[1657], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1658: cell 20, seg 0 (0.5) [0.5 on Epop[20]] -> cell 58, seg 0 (0.5) [0.5 on Epop[58]], weight: 4.1363508E-4, delay 1.5
        h("Epop[58] syn_projEE_ampa[1658] = new ampa(0.5)")
        h("Epop[20] netConn_projEE_ampa[1658] = new NetCon(&v(0.5), syn_projEE_ampa[1658], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1659: cell 20, seg 0 (0.5) [0.5 on Epop[20]] -> cell 59, seg 0 (0.5) [0.5 on Epop[59]], weight: 4.1363508E-4, delay 1.5
        h("Epop[59] syn_projEE_ampa[1659] = new ampa(0.5)")
        h("Epop[20] netConn_projEE_ampa[1659] = new NetCon(&v(0.5), syn_projEE_ampa[1659], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1660: cell 20, seg 0 (0.5) [0.5 on Epop[20]] -> cell 60, seg 0 (0.5) [0.5 on Epop[60]], weight: 4.1363508E-4, delay 1.5
        h("Epop[60] syn_projEE_ampa[1660] = new ampa(0.5)")
        h("Epop[20] netConn_projEE_ampa[1660] = new NetCon(&v(0.5), syn_projEE_ampa[1660], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1661: cell 20, seg 0 (0.5) [0.5 on Epop[20]] -> cell 61, seg 0 (0.5) [0.5 on Epop[61]], weight: 4.1363508E-4, delay 1.5
        h("Epop[61] syn_projEE_ampa[1661] = new ampa(0.5)")
        h("Epop[20] netConn_projEE_ampa[1661] = new NetCon(&v(0.5), syn_projEE_ampa[1661], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1662: cell 20, seg 0 (0.5) [0.5 on Epop[20]] -> cell 62, seg 0 (0.5) [0.5 on Epop[62]], weight: 4.1363508E-4, delay 1.5
        h("Epop[62] syn_projEE_ampa[1662] = new ampa(0.5)")
        h("Epop[20] netConn_projEE_ampa[1662] = new NetCon(&v(0.5), syn_projEE_ampa[1662], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1663: cell 20, seg 0 (0.5) [0.5 on Epop[20]] -> cell 63, seg 0 (0.5) [0.5 on Epop[63]], weight: 4.1363508E-4, delay 1.5
        h("Epop[63] syn_projEE_ampa[1663] = new ampa(0.5)")
        h("Epop[20] netConn_projEE_ampa[1663] = new NetCon(&v(0.5), syn_projEE_ampa[1663], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1664: cell 20, seg 0 (0.5) [0.5 on Epop[20]] -> cell 64, seg 0 (0.5) [0.5 on Epop[64]], weight: 4.1363508E-4, delay 1.5
        h("Epop[64] syn_projEE_ampa[1664] = new ampa(0.5)")
        h("Epop[20] netConn_projEE_ampa[1664] = new NetCon(&v(0.5), syn_projEE_ampa[1664], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1665: cell 20, seg 0 (0.5) [0.5 on Epop[20]] -> cell 65, seg 0 (0.5) [0.5 on Epop[65]], weight: 4.1363508E-4, delay 1.5
        h("Epop[65] syn_projEE_ampa[1665] = new ampa(0.5)")
        h("Epop[20] netConn_projEE_ampa[1665] = new NetCon(&v(0.5), syn_projEE_ampa[1665], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1666: cell 20, seg 0 (0.5) [0.5 on Epop[20]] -> cell 66, seg 0 (0.5) [0.5 on Epop[66]], weight: 4.1363508E-4, delay 1.5
        h("Epop[66] syn_projEE_ampa[1666] = new ampa(0.5)")
        h("Epop[20] netConn_projEE_ampa[1666] = new NetCon(&v(0.5), syn_projEE_ampa[1666], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1667: cell 20, seg 0 (0.5) [0.5 on Epop[20]] -> cell 67, seg 0 (0.5) [0.5 on Epop[67]], weight: 4.1363508E-4, delay 1.5
        h("Epop[67] syn_projEE_ampa[1667] = new ampa(0.5)")
        h("Epop[20] netConn_projEE_ampa[1667] = new NetCon(&v(0.5), syn_projEE_ampa[1667], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1668: cell 20, seg 0 (0.5) [0.5 on Epop[20]] -> cell 68, seg 0 (0.5) [0.5 on Epop[68]], weight: 4.1363508E-4, delay 1.5
        h("Epop[68] syn_projEE_ampa[1668] = new ampa(0.5)")
        h("Epop[20] netConn_projEE_ampa[1668] = new NetCon(&v(0.5), syn_projEE_ampa[1668], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1669: cell 20, seg 0 (0.5) [0.5 on Epop[20]] -> cell 69, seg 0 (0.5) [0.5 on Epop[69]], weight: 4.1363508E-4, delay 1.5
        h("Epop[69] syn_projEE_ampa[1669] = new ampa(0.5)")
        h("Epop[20] netConn_projEE_ampa[1669] = new NetCon(&v(0.5), syn_projEE_ampa[1669], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1670: cell 20, seg 0 (0.5) [0.5 on Epop[20]] -> cell 70, seg 0 (0.5) [0.5 on Epop[70]], weight: 4.1363508E-4, delay 1.5
        h("Epop[70] syn_projEE_ampa[1670] = new ampa(0.5)")
        h("Epop[20] netConn_projEE_ampa[1670] = new NetCon(&v(0.5), syn_projEE_ampa[1670], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1671: cell 20, seg 0 (0.5) [0.5 on Epop[20]] -> cell 71, seg 0 (0.5) [0.5 on Epop[71]], weight: 4.1363508E-4, delay 1.5
        h("Epop[71] syn_projEE_ampa[1671] = new ampa(0.5)")
        h("Epop[20] netConn_projEE_ampa[1671] = new NetCon(&v(0.5), syn_projEE_ampa[1671], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1672: cell 20, seg 0 (0.5) [0.5 on Epop[20]] -> cell 72, seg 0 (0.5) [0.5 on Epop[72]], weight: 4.1363508E-4, delay 1.5
        h("Epop[72] syn_projEE_ampa[1672] = new ampa(0.5)")
        h("Epop[20] netConn_projEE_ampa[1672] = new NetCon(&v(0.5), syn_projEE_ampa[1672], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1673: cell 20, seg 0 (0.5) [0.5 on Epop[20]] -> cell 73, seg 0 (0.5) [0.5 on Epop[73]], weight: 4.1363508E-4, delay 1.5
        h("Epop[73] syn_projEE_ampa[1673] = new ampa(0.5)")
        h("Epop[20] netConn_projEE_ampa[1673] = new NetCon(&v(0.5), syn_projEE_ampa[1673], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1674: cell 20, seg 0 (0.5) [0.5 on Epop[20]] -> cell 74, seg 0 (0.5) [0.5 on Epop[74]], weight: 4.1363508E-4, delay 1.5
        h("Epop[74] syn_projEE_ampa[1674] = new ampa(0.5)")
        h("Epop[20] netConn_projEE_ampa[1674] = new NetCon(&v(0.5), syn_projEE_ampa[1674], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1675: cell 20, seg 0 (0.5) [0.5 on Epop[20]] -> cell 75, seg 0 (0.5) [0.5 on Epop[75]], weight: 4.1363508E-4, delay 1.5
        h("Epop[75] syn_projEE_ampa[1675] = new ampa(0.5)")
        h("Epop[20] netConn_projEE_ampa[1675] = new NetCon(&v(0.5), syn_projEE_ampa[1675], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1676: cell 20, seg 0 (0.5) [0.5 on Epop[20]] -> cell 76, seg 0 (0.5) [0.5 on Epop[76]], weight: 4.1363508E-4, delay 1.5
        h("Epop[76] syn_projEE_ampa[1676] = new ampa(0.5)")
        h("Epop[20] netConn_projEE_ampa[1676] = new NetCon(&v(0.5), syn_projEE_ampa[1676], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1677: cell 20, seg 0 (0.5) [0.5 on Epop[20]] -> cell 77, seg 0 (0.5) [0.5 on Epop[77]], weight: 4.1363508E-4, delay 1.5
        h("Epop[77] syn_projEE_ampa[1677] = new ampa(0.5)")
        h("Epop[20] netConn_projEE_ampa[1677] = new NetCon(&v(0.5), syn_projEE_ampa[1677], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1678: cell 20, seg 0 (0.5) [0.5 on Epop[20]] -> cell 78, seg 0 (0.5) [0.5 on Epop[78]], weight: 4.1363508E-4, delay 1.5
        h("Epop[78] syn_projEE_ampa[1678] = new ampa(0.5)")
        h("Epop[20] netConn_projEE_ampa[1678] = new NetCon(&v(0.5), syn_projEE_ampa[1678], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1679: cell 20, seg 0 (0.5) [0.5 on Epop[20]] -> cell 79, seg 0 (0.5) [0.5 on Epop[79]], weight: 4.1363508E-4, delay 1.5
        h("Epop[79] syn_projEE_ampa[1679] = new ampa(0.5)")
        h("Epop[20] netConn_projEE_ampa[1679] = new NetCon(&v(0.5), syn_projEE_ampa[1679], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1680: cell 21, seg 0 (0.5) [0.5 on Epop[21]] -> cell 0, seg 0 (0.5) [0.5 on Epop[0]], weight: 4.1363508E-4, delay 1.5
        h("Epop[0] syn_projEE_ampa[1680] = new ampa(0.5)")
        h("Epop[21] netConn_projEE_ampa[1680] = new NetCon(&v(0.5), syn_projEE_ampa[1680], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1681: cell 21, seg 0 (0.5) [0.5 on Epop[21]] -> cell 1, seg 0 (0.5) [0.5 on Epop[1]], weight: 4.1363508E-4, delay 1.5
        h("Epop[1] syn_projEE_ampa[1681] = new ampa(0.5)")
        h("Epop[21] netConn_projEE_ampa[1681] = new NetCon(&v(0.5), syn_projEE_ampa[1681], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1682: cell 21, seg 0 (0.5) [0.5 on Epop[21]] -> cell 2, seg 0 (0.5) [0.5 on Epop[2]], weight: 4.1363508E-4, delay 1.5
        h("Epop[2] syn_projEE_ampa[1682] = new ampa(0.5)")
        h("Epop[21] netConn_projEE_ampa[1682] = new NetCon(&v(0.5), syn_projEE_ampa[1682], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1683: cell 21, seg 0 (0.5) [0.5 on Epop[21]] -> cell 3, seg 0 (0.5) [0.5 on Epop[3]], weight: 4.1363508E-4, delay 1.5
        h("Epop[3] syn_projEE_ampa[1683] = new ampa(0.5)")
        h("Epop[21] netConn_projEE_ampa[1683] = new NetCon(&v(0.5), syn_projEE_ampa[1683], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1684: cell 21, seg 0 (0.5) [0.5 on Epop[21]] -> cell 4, seg 0 (0.5) [0.5 on Epop[4]], weight: 4.1363508E-4, delay 1.5
        h("Epop[4] syn_projEE_ampa[1684] = new ampa(0.5)")
        h("Epop[21] netConn_projEE_ampa[1684] = new NetCon(&v(0.5), syn_projEE_ampa[1684], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1685: cell 21, seg 0 (0.5) [0.5 on Epop[21]] -> cell 5, seg 0 (0.5) [0.5 on Epop[5]], weight: 4.1363508E-4, delay 1.5
        h("Epop[5] syn_projEE_ampa[1685] = new ampa(0.5)")
        h("Epop[21] netConn_projEE_ampa[1685] = new NetCon(&v(0.5), syn_projEE_ampa[1685], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1686: cell 21, seg 0 (0.5) [0.5 on Epop[21]] -> cell 6, seg 0 (0.5) [0.5 on Epop[6]], weight: 4.1363508E-4, delay 1.5
        h("Epop[6] syn_projEE_ampa[1686] = new ampa(0.5)")
        h("Epop[21] netConn_projEE_ampa[1686] = new NetCon(&v(0.5), syn_projEE_ampa[1686], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1687: cell 21, seg 0 (0.5) [0.5 on Epop[21]] -> cell 7, seg 0 (0.5) [0.5 on Epop[7]], weight: 4.1363508E-4, delay 1.5
        h("Epop[7] syn_projEE_ampa[1687] = new ampa(0.5)")
        h("Epop[21] netConn_projEE_ampa[1687] = new NetCon(&v(0.5), syn_projEE_ampa[1687], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1688: cell 21, seg 0 (0.5) [0.5 on Epop[21]] -> cell 8, seg 0 (0.5) [0.5 on Epop[8]], weight: 4.1363508E-4, delay 1.5
        h("Epop[8] syn_projEE_ampa[1688] = new ampa(0.5)")
        h("Epop[21] netConn_projEE_ampa[1688] = new NetCon(&v(0.5), syn_projEE_ampa[1688], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1689: cell 21, seg 0 (0.5) [0.5 on Epop[21]] -> cell 9, seg 0 (0.5) [0.5 on Epop[9]], weight: 4.1363508E-4, delay 1.5
        h("Epop[9] syn_projEE_ampa[1689] = new ampa(0.5)")
        h("Epop[21] netConn_projEE_ampa[1689] = new NetCon(&v(0.5), syn_projEE_ampa[1689], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1690: cell 21, seg 0 (0.5) [0.5 on Epop[21]] -> cell 10, seg 0 (0.5) [0.5 on Epop[10]], weight: 4.1363508E-4, delay 1.5
        h("Epop[10] syn_projEE_ampa[1690] = new ampa(0.5)")
        h("Epop[21] netConn_projEE_ampa[1690] = new NetCon(&v(0.5), syn_projEE_ampa[1690], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1691: cell 21, seg 0 (0.5) [0.5 on Epop[21]] -> cell 11, seg 0 (0.5) [0.5 on Epop[11]], weight: 4.1363508E-4, delay 1.5
        h("Epop[11] syn_projEE_ampa[1691] = new ampa(0.5)")
        h("Epop[21] netConn_projEE_ampa[1691] = new NetCon(&v(0.5), syn_projEE_ampa[1691], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1692: cell 21, seg 0 (0.5) [0.5 on Epop[21]] -> cell 12, seg 0 (0.5) [0.5 on Epop[12]], weight: 4.1363508E-4, delay 1.5
        h("Epop[12] syn_projEE_ampa[1692] = new ampa(0.5)")
        h("Epop[21] netConn_projEE_ampa[1692] = new NetCon(&v(0.5), syn_projEE_ampa[1692], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1693: cell 21, seg 0 (0.5) [0.5 on Epop[21]] -> cell 13, seg 0 (0.5) [0.5 on Epop[13]], weight: 4.1363508E-4, delay 1.5
        h("Epop[13] syn_projEE_ampa[1693] = new ampa(0.5)")
        h("Epop[21] netConn_projEE_ampa[1693] = new NetCon(&v(0.5), syn_projEE_ampa[1693], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1694: cell 21, seg 0 (0.5) [0.5 on Epop[21]] -> cell 14, seg 0 (0.5) [0.5 on Epop[14]], weight: 4.1363508E-4, delay 1.5
        h("Epop[14] syn_projEE_ampa[1694] = new ampa(0.5)")
        h("Epop[21] netConn_projEE_ampa[1694] = new NetCon(&v(0.5), syn_projEE_ampa[1694], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1695: cell 21, seg 0 (0.5) [0.5 on Epop[21]] -> cell 15, seg 0 (0.5) [0.5 on Epop[15]], weight: 4.1363508E-4, delay 1.5
        h("Epop[15] syn_projEE_ampa[1695] = new ampa(0.5)")
        h("Epop[21] netConn_projEE_ampa[1695] = new NetCon(&v(0.5), syn_projEE_ampa[1695], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1696: cell 21, seg 0 (0.5) [0.5 on Epop[21]] -> cell 16, seg 0 (0.5) [0.5 on Epop[16]], weight: 4.1363508E-4, delay 1.5
        h("Epop[16] syn_projEE_ampa[1696] = new ampa(0.5)")
        h("Epop[21] netConn_projEE_ampa[1696] = new NetCon(&v(0.5), syn_projEE_ampa[1696], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1697: cell 21, seg 0 (0.5) [0.5 on Epop[21]] -> cell 17, seg 0 (0.5) [0.5 on Epop[17]], weight: 4.1363508E-4, delay 1.5
        h("Epop[17] syn_projEE_ampa[1697] = new ampa(0.5)")
        h("Epop[21] netConn_projEE_ampa[1697] = new NetCon(&v(0.5), syn_projEE_ampa[1697], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1698: cell 21, seg 0 (0.5) [0.5 on Epop[21]] -> cell 18, seg 0 (0.5) [0.5 on Epop[18]], weight: 4.1363508E-4, delay 1.5
        h("Epop[18] syn_projEE_ampa[1698] = new ampa(0.5)")
        h("Epop[21] netConn_projEE_ampa[1698] = new NetCon(&v(0.5), syn_projEE_ampa[1698], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1699: cell 21, seg 0 (0.5) [0.5 on Epop[21]] -> cell 19, seg 0 (0.5) [0.5 on Epop[19]], weight: 4.1363508E-4, delay 1.5
        h("Epop[19] syn_projEE_ampa[1699] = new ampa(0.5)")
        h("Epop[21] netConn_projEE_ampa[1699] = new NetCon(&v(0.5), syn_projEE_ampa[1699], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1700: cell 21, seg 0 (0.5) [0.5 on Epop[21]] -> cell 20, seg 0 (0.5) [0.5 on Epop[20]], weight: 4.1363508E-4, delay 1.5
        h("Epop[20] syn_projEE_ampa[1700] = new ampa(0.5)")
        h("Epop[21] netConn_projEE_ampa[1700] = new NetCon(&v(0.5), syn_projEE_ampa[1700], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1701: cell 21, seg 0 (0.5) [0.5 on Epop[21]] -> cell 21, seg 0 (0.5) [0.5 on Epop[21]], weight: 4.1363508E-4, delay 1.5
        h("Epop[21] syn_projEE_ampa[1701] = new ampa(0.5)")
        h("Epop[21] netConn_projEE_ampa[1701] = new NetCon(&v(0.5), syn_projEE_ampa[1701], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1702: cell 21, seg 0 (0.5) [0.5 on Epop[21]] -> cell 22, seg 0 (0.5) [0.5 on Epop[22]], weight: 4.1363508E-4, delay 1.5
        h("Epop[22] syn_projEE_ampa[1702] = new ampa(0.5)")
        h("Epop[21] netConn_projEE_ampa[1702] = new NetCon(&v(0.5), syn_projEE_ampa[1702], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1703: cell 21, seg 0 (0.5) [0.5 on Epop[21]] -> cell 23, seg 0 (0.5) [0.5 on Epop[23]], weight: 4.1363508E-4, delay 1.5
        h("Epop[23] syn_projEE_ampa[1703] = new ampa(0.5)")
        h("Epop[21] netConn_projEE_ampa[1703] = new NetCon(&v(0.5), syn_projEE_ampa[1703], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1704: cell 21, seg 0 (0.5) [0.5 on Epop[21]] -> cell 24, seg 0 (0.5) [0.5 on Epop[24]], weight: 4.1363508E-4, delay 1.5
        h("Epop[24] syn_projEE_ampa[1704] = new ampa(0.5)")
        h("Epop[21] netConn_projEE_ampa[1704] = new NetCon(&v(0.5), syn_projEE_ampa[1704], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1705: cell 21, seg 0 (0.5) [0.5 on Epop[21]] -> cell 25, seg 0 (0.5) [0.5 on Epop[25]], weight: 4.1363508E-4, delay 1.5
        h("Epop[25] syn_projEE_ampa[1705] = new ampa(0.5)")
        h("Epop[21] netConn_projEE_ampa[1705] = new NetCon(&v(0.5), syn_projEE_ampa[1705], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1706: cell 21, seg 0 (0.5) [0.5 on Epop[21]] -> cell 26, seg 0 (0.5) [0.5 on Epop[26]], weight: 4.1363508E-4, delay 1.5
        h("Epop[26] syn_projEE_ampa[1706] = new ampa(0.5)")
        h("Epop[21] netConn_projEE_ampa[1706] = new NetCon(&v(0.5), syn_projEE_ampa[1706], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1707: cell 21, seg 0 (0.5) [0.5 on Epop[21]] -> cell 27, seg 0 (0.5) [0.5 on Epop[27]], weight: 4.1363508E-4, delay 1.5
        h("Epop[27] syn_projEE_ampa[1707] = new ampa(0.5)")
        h("Epop[21] netConn_projEE_ampa[1707] = new NetCon(&v(0.5), syn_projEE_ampa[1707], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1708: cell 21, seg 0 (0.5) [0.5 on Epop[21]] -> cell 28, seg 0 (0.5) [0.5 on Epop[28]], weight: 4.1363508E-4, delay 1.5
        h("Epop[28] syn_projEE_ampa[1708] = new ampa(0.5)")
        h("Epop[21] netConn_projEE_ampa[1708] = new NetCon(&v(0.5), syn_projEE_ampa[1708], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1709: cell 21, seg 0 (0.5) [0.5 on Epop[21]] -> cell 29, seg 0 (0.5) [0.5 on Epop[29]], weight: 4.1363508E-4, delay 1.5
        h("Epop[29] syn_projEE_ampa[1709] = new ampa(0.5)")
        h("Epop[21] netConn_projEE_ampa[1709] = new NetCon(&v(0.5), syn_projEE_ampa[1709], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1710: cell 21, seg 0 (0.5) [0.5 on Epop[21]] -> cell 30, seg 0 (0.5) [0.5 on Epop[30]], weight: 4.1363508E-4, delay 1.5
        h("Epop[30] syn_projEE_ampa[1710] = new ampa(0.5)")
        h("Epop[21] netConn_projEE_ampa[1710] = new NetCon(&v(0.5), syn_projEE_ampa[1710], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1711: cell 21, seg 0 (0.5) [0.5 on Epop[21]] -> cell 31, seg 0 (0.5) [0.5 on Epop[31]], weight: 4.1363508E-4, delay 1.5
        h("Epop[31] syn_projEE_ampa[1711] = new ampa(0.5)")
        h("Epop[21] netConn_projEE_ampa[1711] = new NetCon(&v(0.5), syn_projEE_ampa[1711], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1712: cell 21, seg 0 (0.5) [0.5 on Epop[21]] -> cell 32, seg 0 (0.5) [0.5 on Epop[32]], weight: 4.1363508E-4, delay 1.5
        h("Epop[32] syn_projEE_ampa[1712] = new ampa(0.5)")
        h("Epop[21] netConn_projEE_ampa[1712] = new NetCon(&v(0.5), syn_projEE_ampa[1712], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1713: cell 21, seg 0 (0.5) [0.5 on Epop[21]] -> cell 33, seg 0 (0.5) [0.5 on Epop[33]], weight: 4.1363508E-4, delay 1.5
        h("Epop[33] syn_projEE_ampa[1713] = new ampa(0.5)")
        h("Epop[21] netConn_projEE_ampa[1713] = new NetCon(&v(0.5), syn_projEE_ampa[1713], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1714: cell 21, seg 0 (0.5) [0.5 on Epop[21]] -> cell 34, seg 0 (0.5) [0.5 on Epop[34]], weight: 4.1363508E-4, delay 1.5
        h("Epop[34] syn_projEE_ampa[1714] = new ampa(0.5)")
        h("Epop[21] netConn_projEE_ampa[1714] = new NetCon(&v(0.5), syn_projEE_ampa[1714], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1715: cell 21, seg 0 (0.5) [0.5 on Epop[21]] -> cell 35, seg 0 (0.5) [0.5 on Epop[35]], weight: 4.1363508E-4, delay 1.5
        h("Epop[35] syn_projEE_ampa[1715] = new ampa(0.5)")
        h("Epop[21] netConn_projEE_ampa[1715] = new NetCon(&v(0.5), syn_projEE_ampa[1715], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1716: cell 21, seg 0 (0.5) [0.5 on Epop[21]] -> cell 36, seg 0 (0.5) [0.5 on Epop[36]], weight: 4.1363508E-4, delay 1.5
        h("Epop[36] syn_projEE_ampa[1716] = new ampa(0.5)")
        h("Epop[21] netConn_projEE_ampa[1716] = new NetCon(&v(0.5), syn_projEE_ampa[1716], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1717: cell 21, seg 0 (0.5) [0.5 on Epop[21]] -> cell 37, seg 0 (0.5) [0.5 on Epop[37]], weight: 4.1363508E-4, delay 1.5
        h("Epop[37] syn_projEE_ampa[1717] = new ampa(0.5)")
        h("Epop[21] netConn_projEE_ampa[1717] = new NetCon(&v(0.5), syn_projEE_ampa[1717], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1718: cell 21, seg 0 (0.5) [0.5 on Epop[21]] -> cell 38, seg 0 (0.5) [0.5 on Epop[38]], weight: 4.1363508E-4, delay 1.5
        h("Epop[38] syn_projEE_ampa[1718] = new ampa(0.5)")
        h("Epop[21] netConn_projEE_ampa[1718] = new NetCon(&v(0.5), syn_projEE_ampa[1718], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1719: cell 21, seg 0 (0.5) [0.5 on Epop[21]] -> cell 39, seg 0 (0.5) [0.5 on Epop[39]], weight: 4.1363508E-4, delay 1.5
        h("Epop[39] syn_projEE_ampa[1719] = new ampa(0.5)")
        h("Epop[21] netConn_projEE_ampa[1719] = new NetCon(&v(0.5), syn_projEE_ampa[1719], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1720: cell 21, seg 0 (0.5) [0.5 on Epop[21]] -> cell 40, seg 0 (0.5) [0.5 on Epop[40]], weight: 4.1363508E-4, delay 1.5
        h("Epop[40] syn_projEE_ampa[1720] = new ampa(0.5)")
        h("Epop[21] netConn_projEE_ampa[1720] = new NetCon(&v(0.5), syn_projEE_ampa[1720], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1721: cell 21, seg 0 (0.5) [0.5 on Epop[21]] -> cell 41, seg 0 (0.5) [0.5 on Epop[41]], weight: 4.1363508E-4, delay 1.5
        h("Epop[41] syn_projEE_ampa[1721] = new ampa(0.5)")
        h("Epop[21] netConn_projEE_ampa[1721] = new NetCon(&v(0.5), syn_projEE_ampa[1721], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1722: cell 21, seg 0 (0.5) [0.5 on Epop[21]] -> cell 42, seg 0 (0.5) [0.5 on Epop[42]], weight: 4.1363508E-4, delay 1.5
        h("Epop[42] syn_projEE_ampa[1722] = new ampa(0.5)")
        h("Epop[21] netConn_projEE_ampa[1722] = new NetCon(&v(0.5), syn_projEE_ampa[1722], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1723: cell 21, seg 0 (0.5) [0.5 on Epop[21]] -> cell 43, seg 0 (0.5) [0.5 on Epop[43]], weight: 4.1363508E-4, delay 1.5
        h("Epop[43] syn_projEE_ampa[1723] = new ampa(0.5)")
        h("Epop[21] netConn_projEE_ampa[1723] = new NetCon(&v(0.5), syn_projEE_ampa[1723], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1724: cell 21, seg 0 (0.5) [0.5 on Epop[21]] -> cell 44, seg 0 (0.5) [0.5 on Epop[44]], weight: 4.1363508E-4, delay 1.5
        h("Epop[44] syn_projEE_ampa[1724] = new ampa(0.5)")
        h("Epop[21] netConn_projEE_ampa[1724] = new NetCon(&v(0.5), syn_projEE_ampa[1724], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1725: cell 21, seg 0 (0.5) [0.5 on Epop[21]] -> cell 45, seg 0 (0.5) [0.5 on Epop[45]], weight: 4.1363508E-4, delay 1.5
        h("Epop[45] syn_projEE_ampa[1725] = new ampa(0.5)")
        h("Epop[21] netConn_projEE_ampa[1725] = new NetCon(&v(0.5), syn_projEE_ampa[1725], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1726: cell 21, seg 0 (0.5) [0.5 on Epop[21]] -> cell 46, seg 0 (0.5) [0.5 on Epop[46]], weight: 4.1363508E-4, delay 1.5
        h("Epop[46] syn_projEE_ampa[1726] = new ampa(0.5)")
        h("Epop[21] netConn_projEE_ampa[1726] = new NetCon(&v(0.5), syn_projEE_ampa[1726], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1727: cell 21, seg 0 (0.5) [0.5 on Epop[21]] -> cell 47, seg 0 (0.5) [0.5 on Epop[47]], weight: 4.1363508E-4, delay 1.5
        h("Epop[47] syn_projEE_ampa[1727] = new ampa(0.5)")
        h("Epop[21] netConn_projEE_ampa[1727] = new NetCon(&v(0.5), syn_projEE_ampa[1727], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1728: cell 21, seg 0 (0.5) [0.5 on Epop[21]] -> cell 48, seg 0 (0.5) [0.5 on Epop[48]], weight: 4.1363508E-4, delay 1.5
        h("Epop[48] syn_projEE_ampa[1728] = new ampa(0.5)")
        h("Epop[21] netConn_projEE_ampa[1728] = new NetCon(&v(0.5), syn_projEE_ampa[1728], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1729: cell 21, seg 0 (0.5) [0.5 on Epop[21]] -> cell 49, seg 0 (0.5) [0.5 on Epop[49]], weight: 4.1363508E-4, delay 1.5
        h("Epop[49] syn_projEE_ampa[1729] = new ampa(0.5)")
        h("Epop[21] netConn_projEE_ampa[1729] = new NetCon(&v(0.5), syn_projEE_ampa[1729], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1730: cell 21, seg 0 (0.5) [0.5 on Epop[21]] -> cell 50, seg 0 (0.5) [0.5 on Epop[50]], weight: 4.1363508E-4, delay 1.5
        h("Epop[50] syn_projEE_ampa[1730] = new ampa(0.5)")
        h("Epop[21] netConn_projEE_ampa[1730] = new NetCon(&v(0.5), syn_projEE_ampa[1730], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1731: cell 21, seg 0 (0.5) [0.5 on Epop[21]] -> cell 51, seg 0 (0.5) [0.5 on Epop[51]], weight: 4.1363508E-4, delay 1.5
        h("Epop[51] syn_projEE_ampa[1731] = new ampa(0.5)")
        h("Epop[21] netConn_projEE_ampa[1731] = new NetCon(&v(0.5), syn_projEE_ampa[1731], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1732: cell 21, seg 0 (0.5) [0.5 on Epop[21]] -> cell 52, seg 0 (0.5) [0.5 on Epop[52]], weight: 4.1363508E-4, delay 1.5
        h("Epop[52] syn_projEE_ampa[1732] = new ampa(0.5)")
        h("Epop[21] netConn_projEE_ampa[1732] = new NetCon(&v(0.5), syn_projEE_ampa[1732], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1733: cell 21, seg 0 (0.5) [0.5 on Epop[21]] -> cell 53, seg 0 (0.5) [0.5 on Epop[53]], weight: 4.1363508E-4, delay 1.5
        h("Epop[53] syn_projEE_ampa[1733] = new ampa(0.5)")
        h("Epop[21] netConn_projEE_ampa[1733] = new NetCon(&v(0.5), syn_projEE_ampa[1733], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1734: cell 21, seg 0 (0.5) [0.5 on Epop[21]] -> cell 54, seg 0 (0.5) [0.5 on Epop[54]], weight: 4.1363508E-4, delay 1.5
        h("Epop[54] syn_projEE_ampa[1734] = new ampa(0.5)")
        h("Epop[21] netConn_projEE_ampa[1734] = new NetCon(&v(0.5), syn_projEE_ampa[1734], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1735: cell 21, seg 0 (0.5) [0.5 on Epop[21]] -> cell 55, seg 0 (0.5) [0.5 on Epop[55]], weight: 4.1363508E-4, delay 1.5
        h("Epop[55] syn_projEE_ampa[1735] = new ampa(0.5)")
        h("Epop[21] netConn_projEE_ampa[1735] = new NetCon(&v(0.5), syn_projEE_ampa[1735], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1736: cell 21, seg 0 (0.5) [0.5 on Epop[21]] -> cell 56, seg 0 (0.5) [0.5 on Epop[56]], weight: 4.1363508E-4, delay 1.5
        h("Epop[56] syn_projEE_ampa[1736] = new ampa(0.5)")
        h("Epop[21] netConn_projEE_ampa[1736] = new NetCon(&v(0.5), syn_projEE_ampa[1736], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1737: cell 21, seg 0 (0.5) [0.5 on Epop[21]] -> cell 57, seg 0 (0.5) [0.5 on Epop[57]], weight: 4.1363508E-4, delay 1.5
        h("Epop[57] syn_projEE_ampa[1737] = new ampa(0.5)")
        h("Epop[21] netConn_projEE_ampa[1737] = new NetCon(&v(0.5), syn_projEE_ampa[1737], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1738: cell 21, seg 0 (0.5) [0.5 on Epop[21]] -> cell 58, seg 0 (0.5) [0.5 on Epop[58]], weight: 4.1363508E-4, delay 1.5
        h("Epop[58] syn_projEE_ampa[1738] = new ampa(0.5)")
        h("Epop[21] netConn_projEE_ampa[1738] = new NetCon(&v(0.5), syn_projEE_ampa[1738], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1739: cell 21, seg 0 (0.5) [0.5 on Epop[21]] -> cell 59, seg 0 (0.5) [0.5 on Epop[59]], weight: 4.1363508E-4, delay 1.5
        h("Epop[59] syn_projEE_ampa[1739] = new ampa(0.5)")
        h("Epop[21] netConn_projEE_ampa[1739] = new NetCon(&v(0.5), syn_projEE_ampa[1739], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1740: cell 21, seg 0 (0.5) [0.5 on Epop[21]] -> cell 60, seg 0 (0.5) [0.5 on Epop[60]], weight: 4.1363508E-4, delay 1.5
        h("Epop[60] syn_projEE_ampa[1740] = new ampa(0.5)")
        h("Epop[21] netConn_projEE_ampa[1740] = new NetCon(&v(0.5), syn_projEE_ampa[1740], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1741: cell 21, seg 0 (0.5) [0.5 on Epop[21]] -> cell 61, seg 0 (0.5) [0.5 on Epop[61]], weight: 4.1363508E-4, delay 1.5
        h("Epop[61] syn_projEE_ampa[1741] = new ampa(0.5)")
        h("Epop[21] netConn_projEE_ampa[1741] = new NetCon(&v(0.5), syn_projEE_ampa[1741], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1742: cell 21, seg 0 (0.5) [0.5 on Epop[21]] -> cell 62, seg 0 (0.5) [0.5 on Epop[62]], weight: 4.1363508E-4, delay 1.5
        h("Epop[62] syn_projEE_ampa[1742] = new ampa(0.5)")
        h("Epop[21] netConn_projEE_ampa[1742] = new NetCon(&v(0.5), syn_projEE_ampa[1742], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1743: cell 21, seg 0 (0.5) [0.5 on Epop[21]] -> cell 63, seg 0 (0.5) [0.5 on Epop[63]], weight: 4.1363508E-4, delay 1.5
        h("Epop[63] syn_projEE_ampa[1743] = new ampa(0.5)")
        h("Epop[21] netConn_projEE_ampa[1743] = new NetCon(&v(0.5), syn_projEE_ampa[1743], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1744: cell 21, seg 0 (0.5) [0.5 on Epop[21]] -> cell 64, seg 0 (0.5) [0.5 on Epop[64]], weight: 4.1363508E-4, delay 1.5
        h("Epop[64] syn_projEE_ampa[1744] = new ampa(0.5)")
        h("Epop[21] netConn_projEE_ampa[1744] = new NetCon(&v(0.5), syn_projEE_ampa[1744], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1745: cell 21, seg 0 (0.5) [0.5 on Epop[21]] -> cell 65, seg 0 (0.5) [0.5 on Epop[65]], weight: 4.1363508E-4, delay 1.5
        h("Epop[65] syn_projEE_ampa[1745] = new ampa(0.5)")
        h("Epop[21] netConn_projEE_ampa[1745] = new NetCon(&v(0.5), syn_projEE_ampa[1745], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1746: cell 21, seg 0 (0.5) [0.5 on Epop[21]] -> cell 66, seg 0 (0.5) [0.5 on Epop[66]], weight: 4.1363508E-4, delay 1.5
        h("Epop[66] syn_projEE_ampa[1746] = new ampa(0.5)")
        h("Epop[21] netConn_projEE_ampa[1746] = new NetCon(&v(0.5), syn_projEE_ampa[1746], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1747: cell 21, seg 0 (0.5) [0.5 on Epop[21]] -> cell 67, seg 0 (0.5) [0.5 on Epop[67]], weight: 4.1363508E-4, delay 1.5
        h("Epop[67] syn_projEE_ampa[1747] = new ampa(0.5)")
        h("Epop[21] netConn_projEE_ampa[1747] = new NetCon(&v(0.5), syn_projEE_ampa[1747], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1748: cell 21, seg 0 (0.5) [0.5 on Epop[21]] -> cell 68, seg 0 (0.5) [0.5 on Epop[68]], weight: 4.1363508E-4, delay 1.5
        h("Epop[68] syn_projEE_ampa[1748] = new ampa(0.5)")
        h("Epop[21] netConn_projEE_ampa[1748] = new NetCon(&v(0.5), syn_projEE_ampa[1748], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1749: cell 21, seg 0 (0.5) [0.5 on Epop[21]] -> cell 69, seg 0 (0.5) [0.5 on Epop[69]], weight: 4.1363508E-4, delay 1.5
        h("Epop[69] syn_projEE_ampa[1749] = new ampa(0.5)")
        h("Epop[21] netConn_projEE_ampa[1749] = new NetCon(&v(0.5), syn_projEE_ampa[1749], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1750: cell 21, seg 0 (0.5) [0.5 on Epop[21]] -> cell 70, seg 0 (0.5) [0.5 on Epop[70]], weight: 4.1363508E-4, delay 1.5
        h("Epop[70] syn_projEE_ampa[1750] = new ampa(0.5)")
        h("Epop[21] netConn_projEE_ampa[1750] = new NetCon(&v(0.5), syn_projEE_ampa[1750], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1751: cell 21, seg 0 (0.5) [0.5 on Epop[21]] -> cell 71, seg 0 (0.5) [0.5 on Epop[71]], weight: 4.1363508E-4, delay 1.5
        h("Epop[71] syn_projEE_ampa[1751] = new ampa(0.5)")
        h("Epop[21] netConn_projEE_ampa[1751] = new NetCon(&v(0.5), syn_projEE_ampa[1751], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1752: cell 21, seg 0 (0.5) [0.5 on Epop[21]] -> cell 72, seg 0 (0.5) [0.5 on Epop[72]], weight: 4.1363508E-4, delay 1.5
        h("Epop[72] syn_projEE_ampa[1752] = new ampa(0.5)")
        h("Epop[21] netConn_projEE_ampa[1752] = new NetCon(&v(0.5), syn_projEE_ampa[1752], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1753: cell 21, seg 0 (0.5) [0.5 on Epop[21]] -> cell 73, seg 0 (0.5) [0.5 on Epop[73]], weight: 4.1363508E-4, delay 1.5
        h("Epop[73] syn_projEE_ampa[1753] = new ampa(0.5)")
        h("Epop[21] netConn_projEE_ampa[1753] = new NetCon(&v(0.5), syn_projEE_ampa[1753], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1754: cell 21, seg 0 (0.5) [0.5 on Epop[21]] -> cell 74, seg 0 (0.5) [0.5 on Epop[74]], weight: 4.1363508E-4, delay 1.5
        h("Epop[74] syn_projEE_ampa[1754] = new ampa(0.5)")
        h("Epop[21] netConn_projEE_ampa[1754] = new NetCon(&v(0.5), syn_projEE_ampa[1754], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1755: cell 21, seg 0 (0.5) [0.5 on Epop[21]] -> cell 75, seg 0 (0.5) [0.5 on Epop[75]], weight: 4.1363508E-4, delay 1.5
        h("Epop[75] syn_projEE_ampa[1755] = new ampa(0.5)")
        h("Epop[21] netConn_projEE_ampa[1755] = new NetCon(&v(0.5), syn_projEE_ampa[1755], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1756: cell 21, seg 0 (0.5) [0.5 on Epop[21]] -> cell 76, seg 0 (0.5) [0.5 on Epop[76]], weight: 4.1363508E-4, delay 1.5
        h("Epop[76] syn_projEE_ampa[1756] = new ampa(0.5)")
        h("Epop[21] netConn_projEE_ampa[1756] = new NetCon(&v(0.5), syn_projEE_ampa[1756], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1757: cell 21, seg 0 (0.5) [0.5 on Epop[21]] -> cell 77, seg 0 (0.5) [0.5 on Epop[77]], weight: 4.1363508E-4, delay 1.5
        h("Epop[77] syn_projEE_ampa[1757] = new ampa(0.5)")
        h("Epop[21] netConn_projEE_ampa[1757] = new NetCon(&v(0.5), syn_projEE_ampa[1757], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1758: cell 21, seg 0 (0.5) [0.5 on Epop[21]] -> cell 78, seg 0 (0.5) [0.5 on Epop[78]], weight: 4.1363508E-4, delay 1.5
        h("Epop[78] syn_projEE_ampa[1758] = new ampa(0.5)")
        h("Epop[21] netConn_projEE_ampa[1758] = new NetCon(&v(0.5), syn_projEE_ampa[1758], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1759: cell 21, seg 0 (0.5) [0.5 on Epop[21]] -> cell 79, seg 0 (0.5) [0.5 on Epop[79]], weight: 4.1363508E-4, delay 1.5
        h("Epop[79] syn_projEE_ampa[1759] = new ampa(0.5)")
        h("Epop[21] netConn_projEE_ampa[1759] = new NetCon(&v(0.5), syn_projEE_ampa[1759], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1760: cell 22, seg 0 (0.5) [0.5 on Epop[22]] -> cell 0, seg 0 (0.5) [0.5 on Epop[0]], weight: 4.1363508E-4, delay 1.5
        h("Epop[0] syn_projEE_ampa[1760] = new ampa(0.5)")
        h("Epop[22] netConn_projEE_ampa[1760] = new NetCon(&v(0.5), syn_projEE_ampa[1760], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1761: cell 22, seg 0 (0.5) [0.5 on Epop[22]] -> cell 1, seg 0 (0.5) [0.5 on Epop[1]], weight: 4.1363508E-4, delay 1.5
        h("Epop[1] syn_projEE_ampa[1761] = new ampa(0.5)")
        h("Epop[22] netConn_projEE_ampa[1761] = new NetCon(&v(0.5), syn_projEE_ampa[1761], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1762: cell 22, seg 0 (0.5) [0.5 on Epop[22]] -> cell 2, seg 0 (0.5) [0.5 on Epop[2]], weight: 4.1363508E-4, delay 1.5
        h("Epop[2] syn_projEE_ampa[1762] = new ampa(0.5)")
        h("Epop[22] netConn_projEE_ampa[1762] = new NetCon(&v(0.5), syn_projEE_ampa[1762], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1763: cell 22, seg 0 (0.5) [0.5 on Epop[22]] -> cell 3, seg 0 (0.5) [0.5 on Epop[3]], weight: 4.1363508E-4, delay 1.5
        h("Epop[3] syn_projEE_ampa[1763] = new ampa(0.5)")
        h("Epop[22] netConn_projEE_ampa[1763] = new NetCon(&v(0.5), syn_projEE_ampa[1763], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1764: cell 22, seg 0 (0.5) [0.5 on Epop[22]] -> cell 4, seg 0 (0.5) [0.5 on Epop[4]], weight: 4.1363508E-4, delay 1.5
        h("Epop[4] syn_projEE_ampa[1764] = new ampa(0.5)")
        h("Epop[22] netConn_projEE_ampa[1764] = new NetCon(&v(0.5), syn_projEE_ampa[1764], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1765: cell 22, seg 0 (0.5) [0.5 on Epop[22]] -> cell 5, seg 0 (0.5) [0.5 on Epop[5]], weight: 4.1363508E-4, delay 1.5
        h("Epop[5] syn_projEE_ampa[1765] = new ampa(0.5)")
        h("Epop[22] netConn_projEE_ampa[1765] = new NetCon(&v(0.5), syn_projEE_ampa[1765], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1766: cell 22, seg 0 (0.5) [0.5 on Epop[22]] -> cell 6, seg 0 (0.5) [0.5 on Epop[6]], weight: 4.1363508E-4, delay 1.5
        h("Epop[6] syn_projEE_ampa[1766] = new ampa(0.5)")
        h("Epop[22] netConn_projEE_ampa[1766] = new NetCon(&v(0.5), syn_projEE_ampa[1766], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1767: cell 22, seg 0 (0.5) [0.5 on Epop[22]] -> cell 7, seg 0 (0.5) [0.5 on Epop[7]], weight: 4.1363508E-4, delay 1.5
        h("Epop[7] syn_projEE_ampa[1767] = new ampa(0.5)")
        h("Epop[22] netConn_projEE_ampa[1767] = new NetCon(&v(0.5), syn_projEE_ampa[1767], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1768: cell 22, seg 0 (0.5) [0.5 on Epop[22]] -> cell 8, seg 0 (0.5) [0.5 on Epop[8]], weight: 4.1363508E-4, delay 1.5
        h("Epop[8] syn_projEE_ampa[1768] = new ampa(0.5)")
        h("Epop[22] netConn_projEE_ampa[1768] = new NetCon(&v(0.5), syn_projEE_ampa[1768], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1769: cell 22, seg 0 (0.5) [0.5 on Epop[22]] -> cell 9, seg 0 (0.5) [0.5 on Epop[9]], weight: 4.1363508E-4, delay 1.5
        h("Epop[9] syn_projEE_ampa[1769] = new ampa(0.5)")
        h("Epop[22] netConn_projEE_ampa[1769] = new NetCon(&v(0.5), syn_projEE_ampa[1769], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1770: cell 22, seg 0 (0.5) [0.5 on Epop[22]] -> cell 10, seg 0 (0.5) [0.5 on Epop[10]], weight: 4.1363508E-4, delay 1.5
        h("Epop[10] syn_projEE_ampa[1770] = new ampa(0.5)")
        h("Epop[22] netConn_projEE_ampa[1770] = new NetCon(&v(0.5), syn_projEE_ampa[1770], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1771: cell 22, seg 0 (0.5) [0.5 on Epop[22]] -> cell 11, seg 0 (0.5) [0.5 on Epop[11]], weight: 4.1363508E-4, delay 1.5
        h("Epop[11] syn_projEE_ampa[1771] = new ampa(0.5)")
        h("Epop[22] netConn_projEE_ampa[1771] = new NetCon(&v(0.5), syn_projEE_ampa[1771], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1772: cell 22, seg 0 (0.5) [0.5 on Epop[22]] -> cell 12, seg 0 (0.5) [0.5 on Epop[12]], weight: 4.1363508E-4, delay 1.5
        h("Epop[12] syn_projEE_ampa[1772] = new ampa(0.5)")
        h("Epop[22] netConn_projEE_ampa[1772] = new NetCon(&v(0.5), syn_projEE_ampa[1772], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1773: cell 22, seg 0 (0.5) [0.5 on Epop[22]] -> cell 13, seg 0 (0.5) [0.5 on Epop[13]], weight: 4.1363508E-4, delay 1.5
        h("Epop[13] syn_projEE_ampa[1773] = new ampa(0.5)")
        h("Epop[22] netConn_projEE_ampa[1773] = new NetCon(&v(0.5), syn_projEE_ampa[1773], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1774: cell 22, seg 0 (0.5) [0.5 on Epop[22]] -> cell 14, seg 0 (0.5) [0.5 on Epop[14]], weight: 4.1363508E-4, delay 1.5
        h("Epop[14] syn_projEE_ampa[1774] = new ampa(0.5)")
        h("Epop[22] netConn_projEE_ampa[1774] = new NetCon(&v(0.5), syn_projEE_ampa[1774], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1775: cell 22, seg 0 (0.5) [0.5 on Epop[22]] -> cell 15, seg 0 (0.5) [0.5 on Epop[15]], weight: 4.1363508E-4, delay 1.5
        h("Epop[15] syn_projEE_ampa[1775] = new ampa(0.5)")
        h("Epop[22] netConn_projEE_ampa[1775] = new NetCon(&v(0.5), syn_projEE_ampa[1775], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1776: cell 22, seg 0 (0.5) [0.5 on Epop[22]] -> cell 16, seg 0 (0.5) [0.5 on Epop[16]], weight: 4.1363508E-4, delay 1.5
        h("Epop[16] syn_projEE_ampa[1776] = new ampa(0.5)")
        h("Epop[22] netConn_projEE_ampa[1776] = new NetCon(&v(0.5), syn_projEE_ampa[1776], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1777: cell 22, seg 0 (0.5) [0.5 on Epop[22]] -> cell 17, seg 0 (0.5) [0.5 on Epop[17]], weight: 4.1363508E-4, delay 1.5
        h("Epop[17] syn_projEE_ampa[1777] = new ampa(0.5)")
        h("Epop[22] netConn_projEE_ampa[1777] = new NetCon(&v(0.5), syn_projEE_ampa[1777], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1778: cell 22, seg 0 (0.5) [0.5 on Epop[22]] -> cell 18, seg 0 (0.5) [0.5 on Epop[18]], weight: 4.1363508E-4, delay 1.5
        h("Epop[18] syn_projEE_ampa[1778] = new ampa(0.5)")
        h("Epop[22] netConn_projEE_ampa[1778] = new NetCon(&v(0.5), syn_projEE_ampa[1778], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1779: cell 22, seg 0 (0.5) [0.5 on Epop[22]] -> cell 19, seg 0 (0.5) [0.5 on Epop[19]], weight: 4.1363508E-4, delay 1.5
        h("Epop[19] syn_projEE_ampa[1779] = new ampa(0.5)")
        h("Epop[22] netConn_projEE_ampa[1779] = new NetCon(&v(0.5), syn_projEE_ampa[1779], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1780: cell 22, seg 0 (0.5) [0.5 on Epop[22]] -> cell 20, seg 0 (0.5) [0.5 on Epop[20]], weight: 4.1363508E-4, delay 1.5
        h("Epop[20] syn_projEE_ampa[1780] = new ampa(0.5)")
        h("Epop[22] netConn_projEE_ampa[1780] = new NetCon(&v(0.5), syn_projEE_ampa[1780], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1781: cell 22, seg 0 (0.5) [0.5 on Epop[22]] -> cell 21, seg 0 (0.5) [0.5 on Epop[21]], weight: 4.1363508E-4, delay 1.5
        h("Epop[21] syn_projEE_ampa[1781] = new ampa(0.5)")
        h("Epop[22] netConn_projEE_ampa[1781] = new NetCon(&v(0.5), syn_projEE_ampa[1781], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1782: cell 22, seg 0 (0.5) [0.5 on Epop[22]] -> cell 22, seg 0 (0.5) [0.5 on Epop[22]], weight: 4.1363508E-4, delay 1.5
        h("Epop[22] syn_projEE_ampa[1782] = new ampa(0.5)")
        h("Epop[22] netConn_projEE_ampa[1782] = new NetCon(&v(0.5), syn_projEE_ampa[1782], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1783: cell 22, seg 0 (0.5) [0.5 on Epop[22]] -> cell 23, seg 0 (0.5) [0.5 on Epop[23]], weight: 4.1363508E-4, delay 1.5
        h("Epop[23] syn_projEE_ampa[1783] = new ampa(0.5)")
        h("Epop[22] netConn_projEE_ampa[1783] = new NetCon(&v(0.5), syn_projEE_ampa[1783], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1784: cell 22, seg 0 (0.5) [0.5 on Epop[22]] -> cell 24, seg 0 (0.5) [0.5 on Epop[24]], weight: 4.1363508E-4, delay 1.5
        h("Epop[24] syn_projEE_ampa[1784] = new ampa(0.5)")
        h("Epop[22] netConn_projEE_ampa[1784] = new NetCon(&v(0.5), syn_projEE_ampa[1784], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1785: cell 22, seg 0 (0.5) [0.5 on Epop[22]] -> cell 25, seg 0 (0.5) [0.5 on Epop[25]], weight: 4.1363508E-4, delay 1.5
        h("Epop[25] syn_projEE_ampa[1785] = new ampa(0.5)")
        h("Epop[22] netConn_projEE_ampa[1785] = new NetCon(&v(0.5), syn_projEE_ampa[1785], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1786: cell 22, seg 0 (0.5) [0.5 on Epop[22]] -> cell 26, seg 0 (0.5) [0.5 on Epop[26]], weight: 4.1363508E-4, delay 1.5
        h("Epop[26] syn_projEE_ampa[1786] = new ampa(0.5)")
        h("Epop[22] netConn_projEE_ampa[1786] = new NetCon(&v(0.5), syn_projEE_ampa[1786], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1787: cell 22, seg 0 (0.5) [0.5 on Epop[22]] -> cell 27, seg 0 (0.5) [0.5 on Epop[27]], weight: 4.1363508E-4, delay 1.5
        h("Epop[27] syn_projEE_ampa[1787] = new ampa(0.5)")
        h("Epop[22] netConn_projEE_ampa[1787] = new NetCon(&v(0.5), syn_projEE_ampa[1787], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1788: cell 22, seg 0 (0.5) [0.5 on Epop[22]] -> cell 28, seg 0 (0.5) [0.5 on Epop[28]], weight: 4.1363508E-4, delay 1.5
        h("Epop[28] syn_projEE_ampa[1788] = new ampa(0.5)")
        h("Epop[22] netConn_projEE_ampa[1788] = new NetCon(&v(0.5), syn_projEE_ampa[1788], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1789: cell 22, seg 0 (0.5) [0.5 on Epop[22]] -> cell 29, seg 0 (0.5) [0.5 on Epop[29]], weight: 4.1363508E-4, delay 1.5
        h("Epop[29] syn_projEE_ampa[1789] = new ampa(0.5)")
        h("Epop[22] netConn_projEE_ampa[1789] = new NetCon(&v(0.5), syn_projEE_ampa[1789], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1790: cell 22, seg 0 (0.5) [0.5 on Epop[22]] -> cell 30, seg 0 (0.5) [0.5 on Epop[30]], weight: 4.1363508E-4, delay 1.5
        h("Epop[30] syn_projEE_ampa[1790] = new ampa(0.5)")
        h("Epop[22] netConn_projEE_ampa[1790] = new NetCon(&v(0.5), syn_projEE_ampa[1790], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1791: cell 22, seg 0 (0.5) [0.5 on Epop[22]] -> cell 31, seg 0 (0.5) [0.5 on Epop[31]], weight: 4.1363508E-4, delay 1.5
        h("Epop[31] syn_projEE_ampa[1791] = new ampa(0.5)")
        h("Epop[22] netConn_projEE_ampa[1791] = new NetCon(&v(0.5), syn_projEE_ampa[1791], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1792: cell 22, seg 0 (0.5) [0.5 on Epop[22]] -> cell 32, seg 0 (0.5) [0.5 on Epop[32]], weight: 4.1363508E-4, delay 1.5
        h("Epop[32] syn_projEE_ampa[1792] = new ampa(0.5)")
        h("Epop[22] netConn_projEE_ampa[1792] = new NetCon(&v(0.5), syn_projEE_ampa[1792], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1793: cell 22, seg 0 (0.5) [0.5 on Epop[22]] -> cell 33, seg 0 (0.5) [0.5 on Epop[33]], weight: 4.1363508E-4, delay 1.5
        h("Epop[33] syn_projEE_ampa[1793] = new ampa(0.5)")
        h("Epop[22] netConn_projEE_ampa[1793] = new NetCon(&v(0.5), syn_projEE_ampa[1793], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1794: cell 22, seg 0 (0.5) [0.5 on Epop[22]] -> cell 34, seg 0 (0.5) [0.5 on Epop[34]], weight: 4.1363508E-4, delay 1.5
        h("Epop[34] syn_projEE_ampa[1794] = new ampa(0.5)")
        h("Epop[22] netConn_projEE_ampa[1794] = new NetCon(&v(0.5), syn_projEE_ampa[1794], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1795: cell 22, seg 0 (0.5) [0.5 on Epop[22]] -> cell 35, seg 0 (0.5) [0.5 on Epop[35]], weight: 4.1363508E-4, delay 1.5
        h("Epop[35] syn_projEE_ampa[1795] = new ampa(0.5)")
        h("Epop[22] netConn_projEE_ampa[1795] = new NetCon(&v(0.5), syn_projEE_ampa[1795], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1796: cell 22, seg 0 (0.5) [0.5 on Epop[22]] -> cell 36, seg 0 (0.5) [0.5 on Epop[36]], weight: 4.1363508E-4, delay 1.5
        h("Epop[36] syn_projEE_ampa[1796] = new ampa(0.5)")
        h("Epop[22] netConn_projEE_ampa[1796] = new NetCon(&v(0.5), syn_projEE_ampa[1796], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1797: cell 22, seg 0 (0.5) [0.5 on Epop[22]] -> cell 37, seg 0 (0.5) [0.5 on Epop[37]], weight: 4.1363508E-4, delay 1.5
        h("Epop[37] syn_projEE_ampa[1797] = new ampa(0.5)")
        h("Epop[22] netConn_projEE_ampa[1797] = new NetCon(&v(0.5), syn_projEE_ampa[1797], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1798: cell 22, seg 0 (0.5) [0.5 on Epop[22]] -> cell 38, seg 0 (0.5) [0.5 on Epop[38]], weight: 4.1363508E-4, delay 1.5
        h("Epop[38] syn_projEE_ampa[1798] = new ampa(0.5)")
        h("Epop[22] netConn_projEE_ampa[1798] = new NetCon(&v(0.5), syn_projEE_ampa[1798], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1799: cell 22, seg 0 (0.5) [0.5 on Epop[22]] -> cell 39, seg 0 (0.5) [0.5 on Epop[39]], weight: 4.1363508E-4, delay 1.5
        h("Epop[39] syn_projEE_ampa[1799] = new ampa(0.5)")
        h("Epop[22] netConn_projEE_ampa[1799] = new NetCon(&v(0.5), syn_projEE_ampa[1799], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1800: cell 22, seg 0 (0.5) [0.5 on Epop[22]] -> cell 40, seg 0 (0.5) [0.5 on Epop[40]], weight: 4.1363508E-4, delay 1.5
        h("Epop[40] syn_projEE_ampa[1800] = new ampa(0.5)")
        h("Epop[22] netConn_projEE_ampa[1800] = new NetCon(&v(0.5), syn_projEE_ampa[1800], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1801: cell 22, seg 0 (0.5) [0.5 on Epop[22]] -> cell 41, seg 0 (0.5) [0.5 on Epop[41]], weight: 4.1363508E-4, delay 1.5
        h("Epop[41] syn_projEE_ampa[1801] = new ampa(0.5)")
        h("Epop[22] netConn_projEE_ampa[1801] = new NetCon(&v(0.5), syn_projEE_ampa[1801], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1802: cell 22, seg 0 (0.5) [0.5 on Epop[22]] -> cell 42, seg 0 (0.5) [0.5 on Epop[42]], weight: 4.1363508E-4, delay 1.5
        h("Epop[42] syn_projEE_ampa[1802] = new ampa(0.5)")
        h("Epop[22] netConn_projEE_ampa[1802] = new NetCon(&v(0.5), syn_projEE_ampa[1802], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1803: cell 22, seg 0 (0.5) [0.5 on Epop[22]] -> cell 43, seg 0 (0.5) [0.5 on Epop[43]], weight: 4.1363508E-4, delay 1.5
        h("Epop[43] syn_projEE_ampa[1803] = new ampa(0.5)")
        h("Epop[22] netConn_projEE_ampa[1803] = new NetCon(&v(0.5), syn_projEE_ampa[1803], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1804: cell 22, seg 0 (0.5) [0.5 on Epop[22]] -> cell 44, seg 0 (0.5) [0.5 on Epop[44]], weight: 4.1363508E-4, delay 1.5
        h("Epop[44] syn_projEE_ampa[1804] = new ampa(0.5)")
        h("Epop[22] netConn_projEE_ampa[1804] = new NetCon(&v(0.5), syn_projEE_ampa[1804], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1805: cell 22, seg 0 (0.5) [0.5 on Epop[22]] -> cell 45, seg 0 (0.5) [0.5 on Epop[45]], weight: 4.1363508E-4, delay 1.5
        h("Epop[45] syn_projEE_ampa[1805] = new ampa(0.5)")
        h("Epop[22] netConn_projEE_ampa[1805] = new NetCon(&v(0.5), syn_projEE_ampa[1805], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1806: cell 22, seg 0 (0.5) [0.5 on Epop[22]] -> cell 46, seg 0 (0.5) [0.5 on Epop[46]], weight: 4.1363508E-4, delay 1.5
        h("Epop[46] syn_projEE_ampa[1806] = new ampa(0.5)")
        h("Epop[22] netConn_projEE_ampa[1806] = new NetCon(&v(0.5), syn_projEE_ampa[1806], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1807: cell 22, seg 0 (0.5) [0.5 on Epop[22]] -> cell 47, seg 0 (0.5) [0.5 on Epop[47]], weight: 4.1363508E-4, delay 1.5
        h("Epop[47] syn_projEE_ampa[1807] = new ampa(0.5)")
        h("Epop[22] netConn_projEE_ampa[1807] = new NetCon(&v(0.5), syn_projEE_ampa[1807], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1808: cell 22, seg 0 (0.5) [0.5 on Epop[22]] -> cell 48, seg 0 (0.5) [0.5 on Epop[48]], weight: 4.1363508E-4, delay 1.5
        h("Epop[48] syn_projEE_ampa[1808] = new ampa(0.5)")
        h("Epop[22] netConn_projEE_ampa[1808] = new NetCon(&v(0.5), syn_projEE_ampa[1808], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1809: cell 22, seg 0 (0.5) [0.5 on Epop[22]] -> cell 49, seg 0 (0.5) [0.5 on Epop[49]], weight: 4.1363508E-4, delay 1.5
        h("Epop[49] syn_projEE_ampa[1809] = new ampa(0.5)")
        h("Epop[22] netConn_projEE_ampa[1809] = new NetCon(&v(0.5), syn_projEE_ampa[1809], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1810: cell 22, seg 0 (0.5) [0.5 on Epop[22]] -> cell 50, seg 0 (0.5) [0.5 on Epop[50]], weight: 4.1363508E-4, delay 1.5
        h("Epop[50] syn_projEE_ampa[1810] = new ampa(0.5)")
        h("Epop[22] netConn_projEE_ampa[1810] = new NetCon(&v(0.5), syn_projEE_ampa[1810], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1811: cell 22, seg 0 (0.5) [0.5 on Epop[22]] -> cell 51, seg 0 (0.5) [0.5 on Epop[51]], weight: 4.1363508E-4, delay 1.5
        h("Epop[51] syn_projEE_ampa[1811] = new ampa(0.5)")
        h("Epop[22] netConn_projEE_ampa[1811] = new NetCon(&v(0.5), syn_projEE_ampa[1811], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1812: cell 22, seg 0 (0.5) [0.5 on Epop[22]] -> cell 52, seg 0 (0.5) [0.5 on Epop[52]], weight: 4.1363508E-4, delay 1.5
        h("Epop[52] syn_projEE_ampa[1812] = new ampa(0.5)")
        h("Epop[22] netConn_projEE_ampa[1812] = new NetCon(&v(0.5), syn_projEE_ampa[1812], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1813: cell 22, seg 0 (0.5) [0.5 on Epop[22]] -> cell 53, seg 0 (0.5) [0.5 on Epop[53]], weight: 4.1363508E-4, delay 1.5
        h("Epop[53] syn_projEE_ampa[1813] = new ampa(0.5)")
        h("Epop[22] netConn_projEE_ampa[1813] = new NetCon(&v(0.5), syn_projEE_ampa[1813], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1814: cell 22, seg 0 (0.5) [0.5 on Epop[22]] -> cell 54, seg 0 (0.5) [0.5 on Epop[54]], weight: 4.1363508E-4, delay 1.5
        h("Epop[54] syn_projEE_ampa[1814] = new ampa(0.5)")
        h("Epop[22] netConn_projEE_ampa[1814] = new NetCon(&v(0.5), syn_projEE_ampa[1814], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1815: cell 22, seg 0 (0.5) [0.5 on Epop[22]] -> cell 55, seg 0 (0.5) [0.5 on Epop[55]], weight: 4.1363508E-4, delay 1.5
        h("Epop[55] syn_projEE_ampa[1815] = new ampa(0.5)")
        h("Epop[22] netConn_projEE_ampa[1815] = new NetCon(&v(0.5), syn_projEE_ampa[1815], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1816: cell 22, seg 0 (0.5) [0.5 on Epop[22]] -> cell 56, seg 0 (0.5) [0.5 on Epop[56]], weight: 4.1363508E-4, delay 1.5
        h("Epop[56] syn_projEE_ampa[1816] = new ampa(0.5)")
        h("Epop[22] netConn_projEE_ampa[1816] = new NetCon(&v(0.5), syn_projEE_ampa[1816], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1817: cell 22, seg 0 (0.5) [0.5 on Epop[22]] -> cell 57, seg 0 (0.5) [0.5 on Epop[57]], weight: 4.1363508E-4, delay 1.5
        h("Epop[57] syn_projEE_ampa[1817] = new ampa(0.5)")
        h("Epop[22] netConn_projEE_ampa[1817] = new NetCon(&v(0.5), syn_projEE_ampa[1817], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1818: cell 22, seg 0 (0.5) [0.5 on Epop[22]] -> cell 58, seg 0 (0.5) [0.5 on Epop[58]], weight: 4.1363508E-4, delay 1.5
        h("Epop[58] syn_projEE_ampa[1818] = new ampa(0.5)")
        h("Epop[22] netConn_projEE_ampa[1818] = new NetCon(&v(0.5), syn_projEE_ampa[1818], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1819: cell 22, seg 0 (0.5) [0.5 on Epop[22]] -> cell 59, seg 0 (0.5) [0.5 on Epop[59]], weight: 4.1363508E-4, delay 1.5
        h("Epop[59] syn_projEE_ampa[1819] = new ampa(0.5)")
        h("Epop[22] netConn_projEE_ampa[1819] = new NetCon(&v(0.5), syn_projEE_ampa[1819], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1820: cell 22, seg 0 (0.5) [0.5 on Epop[22]] -> cell 60, seg 0 (0.5) [0.5 on Epop[60]], weight: 4.1363508E-4, delay 1.5
        h("Epop[60] syn_projEE_ampa[1820] = new ampa(0.5)")
        h("Epop[22] netConn_projEE_ampa[1820] = new NetCon(&v(0.5), syn_projEE_ampa[1820], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1821: cell 22, seg 0 (0.5) [0.5 on Epop[22]] -> cell 61, seg 0 (0.5) [0.5 on Epop[61]], weight: 4.1363508E-4, delay 1.5
        h("Epop[61] syn_projEE_ampa[1821] = new ampa(0.5)")
        h("Epop[22] netConn_projEE_ampa[1821] = new NetCon(&v(0.5), syn_projEE_ampa[1821], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1822: cell 22, seg 0 (0.5) [0.5 on Epop[22]] -> cell 62, seg 0 (0.5) [0.5 on Epop[62]], weight: 4.1363508E-4, delay 1.5
        h("Epop[62] syn_projEE_ampa[1822] = new ampa(0.5)")
        h("Epop[22] netConn_projEE_ampa[1822] = new NetCon(&v(0.5), syn_projEE_ampa[1822], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1823: cell 22, seg 0 (0.5) [0.5 on Epop[22]] -> cell 63, seg 0 (0.5) [0.5 on Epop[63]], weight: 4.1363508E-4, delay 1.5
        h("Epop[63] syn_projEE_ampa[1823] = new ampa(0.5)")
        h("Epop[22] netConn_projEE_ampa[1823] = new NetCon(&v(0.5), syn_projEE_ampa[1823], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1824: cell 22, seg 0 (0.5) [0.5 on Epop[22]] -> cell 64, seg 0 (0.5) [0.5 on Epop[64]], weight: 4.1363508E-4, delay 1.5
        h("Epop[64] syn_projEE_ampa[1824] = new ampa(0.5)")
        h("Epop[22] netConn_projEE_ampa[1824] = new NetCon(&v(0.5), syn_projEE_ampa[1824], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1825: cell 22, seg 0 (0.5) [0.5 on Epop[22]] -> cell 65, seg 0 (0.5) [0.5 on Epop[65]], weight: 4.1363508E-4, delay 1.5
        h("Epop[65] syn_projEE_ampa[1825] = new ampa(0.5)")
        h("Epop[22] netConn_projEE_ampa[1825] = new NetCon(&v(0.5), syn_projEE_ampa[1825], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1826: cell 22, seg 0 (0.5) [0.5 on Epop[22]] -> cell 66, seg 0 (0.5) [0.5 on Epop[66]], weight: 4.1363508E-4, delay 1.5
        h("Epop[66] syn_projEE_ampa[1826] = new ampa(0.5)")
        h("Epop[22] netConn_projEE_ampa[1826] = new NetCon(&v(0.5), syn_projEE_ampa[1826], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1827: cell 22, seg 0 (0.5) [0.5 on Epop[22]] -> cell 67, seg 0 (0.5) [0.5 on Epop[67]], weight: 4.1363508E-4, delay 1.5
        h("Epop[67] syn_projEE_ampa[1827] = new ampa(0.5)")
        h("Epop[22] netConn_projEE_ampa[1827] = new NetCon(&v(0.5), syn_projEE_ampa[1827], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1828: cell 22, seg 0 (0.5) [0.5 on Epop[22]] -> cell 68, seg 0 (0.5) [0.5 on Epop[68]], weight: 4.1363508E-4, delay 1.5
        h("Epop[68] syn_projEE_ampa[1828] = new ampa(0.5)")
        h("Epop[22] netConn_projEE_ampa[1828] = new NetCon(&v(0.5), syn_projEE_ampa[1828], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1829: cell 22, seg 0 (0.5) [0.5 on Epop[22]] -> cell 69, seg 0 (0.5) [0.5 on Epop[69]], weight: 4.1363508E-4, delay 1.5
        h("Epop[69] syn_projEE_ampa[1829] = new ampa(0.5)")
        h("Epop[22] netConn_projEE_ampa[1829] = new NetCon(&v(0.5), syn_projEE_ampa[1829], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1830: cell 22, seg 0 (0.5) [0.5 on Epop[22]] -> cell 70, seg 0 (0.5) [0.5 on Epop[70]], weight: 4.1363508E-4, delay 1.5
        h("Epop[70] syn_projEE_ampa[1830] = new ampa(0.5)")
        h("Epop[22] netConn_projEE_ampa[1830] = new NetCon(&v(0.5), syn_projEE_ampa[1830], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1831: cell 22, seg 0 (0.5) [0.5 on Epop[22]] -> cell 71, seg 0 (0.5) [0.5 on Epop[71]], weight: 4.1363508E-4, delay 1.5
        h("Epop[71] syn_projEE_ampa[1831] = new ampa(0.5)")
        h("Epop[22] netConn_projEE_ampa[1831] = new NetCon(&v(0.5), syn_projEE_ampa[1831], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1832: cell 22, seg 0 (0.5) [0.5 on Epop[22]] -> cell 72, seg 0 (0.5) [0.5 on Epop[72]], weight: 4.1363508E-4, delay 1.5
        h("Epop[72] syn_projEE_ampa[1832] = new ampa(0.5)")
        h("Epop[22] netConn_projEE_ampa[1832] = new NetCon(&v(0.5), syn_projEE_ampa[1832], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1833: cell 22, seg 0 (0.5) [0.5 on Epop[22]] -> cell 73, seg 0 (0.5) [0.5 on Epop[73]], weight: 4.1363508E-4, delay 1.5
        h("Epop[73] syn_projEE_ampa[1833] = new ampa(0.5)")
        h("Epop[22] netConn_projEE_ampa[1833] = new NetCon(&v(0.5), syn_projEE_ampa[1833], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1834: cell 22, seg 0 (0.5) [0.5 on Epop[22]] -> cell 74, seg 0 (0.5) [0.5 on Epop[74]], weight: 4.1363508E-4, delay 1.5
        h("Epop[74] syn_projEE_ampa[1834] = new ampa(0.5)")
        h("Epop[22] netConn_projEE_ampa[1834] = new NetCon(&v(0.5), syn_projEE_ampa[1834], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1835: cell 22, seg 0 (0.5) [0.5 on Epop[22]] -> cell 75, seg 0 (0.5) [0.5 on Epop[75]], weight: 4.1363508E-4, delay 1.5
        h("Epop[75] syn_projEE_ampa[1835] = new ampa(0.5)")
        h("Epop[22] netConn_projEE_ampa[1835] = new NetCon(&v(0.5), syn_projEE_ampa[1835], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1836: cell 22, seg 0 (0.5) [0.5 on Epop[22]] -> cell 76, seg 0 (0.5) [0.5 on Epop[76]], weight: 4.1363508E-4, delay 1.5
        h("Epop[76] syn_projEE_ampa[1836] = new ampa(0.5)")
        h("Epop[22] netConn_projEE_ampa[1836] = new NetCon(&v(0.5), syn_projEE_ampa[1836], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1837: cell 22, seg 0 (0.5) [0.5 on Epop[22]] -> cell 77, seg 0 (0.5) [0.5 on Epop[77]], weight: 4.1363508E-4, delay 1.5
        h("Epop[77] syn_projEE_ampa[1837] = new ampa(0.5)")
        h("Epop[22] netConn_projEE_ampa[1837] = new NetCon(&v(0.5), syn_projEE_ampa[1837], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1838: cell 22, seg 0 (0.5) [0.5 on Epop[22]] -> cell 78, seg 0 (0.5) [0.5 on Epop[78]], weight: 4.1363508E-4, delay 1.5
        h("Epop[78] syn_projEE_ampa[1838] = new ampa(0.5)")
        h("Epop[22] netConn_projEE_ampa[1838] = new NetCon(&v(0.5), syn_projEE_ampa[1838], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1839: cell 22, seg 0 (0.5) [0.5 on Epop[22]] -> cell 79, seg 0 (0.5) [0.5 on Epop[79]], weight: 4.1363508E-4, delay 1.5
        h("Epop[79] syn_projEE_ampa[1839] = new ampa(0.5)")
        h("Epop[22] netConn_projEE_ampa[1839] = new NetCon(&v(0.5), syn_projEE_ampa[1839], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1840: cell 23, seg 0 (0.5) [0.5 on Epop[23]] -> cell 0, seg 0 (0.5) [0.5 on Epop[0]], weight: 4.1363508E-4, delay 1.5
        h("Epop[0] syn_projEE_ampa[1840] = new ampa(0.5)")
        h("Epop[23] netConn_projEE_ampa[1840] = new NetCon(&v(0.5), syn_projEE_ampa[1840], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1841: cell 23, seg 0 (0.5) [0.5 on Epop[23]] -> cell 1, seg 0 (0.5) [0.5 on Epop[1]], weight: 4.1363508E-4, delay 1.5
        h("Epop[1] syn_projEE_ampa[1841] = new ampa(0.5)")
        h("Epop[23] netConn_projEE_ampa[1841] = new NetCon(&v(0.5), syn_projEE_ampa[1841], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1842: cell 23, seg 0 (0.5) [0.5 on Epop[23]] -> cell 2, seg 0 (0.5) [0.5 on Epop[2]], weight: 4.1363508E-4, delay 1.5
        h("Epop[2] syn_projEE_ampa[1842] = new ampa(0.5)")
        h("Epop[23] netConn_projEE_ampa[1842] = new NetCon(&v(0.5), syn_projEE_ampa[1842], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1843: cell 23, seg 0 (0.5) [0.5 on Epop[23]] -> cell 3, seg 0 (0.5) [0.5 on Epop[3]], weight: 4.1363508E-4, delay 1.5
        h("Epop[3] syn_projEE_ampa[1843] = new ampa(0.5)")
        h("Epop[23] netConn_projEE_ampa[1843] = new NetCon(&v(0.5), syn_projEE_ampa[1843], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1844: cell 23, seg 0 (0.5) [0.5 on Epop[23]] -> cell 4, seg 0 (0.5) [0.5 on Epop[4]], weight: 4.1363508E-4, delay 1.5
        h("Epop[4] syn_projEE_ampa[1844] = new ampa(0.5)")
        h("Epop[23] netConn_projEE_ampa[1844] = new NetCon(&v(0.5), syn_projEE_ampa[1844], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1845: cell 23, seg 0 (0.5) [0.5 on Epop[23]] -> cell 5, seg 0 (0.5) [0.5 on Epop[5]], weight: 4.1363508E-4, delay 1.5
        h("Epop[5] syn_projEE_ampa[1845] = new ampa(0.5)")
        h("Epop[23] netConn_projEE_ampa[1845] = new NetCon(&v(0.5), syn_projEE_ampa[1845], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1846: cell 23, seg 0 (0.5) [0.5 on Epop[23]] -> cell 6, seg 0 (0.5) [0.5 on Epop[6]], weight: 4.1363508E-4, delay 1.5
        h("Epop[6] syn_projEE_ampa[1846] = new ampa(0.5)")
        h("Epop[23] netConn_projEE_ampa[1846] = new NetCon(&v(0.5), syn_projEE_ampa[1846], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1847: cell 23, seg 0 (0.5) [0.5 on Epop[23]] -> cell 7, seg 0 (0.5) [0.5 on Epop[7]], weight: 4.1363508E-4, delay 1.5
        h("Epop[7] syn_projEE_ampa[1847] = new ampa(0.5)")
        h("Epop[23] netConn_projEE_ampa[1847] = new NetCon(&v(0.5), syn_projEE_ampa[1847], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1848: cell 23, seg 0 (0.5) [0.5 on Epop[23]] -> cell 8, seg 0 (0.5) [0.5 on Epop[8]], weight: 4.1363508E-4, delay 1.5
        h("Epop[8] syn_projEE_ampa[1848] = new ampa(0.5)")
        h("Epop[23] netConn_projEE_ampa[1848] = new NetCon(&v(0.5), syn_projEE_ampa[1848], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1849: cell 23, seg 0 (0.5) [0.5 on Epop[23]] -> cell 9, seg 0 (0.5) [0.5 on Epop[9]], weight: 4.1363508E-4, delay 1.5
        h("Epop[9] syn_projEE_ampa[1849] = new ampa(0.5)")
        h("Epop[23] netConn_projEE_ampa[1849] = new NetCon(&v(0.5), syn_projEE_ampa[1849], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1850: cell 23, seg 0 (0.5) [0.5 on Epop[23]] -> cell 10, seg 0 (0.5) [0.5 on Epop[10]], weight: 4.1363508E-4, delay 1.5
        h("Epop[10] syn_projEE_ampa[1850] = new ampa(0.5)")
        h("Epop[23] netConn_projEE_ampa[1850] = new NetCon(&v(0.5), syn_projEE_ampa[1850], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1851: cell 23, seg 0 (0.5) [0.5 on Epop[23]] -> cell 11, seg 0 (0.5) [0.5 on Epop[11]], weight: 4.1363508E-4, delay 1.5
        h("Epop[11] syn_projEE_ampa[1851] = new ampa(0.5)")
        h("Epop[23] netConn_projEE_ampa[1851] = new NetCon(&v(0.5), syn_projEE_ampa[1851], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1852: cell 23, seg 0 (0.5) [0.5 on Epop[23]] -> cell 12, seg 0 (0.5) [0.5 on Epop[12]], weight: 4.1363508E-4, delay 1.5
        h("Epop[12] syn_projEE_ampa[1852] = new ampa(0.5)")
        h("Epop[23] netConn_projEE_ampa[1852] = new NetCon(&v(0.5), syn_projEE_ampa[1852], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1853: cell 23, seg 0 (0.5) [0.5 on Epop[23]] -> cell 13, seg 0 (0.5) [0.5 on Epop[13]], weight: 4.1363508E-4, delay 1.5
        h("Epop[13] syn_projEE_ampa[1853] = new ampa(0.5)")
        h("Epop[23] netConn_projEE_ampa[1853] = new NetCon(&v(0.5), syn_projEE_ampa[1853], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1854: cell 23, seg 0 (0.5) [0.5 on Epop[23]] -> cell 14, seg 0 (0.5) [0.5 on Epop[14]], weight: 4.1363508E-4, delay 1.5
        h("Epop[14] syn_projEE_ampa[1854] = new ampa(0.5)")
        h("Epop[23] netConn_projEE_ampa[1854] = new NetCon(&v(0.5), syn_projEE_ampa[1854], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1855: cell 23, seg 0 (0.5) [0.5 on Epop[23]] -> cell 15, seg 0 (0.5) [0.5 on Epop[15]], weight: 4.1363508E-4, delay 1.5
        h("Epop[15] syn_projEE_ampa[1855] = new ampa(0.5)")
        h("Epop[23] netConn_projEE_ampa[1855] = new NetCon(&v(0.5), syn_projEE_ampa[1855], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1856: cell 23, seg 0 (0.5) [0.5 on Epop[23]] -> cell 16, seg 0 (0.5) [0.5 on Epop[16]], weight: 4.1363508E-4, delay 1.5
        h("Epop[16] syn_projEE_ampa[1856] = new ampa(0.5)")
        h("Epop[23] netConn_projEE_ampa[1856] = new NetCon(&v(0.5), syn_projEE_ampa[1856], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1857: cell 23, seg 0 (0.5) [0.5 on Epop[23]] -> cell 17, seg 0 (0.5) [0.5 on Epop[17]], weight: 4.1363508E-4, delay 1.5
        h("Epop[17] syn_projEE_ampa[1857] = new ampa(0.5)")
        h("Epop[23] netConn_projEE_ampa[1857] = new NetCon(&v(0.5), syn_projEE_ampa[1857], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1858: cell 23, seg 0 (0.5) [0.5 on Epop[23]] -> cell 18, seg 0 (0.5) [0.5 on Epop[18]], weight: 4.1363508E-4, delay 1.5
        h("Epop[18] syn_projEE_ampa[1858] = new ampa(0.5)")
        h("Epop[23] netConn_projEE_ampa[1858] = new NetCon(&v(0.5), syn_projEE_ampa[1858], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1859: cell 23, seg 0 (0.5) [0.5 on Epop[23]] -> cell 19, seg 0 (0.5) [0.5 on Epop[19]], weight: 4.1363508E-4, delay 1.5
        h("Epop[19] syn_projEE_ampa[1859] = new ampa(0.5)")
        h("Epop[23] netConn_projEE_ampa[1859] = new NetCon(&v(0.5), syn_projEE_ampa[1859], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1860: cell 23, seg 0 (0.5) [0.5 on Epop[23]] -> cell 20, seg 0 (0.5) [0.5 on Epop[20]], weight: 4.1363508E-4, delay 1.5
        h("Epop[20] syn_projEE_ampa[1860] = new ampa(0.5)")
        h("Epop[23] netConn_projEE_ampa[1860] = new NetCon(&v(0.5), syn_projEE_ampa[1860], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1861: cell 23, seg 0 (0.5) [0.5 on Epop[23]] -> cell 21, seg 0 (0.5) [0.5 on Epop[21]], weight: 4.1363508E-4, delay 1.5
        h("Epop[21] syn_projEE_ampa[1861] = new ampa(0.5)")
        h("Epop[23] netConn_projEE_ampa[1861] = new NetCon(&v(0.5), syn_projEE_ampa[1861], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1862: cell 23, seg 0 (0.5) [0.5 on Epop[23]] -> cell 22, seg 0 (0.5) [0.5 on Epop[22]], weight: 4.1363508E-4, delay 1.5
        h("Epop[22] syn_projEE_ampa[1862] = new ampa(0.5)")
        h("Epop[23] netConn_projEE_ampa[1862] = new NetCon(&v(0.5), syn_projEE_ampa[1862], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1863: cell 23, seg 0 (0.5) [0.5 on Epop[23]] -> cell 23, seg 0 (0.5) [0.5 on Epop[23]], weight: 4.1363508E-4, delay 1.5
        h("Epop[23] syn_projEE_ampa[1863] = new ampa(0.5)")
        h("Epop[23] netConn_projEE_ampa[1863] = new NetCon(&v(0.5), syn_projEE_ampa[1863], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1864: cell 23, seg 0 (0.5) [0.5 on Epop[23]] -> cell 24, seg 0 (0.5) [0.5 on Epop[24]], weight: 4.1363508E-4, delay 1.5
        h("Epop[24] syn_projEE_ampa[1864] = new ampa(0.5)")
        h("Epop[23] netConn_projEE_ampa[1864] = new NetCon(&v(0.5), syn_projEE_ampa[1864], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1865: cell 23, seg 0 (0.5) [0.5 on Epop[23]] -> cell 25, seg 0 (0.5) [0.5 on Epop[25]], weight: 4.1363508E-4, delay 1.5
        h("Epop[25] syn_projEE_ampa[1865] = new ampa(0.5)")
        h("Epop[23] netConn_projEE_ampa[1865] = new NetCon(&v(0.5), syn_projEE_ampa[1865], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1866: cell 23, seg 0 (0.5) [0.5 on Epop[23]] -> cell 26, seg 0 (0.5) [0.5 on Epop[26]], weight: 4.1363508E-4, delay 1.5
        h("Epop[26] syn_projEE_ampa[1866] = new ampa(0.5)")
        h("Epop[23] netConn_projEE_ampa[1866] = new NetCon(&v(0.5), syn_projEE_ampa[1866], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1867: cell 23, seg 0 (0.5) [0.5 on Epop[23]] -> cell 27, seg 0 (0.5) [0.5 on Epop[27]], weight: 4.1363508E-4, delay 1.5
        h("Epop[27] syn_projEE_ampa[1867] = new ampa(0.5)")
        h("Epop[23] netConn_projEE_ampa[1867] = new NetCon(&v(0.5), syn_projEE_ampa[1867], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1868: cell 23, seg 0 (0.5) [0.5 on Epop[23]] -> cell 28, seg 0 (0.5) [0.5 on Epop[28]], weight: 4.1363508E-4, delay 1.5
        h("Epop[28] syn_projEE_ampa[1868] = new ampa(0.5)")
        h("Epop[23] netConn_projEE_ampa[1868] = new NetCon(&v(0.5), syn_projEE_ampa[1868], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1869: cell 23, seg 0 (0.5) [0.5 on Epop[23]] -> cell 29, seg 0 (0.5) [0.5 on Epop[29]], weight: 4.1363508E-4, delay 1.5
        h("Epop[29] syn_projEE_ampa[1869] = new ampa(0.5)")
        h("Epop[23] netConn_projEE_ampa[1869] = new NetCon(&v(0.5), syn_projEE_ampa[1869], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1870: cell 23, seg 0 (0.5) [0.5 on Epop[23]] -> cell 30, seg 0 (0.5) [0.5 on Epop[30]], weight: 4.1363508E-4, delay 1.5
        h("Epop[30] syn_projEE_ampa[1870] = new ampa(0.5)")
        h("Epop[23] netConn_projEE_ampa[1870] = new NetCon(&v(0.5), syn_projEE_ampa[1870], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1871: cell 23, seg 0 (0.5) [0.5 on Epop[23]] -> cell 31, seg 0 (0.5) [0.5 on Epop[31]], weight: 4.1363508E-4, delay 1.5
        h("Epop[31] syn_projEE_ampa[1871] = new ampa(0.5)")
        h("Epop[23] netConn_projEE_ampa[1871] = new NetCon(&v(0.5), syn_projEE_ampa[1871], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1872: cell 23, seg 0 (0.5) [0.5 on Epop[23]] -> cell 32, seg 0 (0.5) [0.5 on Epop[32]], weight: 4.1363508E-4, delay 1.5
        h("Epop[32] syn_projEE_ampa[1872] = new ampa(0.5)")
        h("Epop[23] netConn_projEE_ampa[1872] = new NetCon(&v(0.5), syn_projEE_ampa[1872], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1873: cell 23, seg 0 (0.5) [0.5 on Epop[23]] -> cell 33, seg 0 (0.5) [0.5 on Epop[33]], weight: 4.1363508E-4, delay 1.5
        h("Epop[33] syn_projEE_ampa[1873] = new ampa(0.5)")
        h("Epop[23] netConn_projEE_ampa[1873] = new NetCon(&v(0.5), syn_projEE_ampa[1873], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1874: cell 23, seg 0 (0.5) [0.5 on Epop[23]] -> cell 34, seg 0 (0.5) [0.5 on Epop[34]], weight: 4.1363508E-4, delay 1.5
        h("Epop[34] syn_projEE_ampa[1874] = new ampa(0.5)")
        h("Epop[23] netConn_projEE_ampa[1874] = new NetCon(&v(0.5), syn_projEE_ampa[1874], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1875: cell 23, seg 0 (0.5) [0.5 on Epop[23]] -> cell 35, seg 0 (0.5) [0.5 on Epop[35]], weight: 4.1363508E-4, delay 1.5
        h("Epop[35] syn_projEE_ampa[1875] = new ampa(0.5)")
        h("Epop[23] netConn_projEE_ampa[1875] = new NetCon(&v(0.5), syn_projEE_ampa[1875], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1876: cell 23, seg 0 (0.5) [0.5 on Epop[23]] -> cell 36, seg 0 (0.5) [0.5 on Epop[36]], weight: 4.1363508E-4, delay 1.5
        h("Epop[36] syn_projEE_ampa[1876] = new ampa(0.5)")
        h("Epop[23] netConn_projEE_ampa[1876] = new NetCon(&v(0.5), syn_projEE_ampa[1876], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1877: cell 23, seg 0 (0.5) [0.5 on Epop[23]] -> cell 37, seg 0 (0.5) [0.5 on Epop[37]], weight: 4.1363508E-4, delay 1.5
        h("Epop[37] syn_projEE_ampa[1877] = new ampa(0.5)")
        h("Epop[23] netConn_projEE_ampa[1877] = new NetCon(&v(0.5), syn_projEE_ampa[1877], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1878: cell 23, seg 0 (0.5) [0.5 on Epop[23]] -> cell 38, seg 0 (0.5) [0.5 on Epop[38]], weight: 4.1363508E-4, delay 1.5
        h("Epop[38] syn_projEE_ampa[1878] = new ampa(0.5)")
        h("Epop[23] netConn_projEE_ampa[1878] = new NetCon(&v(0.5), syn_projEE_ampa[1878], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1879: cell 23, seg 0 (0.5) [0.5 on Epop[23]] -> cell 39, seg 0 (0.5) [0.5 on Epop[39]], weight: 4.1363508E-4, delay 1.5
        h("Epop[39] syn_projEE_ampa[1879] = new ampa(0.5)")
        h("Epop[23] netConn_projEE_ampa[1879] = new NetCon(&v(0.5), syn_projEE_ampa[1879], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1880: cell 23, seg 0 (0.5) [0.5 on Epop[23]] -> cell 40, seg 0 (0.5) [0.5 on Epop[40]], weight: 4.1363508E-4, delay 1.5
        h("Epop[40] syn_projEE_ampa[1880] = new ampa(0.5)")
        h("Epop[23] netConn_projEE_ampa[1880] = new NetCon(&v(0.5), syn_projEE_ampa[1880], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1881: cell 23, seg 0 (0.5) [0.5 on Epop[23]] -> cell 41, seg 0 (0.5) [0.5 on Epop[41]], weight: 4.1363508E-4, delay 1.5
        h("Epop[41] syn_projEE_ampa[1881] = new ampa(0.5)")
        h("Epop[23] netConn_projEE_ampa[1881] = new NetCon(&v(0.5), syn_projEE_ampa[1881], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1882: cell 23, seg 0 (0.5) [0.5 on Epop[23]] -> cell 42, seg 0 (0.5) [0.5 on Epop[42]], weight: 4.1363508E-4, delay 1.5
        h("Epop[42] syn_projEE_ampa[1882] = new ampa(0.5)")
        h("Epop[23] netConn_projEE_ampa[1882] = new NetCon(&v(0.5), syn_projEE_ampa[1882], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1883: cell 23, seg 0 (0.5) [0.5 on Epop[23]] -> cell 43, seg 0 (0.5) [0.5 on Epop[43]], weight: 4.1363508E-4, delay 1.5
        h("Epop[43] syn_projEE_ampa[1883] = new ampa(0.5)")
        h("Epop[23] netConn_projEE_ampa[1883] = new NetCon(&v(0.5), syn_projEE_ampa[1883], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1884: cell 23, seg 0 (0.5) [0.5 on Epop[23]] -> cell 44, seg 0 (0.5) [0.5 on Epop[44]], weight: 4.1363508E-4, delay 1.5
        h("Epop[44] syn_projEE_ampa[1884] = new ampa(0.5)")
        h("Epop[23] netConn_projEE_ampa[1884] = new NetCon(&v(0.5), syn_projEE_ampa[1884], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1885: cell 23, seg 0 (0.5) [0.5 on Epop[23]] -> cell 45, seg 0 (0.5) [0.5 on Epop[45]], weight: 4.1363508E-4, delay 1.5
        h("Epop[45] syn_projEE_ampa[1885] = new ampa(0.5)")
        h("Epop[23] netConn_projEE_ampa[1885] = new NetCon(&v(0.5), syn_projEE_ampa[1885], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1886: cell 23, seg 0 (0.5) [0.5 on Epop[23]] -> cell 46, seg 0 (0.5) [0.5 on Epop[46]], weight: 4.1363508E-4, delay 1.5
        h("Epop[46] syn_projEE_ampa[1886] = new ampa(0.5)")
        h("Epop[23] netConn_projEE_ampa[1886] = new NetCon(&v(0.5), syn_projEE_ampa[1886], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1887: cell 23, seg 0 (0.5) [0.5 on Epop[23]] -> cell 47, seg 0 (0.5) [0.5 on Epop[47]], weight: 4.1363508E-4, delay 1.5
        h("Epop[47] syn_projEE_ampa[1887] = new ampa(0.5)")
        h("Epop[23] netConn_projEE_ampa[1887] = new NetCon(&v(0.5), syn_projEE_ampa[1887], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1888: cell 23, seg 0 (0.5) [0.5 on Epop[23]] -> cell 48, seg 0 (0.5) [0.5 on Epop[48]], weight: 4.1363508E-4, delay 1.5
        h("Epop[48] syn_projEE_ampa[1888] = new ampa(0.5)")
        h("Epop[23] netConn_projEE_ampa[1888] = new NetCon(&v(0.5), syn_projEE_ampa[1888], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1889: cell 23, seg 0 (0.5) [0.5 on Epop[23]] -> cell 49, seg 0 (0.5) [0.5 on Epop[49]], weight: 4.1363508E-4, delay 1.5
        h("Epop[49] syn_projEE_ampa[1889] = new ampa(0.5)")
        h("Epop[23] netConn_projEE_ampa[1889] = new NetCon(&v(0.5), syn_projEE_ampa[1889], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1890: cell 23, seg 0 (0.5) [0.5 on Epop[23]] -> cell 50, seg 0 (0.5) [0.5 on Epop[50]], weight: 4.1363508E-4, delay 1.5
        h("Epop[50] syn_projEE_ampa[1890] = new ampa(0.5)")
        h("Epop[23] netConn_projEE_ampa[1890] = new NetCon(&v(0.5), syn_projEE_ampa[1890], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1891: cell 23, seg 0 (0.5) [0.5 on Epop[23]] -> cell 51, seg 0 (0.5) [0.5 on Epop[51]], weight: 4.1363508E-4, delay 1.5
        h("Epop[51] syn_projEE_ampa[1891] = new ampa(0.5)")
        h("Epop[23] netConn_projEE_ampa[1891] = new NetCon(&v(0.5), syn_projEE_ampa[1891], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1892: cell 23, seg 0 (0.5) [0.5 on Epop[23]] -> cell 52, seg 0 (0.5) [0.5 on Epop[52]], weight: 4.1363508E-4, delay 1.5
        h("Epop[52] syn_projEE_ampa[1892] = new ampa(0.5)")
        h("Epop[23] netConn_projEE_ampa[1892] = new NetCon(&v(0.5), syn_projEE_ampa[1892], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1893: cell 23, seg 0 (0.5) [0.5 on Epop[23]] -> cell 53, seg 0 (0.5) [0.5 on Epop[53]], weight: 4.1363508E-4, delay 1.5
        h("Epop[53] syn_projEE_ampa[1893] = new ampa(0.5)")
        h("Epop[23] netConn_projEE_ampa[1893] = new NetCon(&v(0.5), syn_projEE_ampa[1893], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1894: cell 23, seg 0 (0.5) [0.5 on Epop[23]] -> cell 54, seg 0 (0.5) [0.5 on Epop[54]], weight: 4.1363508E-4, delay 1.5
        h("Epop[54] syn_projEE_ampa[1894] = new ampa(0.5)")
        h("Epop[23] netConn_projEE_ampa[1894] = new NetCon(&v(0.5), syn_projEE_ampa[1894], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1895: cell 23, seg 0 (0.5) [0.5 on Epop[23]] -> cell 55, seg 0 (0.5) [0.5 on Epop[55]], weight: 4.1363508E-4, delay 1.5
        h("Epop[55] syn_projEE_ampa[1895] = new ampa(0.5)")
        h("Epop[23] netConn_projEE_ampa[1895] = new NetCon(&v(0.5), syn_projEE_ampa[1895], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1896: cell 23, seg 0 (0.5) [0.5 on Epop[23]] -> cell 56, seg 0 (0.5) [0.5 on Epop[56]], weight: 4.1363508E-4, delay 1.5
        h("Epop[56] syn_projEE_ampa[1896] = new ampa(0.5)")
        h("Epop[23] netConn_projEE_ampa[1896] = new NetCon(&v(0.5), syn_projEE_ampa[1896], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1897: cell 23, seg 0 (0.5) [0.5 on Epop[23]] -> cell 57, seg 0 (0.5) [0.5 on Epop[57]], weight: 4.1363508E-4, delay 1.5
        h("Epop[57] syn_projEE_ampa[1897] = new ampa(0.5)")
        h("Epop[23] netConn_projEE_ampa[1897] = new NetCon(&v(0.5), syn_projEE_ampa[1897], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1898: cell 23, seg 0 (0.5) [0.5 on Epop[23]] -> cell 58, seg 0 (0.5) [0.5 on Epop[58]], weight: 4.1363508E-4, delay 1.5
        h("Epop[58] syn_projEE_ampa[1898] = new ampa(0.5)")
        h("Epop[23] netConn_projEE_ampa[1898] = new NetCon(&v(0.5), syn_projEE_ampa[1898], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1899: cell 23, seg 0 (0.5) [0.5 on Epop[23]] -> cell 59, seg 0 (0.5) [0.5 on Epop[59]], weight: 4.1363508E-4, delay 1.5
        h("Epop[59] syn_projEE_ampa[1899] = new ampa(0.5)")
        h("Epop[23] netConn_projEE_ampa[1899] = new NetCon(&v(0.5), syn_projEE_ampa[1899], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1900: cell 23, seg 0 (0.5) [0.5 on Epop[23]] -> cell 60, seg 0 (0.5) [0.5 on Epop[60]], weight: 4.1363508E-4, delay 1.5
        h("Epop[60] syn_projEE_ampa[1900] = new ampa(0.5)")
        h("Epop[23] netConn_projEE_ampa[1900] = new NetCon(&v(0.5), syn_projEE_ampa[1900], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1901: cell 23, seg 0 (0.5) [0.5 on Epop[23]] -> cell 61, seg 0 (0.5) [0.5 on Epop[61]], weight: 4.1363508E-4, delay 1.5
        h("Epop[61] syn_projEE_ampa[1901] = new ampa(0.5)")
        h("Epop[23] netConn_projEE_ampa[1901] = new NetCon(&v(0.5), syn_projEE_ampa[1901], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1902: cell 23, seg 0 (0.5) [0.5 on Epop[23]] -> cell 62, seg 0 (0.5) [0.5 on Epop[62]], weight: 4.1363508E-4, delay 1.5
        h("Epop[62] syn_projEE_ampa[1902] = new ampa(0.5)")
        h("Epop[23] netConn_projEE_ampa[1902] = new NetCon(&v(0.5), syn_projEE_ampa[1902], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1903: cell 23, seg 0 (0.5) [0.5 on Epop[23]] -> cell 63, seg 0 (0.5) [0.5 on Epop[63]], weight: 4.1363508E-4, delay 1.5
        h("Epop[63] syn_projEE_ampa[1903] = new ampa(0.5)")
        h("Epop[23] netConn_projEE_ampa[1903] = new NetCon(&v(0.5), syn_projEE_ampa[1903], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1904: cell 23, seg 0 (0.5) [0.5 on Epop[23]] -> cell 64, seg 0 (0.5) [0.5 on Epop[64]], weight: 4.1363508E-4, delay 1.5
        h("Epop[64] syn_projEE_ampa[1904] = new ampa(0.5)")
        h("Epop[23] netConn_projEE_ampa[1904] = new NetCon(&v(0.5), syn_projEE_ampa[1904], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1905: cell 23, seg 0 (0.5) [0.5 on Epop[23]] -> cell 65, seg 0 (0.5) [0.5 on Epop[65]], weight: 4.1363508E-4, delay 1.5
        h("Epop[65] syn_projEE_ampa[1905] = new ampa(0.5)")
        h("Epop[23] netConn_projEE_ampa[1905] = new NetCon(&v(0.5), syn_projEE_ampa[1905], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1906: cell 23, seg 0 (0.5) [0.5 on Epop[23]] -> cell 66, seg 0 (0.5) [0.5 on Epop[66]], weight: 4.1363508E-4, delay 1.5
        h("Epop[66] syn_projEE_ampa[1906] = new ampa(0.5)")
        h("Epop[23] netConn_projEE_ampa[1906] = new NetCon(&v(0.5), syn_projEE_ampa[1906], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1907: cell 23, seg 0 (0.5) [0.5 on Epop[23]] -> cell 67, seg 0 (0.5) [0.5 on Epop[67]], weight: 4.1363508E-4, delay 1.5
        h("Epop[67] syn_projEE_ampa[1907] = new ampa(0.5)")
        h("Epop[23] netConn_projEE_ampa[1907] = new NetCon(&v(0.5), syn_projEE_ampa[1907], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1908: cell 23, seg 0 (0.5) [0.5 on Epop[23]] -> cell 68, seg 0 (0.5) [0.5 on Epop[68]], weight: 4.1363508E-4, delay 1.5
        h("Epop[68] syn_projEE_ampa[1908] = new ampa(0.5)")
        h("Epop[23] netConn_projEE_ampa[1908] = new NetCon(&v(0.5), syn_projEE_ampa[1908], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1909: cell 23, seg 0 (0.5) [0.5 on Epop[23]] -> cell 69, seg 0 (0.5) [0.5 on Epop[69]], weight: 4.1363508E-4, delay 1.5
        h("Epop[69] syn_projEE_ampa[1909] = new ampa(0.5)")
        h("Epop[23] netConn_projEE_ampa[1909] = new NetCon(&v(0.5), syn_projEE_ampa[1909], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1910: cell 23, seg 0 (0.5) [0.5 on Epop[23]] -> cell 70, seg 0 (0.5) [0.5 on Epop[70]], weight: 4.1363508E-4, delay 1.5
        h("Epop[70] syn_projEE_ampa[1910] = new ampa(0.5)")
        h("Epop[23] netConn_projEE_ampa[1910] = new NetCon(&v(0.5), syn_projEE_ampa[1910], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1911: cell 23, seg 0 (0.5) [0.5 on Epop[23]] -> cell 71, seg 0 (0.5) [0.5 on Epop[71]], weight: 4.1363508E-4, delay 1.5
        h("Epop[71] syn_projEE_ampa[1911] = new ampa(0.5)")
        h("Epop[23] netConn_projEE_ampa[1911] = new NetCon(&v(0.5), syn_projEE_ampa[1911], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1912: cell 23, seg 0 (0.5) [0.5 on Epop[23]] -> cell 72, seg 0 (0.5) [0.5 on Epop[72]], weight: 4.1363508E-4, delay 1.5
        h("Epop[72] syn_projEE_ampa[1912] = new ampa(0.5)")
        h("Epop[23] netConn_projEE_ampa[1912] = new NetCon(&v(0.5), syn_projEE_ampa[1912], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1913: cell 23, seg 0 (0.5) [0.5 on Epop[23]] -> cell 73, seg 0 (0.5) [0.5 on Epop[73]], weight: 4.1363508E-4, delay 1.5
        h("Epop[73] syn_projEE_ampa[1913] = new ampa(0.5)")
        h("Epop[23] netConn_projEE_ampa[1913] = new NetCon(&v(0.5), syn_projEE_ampa[1913], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1914: cell 23, seg 0 (0.5) [0.5 on Epop[23]] -> cell 74, seg 0 (0.5) [0.5 on Epop[74]], weight: 4.1363508E-4, delay 1.5
        h("Epop[74] syn_projEE_ampa[1914] = new ampa(0.5)")
        h("Epop[23] netConn_projEE_ampa[1914] = new NetCon(&v(0.5), syn_projEE_ampa[1914], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1915: cell 23, seg 0 (0.5) [0.5 on Epop[23]] -> cell 75, seg 0 (0.5) [0.5 on Epop[75]], weight: 4.1363508E-4, delay 1.5
        h("Epop[75] syn_projEE_ampa[1915] = new ampa(0.5)")
        h("Epop[23] netConn_projEE_ampa[1915] = new NetCon(&v(0.5), syn_projEE_ampa[1915], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1916: cell 23, seg 0 (0.5) [0.5 on Epop[23]] -> cell 76, seg 0 (0.5) [0.5 on Epop[76]], weight: 4.1363508E-4, delay 1.5
        h("Epop[76] syn_projEE_ampa[1916] = new ampa(0.5)")
        h("Epop[23] netConn_projEE_ampa[1916] = new NetCon(&v(0.5), syn_projEE_ampa[1916], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1917: cell 23, seg 0 (0.5) [0.5 on Epop[23]] -> cell 77, seg 0 (0.5) [0.5 on Epop[77]], weight: 4.1363508E-4, delay 1.5
        h("Epop[77] syn_projEE_ampa[1917] = new ampa(0.5)")
        h("Epop[23] netConn_projEE_ampa[1917] = new NetCon(&v(0.5), syn_projEE_ampa[1917], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1918: cell 23, seg 0 (0.5) [0.5 on Epop[23]] -> cell 78, seg 0 (0.5) [0.5 on Epop[78]], weight: 4.1363508E-4, delay 1.5
        h("Epop[78] syn_projEE_ampa[1918] = new ampa(0.5)")
        h("Epop[23] netConn_projEE_ampa[1918] = new NetCon(&v(0.5), syn_projEE_ampa[1918], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1919: cell 23, seg 0 (0.5) [0.5 on Epop[23]] -> cell 79, seg 0 (0.5) [0.5 on Epop[79]], weight: 4.1363508E-4, delay 1.5
        h("Epop[79] syn_projEE_ampa[1919] = new ampa(0.5)")
        h("Epop[23] netConn_projEE_ampa[1919] = new NetCon(&v(0.5), syn_projEE_ampa[1919], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1920: cell 24, seg 0 (0.5) [0.5 on Epop[24]] -> cell 0, seg 0 (0.5) [0.5 on Epop[0]], weight: 4.1363508E-4, delay 1.5
        h("Epop[0] syn_projEE_ampa[1920] = new ampa(0.5)")
        h("Epop[24] netConn_projEE_ampa[1920] = new NetCon(&v(0.5), syn_projEE_ampa[1920], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1921: cell 24, seg 0 (0.5) [0.5 on Epop[24]] -> cell 1, seg 0 (0.5) [0.5 on Epop[1]], weight: 4.1363508E-4, delay 1.5
        h("Epop[1] syn_projEE_ampa[1921] = new ampa(0.5)")
        h("Epop[24] netConn_projEE_ampa[1921] = new NetCon(&v(0.5), syn_projEE_ampa[1921], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1922: cell 24, seg 0 (0.5) [0.5 on Epop[24]] -> cell 2, seg 0 (0.5) [0.5 on Epop[2]], weight: 4.1363508E-4, delay 1.5
        h("Epop[2] syn_projEE_ampa[1922] = new ampa(0.5)")
        h("Epop[24] netConn_projEE_ampa[1922] = new NetCon(&v(0.5), syn_projEE_ampa[1922], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1923: cell 24, seg 0 (0.5) [0.5 on Epop[24]] -> cell 3, seg 0 (0.5) [0.5 on Epop[3]], weight: 4.1363508E-4, delay 1.5
        h("Epop[3] syn_projEE_ampa[1923] = new ampa(0.5)")
        h("Epop[24] netConn_projEE_ampa[1923] = new NetCon(&v(0.5), syn_projEE_ampa[1923], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1924: cell 24, seg 0 (0.5) [0.5 on Epop[24]] -> cell 4, seg 0 (0.5) [0.5 on Epop[4]], weight: 4.1363508E-4, delay 1.5
        h("Epop[4] syn_projEE_ampa[1924] = new ampa(0.5)")
        h("Epop[24] netConn_projEE_ampa[1924] = new NetCon(&v(0.5), syn_projEE_ampa[1924], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1925: cell 24, seg 0 (0.5) [0.5 on Epop[24]] -> cell 5, seg 0 (0.5) [0.5 on Epop[5]], weight: 4.1363508E-4, delay 1.5
        h("Epop[5] syn_projEE_ampa[1925] = new ampa(0.5)")
        h("Epop[24] netConn_projEE_ampa[1925] = new NetCon(&v(0.5), syn_projEE_ampa[1925], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1926: cell 24, seg 0 (0.5) [0.5 on Epop[24]] -> cell 6, seg 0 (0.5) [0.5 on Epop[6]], weight: 4.1363508E-4, delay 1.5
        h("Epop[6] syn_projEE_ampa[1926] = new ampa(0.5)")
        h("Epop[24] netConn_projEE_ampa[1926] = new NetCon(&v(0.5), syn_projEE_ampa[1926], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1927: cell 24, seg 0 (0.5) [0.5 on Epop[24]] -> cell 7, seg 0 (0.5) [0.5 on Epop[7]], weight: 4.1363508E-4, delay 1.5
        h("Epop[7] syn_projEE_ampa[1927] = new ampa(0.5)")
        h("Epop[24] netConn_projEE_ampa[1927] = new NetCon(&v(0.5), syn_projEE_ampa[1927], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1928: cell 24, seg 0 (0.5) [0.5 on Epop[24]] -> cell 8, seg 0 (0.5) [0.5 on Epop[8]], weight: 4.1363508E-4, delay 1.5
        h("Epop[8] syn_projEE_ampa[1928] = new ampa(0.5)")
        h("Epop[24] netConn_projEE_ampa[1928] = new NetCon(&v(0.5), syn_projEE_ampa[1928], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1929: cell 24, seg 0 (0.5) [0.5 on Epop[24]] -> cell 9, seg 0 (0.5) [0.5 on Epop[9]], weight: 4.1363508E-4, delay 1.5
        h("Epop[9] syn_projEE_ampa[1929] = new ampa(0.5)")
        h("Epop[24] netConn_projEE_ampa[1929] = new NetCon(&v(0.5), syn_projEE_ampa[1929], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1930: cell 24, seg 0 (0.5) [0.5 on Epop[24]] -> cell 10, seg 0 (0.5) [0.5 on Epop[10]], weight: 4.1363508E-4, delay 1.5
        h("Epop[10] syn_projEE_ampa[1930] = new ampa(0.5)")
        h("Epop[24] netConn_projEE_ampa[1930] = new NetCon(&v(0.5), syn_projEE_ampa[1930], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1931: cell 24, seg 0 (0.5) [0.5 on Epop[24]] -> cell 11, seg 0 (0.5) [0.5 on Epop[11]], weight: 4.1363508E-4, delay 1.5
        h("Epop[11] syn_projEE_ampa[1931] = new ampa(0.5)")
        h("Epop[24] netConn_projEE_ampa[1931] = new NetCon(&v(0.5), syn_projEE_ampa[1931], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1932: cell 24, seg 0 (0.5) [0.5 on Epop[24]] -> cell 12, seg 0 (0.5) [0.5 on Epop[12]], weight: 4.1363508E-4, delay 1.5
        h("Epop[12] syn_projEE_ampa[1932] = new ampa(0.5)")
        h("Epop[24] netConn_projEE_ampa[1932] = new NetCon(&v(0.5), syn_projEE_ampa[1932], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1933: cell 24, seg 0 (0.5) [0.5 on Epop[24]] -> cell 13, seg 0 (0.5) [0.5 on Epop[13]], weight: 4.1363508E-4, delay 1.5
        h("Epop[13] syn_projEE_ampa[1933] = new ampa(0.5)")
        h("Epop[24] netConn_projEE_ampa[1933] = new NetCon(&v(0.5), syn_projEE_ampa[1933], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1934: cell 24, seg 0 (0.5) [0.5 on Epop[24]] -> cell 14, seg 0 (0.5) [0.5 on Epop[14]], weight: 4.1363508E-4, delay 1.5
        h("Epop[14] syn_projEE_ampa[1934] = new ampa(0.5)")
        h("Epop[24] netConn_projEE_ampa[1934] = new NetCon(&v(0.5), syn_projEE_ampa[1934], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1935: cell 24, seg 0 (0.5) [0.5 on Epop[24]] -> cell 15, seg 0 (0.5) [0.5 on Epop[15]], weight: 4.1363508E-4, delay 1.5
        h("Epop[15] syn_projEE_ampa[1935] = new ampa(0.5)")
        h("Epop[24] netConn_projEE_ampa[1935] = new NetCon(&v(0.5), syn_projEE_ampa[1935], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1936: cell 24, seg 0 (0.5) [0.5 on Epop[24]] -> cell 16, seg 0 (0.5) [0.5 on Epop[16]], weight: 4.1363508E-4, delay 1.5
        h("Epop[16] syn_projEE_ampa[1936] = new ampa(0.5)")
        h("Epop[24] netConn_projEE_ampa[1936] = new NetCon(&v(0.5), syn_projEE_ampa[1936], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1937: cell 24, seg 0 (0.5) [0.5 on Epop[24]] -> cell 17, seg 0 (0.5) [0.5 on Epop[17]], weight: 4.1363508E-4, delay 1.5
        h("Epop[17] syn_projEE_ampa[1937] = new ampa(0.5)")
        h("Epop[24] netConn_projEE_ampa[1937] = new NetCon(&v(0.5), syn_projEE_ampa[1937], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1938: cell 24, seg 0 (0.5) [0.5 on Epop[24]] -> cell 18, seg 0 (0.5) [0.5 on Epop[18]], weight: 4.1363508E-4, delay 1.5
        h("Epop[18] syn_projEE_ampa[1938] = new ampa(0.5)")
        h("Epop[24] netConn_projEE_ampa[1938] = new NetCon(&v(0.5), syn_projEE_ampa[1938], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1939: cell 24, seg 0 (0.5) [0.5 on Epop[24]] -> cell 19, seg 0 (0.5) [0.5 on Epop[19]], weight: 4.1363508E-4, delay 1.5
        h("Epop[19] syn_projEE_ampa[1939] = new ampa(0.5)")
        h("Epop[24] netConn_projEE_ampa[1939] = new NetCon(&v(0.5), syn_projEE_ampa[1939], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1940: cell 24, seg 0 (0.5) [0.5 on Epop[24]] -> cell 20, seg 0 (0.5) [0.5 on Epop[20]], weight: 4.1363508E-4, delay 1.5
        h("Epop[20] syn_projEE_ampa[1940] = new ampa(0.5)")
        h("Epop[24] netConn_projEE_ampa[1940] = new NetCon(&v(0.5), syn_projEE_ampa[1940], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1941: cell 24, seg 0 (0.5) [0.5 on Epop[24]] -> cell 21, seg 0 (0.5) [0.5 on Epop[21]], weight: 4.1363508E-4, delay 1.5
        h("Epop[21] syn_projEE_ampa[1941] = new ampa(0.5)")
        h("Epop[24] netConn_projEE_ampa[1941] = new NetCon(&v(0.5), syn_projEE_ampa[1941], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1942: cell 24, seg 0 (0.5) [0.5 on Epop[24]] -> cell 22, seg 0 (0.5) [0.5 on Epop[22]], weight: 4.1363508E-4, delay 1.5
        h("Epop[22] syn_projEE_ampa[1942] = new ampa(0.5)")
        h("Epop[24] netConn_projEE_ampa[1942] = new NetCon(&v(0.5), syn_projEE_ampa[1942], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1943: cell 24, seg 0 (0.5) [0.5 on Epop[24]] -> cell 23, seg 0 (0.5) [0.5 on Epop[23]], weight: 4.1363508E-4, delay 1.5
        h("Epop[23] syn_projEE_ampa[1943] = new ampa(0.5)")
        h("Epop[24] netConn_projEE_ampa[1943] = new NetCon(&v(0.5), syn_projEE_ampa[1943], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1944: cell 24, seg 0 (0.5) [0.5 on Epop[24]] -> cell 24, seg 0 (0.5) [0.5 on Epop[24]], weight: 4.1363508E-4, delay 1.5
        h("Epop[24] syn_projEE_ampa[1944] = new ampa(0.5)")
        h("Epop[24] netConn_projEE_ampa[1944] = new NetCon(&v(0.5), syn_projEE_ampa[1944], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1945: cell 24, seg 0 (0.5) [0.5 on Epop[24]] -> cell 25, seg 0 (0.5) [0.5 on Epop[25]], weight: 4.1363508E-4, delay 1.5
        h("Epop[25] syn_projEE_ampa[1945] = new ampa(0.5)")
        h("Epop[24] netConn_projEE_ampa[1945] = new NetCon(&v(0.5), syn_projEE_ampa[1945], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1946: cell 24, seg 0 (0.5) [0.5 on Epop[24]] -> cell 26, seg 0 (0.5) [0.5 on Epop[26]], weight: 4.1363508E-4, delay 1.5
        h("Epop[26] syn_projEE_ampa[1946] = new ampa(0.5)")
        h("Epop[24] netConn_projEE_ampa[1946] = new NetCon(&v(0.5), syn_projEE_ampa[1946], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1947: cell 24, seg 0 (0.5) [0.5 on Epop[24]] -> cell 27, seg 0 (0.5) [0.5 on Epop[27]], weight: 4.1363508E-4, delay 1.5
        h("Epop[27] syn_projEE_ampa[1947] = new ampa(0.5)")
        h("Epop[24] netConn_projEE_ampa[1947] = new NetCon(&v(0.5), syn_projEE_ampa[1947], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1948: cell 24, seg 0 (0.5) [0.5 on Epop[24]] -> cell 28, seg 0 (0.5) [0.5 on Epop[28]], weight: 4.1363508E-4, delay 1.5
        h("Epop[28] syn_projEE_ampa[1948] = new ampa(0.5)")
        h("Epop[24] netConn_projEE_ampa[1948] = new NetCon(&v(0.5), syn_projEE_ampa[1948], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1949: cell 24, seg 0 (0.5) [0.5 on Epop[24]] -> cell 29, seg 0 (0.5) [0.5 on Epop[29]], weight: 4.1363508E-4, delay 1.5
        h("Epop[29] syn_projEE_ampa[1949] = new ampa(0.5)")
        h("Epop[24] netConn_projEE_ampa[1949] = new NetCon(&v(0.5), syn_projEE_ampa[1949], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1950: cell 24, seg 0 (0.5) [0.5 on Epop[24]] -> cell 30, seg 0 (0.5) [0.5 on Epop[30]], weight: 4.1363508E-4, delay 1.5
        h("Epop[30] syn_projEE_ampa[1950] = new ampa(0.5)")
        h("Epop[24] netConn_projEE_ampa[1950] = new NetCon(&v(0.5), syn_projEE_ampa[1950], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1951: cell 24, seg 0 (0.5) [0.5 on Epop[24]] -> cell 31, seg 0 (0.5) [0.5 on Epop[31]], weight: 4.1363508E-4, delay 1.5
        h("Epop[31] syn_projEE_ampa[1951] = new ampa(0.5)")
        h("Epop[24] netConn_projEE_ampa[1951] = new NetCon(&v(0.5), syn_projEE_ampa[1951], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1952: cell 24, seg 0 (0.5) [0.5 on Epop[24]] -> cell 32, seg 0 (0.5) [0.5 on Epop[32]], weight: 4.1363508E-4, delay 1.5
        h("Epop[32] syn_projEE_ampa[1952] = new ampa(0.5)")
        h("Epop[24] netConn_projEE_ampa[1952] = new NetCon(&v(0.5), syn_projEE_ampa[1952], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1953: cell 24, seg 0 (0.5) [0.5 on Epop[24]] -> cell 33, seg 0 (0.5) [0.5 on Epop[33]], weight: 4.1363508E-4, delay 1.5
        h("Epop[33] syn_projEE_ampa[1953] = new ampa(0.5)")
        h("Epop[24] netConn_projEE_ampa[1953] = new NetCon(&v(0.5), syn_projEE_ampa[1953], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1954: cell 24, seg 0 (0.5) [0.5 on Epop[24]] -> cell 34, seg 0 (0.5) [0.5 on Epop[34]], weight: 4.1363508E-4, delay 1.5
        h("Epop[34] syn_projEE_ampa[1954] = new ampa(0.5)")
        h("Epop[24] netConn_projEE_ampa[1954] = new NetCon(&v(0.5), syn_projEE_ampa[1954], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1955: cell 24, seg 0 (0.5) [0.5 on Epop[24]] -> cell 35, seg 0 (0.5) [0.5 on Epop[35]], weight: 4.1363508E-4, delay 1.5
        h("Epop[35] syn_projEE_ampa[1955] = new ampa(0.5)")
        h("Epop[24] netConn_projEE_ampa[1955] = new NetCon(&v(0.5), syn_projEE_ampa[1955], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1956: cell 24, seg 0 (0.5) [0.5 on Epop[24]] -> cell 36, seg 0 (0.5) [0.5 on Epop[36]], weight: 4.1363508E-4, delay 1.5
        h("Epop[36] syn_projEE_ampa[1956] = new ampa(0.5)")
        h("Epop[24] netConn_projEE_ampa[1956] = new NetCon(&v(0.5), syn_projEE_ampa[1956], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1957: cell 24, seg 0 (0.5) [0.5 on Epop[24]] -> cell 37, seg 0 (0.5) [0.5 on Epop[37]], weight: 4.1363508E-4, delay 1.5
        h("Epop[37] syn_projEE_ampa[1957] = new ampa(0.5)")
        h("Epop[24] netConn_projEE_ampa[1957] = new NetCon(&v(0.5), syn_projEE_ampa[1957], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1958: cell 24, seg 0 (0.5) [0.5 on Epop[24]] -> cell 38, seg 0 (0.5) [0.5 on Epop[38]], weight: 4.1363508E-4, delay 1.5
        h("Epop[38] syn_projEE_ampa[1958] = new ampa(0.5)")
        h("Epop[24] netConn_projEE_ampa[1958] = new NetCon(&v(0.5), syn_projEE_ampa[1958], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1959: cell 24, seg 0 (0.5) [0.5 on Epop[24]] -> cell 39, seg 0 (0.5) [0.5 on Epop[39]], weight: 4.1363508E-4, delay 1.5
        h("Epop[39] syn_projEE_ampa[1959] = new ampa(0.5)")
        h("Epop[24] netConn_projEE_ampa[1959] = new NetCon(&v(0.5), syn_projEE_ampa[1959], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1960: cell 24, seg 0 (0.5) [0.5 on Epop[24]] -> cell 40, seg 0 (0.5) [0.5 on Epop[40]], weight: 4.1363508E-4, delay 1.5
        h("Epop[40] syn_projEE_ampa[1960] = new ampa(0.5)")
        h("Epop[24] netConn_projEE_ampa[1960] = new NetCon(&v(0.5), syn_projEE_ampa[1960], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1961: cell 24, seg 0 (0.5) [0.5 on Epop[24]] -> cell 41, seg 0 (0.5) [0.5 on Epop[41]], weight: 4.1363508E-4, delay 1.5
        h("Epop[41] syn_projEE_ampa[1961] = new ampa(0.5)")
        h("Epop[24] netConn_projEE_ampa[1961] = new NetCon(&v(0.5), syn_projEE_ampa[1961], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1962: cell 24, seg 0 (0.5) [0.5 on Epop[24]] -> cell 42, seg 0 (0.5) [0.5 on Epop[42]], weight: 4.1363508E-4, delay 1.5
        h("Epop[42] syn_projEE_ampa[1962] = new ampa(0.5)")
        h("Epop[24] netConn_projEE_ampa[1962] = new NetCon(&v(0.5), syn_projEE_ampa[1962], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1963: cell 24, seg 0 (0.5) [0.5 on Epop[24]] -> cell 43, seg 0 (0.5) [0.5 on Epop[43]], weight: 4.1363508E-4, delay 1.5
        h("Epop[43] syn_projEE_ampa[1963] = new ampa(0.5)")
        h("Epop[24] netConn_projEE_ampa[1963] = new NetCon(&v(0.5), syn_projEE_ampa[1963], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1964: cell 24, seg 0 (0.5) [0.5 on Epop[24]] -> cell 44, seg 0 (0.5) [0.5 on Epop[44]], weight: 4.1363508E-4, delay 1.5
        h("Epop[44] syn_projEE_ampa[1964] = new ampa(0.5)")
        h("Epop[24] netConn_projEE_ampa[1964] = new NetCon(&v(0.5), syn_projEE_ampa[1964], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1965: cell 24, seg 0 (0.5) [0.5 on Epop[24]] -> cell 45, seg 0 (0.5) [0.5 on Epop[45]], weight: 4.1363508E-4, delay 1.5
        h("Epop[45] syn_projEE_ampa[1965] = new ampa(0.5)")
        h("Epop[24] netConn_projEE_ampa[1965] = new NetCon(&v(0.5), syn_projEE_ampa[1965], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1966: cell 24, seg 0 (0.5) [0.5 on Epop[24]] -> cell 46, seg 0 (0.5) [0.5 on Epop[46]], weight: 4.1363508E-4, delay 1.5
        h("Epop[46] syn_projEE_ampa[1966] = new ampa(0.5)")
        h("Epop[24] netConn_projEE_ampa[1966] = new NetCon(&v(0.5), syn_projEE_ampa[1966], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1967: cell 24, seg 0 (0.5) [0.5 on Epop[24]] -> cell 47, seg 0 (0.5) [0.5 on Epop[47]], weight: 4.1363508E-4, delay 1.5
        h("Epop[47] syn_projEE_ampa[1967] = new ampa(0.5)")
        h("Epop[24] netConn_projEE_ampa[1967] = new NetCon(&v(0.5), syn_projEE_ampa[1967], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1968: cell 24, seg 0 (0.5) [0.5 on Epop[24]] -> cell 48, seg 0 (0.5) [0.5 on Epop[48]], weight: 4.1363508E-4, delay 1.5
        h("Epop[48] syn_projEE_ampa[1968] = new ampa(0.5)")
        h("Epop[24] netConn_projEE_ampa[1968] = new NetCon(&v(0.5), syn_projEE_ampa[1968], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1969: cell 24, seg 0 (0.5) [0.5 on Epop[24]] -> cell 49, seg 0 (0.5) [0.5 on Epop[49]], weight: 4.1363508E-4, delay 1.5
        h("Epop[49] syn_projEE_ampa[1969] = new ampa(0.5)")
        h("Epop[24] netConn_projEE_ampa[1969] = new NetCon(&v(0.5), syn_projEE_ampa[1969], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1970: cell 24, seg 0 (0.5) [0.5 on Epop[24]] -> cell 50, seg 0 (0.5) [0.5 on Epop[50]], weight: 4.1363508E-4, delay 1.5
        h("Epop[50] syn_projEE_ampa[1970] = new ampa(0.5)")
        h("Epop[24] netConn_projEE_ampa[1970] = new NetCon(&v(0.5), syn_projEE_ampa[1970], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1971: cell 24, seg 0 (0.5) [0.5 on Epop[24]] -> cell 51, seg 0 (0.5) [0.5 on Epop[51]], weight: 4.1363508E-4, delay 1.5
        h("Epop[51] syn_projEE_ampa[1971] = new ampa(0.5)")
        h("Epop[24] netConn_projEE_ampa[1971] = new NetCon(&v(0.5), syn_projEE_ampa[1971], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1972: cell 24, seg 0 (0.5) [0.5 on Epop[24]] -> cell 52, seg 0 (0.5) [0.5 on Epop[52]], weight: 4.1363508E-4, delay 1.5
        h("Epop[52] syn_projEE_ampa[1972] = new ampa(0.5)")
        h("Epop[24] netConn_projEE_ampa[1972] = new NetCon(&v(0.5), syn_projEE_ampa[1972], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1973: cell 24, seg 0 (0.5) [0.5 on Epop[24]] -> cell 53, seg 0 (0.5) [0.5 on Epop[53]], weight: 4.1363508E-4, delay 1.5
        h("Epop[53] syn_projEE_ampa[1973] = new ampa(0.5)")
        h("Epop[24] netConn_projEE_ampa[1973] = new NetCon(&v(0.5), syn_projEE_ampa[1973], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1974: cell 24, seg 0 (0.5) [0.5 on Epop[24]] -> cell 54, seg 0 (0.5) [0.5 on Epop[54]], weight: 4.1363508E-4, delay 1.5
        h("Epop[54] syn_projEE_ampa[1974] = new ampa(0.5)")
        h("Epop[24] netConn_projEE_ampa[1974] = new NetCon(&v(0.5), syn_projEE_ampa[1974], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1975: cell 24, seg 0 (0.5) [0.5 on Epop[24]] -> cell 55, seg 0 (0.5) [0.5 on Epop[55]], weight: 4.1363508E-4, delay 1.5
        h("Epop[55] syn_projEE_ampa[1975] = new ampa(0.5)")
        h("Epop[24] netConn_projEE_ampa[1975] = new NetCon(&v(0.5), syn_projEE_ampa[1975], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1976: cell 24, seg 0 (0.5) [0.5 on Epop[24]] -> cell 56, seg 0 (0.5) [0.5 on Epop[56]], weight: 4.1363508E-4, delay 1.5
        h("Epop[56] syn_projEE_ampa[1976] = new ampa(0.5)")
        h("Epop[24] netConn_projEE_ampa[1976] = new NetCon(&v(0.5), syn_projEE_ampa[1976], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1977: cell 24, seg 0 (0.5) [0.5 on Epop[24]] -> cell 57, seg 0 (0.5) [0.5 on Epop[57]], weight: 4.1363508E-4, delay 1.5
        h("Epop[57] syn_projEE_ampa[1977] = new ampa(0.5)")
        h("Epop[24] netConn_projEE_ampa[1977] = new NetCon(&v(0.5), syn_projEE_ampa[1977], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1978: cell 24, seg 0 (0.5) [0.5 on Epop[24]] -> cell 58, seg 0 (0.5) [0.5 on Epop[58]], weight: 4.1363508E-4, delay 1.5
        h("Epop[58] syn_projEE_ampa[1978] = new ampa(0.5)")
        h("Epop[24] netConn_projEE_ampa[1978] = new NetCon(&v(0.5), syn_projEE_ampa[1978], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1979: cell 24, seg 0 (0.5) [0.5 on Epop[24]] -> cell 59, seg 0 (0.5) [0.5 on Epop[59]], weight: 4.1363508E-4, delay 1.5
        h("Epop[59] syn_projEE_ampa[1979] = new ampa(0.5)")
        h("Epop[24] netConn_projEE_ampa[1979] = new NetCon(&v(0.5), syn_projEE_ampa[1979], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1980: cell 24, seg 0 (0.5) [0.5 on Epop[24]] -> cell 60, seg 0 (0.5) [0.5 on Epop[60]], weight: 4.1363508E-4, delay 1.5
        h("Epop[60] syn_projEE_ampa[1980] = new ampa(0.5)")
        h("Epop[24] netConn_projEE_ampa[1980] = new NetCon(&v(0.5), syn_projEE_ampa[1980], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1981: cell 24, seg 0 (0.5) [0.5 on Epop[24]] -> cell 61, seg 0 (0.5) [0.5 on Epop[61]], weight: 4.1363508E-4, delay 1.5
        h("Epop[61] syn_projEE_ampa[1981] = new ampa(0.5)")
        h("Epop[24] netConn_projEE_ampa[1981] = new NetCon(&v(0.5), syn_projEE_ampa[1981], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1982: cell 24, seg 0 (0.5) [0.5 on Epop[24]] -> cell 62, seg 0 (0.5) [0.5 on Epop[62]], weight: 4.1363508E-4, delay 1.5
        h("Epop[62] syn_projEE_ampa[1982] = new ampa(0.5)")
        h("Epop[24] netConn_projEE_ampa[1982] = new NetCon(&v(0.5), syn_projEE_ampa[1982], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1983: cell 24, seg 0 (0.5) [0.5 on Epop[24]] -> cell 63, seg 0 (0.5) [0.5 on Epop[63]], weight: 4.1363508E-4, delay 1.5
        h("Epop[63] syn_projEE_ampa[1983] = new ampa(0.5)")
        h("Epop[24] netConn_projEE_ampa[1983] = new NetCon(&v(0.5), syn_projEE_ampa[1983], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1984: cell 24, seg 0 (0.5) [0.5 on Epop[24]] -> cell 64, seg 0 (0.5) [0.5 on Epop[64]], weight: 4.1363508E-4, delay 1.5
        h("Epop[64] syn_projEE_ampa[1984] = new ampa(0.5)")
        h("Epop[24] netConn_projEE_ampa[1984] = new NetCon(&v(0.5), syn_projEE_ampa[1984], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1985: cell 24, seg 0 (0.5) [0.5 on Epop[24]] -> cell 65, seg 0 (0.5) [0.5 on Epop[65]], weight: 4.1363508E-4, delay 1.5
        h("Epop[65] syn_projEE_ampa[1985] = new ampa(0.5)")
        h("Epop[24] netConn_projEE_ampa[1985] = new NetCon(&v(0.5), syn_projEE_ampa[1985], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1986: cell 24, seg 0 (0.5) [0.5 on Epop[24]] -> cell 66, seg 0 (0.5) [0.5 on Epop[66]], weight: 4.1363508E-4, delay 1.5
        h("Epop[66] syn_projEE_ampa[1986] = new ampa(0.5)")
        h("Epop[24] netConn_projEE_ampa[1986] = new NetCon(&v(0.5), syn_projEE_ampa[1986], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1987: cell 24, seg 0 (0.5) [0.5 on Epop[24]] -> cell 67, seg 0 (0.5) [0.5 on Epop[67]], weight: 4.1363508E-4, delay 1.5
        h("Epop[67] syn_projEE_ampa[1987] = new ampa(0.5)")
        h("Epop[24] netConn_projEE_ampa[1987] = new NetCon(&v(0.5), syn_projEE_ampa[1987], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1988: cell 24, seg 0 (0.5) [0.5 on Epop[24]] -> cell 68, seg 0 (0.5) [0.5 on Epop[68]], weight: 4.1363508E-4, delay 1.5
        h("Epop[68] syn_projEE_ampa[1988] = new ampa(0.5)")
        h("Epop[24] netConn_projEE_ampa[1988] = new NetCon(&v(0.5), syn_projEE_ampa[1988], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1989: cell 24, seg 0 (0.5) [0.5 on Epop[24]] -> cell 69, seg 0 (0.5) [0.5 on Epop[69]], weight: 4.1363508E-4, delay 1.5
        h("Epop[69] syn_projEE_ampa[1989] = new ampa(0.5)")
        h("Epop[24] netConn_projEE_ampa[1989] = new NetCon(&v(0.5), syn_projEE_ampa[1989], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1990: cell 24, seg 0 (0.5) [0.5 on Epop[24]] -> cell 70, seg 0 (0.5) [0.5 on Epop[70]], weight: 4.1363508E-4, delay 1.5
        h("Epop[70] syn_projEE_ampa[1990] = new ampa(0.5)")
        h("Epop[24] netConn_projEE_ampa[1990] = new NetCon(&v(0.5), syn_projEE_ampa[1990], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1991: cell 24, seg 0 (0.5) [0.5 on Epop[24]] -> cell 71, seg 0 (0.5) [0.5 on Epop[71]], weight: 4.1363508E-4, delay 1.5
        h("Epop[71] syn_projEE_ampa[1991] = new ampa(0.5)")
        h("Epop[24] netConn_projEE_ampa[1991] = new NetCon(&v(0.5), syn_projEE_ampa[1991], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1992: cell 24, seg 0 (0.5) [0.5 on Epop[24]] -> cell 72, seg 0 (0.5) [0.5 on Epop[72]], weight: 4.1363508E-4, delay 1.5
        h("Epop[72] syn_projEE_ampa[1992] = new ampa(0.5)")
        h("Epop[24] netConn_projEE_ampa[1992] = new NetCon(&v(0.5), syn_projEE_ampa[1992], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1993: cell 24, seg 0 (0.5) [0.5 on Epop[24]] -> cell 73, seg 0 (0.5) [0.5 on Epop[73]], weight: 4.1363508E-4, delay 1.5
        h("Epop[73] syn_projEE_ampa[1993] = new ampa(0.5)")
        h("Epop[24] netConn_projEE_ampa[1993] = new NetCon(&v(0.5), syn_projEE_ampa[1993], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1994: cell 24, seg 0 (0.5) [0.5 on Epop[24]] -> cell 74, seg 0 (0.5) [0.5 on Epop[74]], weight: 4.1363508E-4, delay 1.5
        h("Epop[74] syn_projEE_ampa[1994] = new ampa(0.5)")
        h("Epop[24] netConn_projEE_ampa[1994] = new NetCon(&v(0.5), syn_projEE_ampa[1994], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1995: cell 24, seg 0 (0.5) [0.5 on Epop[24]] -> cell 75, seg 0 (0.5) [0.5 on Epop[75]], weight: 4.1363508E-4, delay 1.5
        h("Epop[75] syn_projEE_ampa[1995] = new ampa(0.5)")
        h("Epop[24] netConn_projEE_ampa[1995] = new NetCon(&v(0.5), syn_projEE_ampa[1995], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1996: cell 24, seg 0 (0.5) [0.5 on Epop[24]] -> cell 76, seg 0 (0.5) [0.5 on Epop[76]], weight: 4.1363508E-4, delay 1.5
        h("Epop[76] syn_projEE_ampa[1996] = new ampa(0.5)")
        h("Epop[24] netConn_projEE_ampa[1996] = new NetCon(&v(0.5), syn_projEE_ampa[1996], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1997: cell 24, seg 0 (0.5) [0.5 on Epop[24]] -> cell 77, seg 0 (0.5) [0.5 on Epop[77]], weight: 4.1363508E-4, delay 1.5
        h("Epop[77] syn_projEE_ampa[1997] = new ampa(0.5)")
        h("Epop[24] netConn_projEE_ampa[1997] = new NetCon(&v(0.5), syn_projEE_ampa[1997], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1998: cell 24, seg 0 (0.5) [0.5 on Epop[24]] -> cell 78, seg 0 (0.5) [0.5 on Epop[78]], weight: 4.1363508E-4, delay 1.5
        h("Epop[78] syn_projEE_ampa[1998] = new ampa(0.5)")
        h("Epop[24] netConn_projEE_ampa[1998] = new NetCon(&v(0.5), syn_projEE_ampa[1998], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1999: cell 24, seg 0 (0.5) [0.5 on Epop[24]] -> cell 79, seg 0 (0.5) [0.5 on Epop[79]], weight: 4.1363508E-4, delay 1.5
        h("Epop[79] syn_projEE_ampa[1999] = new ampa(0.5)")
        h("Epop[24] netConn_projEE_ampa[1999] = new NetCon(&v(0.5), syn_projEE_ampa[1999], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2000: cell 25, seg 0 (0.5) [0.5 on Epop[25]] -> cell 0, seg 0 (0.5) [0.5 on Epop[0]], weight: 4.1363508E-4, delay 1.5
        h("Epop[0] syn_projEE_ampa[2000] = new ampa(0.5)")
        h("Epop[25] netConn_projEE_ampa[2000] = new NetCon(&v(0.5), syn_projEE_ampa[2000], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2001: cell 25, seg 0 (0.5) [0.5 on Epop[25]] -> cell 1, seg 0 (0.5) [0.5 on Epop[1]], weight: 4.1363508E-4, delay 1.5
        h("Epop[1] syn_projEE_ampa[2001] = new ampa(0.5)")
        h("Epop[25] netConn_projEE_ampa[2001] = new NetCon(&v(0.5), syn_projEE_ampa[2001], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2002: cell 25, seg 0 (0.5) [0.5 on Epop[25]] -> cell 2, seg 0 (0.5) [0.5 on Epop[2]], weight: 4.1363508E-4, delay 1.5
        h("Epop[2] syn_projEE_ampa[2002] = new ampa(0.5)")
        h("Epop[25] netConn_projEE_ampa[2002] = new NetCon(&v(0.5), syn_projEE_ampa[2002], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2003: cell 25, seg 0 (0.5) [0.5 on Epop[25]] -> cell 3, seg 0 (0.5) [0.5 on Epop[3]], weight: 4.1363508E-4, delay 1.5
        h("Epop[3] syn_projEE_ampa[2003] = new ampa(0.5)")
        h("Epop[25] netConn_projEE_ampa[2003] = new NetCon(&v(0.5), syn_projEE_ampa[2003], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2004: cell 25, seg 0 (0.5) [0.5 on Epop[25]] -> cell 4, seg 0 (0.5) [0.5 on Epop[4]], weight: 4.1363508E-4, delay 1.5
        h("Epop[4] syn_projEE_ampa[2004] = new ampa(0.5)")
        h("Epop[25] netConn_projEE_ampa[2004] = new NetCon(&v(0.5), syn_projEE_ampa[2004], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2005: cell 25, seg 0 (0.5) [0.5 on Epop[25]] -> cell 5, seg 0 (0.5) [0.5 on Epop[5]], weight: 4.1363508E-4, delay 1.5
        h("Epop[5] syn_projEE_ampa[2005] = new ampa(0.5)")
        h("Epop[25] netConn_projEE_ampa[2005] = new NetCon(&v(0.5), syn_projEE_ampa[2005], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2006: cell 25, seg 0 (0.5) [0.5 on Epop[25]] -> cell 6, seg 0 (0.5) [0.5 on Epop[6]], weight: 4.1363508E-4, delay 1.5
        h("Epop[6] syn_projEE_ampa[2006] = new ampa(0.5)")
        h("Epop[25] netConn_projEE_ampa[2006] = new NetCon(&v(0.5), syn_projEE_ampa[2006], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2007: cell 25, seg 0 (0.5) [0.5 on Epop[25]] -> cell 7, seg 0 (0.5) [0.5 on Epop[7]], weight: 4.1363508E-4, delay 1.5
        h("Epop[7] syn_projEE_ampa[2007] = new ampa(0.5)")
        h("Epop[25] netConn_projEE_ampa[2007] = new NetCon(&v(0.5), syn_projEE_ampa[2007], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2008: cell 25, seg 0 (0.5) [0.5 on Epop[25]] -> cell 8, seg 0 (0.5) [0.5 on Epop[8]], weight: 4.1363508E-4, delay 1.5
        h("Epop[8] syn_projEE_ampa[2008] = new ampa(0.5)")
        h("Epop[25] netConn_projEE_ampa[2008] = new NetCon(&v(0.5), syn_projEE_ampa[2008], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2009: cell 25, seg 0 (0.5) [0.5 on Epop[25]] -> cell 9, seg 0 (0.5) [0.5 on Epop[9]], weight: 4.1363508E-4, delay 1.5
        h("Epop[9] syn_projEE_ampa[2009] = new ampa(0.5)")
        h("Epop[25] netConn_projEE_ampa[2009] = new NetCon(&v(0.5), syn_projEE_ampa[2009], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2010: cell 25, seg 0 (0.5) [0.5 on Epop[25]] -> cell 10, seg 0 (0.5) [0.5 on Epop[10]], weight: 4.1363508E-4, delay 1.5
        h("Epop[10] syn_projEE_ampa[2010] = new ampa(0.5)")
        h("Epop[25] netConn_projEE_ampa[2010] = new NetCon(&v(0.5), syn_projEE_ampa[2010], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2011: cell 25, seg 0 (0.5) [0.5 on Epop[25]] -> cell 11, seg 0 (0.5) [0.5 on Epop[11]], weight: 4.1363508E-4, delay 1.5
        h("Epop[11] syn_projEE_ampa[2011] = new ampa(0.5)")
        h("Epop[25] netConn_projEE_ampa[2011] = new NetCon(&v(0.5), syn_projEE_ampa[2011], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2012: cell 25, seg 0 (0.5) [0.5 on Epop[25]] -> cell 12, seg 0 (0.5) [0.5 on Epop[12]], weight: 4.1363508E-4, delay 1.5
        h("Epop[12] syn_projEE_ampa[2012] = new ampa(0.5)")
        h("Epop[25] netConn_projEE_ampa[2012] = new NetCon(&v(0.5), syn_projEE_ampa[2012], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2013: cell 25, seg 0 (0.5) [0.5 on Epop[25]] -> cell 13, seg 0 (0.5) [0.5 on Epop[13]], weight: 4.1363508E-4, delay 1.5
        h("Epop[13] syn_projEE_ampa[2013] = new ampa(0.5)")
        h("Epop[25] netConn_projEE_ampa[2013] = new NetCon(&v(0.5), syn_projEE_ampa[2013], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2014: cell 25, seg 0 (0.5) [0.5 on Epop[25]] -> cell 14, seg 0 (0.5) [0.5 on Epop[14]], weight: 4.1363508E-4, delay 1.5
        h("Epop[14] syn_projEE_ampa[2014] = new ampa(0.5)")
        h("Epop[25] netConn_projEE_ampa[2014] = new NetCon(&v(0.5), syn_projEE_ampa[2014], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2015: cell 25, seg 0 (0.5) [0.5 on Epop[25]] -> cell 15, seg 0 (0.5) [0.5 on Epop[15]], weight: 4.1363508E-4, delay 1.5
        h("Epop[15] syn_projEE_ampa[2015] = new ampa(0.5)")
        h("Epop[25] netConn_projEE_ampa[2015] = new NetCon(&v(0.5), syn_projEE_ampa[2015], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2016: cell 25, seg 0 (0.5) [0.5 on Epop[25]] -> cell 16, seg 0 (0.5) [0.5 on Epop[16]], weight: 4.1363508E-4, delay 1.5
        h("Epop[16] syn_projEE_ampa[2016] = new ampa(0.5)")
        h("Epop[25] netConn_projEE_ampa[2016] = new NetCon(&v(0.5), syn_projEE_ampa[2016], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2017: cell 25, seg 0 (0.5) [0.5 on Epop[25]] -> cell 17, seg 0 (0.5) [0.5 on Epop[17]], weight: 4.1363508E-4, delay 1.5
        h("Epop[17] syn_projEE_ampa[2017] = new ampa(0.5)")
        h("Epop[25] netConn_projEE_ampa[2017] = new NetCon(&v(0.5), syn_projEE_ampa[2017], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2018: cell 25, seg 0 (0.5) [0.5 on Epop[25]] -> cell 18, seg 0 (0.5) [0.5 on Epop[18]], weight: 4.1363508E-4, delay 1.5
        h("Epop[18] syn_projEE_ampa[2018] = new ampa(0.5)")
        h("Epop[25] netConn_projEE_ampa[2018] = new NetCon(&v(0.5), syn_projEE_ampa[2018], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2019: cell 25, seg 0 (0.5) [0.5 on Epop[25]] -> cell 19, seg 0 (0.5) [0.5 on Epop[19]], weight: 4.1363508E-4, delay 1.5
        h("Epop[19] syn_projEE_ampa[2019] = new ampa(0.5)")
        h("Epop[25] netConn_projEE_ampa[2019] = new NetCon(&v(0.5), syn_projEE_ampa[2019], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2020: cell 25, seg 0 (0.5) [0.5 on Epop[25]] -> cell 20, seg 0 (0.5) [0.5 on Epop[20]], weight: 4.1363508E-4, delay 1.5
        h("Epop[20] syn_projEE_ampa[2020] = new ampa(0.5)")
        h("Epop[25] netConn_projEE_ampa[2020] = new NetCon(&v(0.5), syn_projEE_ampa[2020], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2021: cell 25, seg 0 (0.5) [0.5 on Epop[25]] -> cell 21, seg 0 (0.5) [0.5 on Epop[21]], weight: 4.1363508E-4, delay 1.5
        h("Epop[21] syn_projEE_ampa[2021] = new ampa(0.5)")
        h("Epop[25] netConn_projEE_ampa[2021] = new NetCon(&v(0.5), syn_projEE_ampa[2021], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2022: cell 25, seg 0 (0.5) [0.5 on Epop[25]] -> cell 22, seg 0 (0.5) [0.5 on Epop[22]], weight: 4.1363508E-4, delay 1.5
        h("Epop[22] syn_projEE_ampa[2022] = new ampa(0.5)")
        h("Epop[25] netConn_projEE_ampa[2022] = new NetCon(&v(0.5), syn_projEE_ampa[2022], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2023: cell 25, seg 0 (0.5) [0.5 on Epop[25]] -> cell 23, seg 0 (0.5) [0.5 on Epop[23]], weight: 4.1363508E-4, delay 1.5
        h("Epop[23] syn_projEE_ampa[2023] = new ampa(0.5)")
        h("Epop[25] netConn_projEE_ampa[2023] = new NetCon(&v(0.5), syn_projEE_ampa[2023], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2024: cell 25, seg 0 (0.5) [0.5 on Epop[25]] -> cell 24, seg 0 (0.5) [0.5 on Epop[24]], weight: 4.1363508E-4, delay 1.5
        h("Epop[24] syn_projEE_ampa[2024] = new ampa(0.5)")
        h("Epop[25] netConn_projEE_ampa[2024] = new NetCon(&v(0.5), syn_projEE_ampa[2024], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2025: cell 25, seg 0 (0.5) [0.5 on Epop[25]] -> cell 25, seg 0 (0.5) [0.5 on Epop[25]], weight: 4.1363508E-4, delay 1.5
        h("Epop[25] syn_projEE_ampa[2025] = new ampa(0.5)")
        h("Epop[25] netConn_projEE_ampa[2025] = new NetCon(&v(0.5), syn_projEE_ampa[2025], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2026: cell 25, seg 0 (0.5) [0.5 on Epop[25]] -> cell 26, seg 0 (0.5) [0.5 on Epop[26]], weight: 4.1363508E-4, delay 1.5
        h("Epop[26] syn_projEE_ampa[2026] = new ampa(0.5)")
        h("Epop[25] netConn_projEE_ampa[2026] = new NetCon(&v(0.5), syn_projEE_ampa[2026], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2027: cell 25, seg 0 (0.5) [0.5 on Epop[25]] -> cell 27, seg 0 (0.5) [0.5 on Epop[27]], weight: 4.1363508E-4, delay 1.5
        h("Epop[27] syn_projEE_ampa[2027] = new ampa(0.5)")
        h("Epop[25] netConn_projEE_ampa[2027] = new NetCon(&v(0.5), syn_projEE_ampa[2027], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2028: cell 25, seg 0 (0.5) [0.5 on Epop[25]] -> cell 28, seg 0 (0.5) [0.5 on Epop[28]], weight: 4.1363508E-4, delay 1.5
        h("Epop[28] syn_projEE_ampa[2028] = new ampa(0.5)")
        h("Epop[25] netConn_projEE_ampa[2028] = new NetCon(&v(0.5), syn_projEE_ampa[2028], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2029: cell 25, seg 0 (0.5) [0.5 on Epop[25]] -> cell 29, seg 0 (0.5) [0.5 on Epop[29]], weight: 4.1363508E-4, delay 1.5
        h("Epop[29] syn_projEE_ampa[2029] = new ampa(0.5)")
        h("Epop[25] netConn_projEE_ampa[2029] = new NetCon(&v(0.5), syn_projEE_ampa[2029], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2030: cell 25, seg 0 (0.5) [0.5 on Epop[25]] -> cell 30, seg 0 (0.5) [0.5 on Epop[30]], weight: 4.1363508E-4, delay 1.5
        h("Epop[30] syn_projEE_ampa[2030] = new ampa(0.5)")
        h("Epop[25] netConn_projEE_ampa[2030] = new NetCon(&v(0.5), syn_projEE_ampa[2030], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2031: cell 25, seg 0 (0.5) [0.5 on Epop[25]] -> cell 31, seg 0 (0.5) [0.5 on Epop[31]], weight: 4.1363508E-4, delay 1.5
        h("Epop[31] syn_projEE_ampa[2031] = new ampa(0.5)")
        h("Epop[25] netConn_projEE_ampa[2031] = new NetCon(&v(0.5), syn_projEE_ampa[2031], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2032: cell 25, seg 0 (0.5) [0.5 on Epop[25]] -> cell 32, seg 0 (0.5) [0.5 on Epop[32]], weight: 4.1363508E-4, delay 1.5
        h("Epop[32] syn_projEE_ampa[2032] = new ampa(0.5)")
        h("Epop[25] netConn_projEE_ampa[2032] = new NetCon(&v(0.5), syn_projEE_ampa[2032], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2033: cell 25, seg 0 (0.5) [0.5 on Epop[25]] -> cell 33, seg 0 (0.5) [0.5 on Epop[33]], weight: 4.1363508E-4, delay 1.5
        h("Epop[33] syn_projEE_ampa[2033] = new ampa(0.5)")
        h("Epop[25] netConn_projEE_ampa[2033] = new NetCon(&v(0.5), syn_projEE_ampa[2033], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2034: cell 25, seg 0 (0.5) [0.5 on Epop[25]] -> cell 34, seg 0 (0.5) [0.5 on Epop[34]], weight: 4.1363508E-4, delay 1.5
        h("Epop[34] syn_projEE_ampa[2034] = new ampa(0.5)")
        h("Epop[25] netConn_projEE_ampa[2034] = new NetCon(&v(0.5), syn_projEE_ampa[2034], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2035: cell 25, seg 0 (0.5) [0.5 on Epop[25]] -> cell 35, seg 0 (0.5) [0.5 on Epop[35]], weight: 4.1363508E-4, delay 1.5
        h("Epop[35] syn_projEE_ampa[2035] = new ampa(0.5)")
        h("Epop[25] netConn_projEE_ampa[2035] = new NetCon(&v(0.5), syn_projEE_ampa[2035], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2036: cell 25, seg 0 (0.5) [0.5 on Epop[25]] -> cell 36, seg 0 (0.5) [0.5 on Epop[36]], weight: 4.1363508E-4, delay 1.5
        h("Epop[36] syn_projEE_ampa[2036] = new ampa(0.5)")
        h("Epop[25] netConn_projEE_ampa[2036] = new NetCon(&v(0.5), syn_projEE_ampa[2036], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2037: cell 25, seg 0 (0.5) [0.5 on Epop[25]] -> cell 37, seg 0 (0.5) [0.5 on Epop[37]], weight: 4.1363508E-4, delay 1.5
        h("Epop[37] syn_projEE_ampa[2037] = new ampa(0.5)")
        h("Epop[25] netConn_projEE_ampa[2037] = new NetCon(&v(0.5), syn_projEE_ampa[2037], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2038: cell 25, seg 0 (0.5) [0.5 on Epop[25]] -> cell 38, seg 0 (0.5) [0.5 on Epop[38]], weight: 4.1363508E-4, delay 1.5
        h("Epop[38] syn_projEE_ampa[2038] = new ampa(0.5)")
        h("Epop[25] netConn_projEE_ampa[2038] = new NetCon(&v(0.5), syn_projEE_ampa[2038], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2039: cell 25, seg 0 (0.5) [0.5 on Epop[25]] -> cell 39, seg 0 (0.5) [0.5 on Epop[39]], weight: 4.1363508E-4, delay 1.5
        h("Epop[39] syn_projEE_ampa[2039] = new ampa(0.5)")
        h("Epop[25] netConn_projEE_ampa[2039] = new NetCon(&v(0.5), syn_projEE_ampa[2039], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2040: cell 25, seg 0 (0.5) [0.5 on Epop[25]] -> cell 40, seg 0 (0.5) [0.5 on Epop[40]], weight: 4.1363508E-4, delay 1.5
        h("Epop[40] syn_projEE_ampa[2040] = new ampa(0.5)")
        h("Epop[25] netConn_projEE_ampa[2040] = new NetCon(&v(0.5), syn_projEE_ampa[2040], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2041: cell 25, seg 0 (0.5) [0.5 on Epop[25]] -> cell 41, seg 0 (0.5) [0.5 on Epop[41]], weight: 4.1363508E-4, delay 1.5
        h("Epop[41] syn_projEE_ampa[2041] = new ampa(0.5)")
        h("Epop[25] netConn_projEE_ampa[2041] = new NetCon(&v(0.5), syn_projEE_ampa[2041], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2042: cell 25, seg 0 (0.5) [0.5 on Epop[25]] -> cell 42, seg 0 (0.5) [0.5 on Epop[42]], weight: 4.1363508E-4, delay 1.5
        h("Epop[42] syn_projEE_ampa[2042] = new ampa(0.5)")
        h("Epop[25] netConn_projEE_ampa[2042] = new NetCon(&v(0.5), syn_projEE_ampa[2042], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2043: cell 25, seg 0 (0.5) [0.5 on Epop[25]] -> cell 43, seg 0 (0.5) [0.5 on Epop[43]], weight: 4.1363508E-4, delay 1.5
        h("Epop[43] syn_projEE_ampa[2043] = new ampa(0.5)")
        h("Epop[25] netConn_projEE_ampa[2043] = new NetCon(&v(0.5), syn_projEE_ampa[2043], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2044: cell 25, seg 0 (0.5) [0.5 on Epop[25]] -> cell 44, seg 0 (0.5) [0.5 on Epop[44]], weight: 4.1363508E-4, delay 1.5
        h("Epop[44] syn_projEE_ampa[2044] = new ampa(0.5)")
        h("Epop[25] netConn_projEE_ampa[2044] = new NetCon(&v(0.5), syn_projEE_ampa[2044], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2045: cell 25, seg 0 (0.5) [0.5 on Epop[25]] -> cell 45, seg 0 (0.5) [0.5 on Epop[45]], weight: 4.1363508E-4, delay 1.5
        h("Epop[45] syn_projEE_ampa[2045] = new ampa(0.5)")
        h("Epop[25] netConn_projEE_ampa[2045] = new NetCon(&v(0.5), syn_projEE_ampa[2045], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2046: cell 25, seg 0 (0.5) [0.5 on Epop[25]] -> cell 46, seg 0 (0.5) [0.5 on Epop[46]], weight: 4.1363508E-4, delay 1.5
        h("Epop[46] syn_projEE_ampa[2046] = new ampa(0.5)")
        h("Epop[25] netConn_projEE_ampa[2046] = new NetCon(&v(0.5), syn_projEE_ampa[2046], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2047: cell 25, seg 0 (0.5) [0.5 on Epop[25]] -> cell 47, seg 0 (0.5) [0.5 on Epop[47]], weight: 4.1363508E-4, delay 1.5
        h("Epop[47] syn_projEE_ampa[2047] = new ampa(0.5)")
        h("Epop[25] netConn_projEE_ampa[2047] = new NetCon(&v(0.5), syn_projEE_ampa[2047], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2048: cell 25, seg 0 (0.5) [0.5 on Epop[25]] -> cell 48, seg 0 (0.5) [0.5 on Epop[48]], weight: 4.1363508E-4, delay 1.5
        h("Epop[48] syn_projEE_ampa[2048] = new ampa(0.5)")
        h("Epop[25] netConn_projEE_ampa[2048] = new NetCon(&v(0.5), syn_projEE_ampa[2048], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2049: cell 25, seg 0 (0.5) [0.5 on Epop[25]] -> cell 49, seg 0 (0.5) [0.5 on Epop[49]], weight: 4.1363508E-4, delay 1.5
        h("Epop[49] syn_projEE_ampa[2049] = new ampa(0.5)")
        h("Epop[25] netConn_projEE_ampa[2049] = new NetCon(&v(0.5), syn_projEE_ampa[2049], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2050: cell 25, seg 0 (0.5) [0.5 on Epop[25]] -> cell 50, seg 0 (0.5) [0.5 on Epop[50]], weight: 4.1363508E-4, delay 1.5
        h("Epop[50] syn_projEE_ampa[2050] = new ampa(0.5)")
        h("Epop[25] netConn_projEE_ampa[2050] = new NetCon(&v(0.5), syn_projEE_ampa[2050], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2051: cell 25, seg 0 (0.5) [0.5 on Epop[25]] -> cell 51, seg 0 (0.5) [0.5 on Epop[51]], weight: 4.1363508E-4, delay 1.5
        h("Epop[51] syn_projEE_ampa[2051] = new ampa(0.5)")
        h("Epop[25] netConn_projEE_ampa[2051] = new NetCon(&v(0.5), syn_projEE_ampa[2051], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2052: cell 25, seg 0 (0.5) [0.5 on Epop[25]] -> cell 52, seg 0 (0.5) [0.5 on Epop[52]], weight: 4.1363508E-4, delay 1.5
        h("Epop[52] syn_projEE_ampa[2052] = new ampa(0.5)")
        h("Epop[25] netConn_projEE_ampa[2052] = new NetCon(&v(0.5), syn_projEE_ampa[2052], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2053: cell 25, seg 0 (0.5) [0.5 on Epop[25]] -> cell 53, seg 0 (0.5) [0.5 on Epop[53]], weight: 4.1363508E-4, delay 1.5
        h("Epop[53] syn_projEE_ampa[2053] = new ampa(0.5)")
        h("Epop[25] netConn_projEE_ampa[2053] = new NetCon(&v(0.5), syn_projEE_ampa[2053], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2054: cell 25, seg 0 (0.5) [0.5 on Epop[25]] -> cell 54, seg 0 (0.5) [0.5 on Epop[54]], weight: 4.1363508E-4, delay 1.5
        h("Epop[54] syn_projEE_ampa[2054] = new ampa(0.5)")
        h("Epop[25] netConn_projEE_ampa[2054] = new NetCon(&v(0.5), syn_projEE_ampa[2054], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2055: cell 25, seg 0 (0.5) [0.5 on Epop[25]] -> cell 55, seg 0 (0.5) [0.5 on Epop[55]], weight: 4.1363508E-4, delay 1.5
        h("Epop[55] syn_projEE_ampa[2055] = new ampa(0.5)")
        h("Epop[25] netConn_projEE_ampa[2055] = new NetCon(&v(0.5), syn_projEE_ampa[2055], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2056: cell 25, seg 0 (0.5) [0.5 on Epop[25]] -> cell 56, seg 0 (0.5) [0.5 on Epop[56]], weight: 4.1363508E-4, delay 1.5
        h("Epop[56] syn_projEE_ampa[2056] = new ampa(0.5)")
        h("Epop[25] netConn_projEE_ampa[2056] = new NetCon(&v(0.5), syn_projEE_ampa[2056], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2057: cell 25, seg 0 (0.5) [0.5 on Epop[25]] -> cell 57, seg 0 (0.5) [0.5 on Epop[57]], weight: 4.1363508E-4, delay 1.5
        h("Epop[57] syn_projEE_ampa[2057] = new ampa(0.5)")
        h("Epop[25] netConn_projEE_ampa[2057] = new NetCon(&v(0.5), syn_projEE_ampa[2057], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2058: cell 25, seg 0 (0.5) [0.5 on Epop[25]] -> cell 58, seg 0 (0.5) [0.5 on Epop[58]], weight: 4.1363508E-4, delay 1.5
        h("Epop[58] syn_projEE_ampa[2058] = new ampa(0.5)")
        h("Epop[25] netConn_projEE_ampa[2058] = new NetCon(&v(0.5), syn_projEE_ampa[2058], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2059: cell 25, seg 0 (0.5) [0.5 on Epop[25]] -> cell 59, seg 0 (0.5) [0.5 on Epop[59]], weight: 4.1363508E-4, delay 1.5
        h("Epop[59] syn_projEE_ampa[2059] = new ampa(0.5)")
        h("Epop[25] netConn_projEE_ampa[2059] = new NetCon(&v(0.5), syn_projEE_ampa[2059], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2060: cell 25, seg 0 (0.5) [0.5 on Epop[25]] -> cell 60, seg 0 (0.5) [0.5 on Epop[60]], weight: 4.1363508E-4, delay 1.5
        h("Epop[60] syn_projEE_ampa[2060] = new ampa(0.5)")
        h("Epop[25] netConn_projEE_ampa[2060] = new NetCon(&v(0.5), syn_projEE_ampa[2060], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2061: cell 25, seg 0 (0.5) [0.5 on Epop[25]] -> cell 61, seg 0 (0.5) [0.5 on Epop[61]], weight: 4.1363508E-4, delay 1.5
        h("Epop[61] syn_projEE_ampa[2061] = new ampa(0.5)")
        h("Epop[25] netConn_projEE_ampa[2061] = new NetCon(&v(0.5), syn_projEE_ampa[2061], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2062: cell 25, seg 0 (0.5) [0.5 on Epop[25]] -> cell 62, seg 0 (0.5) [0.5 on Epop[62]], weight: 4.1363508E-4, delay 1.5
        h("Epop[62] syn_projEE_ampa[2062] = new ampa(0.5)")
        h("Epop[25] netConn_projEE_ampa[2062] = new NetCon(&v(0.5), syn_projEE_ampa[2062], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2063: cell 25, seg 0 (0.5) [0.5 on Epop[25]] -> cell 63, seg 0 (0.5) [0.5 on Epop[63]], weight: 4.1363508E-4, delay 1.5
        h("Epop[63] syn_projEE_ampa[2063] = new ampa(0.5)")
        h("Epop[25] netConn_projEE_ampa[2063] = new NetCon(&v(0.5), syn_projEE_ampa[2063], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2064: cell 25, seg 0 (0.5) [0.5 on Epop[25]] -> cell 64, seg 0 (0.5) [0.5 on Epop[64]], weight: 4.1363508E-4, delay 1.5
        h("Epop[64] syn_projEE_ampa[2064] = new ampa(0.5)")
        h("Epop[25] netConn_projEE_ampa[2064] = new NetCon(&v(0.5), syn_projEE_ampa[2064], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2065: cell 25, seg 0 (0.5) [0.5 on Epop[25]] -> cell 65, seg 0 (0.5) [0.5 on Epop[65]], weight: 4.1363508E-4, delay 1.5
        h("Epop[65] syn_projEE_ampa[2065] = new ampa(0.5)")
        h("Epop[25] netConn_projEE_ampa[2065] = new NetCon(&v(0.5), syn_projEE_ampa[2065], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2066: cell 25, seg 0 (0.5) [0.5 on Epop[25]] -> cell 66, seg 0 (0.5) [0.5 on Epop[66]], weight: 4.1363508E-4, delay 1.5
        h("Epop[66] syn_projEE_ampa[2066] = new ampa(0.5)")
        h("Epop[25] netConn_projEE_ampa[2066] = new NetCon(&v(0.5), syn_projEE_ampa[2066], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2067: cell 25, seg 0 (0.5) [0.5 on Epop[25]] -> cell 67, seg 0 (0.5) [0.5 on Epop[67]], weight: 4.1363508E-4, delay 1.5
        h("Epop[67] syn_projEE_ampa[2067] = new ampa(0.5)")
        h("Epop[25] netConn_projEE_ampa[2067] = new NetCon(&v(0.5), syn_projEE_ampa[2067], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2068: cell 25, seg 0 (0.5) [0.5 on Epop[25]] -> cell 68, seg 0 (0.5) [0.5 on Epop[68]], weight: 4.1363508E-4, delay 1.5
        h("Epop[68] syn_projEE_ampa[2068] = new ampa(0.5)")
        h("Epop[25] netConn_projEE_ampa[2068] = new NetCon(&v(0.5), syn_projEE_ampa[2068], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2069: cell 25, seg 0 (0.5) [0.5 on Epop[25]] -> cell 69, seg 0 (0.5) [0.5 on Epop[69]], weight: 4.1363508E-4, delay 1.5
        h("Epop[69] syn_projEE_ampa[2069] = new ampa(0.5)")
        h("Epop[25] netConn_projEE_ampa[2069] = new NetCon(&v(0.5), syn_projEE_ampa[2069], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2070: cell 25, seg 0 (0.5) [0.5 on Epop[25]] -> cell 70, seg 0 (0.5) [0.5 on Epop[70]], weight: 4.1363508E-4, delay 1.5
        h("Epop[70] syn_projEE_ampa[2070] = new ampa(0.5)")
        h("Epop[25] netConn_projEE_ampa[2070] = new NetCon(&v(0.5), syn_projEE_ampa[2070], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2071: cell 25, seg 0 (0.5) [0.5 on Epop[25]] -> cell 71, seg 0 (0.5) [0.5 on Epop[71]], weight: 4.1363508E-4, delay 1.5
        h("Epop[71] syn_projEE_ampa[2071] = new ampa(0.5)")
        h("Epop[25] netConn_projEE_ampa[2071] = new NetCon(&v(0.5), syn_projEE_ampa[2071], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2072: cell 25, seg 0 (0.5) [0.5 on Epop[25]] -> cell 72, seg 0 (0.5) [0.5 on Epop[72]], weight: 4.1363508E-4, delay 1.5
        h("Epop[72] syn_projEE_ampa[2072] = new ampa(0.5)")
        h("Epop[25] netConn_projEE_ampa[2072] = new NetCon(&v(0.5), syn_projEE_ampa[2072], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2073: cell 25, seg 0 (0.5) [0.5 on Epop[25]] -> cell 73, seg 0 (0.5) [0.5 on Epop[73]], weight: 4.1363508E-4, delay 1.5
        h("Epop[73] syn_projEE_ampa[2073] = new ampa(0.5)")
        h("Epop[25] netConn_projEE_ampa[2073] = new NetCon(&v(0.5), syn_projEE_ampa[2073], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2074: cell 25, seg 0 (0.5) [0.5 on Epop[25]] -> cell 74, seg 0 (0.5) [0.5 on Epop[74]], weight: 4.1363508E-4, delay 1.5
        h("Epop[74] syn_projEE_ampa[2074] = new ampa(0.5)")
        h("Epop[25] netConn_projEE_ampa[2074] = new NetCon(&v(0.5), syn_projEE_ampa[2074], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2075: cell 25, seg 0 (0.5) [0.5 on Epop[25]] -> cell 75, seg 0 (0.5) [0.5 on Epop[75]], weight: 4.1363508E-4, delay 1.5
        h("Epop[75] syn_projEE_ampa[2075] = new ampa(0.5)")
        h("Epop[25] netConn_projEE_ampa[2075] = new NetCon(&v(0.5), syn_projEE_ampa[2075], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2076: cell 25, seg 0 (0.5) [0.5 on Epop[25]] -> cell 76, seg 0 (0.5) [0.5 on Epop[76]], weight: 4.1363508E-4, delay 1.5
        h("Epop[76] syn_projEE_ampa[2076] = new ampa(0.5)")
        h("Epop[25] netConn_projEE_ampa[2076] = new NetCon(&v(0.5), syn_projEE_ampa[2076], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2077: cell 25, seg 0 (0.5) [0.5 on Epop[25]] -> cell 77, seg 0 (0.5) [0.5 on Epop[77]], weight: 4.1363508E-4, delay 1.5
        h("Epop[77] syn_projEE_ampa[2077] = new ampa(0.5)")
        h("Epop[25] netConn_projEE_ampa[2077] = new NetCon(&v(0.5), syn_projEE_ampa[2077], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2078: cell 25, seg 0 (0.5) [0.5 on Epop[25]] -> cell 78, seg 0 (0.5) [0.5 on Epop[78]], weight: 4.1363508E-4, delay 1.5
        h("Epop[78] syn_projEE_ampa[2078] = new ampa(0.5)")
        h("Epop[25] netConn_projEE_ampa[2078] = new NetCon(&v(0.5), syn_projEE_ampa[2078], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2079: cell 25, seg 0 (0.5) [0.5 on Epop[25]] -> cell 79, seg 0 (0.5) [0.5 on Epop[79]], weight: 4.1363508E-4, delay 1.5
        h("Epop[79] syn_projEE_ampa[2079] = new ampa(0.5)")
        h("Epop[25] netConn_projEE_ampa[2079] = new NetCon(&v(0.5), syn_projEE_ampa[2079], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2080: cell 26, seg 0 (0.5) [0.5 on Epop[26]] -> cell 0, seg 0 (0.5) [0.5 on Epop[0]], weight: 4.1363508E-4, delay 1.5
        h("Epop[0] syn_projEE_ampa[2080] = new ampa(0.5)")
        h("Epop[26] netConn_projEE_ampa[2080] = new NetCon(&v(0.5), syn_projEE_ampa[2080], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2081: cell 26, seg 0 (0.5) [0.5 on Epop[26]] -> cell 1, seg 0 (0.5) [0.5 on Epop[1]], weight: 4.1363508E-4, delay 1.5
        h("Epop[1] syn_projEE_ampa[2081] = new ampa(0.5)")
        h("Epop[26] netConn_projEE_ampa[2081] = new NetCon(&v(0.5), syn_projEE_ampa[2081], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2082: cell 26, seg 0 (0.5) [0.5 on Epop[26]] -> cell 2, seg 0 (0.5) [0.5 on Epop[2]], weight: 4.1363508E-4, delay 1.5
        h("Epop[2] syn_projEE_ampa[2082] = new ampa(0.5)")
        h("Epop[26] netConn_projEE_ampa[2082] = new NetCon(&v(0.5), syn_projEE_ampa[2082], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2083: cell 26, seg 0 (0.5) [0.5 on Epop[26]] -> cell 3, seg 0 (0.5) [0.5 on Epop[3]], weight: 4.1363508E-4, delay 1.5
        h("Epop[3] syn_projEE_ampa[2083] = new ampa(0.5)")
        h("Epop[26] netConn_projEE_ampa[2083] = new NetCon(&v(0.5), syn_projEE_ampa[2083], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2084: cell 26, seg 0 (0.5) [0.5 on Epop[26]] -> cell 4, seg 0 (0.5) [0.5 on Epop[4]], weight: 4.1363508E-4, delay 1.5
        h("Epop[4] syn_projEE_ampa[2084] = new ampa(0.5)")
        h("Epop[26] netConn_projEE_ampa[2084] = new NetCon(&v(0.5), syn_projEE_ampa[2084], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2085: cell 26, seg 0 (0.5) [0.5 on Epop[26]] -> cell 5, seg 0 (0.5) [0.5 on Epop[5]], weight: 4.1363508E-4, delay 1.5
        h("Epop[5] syn_projEE_ampa[2085] = new ampa(0.5)")
        h("Epop[26] netConn_projEE_ampa[2085] = new NetCon(&v(0.5), syn_projEE_ampa[2085], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2086: cell 26, seg 0 (0.5) [0.5 on Epop[26]] -> cell 6, seg 0 (0.5) [0.5 on Epop[6]], weight: 4.1363508E-4, delay 1.5
        h("Epop[6] syn_projEE_ampa[2086] = new ampa(0.5)")
        h("Epop[26] netConn_projEE_ampa[2086] = new NetCon(&v(0.5), syn_projEE_ampa[2086], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2087: cell 26, seg 0 (0.5) [0.5 on Epop[26]] -> cell 7, seg 0 (0.5) [0.5 on Epop[7]], weight: 4.1363508E-4, delay 1.5
        h("Epop[7] syn_projEE_ampa[2087] = new ampa(0.5)")
        h("Epop[26] netConn_projEE_ampa[2087] = new NetCon(&v(0.5), syn_projEE_ampa[2087], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2088: cell 26, seg 0 (0.5) [0.5 on Epop[26]] -> cell 8, seg 0 (0.5) [0.5 on Epop[8]], weight: 4.1363508E-4, delay 1.5
        h("Epop[8] syn_projEE_ampa[2088] = new ampa(0.5)")
        h("Epop[26] netConn_projEE_ampa[2088] = new NetCon(&v(0.5), syn_projEE_ampa[2088], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2089: cell 26, seg 0 (0.5) [0.5 on Epop[26]] -> cell 9, seg 0 (0.5) [0.5 on Epop[9]], weight: 4.1363508E-4, delay 1.5
        h("Epop[9] syn_projEE_ampa[2089] = new ampa(0.5)")
        h("Epop[26] netConn_projEE_ampa[2089] = new NetCon(&v(0.5), syn_projEE_ampa[2089], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2090: cell 26, seg 0 (0.5) [0.5 on Epop[26]] -> cell 10, seg 0 (0.5) [0.5 on Epop[10]], weight: 4.1363508E-4, delay 1.5
        h("Epop[10] syn_projEE_ampa[2090] = new ampa(0.5)")
        h("Epop[26] netConn_projEE_ampa[2090] = new NetCon(&v(0.5), syn_projEE_ampa[2090], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2091: cell 26, seg 0 (0.5) [0.5 on Epop[26]] -> cell 11, seg 0 (0.5) [0.5 on Epop[11]], weight: 4.1363508E-4, delay 1.5
        h("Epop[11] syn_projEE_ampa[2091] = new ampa(0.5)")
        h("Epop[26] netConn_projEE_ampa[2091] = new NetCon(&v(0.5), syn_projEE_ampa[2091], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2092: cell 26, seg 0 (0.5) [0.5 on Epop[26]] -> cell 12, seg 0 (0.5) [0.5 on Epop[12]], weight: 4.1363508E-4, delay 1.5
        h("Epop[12] syn_projEE_ampa[2092] = new ampa(0.5)")
        h("Epop[26] netConn_projEE_ampa[2092] = new NetCon(&v(0.5), syn_projEE_ampa[2092], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2093: cell 26, seg 0 (0.5) [0.5 on Epop[26]] -> cell 13, seg 0 (0.5) [0.5 on Epop[13]], weight: 4.1363508E-4, delay 1.5
        h("Epop[13] syn_projEE_ampa[2093] = new ampa(0.5)")
        h("Epop[26] netConn_projEE_ampa[2093] = new NetCon(&v(0.5), syn_projEE_ampa[2093], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2094: cell 26, seg 0 (0.5) [0.5 on Epop[26]] -> cell 14, seg 0 (0.5) [0.5 on Epop[14]], weight: 4.1363508E-4, delay 1.5
        h("Epop[14] syn_projEE_ampa[2094] = new ampa(0.5)")
        h("Epop[26] netConn_projEE_ampa[2094] = new NetCon(&v(0.5), syn_projEE_ampa[2094], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2095: cell 26, seg 0 (0.5) [0.5 on Epop[26]] -> cell 15, seg 0 (0.5) [0.5 on Epop[15]], weight: 4.1363508E-4, delay 1.5
        h("Epop[15] syn_projEE_ampa[2095] = new ampa(0.5)")
        h("Epop[26] netConn_projEE_ampa[2095] = new NetCon(&v(0.5), syn_projEE_ampa[2095], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2096: cell 26, seg 0 (0.5) [0.5 on Epop[26]] -> cell 16, seg 0 (0.5) [0.5 on Epop[16]], weight: 4.1363508E-4, delay 1.5
        h("Epop[16] syn_projEE_ampa[2096] = new ampa(0.5)")
        h("Epop[26] netConn_projEE_ampa[2096] = new NetCon(&v(0.5), syn_projEE_ampa[2096], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2097: cell 26, seg 0 (0.5) [0.5 on Epop[26]] -> cell 17, seg 0 (0.5) [0.5 on Epop[17]], weight: 4.1363508E-4, delay 1.5
        h("Epop[17] syn_projEE_ampa[2097] = new ampa(0.5)")
        h("Epop[26] netConn_projEE_ampa[2097] = new NetCon(&v(0.5), syn_projEE_ampa[2097], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2098: cell 26, seg 0 (0.5) [0.5 on Epop[26]] -> cell 18, seg 0 (0.5) [0.5 on Epop[18]], weight: 4.1363508E-4, delay 1.5
        h("Epop[18] syn_projEE_ampa[2098] = new ampa(0.5)")
        h("Epop[26] netConn_projEE_ampa[2098] = new NetCon(&v(0.5), syn_projEE_ampa[2098], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2099: cell 26, seg 0 (0.5) [0.5 on Epop[26]] -> cell 19, seg 0 (0.5) [0.5 on Epop[19]], weight: 4.1363508E-4, delay 1.5
        h("Epop[19] syn_projEE_ampa[2099] = new ampa(0.5)")
        h("Epop[26] netConn_projEE_ampa[2099] = new NetCon(&v(0.5), syn_projEE_ampa[2099], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2100: cell 26, seg 0 (0.5) [0.5 on Epop[26]] -> cell 20, seg 0 (0.5) [0.5 on Epop[20]], weight: 4.1363508E-4, delay 1.5
        h("Epop[20] syn_projEE_ampa[2100] = new ampa(0.5)")
        h("Epop[26] netConn_projEE_ampa[2100] = new NetCon(&v(0.5), syn_projEE_ampa[2100], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2101: cell 26, seg 0 (0.5) [0.5 on Epop[26]] -> cell 21, seg 0 (0.5) [0.5 on Epop[21]], weight: 4.1363508E-4, delay 1.5
        h("Epop[21] syn_projEE_ampa[2101] = new ampa(0.5)")
        h("Epop[26] netConn_projEE_ampa[2101] = new NetCon(&v(0.5), syn_projEE_ampa[2101], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2102: cell 26, seg 0 (0.5) [0.5 on Epop[26]] -> cell 22, seg 0 (0.5) [0.5 on Epop[22]], weight: 4.1363508E-4, delay 1.5
        h("Epop[22] syn_projEE_ampa[2102] = new ampa(0.5)")
        h("Epop[26] netConn_projEE_ampa[2102] = new NetCon(&v(0.5), syn_projEE_ampa[2102], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2103: cell 26, seg 0 (0.5) [0.5 on Epop[26]] -> cell 23, seg 0 (0.5) [0.5 on Epop[23]], weight: 4.1363508E-4, delay 1.5
        h("Epop[23] syn_projEE_ampa[2103] = new ampa(0.5)")
        h("Epop[26] netConn_projEE_ampa[2103] = new NetCon(&v(0.5), syn_projEE_ampa[2103], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2104: cell 26, seg 0 (0.5) [0.5 on Epop[26]] -> cell 24, seg 0 (0.5) [0.5 on Epop[24]], weight: 4.1363508E-4, delay 1.5
        h("Epop[24] syn_projEE_ampa[2104] = new ampa(0.5)")
        h("Epop[26] netConn_projEE_ampa[2104] = new NetCon(&v(0.5), syn_projEE_ampa[2104], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2105: cell 26, seg 0 (0.5) [0.5 on Epop[26]] -> cell 25, seg 0 (0.5) [0.5 on Epop[25]], weight: 4.1363508E-4, delay 1.5
        h("Epop[25] syn_projEE_ampa[2105] = new ampa(0.5)")
        h("Epop[26] netConn_projEE_ampa[2105] = new NetCon(&v(0.5), syn_projEE_ampa[2105], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2106: cell 26, seg 0 (0.5) [0.5 on Epop[26]] -> cell 26, seg 0 (0.5) [0.5 on Epop[26]], weight: 4.1363508E-4, delay 1.5
        h("Epop[26] syn_projEE_ampa[2106] = new ampa(0.5)")
        h("Epop[26] netConn_projEE_ampa[2106] = new NetCon(&v(0.5), syn_projEE_ampa[2106], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2107: cell 26, seg 0 (0.5) [0.5 on Epop[26]] -> cell 27, seg 0 (0.5) [0.5 on Epop[27]], weight: 4.1363508E-4, delay 1.5
        h("Epop[27] syn_projEE_ampa[2107] = new ampa(0.5)")
        h("Epop[26] netConn_projEE_ampa[2107] = new NetCon(&v(0.5), syn_projEE_ampa[2107], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2108: cell 26, seg 0 (0.5) [0.5 on Epop[26]] -> cell 28, seg 0 (0.5) [0.5 on Epop[28]], weight: 4.1363508E-4, delay 1.5
        h("Epop[28] syn_projEE_ampa[2108] = new ampa(0.5)")
        h("Epop[26] netConn_projEE_ampa[2108] = new NetCon(&v(0.5), syn_projEE_ampa[2108], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2109: cell 26, seg 0 (0.5) [0.5 on Epop[26]] -> cell 29, seg 0 (0.5) [0.5 on Epop[29]], weight: 4.1363508E-4, delay 1.5
        h("Epop[29] syn_projEE_ampa[2109] = new ampa(0.5)")
        h("Epop[26] netConn_projEE_ampa[2109] = new NetCon(&v(0.5), syn_projEE_ampa[2109], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2110: cell 26, seg 0 (0.5) [0.5 on Epop[26]] -> cell 30, seg 0 (0.5) [0.5 on Epop[30]], weight: 4.1363508E-4, delay 1.5
        h("Epop[30] syn_projEE_ampa[2110] = new ampa(0.5)")
        h("Epop[26] netConn_projEE_ampa[2110] = new NetCon(&v(0.5), syn_projEE_ampa[2110], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2111: cell 26, seg 0 (0.5) [0.5 on Epop[26]] -> cell 31, seg 0 (0.5) [0.5 on Epop[31]], weight: 4.1363508E-4, delay 1.5
        h("Epop[31] syn_projEE_ampa[2111] = new ampa(0.5)")
        h("Epop[26] netConn_projEE_ampa[2111] = new NetCon(&v(0.5), syn_projEE_ampa[2111], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2112: cell 26, seg 0 (0.5) [0.5 on Epop[26]] -> cell 32, seg 0 (0.5) [0.5 on Epop[32]], weight: 4.1363508E-4, delay 1.5
        h("Epop[32] syn_projEE_ampa[2112] = new ampa(0.5)")
        h("Epop[26] netConn_projEE_ampa[2112] = new NetCon(&v(0.5), syn_projEE_ampa[2112], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2113: cell 26, seg 0 (0.5) [0.5 on Epop[26]] -> cell 33, seg 0 (0.5) [0.5 on Epop[33]], weight: 4.1363508E-4, delay 1.5
        h("Epop[33] syn_projEE_ampa[2113] = new ampa(0.5)")
        h("Epop[26] netConn_projEE_ampa[2113] = new NetCon(&v(0.5), syn_projEE_ampa[2113], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2114: cell 26, seg 0 (0.5) [0.5 on Epop[26]] -> cell 34, seg 0 (0.5) [0.5 on Epop[34]], weight: 4.1363508E-4, delay 1.5
        h("Epop[34] syn_projEE_ampa[2114] = new ampa(0.5)")
        h("Epop[26] netConn_projEE_ampa[2114] = new NetCon(&v(0.5), syn_projEE_ampa[2114], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2115: cell 26, seg 0 (0.5) [0.5 on Epop[26]] -> cell 35, seg 0 (0.5) [0.5 on Epop[35]], weight: 4.1363508E-4, delay 1.5
        h("Epop[35] syn_projEE_ampa[2115] = new ampa(0.5)")
        h("Epop[26] netConn_projEE_ampa[2115] = new NetCon(&v(0.5), syn_projEE_ampa[2115], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2116: cell 26, seg 0 (0.5) [0.5 on Epop[26]] -> cell 36, seg 0 (0.5) [0.5 on Epop[36]], weight: 4.1363508E-4, delay 1.5
        h("Epop[36] syn_projEE_ampa[2116] = new ampa(0.5)")
        h("Epop[26] netConn_projEE_ampa[2116] = new NetCon(&v(0.5), syn_projEE_ampa[2116], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2117: cell 26, seg 0 (0.5) [0.5 on Epop[26]] -> cell 37, seg 0 (0.5) [0.5 on Epop[37]], weight: 4.1363508E-4, delay 1.5
        h("Epop[37] syn_projEE_ampa[2117] = new ampa(0.5)")
        h("Epop[26] netConn_projEE_ampa[2117] = new NetCon(&v(0.5), syn_projEE_ampa[2117], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2118: cell 26, seg 0 (0.5) [0.5 on Epop[26]] -> cell 38, seg 0 (0.5) [0.5 on Epop[38]], weight: 4.1363508E-4, delay 1.5
        h("Epop[38] syn_projEE_ampa[2118] = new ampa(0.5)")
        h("Epop[26] netConn_projEE_ampa[2118] = new NetCon(&v(0.5), syn_projEE_ampa[2118], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2119: cell 26, seg 0 (0.5) [0.5 on Epop[26]] -> cell 39, seg 0 (0.5) [0.5 on Epop[39]], weight: 4.1363508E-4, delay 1.5
        h("Epop[39] syn_projEE_ampa[2119] = new ampa(0.5)")
        h("Epop[26] netConn_projEE_ampa[2119] = new NetCon(&v(0.5), syn_projEE_ampa[2119], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2120: cell 26, seg 0 (0.5) [0.5 on Epop[26]] -> cell 40, seg 0 (0.5) [0.5 on Epop[40]], weight: 4.1363508E-4, delay 1.5
        h("Epop[40] syn_projEE_ampa[2120] = new ampa(0.5)")
        h("Epop[26] netConn_projEE_ampa[2120] = new NetCon(&v(0.5), syn_projEE_ampa[2120], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2121: cell 26, seg 0 (0.5) [0.5 on Epop[26]] -> cell 41, seg 0 (0.5) [0.5 on Epop[41]], weight: 4.1363508E-4, delay 1.5
        h("Epop[41] syn_projEE_ampa[2121] = new ampa(0.5)")
        h("Epop[26] netConn_projEE_ampa[2121] = new NetCon(&v(0.5), syn_projEE_ampa[2121], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2122: cell 26, seg 0 (0.5) [0.5 on Epop[26]] -> cell 42, seg 0 (0.5) [0.5 on Epop[42]], weight: 4.1363508E-4, delay 1.5
        h("Epop[42] syn_projEE_ampa[2122] = new ampa(0.5)")
        h("Epop[26] netConn_projEE_ampa[2122] = new NetCon(&v(0.5), syn_projEE_ampa[2122], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2123: cell 26, seg 0 (0.5) [0.5 on Epop[26]] -> cell 43, seg 0 (0.5) [0.5 on Epop[43]], weight: 4.1363508E-4, delay 1.5
        h("Epop[43] syn_projEE_ampa[2123] = new ampa(0.5)")
        h("Epop[26] netConn_projEE_ampa[2123] = new NetCon(&v(0.5), syn_projEE_ampa[2123], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2124: cell 26, seg 0 (0.5) [0.5 on Epop[26]] -> cell 44, seg 0 (0.5) [0.5 on Epop[44]], weight: 4.1363508E-4, delay 1.5
        h("Epop[44] syn_projEE_ampa[2124] = new ampa(0.5)")
        h("Epop[26] netConn_projEE_ampa[2124] = new NetCon(&v(0.5), syn_projEE_ampa[2124], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2125: cell 26, seg 0 (0.5) [0.5 on Epop[26]] -> cell 45, seg 0 (0.5) [0.5 on Epop[45]], weight: 4.1363508E-4, delay 1.5
        h("Epop[45] syn_projEE_ampa[2125] = new ampa(0.5)")
        h("Epop[26] netConn_projEE_ampa[2125] = new NetCon(&v(0.5), syn_projEE_ampa[2125], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2126: cell 26, seg 0 (0.5) [0.5 on Epop[26]] -> cell 46, seg 0 (0.5) [0.5 on Epop[46]], weight: 4.1363508E-4, delay 1.5
        h("Epop[46] syn_projEE_ampa[2126] = new ampa(0.5)")
        h("Epop[26] netConn_projEE_ampa[2126] = new NetCon(&v(0.5), syn_projEE_ampa[2126], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2127: cell 26, seg 0 (0.5) [0.5 on Epop[26]] -> cell 47, seg 0 (0.5) [0.5 on Epop[47]], weight: 4.1363508E-4, delay 1.5
        h("Epop[47] syn_projEE_ampa[2127] = new ampa(0.5)")
        h("Epop[26] netConn_projEE_ampa[2127] = new NetCon(&v(0.5), syn_projEE_ampa[2127], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2128: cell 26, seg 0 (0.5) [0.5 on Epop[26]] -> cell 48, seg 0 (0.5) [0.5 on Epop[48]], weight: 4.1363508E-4, delay 1.5
        h("Epop[48] syn_projEE_ampa[2128] = new ampa(0.5)")
        h("Epop[26] netConn_projEE_ampa[2128] = new NetCon(&v(0.5), syn_projEE_ampa[2128], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2129: cell 26, seg 0 (0.5) [0.5 on Epop[26]] -> cell 49, seg 0 (0.5) [0.5 on Epop[49]], weight: 4.1363508E-4, delay 1.5
        h("Epop[49] syn_projEE_ampa[2129] = new ampa(0.5)")
        h("Epop[26] netConn_projEE_ampa[2129] = new NetCon(&v(0.5), syn_projEE_ampa[2129], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2130: cell 26, seg 0 (0.5) [0.5 on Epop[26]] -> cell 50, seg 0 (0.5) [0.5 on Epop[50]], weight: 4.1363508E-4, delay 1.5
        h("Epop[50] syn_projEE_ampa[2130] = new ampa(0.5)")
        h("Epop[26] netConn_projEE_ampa[2130] = new NetCon(&v(0.5), syn_projEE_ampa[2130], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2131: cell 26, seg 0 (0.5) [0.5 on Epop[26]] -> cell 51, seg 0 (0.5) [0.5 on Epop[51]], weight: 4.1363508E-4, delay 1.5
        h("Epop[51] syn_projEE_ampa[2131] = new ampa(0.5)")
        h("Epop[26] netConn_projEE_ampa[2131] = new NetCon(&v(0.5), syn_projEE_ampa[2131], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2132: cell 26, seg 0 (0.5) [0.5 on Epop[26]] -> cell 52, seg 0 (0.5) [0.5 on Epop[52]], weight: 4.1363508E-4, delay 1.5
        h("Epop[52] syn_projEE_ampa[2132] = new ampa(0.5)")
        h("Epop[26] netConn_projEE_ampa[2132] = new NetCon(&v(0.5), syn_projEE_ampa[2132], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2133: cell 26, seg 0 (0.5) [0.5 on Epop[26]] -> cell 53, seg 0 (0.5) [0.5 on Epop[53]], weight: 4.1363508E-4, delay 1.5
        h("Epop[53] syn_projEE_ampa[2133] = new ampa(0.5)")
        h("Epop[26] netConn_projEE_ampa[2133] = new NetCon(&v(0.5), syn_projEE_ampa[2133], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2134: cell 26, seg 0 (0.5) [0.5 on Epop[26]] -> cell 54, seg 0 (0.5) [0.5 on Epop[54]], weight: 4.1363508E-4, delay 1.5
        h("Epop[54] syn_projEE_ampa[2134] = new ampa(0.5)")
        h("Epop[26] netConn_projEE_ampa[2134] = new NetCon(&v(0.5), syn_projEE_ampa[2134], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2135: cell 26, seg 0 (0.5) [0.5 on Epop[26]] -> cell 55, seg 0 (0.5) [0.5 on Epop[55]], weight: 4.1363508E-4, delay 1.5
        h("Epop[55] syn_projEE_ampa[2135] = new ampa(0.5)")
        h("Epop[26] netConn_projEE_ampa[2135] = new NetCon(&v(0.5), syn_projEE_ampa[2135], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2136: cell 26, seg 0 (0.5) [0.5 on Epop[26]] -> cell 56, seg 0 (0.5) [0.5 on Epop[56]], weight: 4.1363508E-4, delay 1.5
        h("Epop[56] syn_projEE_ampa[2136] = new ampa(0.5)")
        h("Epop[26] netConn_projEE_ampa[2136] = new NetCon(&v(0.5), syn_projEE_ampa[2136], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2137: cell 26, seg 0 (0.5) [0.5 on Epop[26]] -> cell 57, seg 0 (0.5) [0.5 on Epop[57]], weight: 4.1363508E-4, delay 1.5
        h("Epop[57] syn_projEE_ampa[2137] = new ampa(0.5)")
        h("Epop[26] netConn_projEE_ampa[2137] = new NetCon(&v(0.5), syn_projEE_ampa[2137], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2138: cell 26, seg 0 (0.5) [0.5 on Epop[26]] -> cell 58, seg 0 (0.5) [0.5 on Epop[58]], weight: 4.1363508E-4, delay 1.5
        h("Epop[58] syn_projEE_ampa[2138] = new ampa(0.5)")
        h("Epop[26] netConn_projEE_ampa[2138] = new NetCon(&v(0.5), syn_projEE_ampa[2138], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2139: cell 26, seg 0 (0.5) [0.5 on Epop[26]] -> cell 59, seg 0 (0.5) [0.5 on Epop[59]], weight: 4.1363508E-4, delay 1.5
        h("Epop[59] syn_projEE_ampa[2139] = new ampa(0.5)")
        h("Epop[26] netConn_projEE_ampa[2139] = new NetCon(&v(0.5), syn_projEE_ampa[2139], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2140: cell 26, seg 0 (0.5) [0.5 on Epop[26]] -> cell 60, seg 0 (0.5) [0.5 on Epop[60]], weight: 4.1363508E-4, delay 1.5
        h("Epop[60] syn_projEE_ampa[2140] = new ampa(0.5)")
        h("Epop[26] netConn_projEE_ampa[2140] = new NetCon(&v(0.5), syn_projEE_ampa[2140], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2141: cell 26, seg 0 (0.5) [0.5 on Epop[26]] -> cell 61, seg 0 (0.5) [0.5 on Epop[61]], weight: 4.1363508E-4, delay 1.5
        h("Epop[61] syn_projEE_ampa[2141] = new ampa(0.5)")
        h("Epop[26] netConn_projEE_ampa[2141] = new NetCon(&v(0.5), syn_projEE_ampa[2141], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2142: cell 26, seg 0 (0.5) [0.5 on Epop[26]] -> cell 62, seg 0 (0.5) [0.5 on Epop[62]], weight: 4.1363508E-4, delay 1.5
        h("Epop[62] syn_projEE_ampa[2142] = new ampa(0.5)")
        h("Epop[26] netConn_projEE_ampa[2142] = new NetCon(&v(0.5), syn_projEE_ampa[2142], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2143: cell 26, seg 0 (0.5) [0.5 on Epop[26]] -> cell 63, seg 0 (0.5) [0.5 on Epop[63]], weight: 4.1363508E-4, delay 1.5
        h("Epop[63] syn_projEE_ampa[2143] = new ampa(0.5)")
        h("Epop[26] netConn_projEE_ampa[2143] = new NetCon(&v(0.5), syn_projEE_ampa[2143], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2144: cell 26, seg 0 (0.5) [0.5 on Epop[26]] -> cell 64, seg 0 (0.5) [0.5 on Epop[64]], weight: 4.1363508E-4, delay 1.5
        h("Epop[64] syn_projEE_ampa[2144] = new ampa(0.5)")
        h("Epop[26] netConn_projEE_ampa[2144] = new NetCon(&v(0.5), syn_projEE_ampa[2144], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2145: cell 26, seg 0 (0.5) [0.5 on Epop[26]] -> cell 65, seg 0 (0.5) [0.5 on Epop[65]], weight: 4.1363508E-4, delay 1.5
        h("Epop[65] syn_projEE_ampa[2145] = new ampa(0.5)")
        h("Epop[26] netConn_projEE_ampa[2145] = new NetCon(&v(0.5), syn_projEE_ampa[2145], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2146: cell 26, seg 0 (0.5) [0.5 on Epop[26]] -> cell 66, seg 0 (0.5) [0.5 on Epop[66]], weight: 4.1363508E-4, delay 1.5
        h("Epop[66] syn_projEE_ampa[2146] = new ampa(0.5)")
        h("Epop[26] netConn_projEE_ampa[2146] = new NetCon(&v(0.5), syn_projEE_ampa[2146], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2147: cell 26, seg 0 (0.5) [0.5 on Epop[26]] -> cell 67, seg 0 (0.5) [0.5 on Epop[67]], weight: 4.1363508E-4, delay 1.5
        h("Epop[67] syn_projEE_ampa[2147] = new ampa(0.5)")
        h("Epop[26] netConn_projEE_ampa[2147] = new NetCon(&v(0.5), syn_projEE_ampa[2147], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2148: cell 26, seg 0 (0.5) [0.5 on Epop[26]] -> cell 68, seg 0 (0.5) [0.5 on Epop[68]], weight: 4.1363508E-4, delay 1.5
        h("Epop[68] syn_projEE_ampa[2148] = new ampa(0.5)")
        h("Epop[26] netConn_projEE_ampa[2148] = new NetCon(&v(0.5), syn_projEE_ampa[2148], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2149: cell 26, seg 0 (0.5) [0.5 on Epop[26]] -> cell 69, seg 0 (0.5) [0.5 on Epop[69]], weight: 4.1363508E-4, delay 1.5
        h("Epop[69] syn_projEE_ampa[2149] = new ampa(0.5)")
        h("Epop[26] netConn_projEE_ampa[2149] = new NetCon(&v(0.5), syn_projEE_ampa[2149], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2150: cell 26, seg 0 (0.5) [0.5 on Epop[26]] -> cell 70, seg 0 (0.5) [0.5 on Epop[70]], weight: 4.1363508E-4, delay 1.5
        h("Epop[70] syn_projEE_ampa[2150] = new ampa(0.5)")
        h("Epop[26] netConn_projEE_ampa[2150] = new NetCon(&v(0.5), syn_projEE_ampa[2150], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2151: cell 26, seg 0 (0.5) [0.5 on Epop[26]] -> cell 71, seg 0 (0.5) [0.5 on Epop[71]], weight: 4.1363508E-4, delay 1.5
        h("Epop[71] syn_projEE_ampa[2151] = new ampa(0.5)")
        h("Epop[26] netConn_projEE_ampa[2151] = new NetCon(&v(0.5), syn_projEE_ampa[2151], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2152: cell 26, seg 0 (0.5) [0.5 on Epop[26]] -> cell 72, seg 0 (0.5) [0.5 on Epop[72]], weight: 4.1363508E-4, delay 1.5
        h("Epop[72] syn_projEE_ampa[2152] = new ampa(0.5)")
        h("Epop[26] netConn_projEE_ampa[2152] = new NetCon(&v(0.5), syn_projEE_ampa[2152], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2153: cell 26, seg 0 (0.5) [0.5 on Epop[26]] -> cell 73, seg 0 (0.5) [0.5 on Epop[73]], weight: 4.1363508E-4, delay 1.5
        h("Epop[73] syn_projEE_ampa[2153] = new ampa(0.5)")
        h("Epop[26] netConn_projEE_ampa[2153] = new NetCon(&v(0.5), syn_projEE_ampa[2153], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2154: cell 26, seg 0 (0.5) [0.5 on Epop[26]] -> cell 74, seg 0 (0.5) [0.5 on Epop[74]], weight: 4.1363508E-4, delay 1.5
        h("Epop[74] syn_projEE_ampa[2154] = new ampa(0.5)")
        h("Epop[26] netConn_projEE_ampa[2154] = new NetCon(&v(0.5), syn_projEE_ampa[2154], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2155: cell 26, seg 0 (0.5) [0.5 on Epop[26]] -> cell 75, seg 0 (0.5) [0.5 on Epop[75]], weight: 4.1363508E-4, delay 1.5
        h("Epop[75] syn_projEE_ampa[2155] = new ampa(0.5)")
        h("Epop[26] netConn_projEE_ampa[2155] = new NetCon(&v(0.5), syn_projEE_ampa[2155], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2156: cell 26, seg 0 (0.5) [0.5 on Epop[26]] -> cell 76, seg 0 (0.5) [0.5 on Epop[76]], weight: 4.1363508E-4, delay 1.5
        h("Epop[76] syn_projEE_ampa[2156] = new ampa(0.5)")
        h("Epop[26] netConn_projEE_ampa[2156] = new NetCon(&v(0.5), syn_projEE_ampa[2156], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2157: cell 26, seg 0 (0.5) [0.5 on Epop[26]] -> cell 77, seg 0 (0.5) [0.5 on Epop[77]], weight: 4.1363508E-4, delay 1.5
        h("Epop[77] syn_projEE_ampa[2157] = new ampa(0.5)")
        h("Epop[26] netConn_projEE_ampa[2157] = new NetCon(&v(0.5), syn_projEE_ampa[2157], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2158: cell 26, seg 0 (0.5) [0.5 on Epop[26]] -> cell 78, seg 0 (0.5) [0.5 on Epop[78]], weight: 4.1363508E-4, delay 1.5
        h("Epop[78] syn_projEE_ampa[2158] = new ampa(0.5)")
        h("Epop[26] netConn_projEE_ampa[2158] = new NetCon(&v(0.5), syn_projEE_ampa[2158], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2159: cell 26, seg 0 (0.5) [0.5 on Epop[26]] -> cell 79, seg 0 (0.5) [0.5 on Epop[79]], weight: 4.1363508E-4, delay 1.5
        h("Epop[79] syn_projEE_ampa[2159] = new ampa(0.5)")
        h("Epop[26] netConn_projEE_ampa[2159] = new NetCon(&v(0.5), syn_projEE_ampa[2159], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2160: cell 27, seg 0 (0.5) [0.5 on Epop[27]] -> cell 0, seg 0 (0.5) [0.5 on Epop[0]], weight: 4.1363508E-4, delay 1.5
        h("Epop[0] syn_projEE_ampa[2160] = new ampa(0.5)")
        h("Epop[27] netConn_projEE_ampa[2160] = new NetCon(&v(0.5), syn_projEE_ampa[2160], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2161: cell 27, seg 0 (0.5) [0.5 on Epop[27]] -> cell 1, seg 0 (0.5) [0.5 on Epop[1]], weight: 4.1363508E-4, delay 1.5
        h("Epop[1] syn_projEE_ampa[2161] = new ampa(0.5)")
        h("Epop[27] netConn_projEE_ampa[2161] = new NetCon(&v(0.5), syn_projEE_ampa[2161], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2162: cell 27, seg 0 (0.5) [0.5 on Epop[27]] -> cell 2, seg 0 (0.5) [0.5 on Epop[2]], weight: 4.1363508E-4, delay 1.5
        h("Epop[2] syn_projEE_ampa[2162] = new ampa(0.5)")
        h("Epop[27] netConn_projEE_ampa[2162] = new NetCon(&v(0.5), syn_projEE_ampa[2162], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2163: cell 27, seg 0 (0.5) [0.5 on Epop[27]] -> cell 3, seg 0 (0.5) [0.5 on Epop[3]], weight: 4.1363508E-4, delay 1.5
        h("Epop[3] syn_projEE_ampa[2163] = new ampa(0.5)")
        h("Epop[27] netConn_projEE_ampa[2163] = new NetCon(&v(0.5), syn_projEE_ampa[2163], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2164: cell 27, seg 0 (0.5) [0.5 on Epop[27]] -> cell 4, seg 0 (0.5) [0.5 on Epop[4]], weight: 4.1363508E-4, delay 1.5
        h("Epop[4] syn_projEE_ampa[2164] = new ampa(0.5)")
        h("Epop[27] netConn_projEE_ampa[2164] = new NetCon(&v(0.5), syn_projEE_ampa[2164], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2165: cell 27, seg 0 (0.5) [0.5 on Epop[27]] -> cell 5, seg 0 (0.5) [0.5 on Epop[5]], weight: 4.1363508E-4, delay 1.5
        h("Epop[5] syn_projEE_ampa[2165] = new ampa(0.5)")
        h("Epop[27] netConn_projEE_ampa[2165] = new NetCon(&v(0.5), syn_projEE_ampa[2165], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2166: cell 27, seg 0 (0.5) [0.5 on Epop[27]] -> cell 6, seg 0 (0.5) [0.5 on Epop[6]], weight: 4.1363508E-4, delay 1.5
        h("Epop[6] syn_projEE_ampa[2166] = new ampa(0.5)")
        h("Epop[27] netConn_projEE_ampa[2166] = new NetCon(&v(0.5), syn_projEE_ampa[2166], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2167: cell 27, seg 0 (0.5) [0.5 on Epop[27]] -> cell 7, seg 0 (0.5) [0.5 on Epop[7]], weight: 4.1363508E-4, delay 1.5
        h("Epop[7] syn_projEE_ampa[2167] = new ampa(0.5)")
        h("Epop[27] netConn_projEE_ampa[2167] = new NetCon(&v(0.5), syn_projEE_ampa[2167], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2168: cell 27, seg 0 (0.5) [0.5 on Epop[27]] -> cell 8, seg 0 (0.5) [0.5 on Epop[8]], weight: 4.1363508E-4, delay 1.5
        h("Epop[8] syn_projEE_ampa[2168] = new ampa(0.5)")
        h("Epop[27] netConn_projEE_ampa[2168] = new NetCon(&v(0.5), syn_projEE_ampa[2168], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2169: cell 27, seg 0 (0.5) [0.5 on Epop[27]] -> cell 9, seg 0 (0.5) [0.5 on Epop[9]], weight: 4.1363508E-4, delay 1.5
        h("Epop[9] syn_projEE_ampa[2169] = new ampa(0.5)")
        h("Epop[27] netConn_projEE_ampa[2169] = new NetCon(&v(0.5), syn_projEE_ampa[2169], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2170: cell 27, seg 0 (0.5) [0.5 on Epop[27]] -> cell 10, seg 0 (0.5) [0.5 on Epop[10]], weight: 4.1363508E-4, delay 1.5
        h("Epop[10] syn_projEE_ampa[2170] = new ampa(0.5)")
        h("Epop[27] netConn_projEE_ampa[2170] = new NetCon(&v(0.5), syn_projEE_ampa[2170], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2171: cell 27, seg 0 (0.5) [0.5 on Epop[27]] -> cell 11, seg 0 (0.5) [0.5 on Epop[11]], weight: 4.1363508E-4, delay 1.5
        h("Epop[11] syn_projEE_ampa[2171] = new ampa(0.5)")
        h("Epop[27] netConn_projEE_ampa[2171] = new NetCon(&v(0.5), syn_projEE_ampa[2171], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2172: cell 27, seg 0 (0.5) [0.5 on Epop[27]] -> cell 12, seg 0 (0.5) [0.5 on Epop[12]], weight: 4.1363508E-4, delay 1.5
        h("Epop[12] syn_projEE_ampa[2172] = new ampa(0.5)")
        h("Epop[27] netConn_projEE_ampa[2172] = new NetCon(&v(0.5), syn_projEE_ampa[2172], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2173: cell 27, seg 0 (0.5) [0.5 on Epop[27]] -> cell 13, seg 0 (0.5) [0.5 on Epop[13]], weight: 4.1363508E-4, delay 1.5
        h("Epop[13] syn_projEE_ampa[2173] = new ampa(0.5)")
        h("Epop[27] netConn_projEE_ampa[2173] = new NetCon(&v(0.5), syn_projEE_ampa[2173], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2174: cell 27, seg 0 (0.5) [0.5 on Epop[27]] -> cell 14, seg 0 (0.5) [0.5 on Epop[14]], weight: 4.1363508E-4, delay 1.5
        h("Epop[14] syn_projEE_ampa[2174] = new ampa(0.5)")
        h("Epop[27] netConn_projEE_ampa[2174] = new NetCon(&v(0.5), syn_projEE_ampa[2174], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2175: cell 27, seg 0 (0.5) [0.5 on Epop[27]] -> cell 15, seg 0 (0.5) [0.5 on Epop[15]], weight: 4.1363508E-4, delay 1.5
        h("Epop[15] syn_projEE_ampa[2175] = new ampa(0.5)")
        h("Epop[27] netConn_projEE_ampa[2175] = new NetCon(&v(0.5), syn_projEE_ampa[2175], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2176: cell 27, seg 0 (0.5) [0.5 on Epop[27]] -> cell 16, seg 0 (0.5) [0.5 on Epop[16]], weight: 4.1363508E-4, delay 1.5
        h("Epop[16] syn_projEE_ampa[2176] = new ampa(0.5)")
        h("Epop[27] netConn_projEE_ampa[2176] = new NetCon(&v(0.5), syn_projEE_ampa[2176], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2177: cell 27, seg 0 (0.5) [0.5 on Epop[27]] -> cell 17, seg 0 (0.5) [0.5 on Epop[17]], weight: 4.1363508E-4, delay 1.5
        h("Epop[17] syn_projEE_ampa[2177] = new ampa(0.5)")
        h("Epop[27] netConn_projEE_ampa[2177] = new NetCon(&v(0.5), syn_projEE_ampa[2177], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2178: cell 27, seg 0 (0.5) [0.5 on Epop[27]] -> cell 18, seg 0 (0.5) [0.5 on Epop[18]], weight: 4.1363508E-4, delay 1.5
        h("Epop[18] syn_projEE_ampa[2178] = new ampa(0.5)")
        h("Epop[27] netConn_projEE_ampa[2178] = new NetCon(&v(0.5), syn_projEE_ampa[2178], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2179: cell 27, seg 0 (0.5) [0.5 on Epop[27]] -> cell 19, seg 0 (0.5) [0.5 on Epop[19]], weight: 4.1363508E-4, delay 1.5
        h("Epop[19] syn_projEE_ampa[2179] = new ampa(0.5)")
        h("Epop[27] netConn_projEE_ampa[2179] = new NetCon(&v(0.5), syn_projEE_ampa[2179], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2180: cell 27, seg 0 (0.5) [0.5 on Epop[27]] -> cell 20, seg 0 (0.5) [0.5 on Epop[20]], weight: 4.1363508E-4, delay 1.5
        h("Epop[20] syn_projEE_ampa[2180] = new ampa(0.5)")
        h("Epop[27] netConn_projEE_ampa[2180] = new NetCon(&v(0.5), syn_projEE_ampa[2180], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2181: cell 27, seg 0 (0.5) [0.5 on Epop[27]] -> cell 21, seg 0 (0.5) [0.5 on Epop[21]], weight: 4.1363508E-4, delay 1.5
        h("Epop[21] syn_projEE_ampa[2181] = new ampa(0.5)")
        h("Epop[27] netConn_projEE_ampa[2181] = new NetCon(&v(0.5), syn_projEE_ampa[2181], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2182: cell 27, seg 0 (0.5) [0.5 on Epop[27]] -> cell 22, seg 0 (0.5) [0.5 on Epop[22]], weight: 4.1363508E-4, delay 1.5
        h("Epop[22] syn_projEE_ampa[2182] = new ampa(0.5)")
        h("Epop[27] netConn_projEE_ampa[2182] = new NetCon(&v(0.5), syn_projEE_ampa[2182], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2183: cell 27, seg 0 (0.5) [0.5 on Epop[27]] -> cell 23, seg 0 (0.5) [0.5 on Epop[23]], weight: 4.1363508E-4, delay 1.5
        h("Epop[23] syn_projEE_ampa[2183] = new ampa(0.5)")
        h("Epop[27] netConn_projEE_ampa[2183] = new NetCon(&v(0.5), syn_projEE_ampa[2183], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2184: cell 27, seg 0 (0.5) [0.5 on Epop[27]] -> cell 24, seg 0 (0.5) [0.5 on Epop[24]], weight: 4.1363508E-4, delay 1.5
        h("Epop[24] syn_projEE_ampa[2184] = new ampa(0.5)")
        h("Epop[27] netConn_projEE_ampa[2184] = new NetCon(&v(0.5), syn_projEE_ampa[2184], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2185: cell 27, seg 0 (0.5) [0.5 on Epop[27]] -> cell 25, seg 0 (0.5) [0.5 on Epop[25]], weight: 4.1363508E-4, delay 1.5
        h("Epop[25] syn_projEE_ampa[2185] = new ampa(0.5)")
        h("Epop[27] netConn_projEE_ampa[2185] = new NetCon(&v(0.5), syn_projEE_ampa[2185], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2186: cell 27, seg 0 (0.5) [0.5 on Epop[27]] -> cell 26, seg 0 (0.5) [0.5 on Epop[26]], weight: 4.1363508E-4, delay 1.5
        h("Epop[26] syn_projEE_ampa[2186] = new ampa(0.5)")
        h("Epop[27] netConn_projEE_ampa[2186] = new NetCon(&v(0.5), syn_projEE_ampa[2186], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2187: cell 27, seg 0 (0.5) [0.5 on Epop[27]] -> cell 27, seg 0 (0.5) [0.5 on Epop[27]], weight: 4.1363508E-4, delay 1.5
        h("Epop[27] syn_projEE_ampa[2187] = new ampa(0.5)")
        h("Epop[27] netConn_projEE_ampa[2187] = new NetCon(&v(0.5), syn_projEE_ampa[2187], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2188: cell 27, seg 0 (0.5) [0.5 on Epop[27]] -> cell 28, seg 0 (0.5) [0.5 on Epop[28]], weight: 4.1363508E-4, delay 1.5
        h("Epop[28] syn_projEE_ampa[2188] = new ampa(0.5)")
        h("Epop[27] netConn_projEE_ampa[2188] = new NetCon(&v(0.5), syn_projEE_ampa[2188], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2189: cell 27, seg 0 (0.5) [0.5 on Epop[27]] -> cell 29, seg 0 (0.5) [0.5 on Epop[29]], weight: 4.1363508E-4, delay 1.5
        h("Epop[29] syn_projEE_ampa[2189] = new ampa(0.5)")
        h("Epop[27] netConn_projEE_ampa[2189] = new NetCon(&v(0.5), syn_projEE_ampa[2189], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2190: cell 27, seg 0 (0.5) [0.5 on Epop[27]] -> cell 30, seg 0 (0.5) [0.5 on Epop[30]], weight: 4.1363508E-4, delay 1.5
        h("Epop[30] syn_projEE_ampa[2190] = new ampa(0.5)")
        h("Epop[27] netConn_projEE_ampa[2190] = new NetCon(&v(0.5), syn_projEE_ampa[2190], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2191: cell 27, seg 0 (0.5) [0.5 on Epop[27]] -> cell 31, seg 0 (0.5) [0.5 on Epop[31]], weight: 4.1363508E-4, delay 1.5
        h("Epop[31] syn_projEE_ampa[2191] = new ampa(0.5)")
        h("Epop[27] netConn_projEE_ampa[2191] = new NetCon(&v(0.5), syn_projEE_ampa[2191], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2192: cell 27, seg 0 (0.5) [0.5 on Epop[27]] -> cell 32, seg 0 (0.5) [0.5 on Epop[32]], weight: 4.1363508E-4, delay 1.5
        h("Epop[32] syn_projEE_ampa[2192] = new ampa(0.5)")
        h("Epop[27] netConn_projEE_ampa[2192] = new NetCon(&v(0.5), syn_projEE_ampa[2192], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2193: cell 27, seg 0 (0.5) [0.5 on Epop[27]] -> cell 33, seg 0 (0.5) [0.5 on Epop[33]], weight: 4.1363508E-4, delay 1.5
        h("Epop[33] syn_projEE_ampa[2193] = new ampa(0.5)")
        h("Epop[27] netConn_projEE_ampa[2193] = new NetCon(&v(0.5), syn_projEE_ampa[2193], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2194: cell 27, seg 0 (0.5) [0.5 on Epop[27]] -> cell 34, seg 0 (0.5) [0.5 on Epop[34]], weight: 4.1363508E-4, delay 1.5
        h("Epop[34] syn_projEE_ampa[2194] = new ampa(0.5)")
        h("Epop[27] netConn_projEE_ampa[2194] = new NetCon(&v(0.5), syn_projEE_ampa[2194], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2195: cell 27, seg 0 (0.5) [0.5 on Epop[27]] -> cell 35, seg 0 (0.5) [0.5 on Epop[35]], weight: 4.1363508E-4, delay 1.5
        h("Epop[35] syn_projEE_ampa[2195] = new ampa(0.5)")
        h("Epop[27] netConn_projEE_ampa[2195] = new NetCon(&v(0.5), syn_projEE_ampa[2195], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2196: cell 27, seg 0 (0.5) [0.5 on Epop[27]] -> cell 36, seg 0 (0.5) [0.5 on Epop[36]], weight: 4.1363508E-4, delay 1.5
        h("Epop[36] syn_projEE_ampa[2196] = new ampa(0.5)")
        h("Epop[27] netConn_projEE_ampa[2196] = new NetCon(&v(0.5), syn_projEE_ampa[2196], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2197: cell 27, seg 0 (0.5) [0.5 on Epop[27]] -> cell 37, seg 0 (0.5) [0.5 on Epop[37]], weight: 4.1363508E-4, delay 1.5
        h("Epop[37] syn_projEE_ampa[2197] = new ampa(0.5)")
        h("Epop[27] netConn_projEE_ampa[2197] = new NetCon(&v(0.5), syn_projEE_ampa[2197], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2198: cell 27, seg 0 (0.5) [0.5 on Epop[27]] -> cell 38, seg 0 (0.5) [0.5 on Epop[38]], weight: 4.1363508E-4, delay 1.5
        h("Epop[38] syn_projEE_ampa[2198] = new ampa(0.5)")
        h("Epop[27] netConn_projEE_ampa[2198] = new NetCon(&v(0.5), syn_projEE_ampa[2198], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2199: cell 27, seg 0 (0.5) [0.5 on Epop[27]] -> cell 39, seg 0 (0.5) [0.5 on Epop[39]], weight: 4.1363508E-4, delay 1.5
        h("Epop[39] syn_projEE_ampa[2199] = new ampa(0.5)")
        h("Epop[27] netConn_projEE_ampa[2199] = new NetCon(&v(0.5), syn_projEE_ampa[2199], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2200: cell 27, seg 0 (0.5) [0.5 on Epop[27]] -> cell 40, seg 0 (0.5) [0.5 on Epop[40]], weight: 4.1363508E-4, delay 1.5
        h("Epop[40] syn_projEE_ampa[2200] = new ampa(0.5)")
        h("Epop[27] netConn_projEE_ampa[2200] = new NetCon(&v(0.5), syn_projEE_ampa[2200], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2201: cell 27, seg 0 (0.5) [0.5 on Epop[27]] -> cell 41, seg 0 (0.5) [0.5 on Epop[41]], weight: 4.1363508E-4, delay 1.5
        h("Epop[41] syn_projEE_ampa[2201] = new ampa(0.5)")
        h("Epop[27] netConn_projEE_ampa[2201] = new NetCon(&v(0.5), syn_projEE_ampa[2201], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2202: cell 27, seg 0 (0.5) [0.5 on Epop[27]] -> cell 42, seg 0 (0.5) [0.5 on Epop[42]], weight: 4.1363508E-4, delay 1.5
        h("Epop[42] syn_projEE_ampa[2202] = new ampa(0.5)")
        h("Epop[27] netConn_projEE_ampa[2202] = new NetCon(&v(0.5), syn_projEE_ampa[2202], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2203: cell 27, seg 0 (0.5) [0.5 on Epop[27]] -> cell 43, seg 0 (0.5) [0.5 on Epop[43]], weight: 4.1363508E-4, delay 1.5
        h("Epop[43] syn_projEE_ampa[2203] = new ampa(0.5)")
        h("Epop[27] netConn_projEE_ampa[2203] = new NetCon(&v(0.5), syn_projEE_ampa[2203], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2204: cell 27, seg 0 (0.5) [0.5 on Epop[27]] -> cell 44, seg 0 (0.5) [0.5 on Epop[44]], weight: 4.1363508E-4, delay 1.5
        h("Epop[44] syn_projEE_ampa[2204] = new ampa(0.5)")
        h("Epop[27] netConn_projEE_ampa[2204] = new NetCon(&v(0.5), syn_projEE_ampa[2204], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2205: cell 27, seg 0 (0.5) [0.5 on Epop[27]] -> cell 45, seg 0 (0.5) [0.5 on Epop[45]], weight: 4.1363508E-4, delay 1.5
        h("Epop[45] syn_projEE_ampa[2205] = new ampa(0.5)")
        h("Epop[27] netConn_projEE_ampa[2205] = new NetCon(&v(0.5), syn_projEE_ampa[2205], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2206: cell 27, seg 0 (0.5) [0.5 on Epop[27]] -> cell 46, seg 0 (0.5) [0.5 on Epop[46]], weight: 4.1363508E-4, delay 1.5
        h("Epop[46] syn_projEE_ampa[2206] = new ampa(0.5)")
        h("Epop[27] netConn_projEE_ampa[2206] = new NetCon(&v(0.5), syn_projEE_ampa[2206], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2207: cell 27, seg 0 (0.5) [0.5 on Epop[27]] -> cell 47, seg 0 (0.5) [0.5 on Epop[47]], weight: 4.1363508E-4, delay 1.5
        h("Epop[47] syn_projEE_ampa[2207] = new ampa(0.5)")
        h("Epop[27] netConn_projEE_ampa[2207] = new NetCon(&v(0.5), syn_projEE_ampa[2207], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2208: cell 27, seg 0 (0.5) [0.5 on Epop[27]] -> cell 48, seg 0 (0.5) [0.5 on Epop[48]], weight: 4.1363508E-4, delay 1.5
        h("Epop[48] syn_projEE_ampa[2208] = new ampa(0.5)")
        h("Epop[27] netConn_projEE_ampa[2208] = new NetCon(&v(0.5), syn_projEE_ampa[2208], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2209: cell 27, seg 0 (0.5) [0.5 on Epop[27]] -> cell 49, seg 0 (0.5) [0.5 on Epop[49]], weight: 4.1363508E-4, delay 1.5
        h("Epop[49] syn_projEE_ampa[2209] = new ampa(0.5)")
        h("Epop[27] netConn_projEE_ampa[2209] = new NetCon(&v(0.5), syn_projEE_ampa[2209], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2210: cell 27, seg 0 (0.5) [0.5 on Epop[27]] -> cell 50, seg 0 (0.5) [0.5 on Epop[50]], weight: 4.1363508E-4, delay 1.5
        h("Epop[50] syn_projEE_ampa[2210] = new ampa(0.5)")
        h("Epop[27] netConn_projEE_ampa[2210] = new NetCon(&v(0.5), syn_projEE_ampa[2210], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2211: cell 27, seg 0 (0.5) [0.5 on Epop[27]] -> cell 51, seg 0 (0.5) [0.5 on Epop[51]], weight: 4.1363508E-4, delay 1.5
        h("Epop[51] syn_projEE_ampa[2211] = new ampa(0.5)")
        h("Epop[27] netConn_projEE_ampa[2211] = new NetCon(&v(0.5), syn_projEE_ampa[2211], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2212: cell 27, seg 0 (0.5) [0.5 on Epop[27]] -> cell 52, seg 0 (0.5) [0.5 on Epop[52]], weight: 4.1363508E-4, delay 1.5
        h("Epop[52] syn_projEE_ampa[2212] = new ampa(0.5)")
        h("Epop[27] netConn_projEE_ampa[2212] = new NetCon(&v(0.5), syn_projEE_ampa[2212], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2213: cell 27, seg 0 (0.5) [0.5 on Epop[27]] -> cell 53, seg 0 (0.5) [0.5 on Epop[53]], weight: 4.1363508E-4, delay 1.5
        h("Epop[53] syn_projEE_ampa[2213] = new ampa(0.5)")
        h("Epop[27] netConn_projEE_ampa[2213] = new NetCon(&v(0.5), syn_projEE_ampa[2213], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2214: cell 27, seg 0 (0.5) [0.5 on Epop[27]] -> cell 54, seg 0 (0.5) [0.5 on Epop[54]], weight: 4.1363508E-4, delay 1.5
        h("Epop[54] syn_projEE_ampa[2214] = new ampa(0.5)")
        h("Epop[27] netConn_projEE_ampa[2214] = new NetCon(&v(0.5), syn_projEE_ampa[2214], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2215: cell 27, seg 0 (0.5) [0.5 on Epop[27]] -> cell 55, seg 0 (0.5) [0.5 on Epop[55]], weight: 4.1363508E-4, delay 1.5
        h("Epop[55] syn_projEE_ampa[2215] = new ampa(0.5)")
        h("Epop[27] netConn_projEE_ampa[2215] = new NetCon(&v(0.5), syn_projEE_ampa[2215], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2216: cell 27, seg 0 (0.5) [0.5 on Epop[27]] -> cell 56, seg 0 (0.5) [0.5 on Epop[56]], weight: 4.1363508E-4, delay 1.5
        h("Epop[56] syn_projEE_ampa[2216] = new ampa(0.5)")
        h("Epop[27] netConn_projEE_ampa[2216] = new NetCon(&v(0.5), syn_projEE_ampa[2216], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2217: cell 27, seg 0 (0.5) [0.5 on Epop[27]] -> cell 57, seg 0 (0.5) [0.5 on Epop[57]], weight: 4.1363508E-4, delay 1.5
        h("Epop[57] syn_projEE_ampa[2217] = new ampa(0.5)")
        h("Epop[27] netConn_projEE_ampa[2217] = new NetCon(&v(0.5), syn_projEE_ampa[2217], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2218: cell 27, seg 0 (0.5) [0.5 on Epop[27]] -> cell 58, seg 0 (0.5) [0.5 on Epop[58]], weight: 4.1363508E-4, delay 1.5
        h("Epop[58] syn_projEE_ampa[2218] = new ampa(0.5)")
        h("Epop[27] netConn_projEE_ampa[2218] = new NetCon(&v(0.5), syn_projEE_ampa[2218], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2219: cell 27, seg 0 (0.5) [0.5 on Epop[27]] -> cell 59, seg 0 (0.5) [0.5 on Epop[59]], weight: 4.1363508E-4, delay 1.5
        h("Epop[59] syn_projEE_ampa[2219] = new ampa(0.5)")
        h("Epop[27] netConn_projEE_ampa[2219] = new NetCon(&v(0.5), syn_projEE_ampa[2219], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2220: cell 27, seg 0 (0.5) [0.5 on Epop[27]] -> cell 60, seg 0 (0.5) [0.5 on Epop[60]], weight: 4.1363508E-4, delay 1.5
        h("Epop[60] syn_projEE_ampa[2220] = new ampa(0.5)")
        h("Epop[27] netConn_projEE_ampa[2220] = new NetCon(&v(0.5), syn_projEE_ampa[2220], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2221: cell 27, seg 0 (0.5) [0.5 on Epop[27]] -> cell 61, seg 0 (0.5) [0.5 on Epop[61]], weight: 4.1363508E-4, delay 1.5
        h("Epop[61] syn_projEE_ampa[2221] = new ampa(0.5)")
        h("Epop[27] netConn_projEE_ampa[2221] = new NetCon(&v(0.5), syn_projEE_ampa[2221], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2222: cell 27, seg 0 (0.5) [0.5 on Epop[27]] -> cell 62, seg 0 (0.5) [0.5 on Epop[62]], weight: 4.1363508E-4, delay 1.5
        h("Epop[62] syn_projEE_ampa[2222] = new ampa(0.5)")
        h("Epop[27] netConn_projEE_ampa[2222] = new NetCon(&v(0.5), syn_projEE_ampa[2222], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2223: cell 27, seg 0 (0.5) [0.5 on Epop[27]] -> cell 63, seg 0 (0.5) [0.5 on Epop[63]], weight: 4.1363508E-4, delay 1.5
        h("Epop[63] syn_projEE_ampa[2223] = new ampa(0.5)")
        h("Epop[27] netConn_projEE_ampa[2223] = new NetCon(&v(0.5), syn_projEE_ampa[2223], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2224: cell 27, seg 0 (0.5) [0.5 on Epop[27]] -> cell 64, seg 0 (0.5) [0.5 on Epop[64]], weight: 4.1363508E-4, delay 1.5
        h("Epop[64] syn_projEE_ampa[2224] = new ampa(0.5)")
        h("Epop[27] netConn_projEE_ampa[2224] = new NetCon(&v(0.5), syn_projEE_ampa[2224], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2225: cell 27, seg 0 (0.5) [0.5 on Epop[27]] -> cell 65, seg 0 (0.5) [0.5 on Epop[65]], weight: 4.1363508E-4, delay 1.5
        h("Epop[65] syn_projEE_ampa[2225] = new ampa(0.5)")
        h("Epop[27] netConn_projEE_ampa[2225] = new NetCon(&v(0.5), syn_projEE_ampa[2225], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2226: cell 27, seg 0 (0.5) [0.5 on Epop[27]] -> cell 66, seg 0 (0.5) [0.5 on Epop[66]], weight: 4.1363508E-4, delay 1.5
        h("Epop[66] syn_projEE_ampa[2226] = new ampa(0.5)")
        h("Epop[27] netConn_projEE_ampa[2226] = new NetCon(&v(0.5), syn_projEE_ampa[2226], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2227: cell 27, seg 0 (0.5) [0.5 on Epop[27]] -> cell 67, seg 0 (0.5) [0.5 on Epop[67]], weight: 4.1363508E-4, delay 1.5
        h("Epop[67] syn_projEE_ampa[2227] = new ampa(0.5)")
        h("Epop[27] netConn_projEE_ampa[2227] = new NetCon(&v(0.5), syn_projEE_ampa[2227], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2228: cell 27, seg 0 (0.5) [0.5 on Epop[27]] -> cell 68, seg 0 (0.5) [0.5 on Epop[68]], weight: 4.1363508E-4, delay 1.5
        h("Epop[68] syn_projEE_ampa[2228] = new ampa(0.5)")
        h("Epop[27] netConn_projEE_ampa[2228] = new NetCon(&v(0.5), syn_projEE_ampa[2228], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2229: cell 27, seg 0 (0.5) [0.5 on Epop[27]] -> cell 69, seg 0 (0.5) [0.5 on Epop[69]], weight: 4.1363508E-4, delay 1.5
        h("Epop[69] syn_projEE_ampa[2229] = new ampa(0.5)")
        h("Epop[27] netConn_projEE_ampa[2229] = new NetCon(&v(0.5), syn_projEE_ampa[2229], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2230: cell 27, seg 0 (0.5) [0.5 on Epop[27]] -> cell 70, seg 0 (0.5) [0.5 on Epop[70]], weight: 4.1363508E-4, delay 1.5
        h("Epop[70] syn_projEE_ampa[2230] = new ampa(0.5)")
        h("Epop[27] netConn_projEE_ampa[2230] = new NetCon(&v(0.5), syn_projEE_ampa[2230], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2231: cell 27, seg 0 (0.5) [0.5 on Epop[27]] -> cell 71, seg 0 (0.5) [0.5 on Epop[71]], weight: 4.1363508E-4, delay 1.5
        h("Epop[71] syn_projEE_ampa[2231] = new ampa(0.5)")
        h("Epop[27] netConn_projEE_ampa[2231] = new NetCon(&v(0.5), syn_projEE_ampa[2231], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2232: cell 27, seg 0 (0.5) [0.5 on Epop[27]] -> cell 72, seg 0 (0.5) [0.5 on Epop[72]], weight: 4.1363508E-4, delay 1.5
        h("Epop[72] syn_projEE_ampa[2232] = new ampa(0.5)")
        h("Epop[27] netConn_projEE_ampa[2232] = new NetCon(&v(0.5), syn_projEE_ampa[2232], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2233: cell 27, seg 0 (0.5) [0.5 on Epop[27]] -> cell 73, seg 0 (0.5) [0.5 on Epop[73]], weight: 4.1363508E-4, delay 1.5
        h("Epop[73] syn_projEE_ampa[2233] = new ampa(0.5)")
        h("Epop[27] netConn_projEE_ampa[2233] = new NetCon(&v(0.5), syn_projEE_ampa[2233], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2234: cell 27, seg 0 (0.5) [0.5 on Epop[27]] -> cell 74, seg 0 (0.5) [0.5 on Epop[74]], weight: 4.1363508E-4, delay 1.5
        h("Epop[74] syn_projEE_ampa[2234] = new ampa(0.5)")
        h("Epop[27] netConn_projEE_ampa[2234] = new NetCon(&v(0.5), syn_projEE_ampa[2234], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2235: cell 27, seg 0 (0.5) [0.5 on Epop[27]] -> cell 75, seg 0 (0.5) [0.5 on Epop[75]], weight: 4.1363508E-4, delay 1.5
        h("Epop[75] syn_projEE_ampa[2235] = new ampa(0.5)")
        h("Epop[27] netConn_projEE_ampa[2235] = new NetCon(&v(0.5), syn_projEE_ampa[2235], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2236: cell 27, seg 0 (0.5) [0.5 on Epop[27]] -> cell 76, seg 0 (0.5) [0.5 on Epop[76]], weight: 4.1363508E-4, delay 1.5
        h("Epop[76] syn_projEE_ampa[2236] = new ampa(0.5)")
        h("Epop[27] netConn_projEE_ampa[2236] = new NetCon(&v(0.5), syn_projEE_ampa[2236], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2237: cell 27, seg 0 (0.5) [0.5 on Epop[27]] -> cell 77, seg 0 (0.5) [0.5 on Epop[77]], weight: 4.1363508E-4, delay 1.5
        h("Epop[77] syn_projEE_ampa[2237] = new ampa(0.5)")
        h("Epop[27] netConn_projEE_ampa[2237] = new NetCon(&v(0.5), syn_projEE_ampa[2237], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2238: cell 27, seg 0 (0.5) [0.5 on Epop[27]] -> cell 78, seg 0 (0.5) [0.5 on Epop[78]], weight: 4.1363508E-4, delay 1.5
        h("Epop[78] syn_projEE_ampa[2238] = new ampa(0.5)")
        h("Epop[27] netConn_projEE_ampa[2238] = new NetCon(&v(0.5), syn_projEE_ampa[2238], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2239: cell 27, seg 0 (0.5) [0.5 on Epop[27]] -> cell 79, seg 0 (0.5) [0.5 on Epop[79]], weight: 4.1363508E-4, delay 1.5
        h("Epop[79] syn_projEE_ampa[2239] = new ampa(0.5)")
        h("Epop[27] netConn_projEE_ampa[2239] = new NetCon(&v(0.5), syn_projEE_ampa[2239], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2240: cell 28, seg 0 (0.5) [0.5 on Epop[28]] -> cell 0, seg 0 (0.5) [0.5 on Epop[0]], weight: 4.1363508E-4, delay 1.5
        h("Epop[0] syn_projEE_ampa[2240] = new ampa(0.5)")
        h("Epop[28] netConn_projEE_ampa[2240] = new NetCon(&v(0.5), syn_projEE_ampa[2240], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2241: cell 28, seg 0 (0.5) [0.5 on Epop[28]] -> cell 1, seg 0 (0.5) [0.5 on Epop[1]], weight: 4.1363508E-4, delay 1.5
        h("Epop[1] syn_projEE_ampa[2241] = new ampa(0.5)")
        h("Epop[28] netConn_projEE_ampa[2241] = new NetCon(&v(0.5), syn_projEE_ampa[2241], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2242: cell 28, seg 0 (0.5) [0.5 on Epop[28]] -> cell 2, seg 0 (0.5) [0.5 on Epop[2]], weight: 4.1363508E-4, delay 1.5
        h("Epop[2] syn_projEE_ampa[2242] = new ampa(0.5)")
        h("Epop[28] netConn_projEE_ampa[2242] = new NetCon(&v(0.5), syn_projEE_ampa[2242], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2243: cell 28, seg 0 (0.5) [0.5 on Epop[28]] -> cell 3, seg 0 (0.5) [0.5 on Epop[3]], weight: 4.1363508E-4, delay 1.5
        h("Epop[3] syn_projEE_ampa[2243] = new ampa(0.5)")
        h("Epop[28] netConn_projEE_ampa[2243] = new NetCon(&v(0.5), syn_projEE_ampa[2243], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2244: cell 28, seg 0 (0.5) [0.5 on Epop[28]] -> cell 4, seg 0 (0.5) [0.5 on Epop[4]], weight: 4.1363508E-4, delay 1.5
        h("Epop[4] syn_projEE_ampa[2244] = new ampa(0.5)")
        h("Epop[28] netConn_projEE_ampa[2244] = new NetCon(&v(0.5), syn_projEE_ampa[2244], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2245: cell 28, seg 0 (0.5) [0.5 on Epop[28]] -> cell 5, seg 0 (0.5) [0.5 on Epop[5]], weight: 4.1363508E-4, delay 1.5
        h("Epop[5] syn_projEE_ampa[2245] = new ampa(0.5)")
        h("Epop[28] netConn_projEE_ampa[2245] = new NetCon(&v(0.5), syn_projEE_ampa[2245], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2246: cell 28, seg 0 (0.5) [0.5 on Epop[28]] -> cell 6, seg 0 (0.5) [0.5 on Epop[6]], weight: 4.1363508E-4, delay 1.5
        h("Epop[6] syn_projEE_ampa[2246] = new ampa(0.5)")
        h("Epop[28] netConn_projEE_ampa[2246] = new NetCon(&v(0.5), syn_projEE_ampa[2246], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2247: cell 28, seg 0 (0.5) [0.5 on Epop[28]] -> cell 7, seg 0 (0.5) [0.5 on Epop[7]], weight: 4.1363508E-4, delay 1.5
        h("Epop[7] syn_projEE_ampa[2247] = new ampa(0.5)")
        h("Epop[28] netConn_projEE_ampa[2247] = new NetCon(&v(0.5), syn_projEE_ampa[2247], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2248: cell 28, seg 0 (0.5) [0.5 on Epop[28]] -> cell 8, seg 0 (0.5) [0.5 on Epop[8]], weight: 4.1363508E-4, delay 1.5
        h("Epop[8] syn_projEE_ampa[2248] = new ampa(0.5)")
        h("Epop[28] netConn_projEE_ampa[2248] = new NetCon(&v(0.5), syn_projEE_ampa[2248], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2249: cell 28, seg 0 (0.5) [0.5 on Epop[28]] -> cell 9, seg 0 (0.5) [0.5 on Epop[9]], weight: 4.1363508E-4, delay 1.5
        h("Epop[9] syn_projEE_ampa[2249] = new ampa(0.5)")
        h("Epop[28] netConn_projEE_ampa[2249] = new NetCon(&v(0.5), syn_projEE_ampa[2249], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2250: cell 28, seg 0 (0.5) [0.5 on Epop[28]] -> cell 10, seg 0 (0.5) [0.5 on Epop[10]], weight: 4.1363508E-4, delay 1.5
        h("Epop[10] syn_projEE_ampa[2250] = new ampa(0.5)")
        h("Epop[28] netConn_projEE_ampa[2250] = new NetCon(&v(0.5), syn_projEE_ampa[2250], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2251: cell 28, seg 0 (0.5) [0.5 on Epop[28]] -> cell 11, seg 0 (0.5) [0.5 on Epop[11]], weight: 4.1363508E-4, delay 1.5
        h("Epop[11] syn_projEE_ampa[2251] = new ampa(0.5)")
        h("Epop[28] netConn_projEE_ampa[2251] = new NetCon(&v(0.5), syn_projEE_ampa[2251], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2252: cell 28, seg 0 (0.5) [0.5 on Epop[28]] -> cell 12, seg 0 (0.5) [0.5 on Epop[12]], weight: 4.1363508E-4, delay 1.5
        h("Epop[12] syn_projEE_ampa[2252] = new ampa(0.5)")
        h("Epop[28] netConn_projEE_ampa[2252] = new NetCon(&v(0.5), syn_projEE_ampa[2252], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2253: cell 28, seg 0 (0.5) [0.5 on Epop[28]] -> cell 13, seg 0 (0.5) [0.5 on Epop[13]], weight: 4.1363508E-4, delay 1.5
        h("Epop[13] syn_projEE_ampa[2253] = new ampa(0.5)")
        h("Epop[28] netConn_projEE_ampa[2253] = new NetCon(&v(0.5), syn_projEE_ampa[2253], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2254: cell 28, seg 0 (0.5) [0.5 on Epop[28]] -> cell 14, seg 0 (0.5) [0.5 on Epop[14]], weight: 4.1363508E-4, delay 1.5
        h("Epop[14] syn_projEE_ampa[2254] = new ampa(0.5)")
        h("Epop[28] netConn_projEE_ampa[2254] = new NetCon(&v(0.5), syn_projEE_ampa[2254], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2255: cell 28, seg 0 (0.5) [0.5 on Epop[28]] -> cell 15, seg 0 (0.5) [0.5 on Epop[15]], weight: 4.1363508E-4, delay 1.5
        h("Epop[15] syn_projEE_ampa[2255] = new ampa(0.5)")
        h("Epop[28] netConn_projEE_ampa[2255] = new NetCon(&v(0.5), syn_projEE_ampa[2255], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2256: cell 28, seg 0 (0.5) [0.5 on Epop[28]] -> cell 16, seg 0 (0.5) [0.5 on Epop[16]], weight: 4.1363508E-4, delay 1.5
        h("Epop[16] syn_projEE_ampa[2256] = new ampa(0.5)")
        h("Epop[28] netConn_projEE_ampa[2256] = new NetCon(&v(0.5), syn_projEE_ampa[2256], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2257: cell 28, seg 0 (0.5) [0.5 on Epop[28]] -> cell 17, seg 0 (0.5) [0.5 on Epop[17]], weight: 4.1363508E-4, delay 1.5
        h("Epop[17] syn_projEE_ampa[2257] = new ampa(0.5)")
        h("Epop[28] netConn_projEE_ampa[2257] = new NetCon(&v(0.5), syn_projEE_ampa[2257], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2258: cell 28, seg 0 (0.5) [0.5 on Epop[28]] -> cell 18, seg 0 (0.5) [0.5 on Epop[18]], weight: 4.1363508E-4, delay 1.5
        h("Epop[18] syn_projEE_ampa[2258] = new ampa(0.5)")
        h("Epop[28] netConn_projEE_ampa[2258] = new NetCon(&v(0.5), syn_projEE_ampa[2258], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2259: cell 28, seg 0 (0.5) [0.5 on Epop[28]] -> cell 19, seg 0 (0.5) [0.5 on Epop[19]], weight: 4.1363508E-4, delay 1.5
        h("Epop[19] syn_projEE_ampa[2259] = new ampa(0.5)")
        h("Epop[28] netConn_projEE_ampa[2259] = new NetCon(&v(0.5), syn_projEE_ampa[2259], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2260: cell 28, seg 0 (0.5) [0.5 on Epop[28]] -> cell 20, seg 0 (0.5) [0.5 on Epop[20]], weight: 4.1363508E-4, delay 1.5
        h("Epop[20] syn_projEE_ampa[2260] = new ampa(0.5)")
        h("Epop[28] netConn_projEE_ampa[2260] = new NetCon(&v(0.5), syn_projEE_ampa[2260], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2261: cell 28, seg 0 (0.5) [0.5 on Epop[28]] -> cell 21, seg 0 (0.5) [0.5 on Epop[21]], weight: 4.1363508E-4, delay 1.5
        h("Epop[21] syn_projEE_ampa[2261] = new ampa(0.5)")
        h("Epop[28] netConn_projEE_ampa[2261] = new NetCon(&v(0.5), syn_projEE_ampa[2261], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2262: cell 28, seg 0 (0.5) [0.5 on Epop[28]] -> cell 22, seg 0 (0.5) [0.5 on Epop[22]], weight: 4.1363508E-4, delay 1.5
        h("Epop[22] syn_projEE_ampa[2262] = new ampa(0.5)")
        h("Epop[28] netConn_projEE_ampa[2262] = new NetCon(&v(0.5), syn_projEE_ampa[2262], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2263: cell 28, seg 0 (0.5) [0.5 on Epop[28]] -> cell 23, seg 0 (0.5) [0.5 on Epop[23]], weight: 4.1363508E-4, delay 1.5
        h("Epop[23] syn_projEE_ampa[2263] = new ampa(0.5)")
        h("Epop[28] netConn_projEE_ampa[2263] = new NetCon(&v(0.5), syn_projEE_ampa[2263], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2264: cell 28, seg 0 (0.5) [0.5 on Epop[28]] -> cell 24, seg 0 (0.5) [0.5 on Epop[24]], weight: 4.1363508E-4, delay 1.5
        h("Epop[24] syn_projEE_ampa[2264] = new ampa(0.5)")
        h("Epop[28] netConn_projEE_ampa[2264] = new NetCon(&v(0.5), syn_projEE_ampa[2264], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2265: cell 28, seg 0 (0.5) [0.5 on Epop[28]] -> cell 25, seg 0 (0.5) [0.5 on Epop[25]], weight: 4.1363508E-4, delay 1.5
        h("Epop[25] syn_projEE_ampa[2265] = new ampa(0.5)")
        h("Epop[28] netConn_projEE_ampa[2265] = new NetCon(&v(0.5), syn_projEE_ampa[2265], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2266: cell 28, seg 0 (0.5) [0.5 on Epop[28]] -> cell 26, seg 0 (0.5) [0.5 on Epop[26]], weight: 4.1363508E-4, delay 1.5
        h("Epop[26] syn_projEE_ampa[2266] = new ampa(0.5)")
        h("Epop[28] netConn_projEE_ampa[2266] = new NetCon(&v(0.5), syn_projEE_ampa[2266], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2267: cell 28, seg 0 (0.5) [0.5 on Epop[28]] -> cell 27, seg 0 (0.5) [0.5 on Epop[27]], weight: 4.1363508E-4, delay 1.5
        h("Epop[27] syn_projEE_ampa[2267] = new ampa(0.5)")
        h("Epop[28] netConn_projEE_ampa[2267] = new NetCon(&v(0.5), syn_projEE_ampa[2267], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2268: cell 28, seg 0 (0.5) [0.5 on Epop[28]] -> cell 28, seg 0 (0.5) [0.5 on Epop[28]], weight: 4.1363508E-4, delay 1.5
        h("Epop[28] syn_projEE_ampa[2268] = new ampa(0.5)")
        h("Epop[28] netConn_projEE_ampa[2268] = new NetCon(&v(0.5), syn_projEE_ampa[2268], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2269: cell 28, seg 0 (0.5) [0.5 on Epop[28]] -> cell 29, seg 0 (0.5) [0.5 on Epop[29]], weight: 4.1363508E-4, delay 1.5
        h("Epop[29] syn_projEE_ampa[2269] = new ampa(0.5)")
        h("Epop[28] netConn_projEE_ampa[2269] = new NetCon(&v(0.5), syn_projEE_ampa[2269], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2270: cell 28, seg 0 (0.5) [0.5 on Epop[28]] -> cell 30, seg 0 (0.5) [0.5 on Epop[30]], weight: 4.1363508E-4, delay 1.5
        h("Epop[30] syn_projEE_ampa[2270] = new ampa(0.5)")
        h("Epop[28] netConn_projEE_ampa[2270] = new NetCon(&v(0.5), syn_projEE_ampa[2270], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2271: cell 28, seg 0 (0.5) [0.5 on Epop[28]] -> cell 31, seg 0 (0.5) [0.5 on Epop[31]], weight: 4.1363508E-4, delay 1.5
        h("Epop[31] syn_projEE_ampa[2271] = new ampa(0.5)")
        h("Epop[28] netConn_projEE_ampa[2271] = new NetCon(&v(0.5), syn_projEE_ampa[2271], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2272: cell 28, seg 0 (0.5) [0.5 on Epop[28]] -> cell 32, seg 0 (0.5) [0.5 on Epop[32]], weight: 4.1363508E-4, delay 1.5
        h("Epop[32] syn_projEE_ampa[2272] = new ampa(0.5)")
        h("Epop[28] netConn_projEE_ampa[2272] = new NetCon(&v(0.5), syn_projEE_ampa[2272], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2273: cell 28, seg 0 (0.5) [0.5 on Epop[28]] -> cell 33, seg 0 (0.5) [0.5 on Epop[33]], weight: 4.1363508E-4, delay 1.5
        h("Epop[33] syn_projEE_ampa[2273] = new ampa(0.5)")
        h("Epop[28] netConn_projEE_ampa[2273] = new NetCon(&v(0.5), syn_projEE_ampa[2273], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2274: cell 28, seg 0 (0.5) [0.5 on Epop[28]] -> cell 34, seg 0 (0.5) [0.5 on Epop[34]], weight: 4.1363508E-4, delay 1.5
        h("Epop[34] syn_projEE_ampa[2274] = new ampa(0.5)")
        h("Epop[28] netConn_projEE_ampa[2274] = new NetCon(&v(0.5), syn_projEE_ampa[2274], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2275: cell 28, seg 0 (0.5) [0.5 on Epop[28]] -> cell 35, seg 0 (0.5) [0.5 on Epop[35]], weight: 4.1363508E-4, delay 1.5
        h("Epop[35] syn_projEE_ampa[2275] = new ampa(0.5)")
        h("Epop[28] netConn_projEE_ampa[2275] = new NetCon(&v(0.5), syn_projEE_ampa[2275], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2276: cell 28, seg 0 (0.5) [0.5 on Epop[28]] -> cell 36, seg 0 (0.5) [0.5 on Epop[36]], weight: 4.1363508E-4, delay 1.5
        h("Epop[36] syn_projEE_ampa[2276] = new ampa(0.5)")
        h("Epop[28] netConn_projEE_ampa[2276] = new NetCon(&v(0.5), syn_projEE_ampa[2276], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2277: cell 28, seg 0 (0.5) [0.5 on Epop[28]] -> cell 37, seg 0 (0.5) [0.5 on Epop[37]], weight: 4.1363508E-4, delay 1.5
        h("Epop[37] syn_projEE_ampa[2277] = new ampa(0.5)")
        h("Epop[28] netConn_projEE_ampa[2277] = new NetCon(&v(0.5), syn_projEE_ampa[2277], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2278: cell 28, seg 0 (0.5) [0.5 on Epop[28]] -> cell 38, seg 0 (0.5) [0.5 on Epop[38]], weight: 4.1363508E-4, delay 1.5
        h("Epop[38] syn_projEE_ampa[2278] = new ampa(0.5)")
        h("Epop[28] netConn_projEE_ampa[2278] = new NetCon(&v(0.5), syn_projEE_ampa[2278], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2279: cell 28, seg 0 (0.5) [0.5 on Epop[28]] -> cell 39, seg 0 (0.5) [0.5 on Epop[39]], weight: 4.1363508E-4, delay 1.5
        h("Epop[39] syn_projEE_ampa[2279] = new ampa(0.5)")
        h("Epop[28] netConn_projEE_ampa[2279] = new NetCon(&v(0.5), syn_projEE_ampa[2279], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2280: cell 28, seg 0 (0.5) [0.5 on Epop[28]] -> cell 40, seg 0 (0.5) [0.5 on Epop[40]], weight: 4.1363508E-4, delay 1.5
        h("Epop[40] syn_projEE_ampa[2280] = new ampa(0.5)")
        h("Epop[28] netConn_projEE_ampa[2280] = new NetCon(&v(0.5), syn_projEE_ampa[2280], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2281: cell 28, seg 0 (0.5) [0.5 on Epop[28]] -> cell 41, seg 0 (0.5) [0.5 on Epop[41]], weight: 4.1363508E-4, delay 1.5
        h("Epop[41] syn_projEE_ampa[2281] = new ampa(0.5)")
        h("Epop[28] netConn_projEE_ampa[2281] = new NetCon(&v(0.5), syn_projEE_ampa[2281], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2282: cell 28, seg 0 (0.5) [0.5 on Epop[28]] -> cell 42, seg 0 (0.5) [0.5 on Epop[42]], weight: 4.1363508E-4, delay 1.5
        h("Epop[42] syn_projEE_ampa[2282] = new ampa(0.5)")
        h("Epop[28] netConn_projEE_ampa[2282] = new NetCon(&v(0.5), syn_projEE_ampa[2282], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2283: cell 28, seg 0 (0.5) [0.5 on Epop[28]] -> cell 43, seg 0 (0.5) [0.5 on Epop[43]], weight: 4.1363508E-4, delay 1.5
        h("Epop[43] syn_projEE_ampa[2283] = new ampa(0.5)")
        h("Epop[28] netConn_projEE_ampa[2283] = new NetCon(&v(0.5), syn_projEE_ampa[2283], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2284: cell 28, seg 0 (0.5) [0.5 on Epop[28]] -> cell 44, seg 0 (0.5) [0.5 on Epop[44]], weight: 4.1363508E-4, delay 1.5
        h("Epop[44] syn_projEE_ampa[2284] = new ampa(0.5)")
        h("Epop[28] netConn_projEE_ampa[2284] = new NetCon(&v(0.5), syn_projEE_ampa[2284], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2285: cell 28, seg 0 (0.5) [0.5 on Epop[28]] -> cell 45, seg 0 (0.5) [0.5 on Epop[45]], weight: 4.1363508E-4, delay 1.5
        h("Epop[45] syn_projEE_ampa[2285] = new ampa(0.5)")
        h("Epop[28] netConn_projEE_ampa[2285] = new NetCon(&v(0.5), syn_projEE_ampa[2285], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2286: cell 28, seg 0 (0.5) [0.5 on Epop[28]] -> cell 46, seg 0 (0.5) [0.5 on Epop[46]], weight: 4.1363508E-4, delay 1.5
        h("Epop[46] syn_projEE_ampa[2286] = new ampa(0.5)")
        h("Epop[28] netConn_projEE_ampa[2286] = new NetCon(&v(0.5), syn_projEE_ampa[2286], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2287: cell 28, seg 0 (0.5) [0.5 on Epop[28]] -> cell 47, seg 0 (0.5) [0.5 on Epop[47]], weight: 4.1363508E-4, delay 1.5
        h("Epop[47] syn_projEE_ampa[2287] = new ampa(0.5)")
        h("Epop[28] netConn_projEE_ampa[2287] = new NetCon(&v(0.5), syn_projEE_ampa[2287], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2288: cell 28, seg 0 (0.5) [0.5 on Epop[28]] -> cell 48, seg 0 (0.5) [0.5 on Epop[48]], weight: 4.1363508E-4, delay 1.5
        h("Epop[48] syn_projEE_ampa[2288] = new ampa(0.5)")
        h("Epop[28] netConn_projEE_ampa[2288] = new NetCon(&v(0.5), syn_projEE_ampa[2288], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2289: cell 28, seg 0 (0.5) [0.5 on Epop[28]] -> cell 49, seg 0 (0.5) [0.5 on Epop[49]], weight: 4.1363508E-4, delay 1.5
        h("Epop[49] syn_projEE_ampa[2289] = new ampa(0.5)")
        h("Epop[28] netConn_projEE_ampa[2289] = new NetCon(&v(0.5), syn_projEE_ampa[2289], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2290: cell 28, seg 0 (0.5) [0.5 on Epop[28]] -> cell 50, seg 0 (0.5) [0.5 on Epop[50]], weight: 4.1363508E-4, delay 1.5
        h("Epop[50] syn_projEE_ampa[2290] = new ampa(0.5)")
        h("Epop[28] netConn_projEE_ampa[2290] = new NetCon(&v(0.5), syn_projEE_ampa[2290], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2291: cell 28, seg 0 (0.5) [0.5 on Epop[28]] -> cell 51, seg 0 (0.5) [0.5 on Epop[51]], weight: 4.1363508E-4, delay 1.5
        h("Epop[51] syn_projEE_ampa[2291] = new ampa(0.5)")
        h("Epop[28] netConn_projEE_ampa[2291] = new NetCon(&v(0.5), syn_projEE_ampa[2291], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2292: cell 28, seg 0 (0.5) [0.5 on Epop[28]] -> cell 52, seg 0 (0.5) [0.5 on Epop[52]], weight: 4.1363508E-4, delay 1.5
        h("Epop[52] syn_projEE_ampa[2292] = new ampa(0.5)")
        h("Epop[28] netConn_projEE_ampa[2292] = new NetCon(&v(0.5), syn_projEE_ampa[2292], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2293: cell 28, seg 0 (0.5) [0.5 on Epop[28]] -> cell 53, seg 0 (0.5) [0.5 on Epop[53]], weight: 4.1363508E-4, delay 1.5
        h("Epop[53] syn_projEE_ampa[2293] = new ampa(0.5)")
        h("Epop[28] netConn_projEE_ampa[2293] = new NetCon(&v(0.5), syn_projEE_ampa[2293], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2294: cell 28, seg 0 (0.5) [0.5 on Epop[28]] -> cell 54, seg 0 (0.5) [0.5 on Epop[54]], weight: 4.1363508E-4, delay 1.5
        h("Epop[54] syn_projEE_ampa[2294] = new ampa(0.5)")
        h("Epop[28] netConn_projEE_ampa[2294] = new NetCon(&v(0.5), syn_projEE_ampa[2294], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2295: cell 28, seg 0 (0.5) [0.5 on Epop[28]] -> cell 55, seg 0 (0.5) [0.5 on Epop[55]], weight: 4.1363508E-4, delay 1.5
        h("Epop[55] syn_projEE_ampa[2295] = new ampa(0.5)")
        h("Epop[28] netConn_projEE_ampa[2295] = new NetCon(&v(0.5), syn_projEE_ampa[2295], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2296: cell 28, seg 0 (0.5) [0.5 on Epop[28]] -> cell 56, seg 0 (0.5) [0.5 on Epop[56]], weight: 4.1363508E-4, delay 1.5
        h("Epop[56] syn_projEE_ampa[2296] = new ampa(0.5)")
        h("Epop[28] netConn_projEE_ampa[2296] = new NetCon(&v(0.5), syn_projEE_ampa[2296], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2297: cell 28, seg 0 (0.5) [0.5 on Epop[28]] -> cell 57, seg 0 (0.5) [0.5 on Epop[57]], weight: 4.1363508E-4, delay 1.5
        h("Epop[57] syn_projEE_ampa[2297] = new ampa(0.5)")
        h("Epop[28] netConn_projEE_ampa[2297] = new NetCon(&v(0.5), syn_projEE_ampa[2297], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2298: cell 28, seg 0 (0.5) [0.5 on Epop[28]] -> cell 58, seg 0 (0.5) [0.5 on Epop[58]], weight: 4.1363508E-4, delay 1.5
        h("Epop[58] syn_projEE_ampa[2298] = new ampa(0.5)")
        h("Epop[28] netConn_projEE_ampa[2298] = new NetCon(&v(0.5), syn_projEE_ampa[2298], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2299: cell 28, seg 0 (0.5) [0.5 on Epop[28]] -> cell 59, seg 0 (0.5) [0.5 on Epop[59]], weight: 4.1363508E-4, delay 1.5
        h("Epop[59] syn_projEE_ampa[2299] = new ampa(0.5)")
        h("Epop[28] netConn_projEE_ampa[2299] = new NetCon(&v(0.5), syn_projEE_ampa[2299], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2300: cell 28, seg 0 (0.5) [0.5 on Epop[28]] -> cell 60, seg 0 (0.5) [0.5 on Epop[60]], weight: 4.1363508E-4, delay 1.5
        h("Epop[60] syn_projEE_ampa[2300] = new ampa(0.5)")
        h("Epop[28] netConn_projEE_ampa[2300] = new NetCon(&v(0.5), syn_projEE_ampa[2300], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2301: cell 28, seg 0 (0.5) [0.5 on Epop[28]] -> cell 61, seg 0 (0.5) [0.5 on Epop[61]], weight: 4.1363508E-4, delay 1.5
        h("Epop[61] syn_projEE_ampa[2301] = new ampa(0.5)")
        h("Epop[28] netConn_projEE_ampa[2301] = new NetCon(&v(0.5), syn_projEE_ampa[2301], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2302: cell 28, seg 0 (0.5) [0.5 on Epop[28]] -> cell 62, seg 0 (0.5) [0.5 on Epop[62]], weight: 4.1363508E-4, delay 1.5
        h("Epop[62] syn_projEE_ampa[2302] = new ampa(0.5)")
        h("Epop[28] netConn_projEE_ampa[2302] = new NetCon(&v(0.5), syn_projEE_ampa[2302], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2303: cell 28, seg 0 (0.5) [0.5 on Epop[28]] -> cell 63, seg 0 (0.5) [0.5 on Epop[63]], weight: 4.1363508E-4, delay 1.5
        h("Epop[63] syn_projEE_ampa[2303] = new ampa(0.5)")
        h("Epop[28] netConn_projEE_ampa[2303] = new NetCon(&v(0.5), syn_projEE_ampa[2303], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2304: cell 28, seg 0 (0.5) [0.5 on Epop[28]] -> cell 64, seg 0 (0.5) [0.5 on Epop[64]], weight: 4.1363508E-4, delay 1.5
        h("Epop[64] syn_projEE_ampa[2304] = new ampa(0.5)")
        h("Epop[28] netConn_projEE_ampa[2304] = new NetCon(&v(0.5), syn_projEE_ampa[2304], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2305: cell 28, seg 0 (0.5) [0.5 on Epop[28]] -> cell 65, seg 0 (0.5) [0.5 on Epop[65]], weight: 4.1363508E-4, delay 1.5
        h("Epop[65] syn_projEE_ampa[2305] = new ampa(0.5)")
        h("Epop[28] netConn_projEE_ampa[2305] = new NetCon(&v(0.5), syn_projEE_ampa[2305], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2306: cell 28, seg 0 (0.5) [0.5 on Epop[28]] -> cell 66, seg 0 (0.5) [0.5 on Epop[66]], weight: 4.1363508E-4, delay 1.5
        h("Epop[66] syn_projEE_ampa[2306] = new ampa(0.5)")
        h("Epop[28] netConn_projEE_ampa[2306] = new NetCon(&v(0.5), syn_projEE_ampa[2306], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2307: cell 28, seg 0 (0.5) [0.5 on Epop[28]] -> cell 67, seg 0 (0.5) [0.5 on Epop[67]], weight: 4.1363508E-4, delay 1.5
        h("Epop[67] syn_projEE_ampa[2307] = new ampa(0.5)")
        h("Epop[28] netConn_projEE_ampa[2307] = new NetCon(&v(0.5), syn_projEE_ampa[2307], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2308: cell 28, seg 0 (0.5) [0.5 on Epop[28]] -> cell 68, seg 0 (0.5) [0.5 on Epop[68]], weight: 4.1363508E-4, delay 1.5
        h("Epop[68] syn_projEE_ampa[2308] = new ampa(0.5)")
        h("Epop[28] netConn_projEE_ampa[2308] = new NetCon(&v(0.5), syn_projEE_ampa[2308], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2309: cell 28, seg 0 (0.5) [0.5 on Epop[28]] -> cell 69, seg 0 (0.5) [0.5 on Epop[69]], weight: 4.1363508E-4, delay 1.5
        h("Epop[69] syn_projEE_ampa[2309] = new ampa(0.5)")
        h("Epop[28] netConn_projEE_ampa[2309] = new NetCon(&v(0.5), syn_projEE_ampa[2309], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2310: cell 28, seg 0 (0.5) [0.5 on Epop[28]] -> cell 70, seg 0 (0.5) [0.5 on Epop[70]], weight: 4.1363508E-4, delay 1.5
        h("Epop[70] syn_projEE_ampa[2310] = new ampa(0.5)")
        h("Epop[28] netConn_projEE_ampa[2310] = new NetCon(&v(0.5), syn_projEE_ampa[2310], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2311: cell 28, seg 0 (0.5) [0.5 on Epop[28]] -> cell 71, seg 0 (0.5) [0.5 on Epop[71]], weight: 4.1363508E-4, delay 1.5
        h("Epop[71] syn_projEE_ampa[2311] = new ampa(0.5)")
        h("Epop[28] netConn_projEE_ampa[2311] = new NetCon(&v(0.5), syn_projEE_ampa[2311], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2312: cell 28, seg 0 (0.5) [0.5 on Epop[28]] -> cell 72, seg 0 (0.5) [0.5 on Epop[72]], weight: 4.1363508E-4, delay 1.5
        h("Epop[72] syn_projEE_ampa[2312] = new ampa(0.5)")
        h("Epop[28] netConn_projEE_ampa[2312] = new NetCon(&v(0.5), syn_projEE_ampa[2312], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2313: cell 28, seg 0 (0.5) [0.5 on Epop[28]] -> cell 73, seg 0 (0.5) [0.5 on Epop[73]], weight: 4.1363508E-4, delay 1.5
        h("Epop[73] syn_projEE_ampa[2313] = new ampa(0.5)")
        h("Epop[28] netConn_projEE_ampa[2313] = new NetCon(&v(0.5), syn_projEE_ampa[2313], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2314: cell 28, seg 0 (0.5) [0.5 on Epop[28]] -> cell 74, seg 0 (0.5) [0.5 on Epop[74]], weight: 4.1363508E-4, delay 1.5
        h("Epop[74] syn_projEE_ampa[2314] = new ampa(0.5)")
        h("Epop[28] netConn_projEE_ampa[2314] = new NetCon(&v(0.5), syn_projEE_ampa[2314], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2315: cell 28, seg 0 (0.5) [0.5 on Epop[28]] -> cell 75, seg 0 (0.5) [0.5 on Epop[75]], weight: 4.1363508E-4, delay 1.5
        h("Epop[75] syn_projEE_ampa[2315] = new ampa(0.5)")
        h("Epop[28] netConn_projEE_ampa[2315] = new NetCon(&v(0.5), syn_projEE_ampa[2315], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2316: cell 28, seg 0 (0.5) [0.5 on Epop[28]] -> cell 76, seg 0 (0.5) [0.5 on Epop[76]], weight: 4.1363508E-4, delay 1.5
        h("Epop[76] syn_projEE_ampa[2316] = new ampa(0.5)")
        h("Epop[28] netConn_projEE_ampa[2316] = new NetCon(&v(0.5), syn_projEE_ampa[2316], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2317: cell 28, seg 0 (0.5) [0.5 on Epop[28]] -> cell 77, seg 0 (0.5) [0.5 on Epop[77]], weight: 4.1363508E-4, delay 1.5
        h("Epop[77] syn_projEE_ampa[2317] = new ampa(0.5)")
        h("Epop[28] netConn_projEE_ampa[2317] = new NetCon(&v(0.5), syn_projEE_ampa[2317], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2318: cell 28, seg 0 (0.5) [0.5 on Epop[28]] -> cell 78, seg 0 (0.5) [0.5 on Epop[78]], weight: 4.1363508E-4, delay 1.5
        h("Epop[78] syn_projEE_ampa[2318] = new ampa(0.5)")
        h("Epop[28] netConn_projEE_ampa[2318] = new NetCon(&v(0.5), syn_projEE_ampa[2318], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2319: cell 28, seg 0 (0.5) [0.5 on Epop[28]] -> cell 79, seg 0 (0.5) [0.5 on Epop[79]], weight: 4.1363508E-4, delay 1.5
        h("Epop[79] syn_projEE_ampa[2319] = new ampa(0.5)")
        h("Epop[28] netConn_projEE_ampa[2319] = new NetCon(&v(0.5), syn_projEE_ampa[2319], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2320: cell 29, seg 0 (0.5) [0.5 on Epop[29]] -> cell 0, seg 0 (0.5) [0.5 on Epop[0]], weight: 4.1363508E-4, delay 1.5
        h("Epop[0] syn_projEE_ampa[2320] = new ampa(0.5)")
        h("Epop[29] netConn_projEE_ampa[2320] = new NetCon(&v(0.5), syn_projEE_ampa[2320], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2321: cell 29, seg 0 (0.5) [0.5 on Epop[29]] -> cell 1, seg 0 (0.5) [0.5 on Epop[1]], weight: 4.1363508E-4, delay 1.5
        h("Epop[1] syn_projEE_ampa[2321] = new ampa(0.5)")
        h("Epop[29] netConn_projEE_ampa[2321] = new NetCon(&v(0.5), syn_projEE_ampa[2321], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2322: cell 29, seg 0 (0.5) [0.5 on Epop[29]] -> cell 2, seg 0 (0.5) [0.5 on Epop[2]], weight: 4.1363508E-4, delay 1.5
        h("Epop[2] syn_projEE_ampa[2322] = new ampa(0.5)")
        h("Epop[29] netConn_projEE_ampa[2322] = new NetCon(&v(0.5), syn_projEE_ampa[2322], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2323: cell 29, seg 0 (0.5) [0.5 on Epop[29]] -> cell 3, seg 0 (0.5) [0.5 on Epop[3]], weight: 4.1363508E-4, delay 1.5
        h("Epop[3] syn_projEE_ampa[2323] = new ampa(0.5)")
        h("Epop[29] netConn_projEE_ampa[2323] = new NetCon(&v(0.5), syn_projEE_ampa[2323], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2324: cell 29, seg 0 (0.5) [0.5 on Epop[29]] -> cell 4, seg 0 (0.5) [0.5 on Epop[4]], weight: 4.1363508E-4, delay 1.5
        h("Epop[4] syn_projEE_ampa[2324] = new ampa(0.5)")
        h("Epop[29] netConn_projEE_ampa[2324] = new NetCon(&v(0.5), syn_projEE_ampa[2324], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2325: cell 29, seg 0 (0.5) [0.5 on Epop[29]] -> cell 5, seg 0 (0.5) [0.5 on Epop[5]], weight: 4.1363508E-4, delay 1.5
        h("Epop[5] syn_projEE_ampa[2325] = new ampa(0.5)")
        h("Epop[29] netConn_projEE_ampa[2325] = new NetCon(&v(0.5), syn_projEE_ampa[2325], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2326: cell 29, seg 0 (0.5) [0.5 on Epop[29]] -> cell 6, seg 0 (0.5) [0.5 on Epop[6]], weight: 4.1363508E-4, delay 1.5
        h("Epop[6] syn_projEE_ampa[2326] = new ampa(0.5)")
        h("Epop[29] netConn_projEE_ampa[2326] = new NetCon(&v(0.5), syn_projEE_ampa[2326], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2327: cell 29, seg 0 (0.5) [0.5 on Epop[29]] -> cell 7, seg 0 (0.5) [0.5 on Epop[7]], weight: 4.1363508E-4, delay 1.5
        h("Epop[7] syn_projEE_ampa[2327] = new ampa(0.5)")
        h("Epop[29] netConn_projEE_ampa[2327] = new NetCon(&v(0.5), syn_projEE_ampa[2327], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2328: cell 29, seg 0 (0.5) [0.5 on Epop[29]] -> cell 8, seg 0 (0.5) [0.5 on Epop[8]], weight: 4.1363508E-4, delay 1.5
        h("Epop[8] syn_projEE_ampa[2328] = new ampa(0.5)")
        h("Epop[29] netConn_projEE_ampa[2328] = new NetCon(&v(0.5), syn_projEE_ampa[2328], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2329: cell 29, seg 0 (0.5) [0.5 on Epop[29]] -> cell 9, seg 0 (0.5) [0.5 on Epop[9]], weight: 4.1363508E-4, delay 1.5
        h("Epop[9] syn_projEE_ampa[2329] = new ampa(0.5)")
        h("Epop[29] netConn_projEE_ampa[2329] = new NetCon(&v(0.5), syn_projEE_ampa[2329], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2330: cell 29, seg 0 (0.5) [0.5 on Epop[29]] -> cell 10, seg 0 (0.5) [0.5 on Epop[10]], weight: 4.1363508E-4, delay 1.5
        h("Epop[10] syn_projEE_ampa[2330] = new ampa(0.5)")
        h("Epop[29] netConn_projEE_ampa[2330] = new NetCon(&v(0.5), syn_projEE_ampa[2330], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2331: cell 29, seg 0 (0.5) [0.5 on Epop[29]] -> cell 11, seg 0 (0.5) [0.5 on Epop[11]], weight: 4.1363508E-4, delay 1.5
        h("Epop[11] syn_projEE_ampa[2331] = new ampa(0.5)")
        h("Epop[29] netConn_projEE_ampa[2331] = new NetCon(&v(0.5), syn_projEE_ampa[2331], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2332: cell 29, seg 0 (0.5) [0.5 on Epop[29]] -> cell 12, seg 0 (0.5) [0.5 on Epop[12]], weight: 4.1363508E-4, delay 1.5
        h("Epop[12] syn_projEE_ampa[2332] = new ampa(0.5)")
        h("Epop[29] netConn_projEE_ampa[2332] = new NetCon(&v(0.5), syn_projEE_ampa[2332], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2333: cell 29, seg 0 (0.5) [0.5 on Epop[29]] -> cell 13, seg 0 (0.5) [0.5 on Epop[13]], weight: 4.1363508E-4, delay 1.5
        h("Epop[13] syn_projEE_ampa[2333] = new ampa(0.5)")
        h("Epop[29] netConn_projEE_ampa[2333] = new NetCon(&v(0.5), syn_projEE_ampa[2333], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2334: cell 29, seg 0 (0.5) [0.5 on Epop[29]] -> cell 14, seg 0 (0.5) [0.5 on Epop[14]], weight: 4.1363508E-4, delay 1.5
        h("Epop[14] syn_projEE_ampa[2334] = new ampa(0.5)")
        h("Epop[29] netConn_projEE_ampa[2334] = new NetCon(&v(0.5), syn_projEE_ampa[2334], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2335: cell 29, seg 0 (0.5) [0.5 on Epop[29]] -> cell 15, seg 0 (0.5) [0.5 on Epop[15]], weight: 4.1363508E-4, delay 1.5
        h("Epop[15] syn_projEE_ampa[2335] = new ampa(0.5)")
        h("Epop[29] netConn_projEE_ampa[2335] = new NetCon(&v(0.5), syn_projEE_ampa[2335], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2336: cell 29, seg 0 (0.5) [0.5 on Epop[29]] -> cell 16, seg 0 (0.5) [0.5 on Epop[16]], weight: 4.1363508E-4, delay 1.5
        h("Epop[16] syn_projEE_ampa[2336] = new ampa(0.5)")
        h("Epop[29] netConn_projEE_ampa[2336] = new NetCon(&v(0.5), syn_projEE_ampa[2336], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2337: cell 29, seg 0 (0.5) [0.5 on Epop[29]] -> cell 17, seg 0 (0.5) [0.5 on Epop[17]], weight: 4.1363508E-4, delay 1.5
        h("Epop[17] syn_projEE_ampa[2337] = new ampa(0.5)")
        h("Epop[29] netConn_projEE_ampa[2337] = new NetCon(&v(0.5), syn_projEE_ampa[2337], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2338: cell 29, seg 0 (0.5) [0.5 on Epop[29]] -> cell 18, seg 0 (0.5) [0.5 on Epop[18]], weight: 4.1363508E-4, delay 1.5
        h("Epop[18] syn_projEE_ampa[2338] = new ampa(0.5)")
        h("Epop[29] netConn_projEE_ampa[2338] = new NetCon(&v(0.5), syn_projEE_ampa[2338], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2339: cell 29, seg 0 (0.5) [0.5 on Epop[29]] -> cell 19, seg 0 (0.5) [0.5 on Epop[19]], weight: 4.1363508E-4, delay 1.5
        h("Epop[19] syn_projEE_ampa[2339] = new ampa(0.5)")
        h("Epop[29] netConn_projEE_ampa[2339] = new NetCon(&v(0.5), syn_projEE_ampa[2339], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2340: cell 29, seg 0 (0.5) [0.5 on Epop[29]] -> cell 20, seg 0 (0.5) [0.5 on Epop[20]], weight: 4.1363508E-4, delay 1.5
        h("Epop[20] syn_projEE_ampa[2340] = new ampa(0.5)")
        h("Epop[29] netConn_projEE_ampa[2340] = new NetCon(&v(0.5), syn_projEE_ampa[2340], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2341: cell 29, seg 0 (0.5) [0.5 on Epop[29]] -> cell 21, seg 0 (0.5) [0.5 on Epop[21]], weight: 4.1363508E-4, delay 1.5
        h("Epop[21] syn_projEE_ampa[2341] = new ampa(0.5)")
        h("Epop[29] netConn_projEE_ampa[2341] = new NetCon(&v(0.5), syn_projEE_ampa[2341], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2342: cell 29, seg 0 (0.5) [0.5 on Epop[29]] -> cell 22, seg 0 (0.5) [0.5 on Epop[22]], weight: 4.1363508E-4, delay 1.5
        h("Epop[22] syn_projEE_ampa[2342] = new ampa(0.5)")
        h("Epop[29] netConn_projEE_ampa[2342] = new NetCon(&v(0.5), syn_projEE_ampa[2342], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2343: cell 29, seg 0 (0.5) [0.5 on Epop[29]] -> cell 23, seg 0 (0.5) [0.5 on Epop[23]], weight: 4.1363508E-4, delay 1.5
        h("Epop[23] syn_projEE_ampa[2343] = new ampa(0.5)")
        h("Epop[29] netConn_projEE_ampa[2343] = new NetCon(&v(0.5), syn_projEE_ampa[2343], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2344: cell 29, seg 0 (0.5) [0.5 on Epop[29]] -> cell 24, seg 0 (0.5) [0.5 on Epop[24]], weight: 4.1363508E-4, delay 1.5
        h("Epop[24] syn_projEE_ampa[2344] = new ampa(0.5)")
        h("Epop[29] netConn_projEE_ampa[2344] = new NetCon(&v(0.5), syn_projEE_ampa[2344], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2345: cell 29, seg 0 (0.5) [0.5 on Epop[29]] -> cell 25, seg 0 (0.5) [0.5 on Epop[25]], weight: 4.1363508E-4, delay 1.5
        h("Epop[25] syn_projEE_ampa[2345] = new ampa(0.5)")
        h("Epop[29] netConn_projEE_ampa[2345] = new NetCon(&v(0.5), syn_projEE_ampa[2345], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2346: cell 29, seg 0 (0.5) [0.5 on Epop[29]] -> cell 26, seg 0 (0.5) [0.5 on Epop[26]], weight: 4.1363508E-4, delay 1.5
        h("Epop[26] syn_projEE_ampa[2346] = new ampa(0.5)")
        h("Epop[29] netConn_projEE_ampa[2346] = new NetCon(&v(0.5), syn_projEE_ampa[2346], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2347: cell 29, seg 0 (0.5) [0.5 on Epop[29]] -> cell 27, seg 0 (0.5) [0.5 on Epop[27]], weight: 4.1363508E-4, delay 1.5
        h("Epop[27] syn_projEE_ampa[2347] = new ampa(0.5)")
        h("Epop[29] netConn_projEE_ampa[2347] = new NetCon(&v(0.5), syn_projEE_ampa[2347], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2348: cell 29, seg 0 (0.5) [0.5 on Epop[29]] -> cell 28, seg 0 (0.5) [0.5 on Epop[28]], weight: 4.1363508E-4, delay 1.5
        h("Epop[28] syn_projEE_ampa[2348] = new ampa(0.5)")
        h("Epop[29] netConn_projEE_ampa[2348] = new NetCon(&v(0.5), syn_projEE_ampa[2348], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2349: cell 29, seg 0 (0.5) [0.5 on Epop[29]] -> cell 29, seg 0 (0.5) [0.5 on Epop[29]], weight: 4.1363508E-4, delay 1.5
        h("Epop[29] syn_projEE_ampa[2349] = new ampa(0.5)")
        h("Epop[29] netConn_projEE_ampa[2349] = new NetCon(&v(0.5), syn_projEE_ampa[2349], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2350: cell 29, seg 0 (0.5) [0.5 on Epop[29]] -> cell 30, seg 0 (0.5) [0.5 on Epop[30]], weight: 4.1363508E-4, delay 1.5
        h("Epop[30] syn_projEE_ampa[2350] = new ampa(0.5)")
        h("Epop[29] netConn_projEE_ampa[2350] = new NetCon(&v(0.5), syn_projEE_ampa[2350], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2351: cell 29, seg 0 (0.5) [0.5 on Epop[29]] -> cell 31, seg 0 (0.5) [0.5 on Epop[31]], weight: 4.1363508E-4, delay 1.5
        h("Epop[31] syn_projEE_ampa[2351] = new ampa(0.5)")
        h("Epop[29] netConn_projEE_ampa[2351] = new NetCon(&v(0.5), syn_projEE_ampa[2351], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2352: cell 29, seg 0 (0.5) [0.5 on Epop[29]] -> cell 32, seg 0 (0.5) [0.5 on Epop[32]], weight: 4.1363508E-4, delay 1.5
        h("Epop[32] syn_projEE_ampa[2352] = new ampa(0.5)")
        h("Epop[29] netConn_projEE_ampa[2352] = new NetCon(&v(0.5), syn_projEE_ampa[2352], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2353: cell 29, seg 0 (0.5) [0.5 on Epop[29]] -> cell 33, seg 0 (0.5) [0.5 on Epop[33]], weight: 4.1363508E-4, delay 1.5
        h("Epop[33] syn_projEE_ampa[2353] = new ampa(0.5)")
        h("Epop[29] netConn_projEE_ampa[2353] = new NetCon(&v(0.5), syn_projEE_ampa[2353], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2354: cell 29, seg 0 (0.5) [0.5 on Epop[29]] -> cell 34, seg 0 (0.5) [0.5 on Epop[34]], weight: 4.1363508E-4, delay 1.5
        h("Epop[34] syn_projEE_ampa[2354] = new ampa(0.5)")
        h("Epop[29] netConn_projEE_ampa[2354] = new NetCon(&v(0.5), syn_projEE_ampa[2354], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2355: cell 29, seg 0 (0.5) [0.5 on Epop[29]] -> cell 35, seg 0 (0.5) [0.5 on Epop[35]], weight: 4.1363508E-4, delay 1.5
        h("Epop[35] syn_projEE_ampa[2355] = new ampa(0.5)")
        h("Epop[29] netConn_projEE_ampa[2355] = new NetCon(&v(0.5), syn_projEE_ampa[2355], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2356: cell 29, seg 0 (0.5) [0.5 on Epop[29]] -> cell 36, seg 0 (0.5) [0.5 on Epop[36]], weight: 4.1363508E-4, delay 1.5
        h("Epop[36] syn_projEE_ampa[2356] = new ampa(0.5)")
        h("Epop[29] netConn_projEE_ampa[2356] = new NetCon(&v(0.5), syn_projEE_ampa[2356], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2357: cell 29, seg 0 (0.5) [0.5 on Epop[29]] -> cell 37, seg 0 (0.5) [0.5 on Epop[37]], weight: 4.1363508E-4, delay 1.5
        h("Epop[37] syn_projEE_ampa[2357] = new ampa(0.5)")
        h("Epop[29] netConn_projEE_ampa[2357] = new NetCon(&v(0.5), syn_projEE_ampa[2357], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2358: cell 29, seg 0 (0.5) [0.5 on Epop[29]] -> cell 38, seg 0 (0.5) [0.5 on Epop[38]], weight: 4.1363508E-4, delay 1.5
        h("Epop[38] syn_projEE_ampa[2358] = new ampa(0.5)")
        h("Epop[29] netConn_projEE_ampa[2358] = new NetCon(&v(0.5), syn_projEE_ampa[2358], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2359: cell 29, seg 0 (0.5) [0.5 on Epop[29]] -> cell 39, seg 0 (0.5) [0.5 on Epop[39]], weight: 4.1363508E-4, delay 1.5
        h("Epop[39] syn_projEE_ampa[2359] = new ampa(0.5)")
        h("Epop[29] netConn_projEE_ampa[2359] = new NetCon(&v(0.5), syn_projEE_ampa[2359], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2360: cell 29, seg 0 (0.5) [0.5 on Epop[29]] -> cell 40, seg 0 (0.5) [0.5 on Epop[40]], weight: 4.1363508E-4, delay 1.5
        h("Epop[40] syn_projEE_ampa[2360] = new ampa(0.5)")
        h("Epop[29] netConn_projEE_ampa[2360] = new NetCon(&v(0.5), syn_projEE_ampa[2360], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2361: cell 29, seg 0 (0.5) [0.5 on Epop[29]] -> cell 41, seg 0 (0.5) [0.5 on Epop[41]], weight: 4.1363508E-4, delay 1.5
        h("Epop[41] syn_projEE_ampa[2361] = new ampa(0.5)")
        h("Epop[29] netConn_projEE_ampa[2361] = new NetCon(&v(0.5), syn_projEE_ampa[2361], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2362: cell 29, seg 0 (0.5) [0.5 on Epop[29]] -> cell 42, seg 0 (0.5) [0.5 on Epop[42]], weight: 4.1363508E-4, delay 1.5
        h("Epop[42] syn_projEE_ampa[2362] = new ampa(0.5)")
        h("Epop[29] netConn_projEE_ampa[2362] = new NetCon(&v(0.5), syn_projEE_ampa[2362], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2363: cell 29, seg 0 (0.5) [0.5 on Epop[29]] -> cell 43, seg 0 (0.5) [0.5 on Epop[43]], weight: 4.1363508E-4, delay 1.5
        h("Epop[43] syn_projEE_ampa[2363] = new ampa(0.5)")
        h("Epop[29] netConn_projEE_ampa[2363] = new NetCon(&v(0.5), syn_projEE_ampa[2363], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2364: cell 29, seg 0 (0.5) [0.5 on Epop[29]] -> cell 44, seg 0 (0.5) [0.5 on Epop[44]], weight: 4.1363508E-4, delay 1.5
        h("Epop[44] syn_projEE_ampa[2364] = new ampa(0.5)")
        h("Epop[29] netConn_projEE_ampa[2364] = new NetCon(&v(0.5), syn_projEE_ampa[2364], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2365: cell 29, seg 0 (0.5) [0.5 on Epop[29]] -> cell 45, seg 0 (0.5) [0.5 on Epop[45]], weight: 4.1363508E-4, delay 1.5
        h("Epop[45] syn_projEE_ampa[2365] = new ampa(0.5)")
        h("Epop[29] netConn_projEE_ampa[2365] = new NetCon(&v(0.5), syn_projEE_ampa[2365], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2366: cell 29, seg 0 (0.5) [0.5 on Epop[29]] -> cell 46, seg 0 (0.5) [0.5 on Epop[46]], weight: 4.1363508E-4, delay 1.5
        h("Epop[46] syn_projEE_ampa[2366] = new ampa(0.5)")
        h("Epop[29] netConn_projEE_ampa[2366] = new NetCon(&v(0.5), syn_projEE_ampa[2366], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2367: cell 29, seg 0 (0.5) [0.5 on Epop[29]] -> cell 47, seg 0 (0.5) [0.5 on Epop[47]], weight: 4.1363508E-4, delay 1.5
        h("Epop[47] syn_projEE_ampa[2367] = new ampa(0.5)")
        h("Epop[29] netConn_projEE_ampa[2367] = new NetCon(&v(0.5), syn_projEE_ampa[2367], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2368: cell 29, seg 0 (0.5) [0.5 on Epop[29]] -> cell 48, seg 0 (0.5) [0.5 on Epop[48]], weight: 4.1363508E-4, delay 1.5
        h("Epop[48] syn_projEE_ampa[2368] = new ampa(0.5)")
        h("Epop[29] netConn_projEE_ampa[2368] = new NetCon(&v(0.5), syn_projEE_ampa[2368], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2369: cell 29, seg 0 (0.5) [0.5 on Epop[29]] -> cell 49, seg 0 (0.5) [0.5 on Epop[49]], weight: 4.1363508E-4, delay 1.5
        h("Epop[49] syn_projEE_ampa[2369] = new ampa(0.5)")
        h("Epop[29] netConn_projEE_ampa[2369] = new NetCon(&v(0.5), syn_projEE_ampa[2369], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2370: cell 29, seg 0 (0.5) [0.5 on Epop[29]] -> cell 50, seg 0 (0.5) [0.5 on Epop[50]], weight: 4.1363508E-4, delay 1.5
        h("Epop[50] syn_projEE_ampa[2370] = new ampa(0.5)")
        h("Epop[29] netConn_projEE_ampa[2370] = new NetCon(&v(0.5), syn_projEE_ampa[2370], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2371: cell 29, seg 0 (0.5) [0.5 on Epop[29]] -> cell 51, seg 0 (0.5) [0.5 on Epop[51]], weight: 4.1363508E-4, delay 1.5
        h("Epop[51] syn_projEE_ampa[2371] = new ampa(0.5)")
        h("Epop[29] netConn_projEE_ampa[2371] = new NetCon(&v(0.5), syn_projEE_ampa[2371], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2372: cell 29, seg 0 (0.5) [0.5 on Epop[29]] -> cell 52, seg 0 (0.5) [0.5 on Epop[52]], weight: 4.1363508E-4, delay 1.5
        h("Epop[52] syn_projEE_ampa[2372] = new ampa(0.5)")
        h("Epop[29] netConn_projEE_ampa[2372] = new NetCon(&v(0.5), syn_projEE_ampa[2372], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2373: cell 29, seg 0 (0.5) [0.5 on Epop[29]] -> cell 53, seg 0 (0.5) [0.5 on Epop[53]], weight: 4.1363508E-4, delay 1.5
        h("Epop[53] syn_projEE_ampa[2373] = new ampa(0.5)")
        h("Epop[29] netConn_projEE_ampa[2373] = new NetCon(&v(0.5), syn_projEE_ampa[2373], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2374: cell 29, seg 0 (0.5) [0.5 on Epop[29]] -> cell 54, seg 0 (0.5) [0.5 on Epop[54]], weight: 4.1363508E-4, delay 1.5
        h("Epop[54] syn_projEE_ampa[2374] = new ampa(0.5)")
        h("Epop[29] netConn_projEE_ampa[2374] = new NetCon(&v(0.5), syn_projEE_ampa[2374], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2375: cell 29, seg 0 (0.5) [0.5 on Epop[29]] -> cell 55, seg 0 (0.5) [0.5 on Epop[55]], weight: 4.1363508E-4, delay 1.5
        h("Epop[55] syn_projEE_ampa[2375] = new ampa(0.5)")
        h("Epop[29] netConn_projEE_ampa[2375] = new NetCon(&v(0.5), syn_projEE_ampa[2375], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2376: cell 29, seg 0 (0.5) [0.5 on Epop[29]] -> cell 56, seg 0 (0.5) [0.5 on Epop[56]], weight: 4.1363508E-4, delay 1.5
        h("Epop[56] syn_projEE_ampa[2376] = new ampa(0.5)")
        h("Epop[29] netConn_projEE_ampa[2376] = new NetCon(&v(0.5), syn_projEE_ampa[2376], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2377: cell 29, seg 0 (0.5) [0.5 on Epop[29]] -> cell 57, seg 0 (0.5) [0.5 on Epop[57]], weight: 4.1363508E-4, delay 1.5
        h("Epop[57] syn_projEE_ampa[2377] = new ampa(0.5)")
        h("Epop[29] netConn_projEE_ampa[2377] = new NetCon(&v(0.5), syn_projEE_ampa[2377], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2378: cell 29, seg 0 (0.5) [0.5 on Epop[29]] -> cell 58, seg 0 (0.5) [0.5 on Epop[58]], weight: 4.1363508E-4, delay 1.5
        h("Epop[58] syn_projEE_ampa[2378] = new ampa(0.5)")
        h("Epop[29] netConn_projEE_ampa[2378] = new NetCon(&v(0.5), syn_projEE_ampa[2378], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2379: cell 29, seg 0 (0.5) [0.5 on Epop[29]] -> cell 59, seg 0 (0.5) [0.5 on Epop[59]], weight: 4.1363508E-4, delay 1.5
        h("Epop[59] syn_projEE_ampa[2379] = new ampa(0.5)")
        h("Epop[29] netConn_projEE_ampa[2379] = new NetCon(&v(0.5), syn_projEE_ampa[2379], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2380: cell 29, seg 0 (0.5) [0.5 on Epop[29]] -> cell 60, seg 0 (0.5) [0.5 on Epop[60]], weight: 4.1363508E-4, delay 1.5
        h("Epop[60] syn_projEE_ampa[2380] = new ampa(0.5)")
        h("Epop[29] netConn_projEE_ampa[2380] = new NetCon(&v(0.5), syn_projEE_ampa[2380], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2381: cell 29, seg 0 (0.5) [0.5 on Epop[29]] -> cell 61, seg 0 (0.5) [0.5 on Epop[61]], weight: 4.1363508E-4, delay 1.5
        h("Epop[61] syn_projEE_ampa[2381] = new ampa(0.5)")
        h("Epop[29] netConn_projEE_ampa[2381] = new NetCon(&v(0.5), syn_projEE_ampa[2381], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2382: cell 29, seg 0 (0.5) [0.5 on Epop[29]] -> cell 62, seg 0 (0.5) [0.5 on Epop[62]], weight: 4.1363508E-4, delay 1.5
        h("Epop[62] syn_projEE_ampa[2382] = new ampa(0.5)")
        h("Epop[29] netConn_projEE_ampa[2382] = new NetCon(&v(0.5), syn_projEE_ampa[2382], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2383: cell 29, seg 0 (0.5) [0.5 on Epop[29]] -> cell 63, seg 0 (0.5) [0.5 on Epop[63]], weight: 4.1363508E-4, delay 1.5
        h("Epop[63] syn_projEE_ampa[2383] = new ampa(0.5)")
        h("Epop[29] netConn_projEE_ampa[2383] = new NetCon(&v(0.5), syn_projEE_ampa[2383], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2384: cell 29, seg 0 (0.5) [0.5 on Epop[29]] -> cell 64, seg 0 (0.5) [0.5 on Epop[64]], weight: 4.1363508E-4, delay 1.5
        h("Epop[64] syn_projEE_ampa[2384] = new ampa(0.5)")
        h("Epop[29] netConn_projEE_ampa[2384] = new NetCon(&v(0.5), syn_projEE_ampa[2384], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2385: cell 29, seg 0 (0.5) [0.5 on Epop[29]] -> cell 65, seg 0 (0.5) [0.5 on Epop[65]], weight: 4.1363508E-4, delay 1.5
        h("Epop[65] syn_projEE_ampa[2385] = new ampa(0.5)")
        h("Epop[29] netConn_projEE_ampa[2385] = new NetCon(&v(0.5), syn_projEE_ampa[2385], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2386: cell 29, seg 0 (0.5) [0.5 on Epop[29]] -> cell 66, seg 0 (0.5) [0.5 on Epop[66]], weight: 4.1363508E-4, delay 1.5
        h("Epop[66] syn_projEE_ampa[2386] = new ampa(0.5)")
        h("Epop[29] netConn_projEE_ampa[2386] = new NetCon(&v(0.5), syn_projEE_ampa[2386], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2387: cell 29, seg 0 (0.5) [0.5 on Epop[29]] -> cell 67, seg 0 (0.5) [0.5 on Epop[67]], weight: 4.1363508E-4, delay 1.5
        h("Epop[67] syn_projEE_ampa[2387] = new ampa(0.5)")
        h("Epop[29] netConn_projEE_ampa[2387] = new NetCon(&v(0.5), syn_projEE_ampa[2387], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2388: cell 29, seg 0 (0.5) [0.5 on Epop[29]] -> cell 68, seg 0 (0.5) [0.5 on Epop[68]], weight: 4.1363508E-4, delay 1.5
        h("Epop[68] syn_projEE_ampa[2388] = new ampa(0.5)")
        h("Epop[29] netConn_projEE_ampa[2388] = new NetCon(&v(0.5), syn_projEE_ampa[2388], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2389: cell 29, seg 0 (0.5) [0.5 on Epop[29]] -> cell 69, seg 0 (0.5) [0.5 on Epop[69]], weight: 4.1363508E-4, delay 1.5
        h("Epop[69] syn_projEE_ampa[2389] = new ampa(0.5)")
        h("Epop[29] netConn_projEE_ampa[2389] = new NetCon(&v(0.5), syn_projEE_ampa[2389], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2390: cell 29, seg 0 (0.5) [0.5 on Epop[29]] -> cell 70, seg 0 (0.5) [0.5 on Epop[70]], weight: 4.1363508E-4, delay 1.5
        h("Epop[70] syn_projEE_ampa[2390] = new ampa(0.5)")
        h("Epop[29] netConn_projEE_ampa[2390] = new NetCon(&v(0.5), syn_projEE_ampa[2390], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2391: cell 29, seg 0 (0.5) [0.5 on Epop[29]] -> cell 71, seg 0 (0.5) [0.5 on Epop[71]], weight: 4.1363508E-4, delay 1.5
        h("Epop[71] syn_projEE_ampa[2391] = new ampa(0.5)")
        h("Epop[29] netConn_projEE_ampa[2391] = new NetCon(&v(0.5), syn_projEE_ampa[2391], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2392: cell 29, seg 0 (0.5) [0.5 on Epop[29]] -> cell 72, seg 0 (0.5) [0.5 on Epop[72]], weight: 4.1363508E-4, delay 1.5
        h("Epop[72] syn_projEE_ampa[2392] = new ampa(0.5)")
        h("Epop[29] netConn_projEE_ampa[2392] = new NetCon(&v(0.5), syn_projEE_ampa[2392], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2393: cell 29, seg 0 (0.5) [0.5 on Epop[29]] -> cell 73, seg 0 (0.5) [0.5 on Epop[73]], weight: 4.1363508E-4, delay 1.5
        h("Epop[73] syn_projEE_ampa[2393] = new ampa(0.5)")
        h("Epop[29] netConn_projEE_ampa[2393] = new NetCon(&v(0.5), syn_projEE_ampa[2393], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2394: cell 29, seg 0 (0.5) [0.5 on Epop[29]] -> cell 74, seg 0 (0.5) [0.5 on Epop[74]], weight: 4.1363508E-4, delay 1.5
        h("Epop[74] syn_projEE_ampa[2394] = new ampa(0.5)")
        h("Epop[29] netConn_projEE_ampa[2394] = new NetCon(&v(0.5), syn_projEE_ampa[2394], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2395: cell 29, seg 0 (0.5) [0.5 on Epop[29]] -> cell 75, seg 0 (0.5) [0.5 on Epop[75]], weight: 4.1363508E-4, delay 1.5
        h("Epop[75] syn_projEE_ampa[2395] = new ampa(0.5)")
        h("Epop[29] netConn_projEE_ampa[2395] = new NetCon(&v(0.5), syn_projEE_ampa[2395], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2396: cell 29, seg 0 (0.5) [0.5 on Epop[29]] -> cell 76, seg 0 (0.5) [0.5 on Epop[76]], weight: 4.1363508E-4, delay 1.5
        h("Epop[76] syn_projEE_ampa[2396] = new ampa(0.5)")
        h("Epop[29] netConn_projEE_ampa[2396] = new NetCon(&v(0.5), syn_projEE_ampa[2396], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2397: cell 29, seg 0 (0.5) [0.5 on Epop[29]] -> cell 77, seg 0 (0.5) [0.5 on Epop[77]], weight: 4.1363508E-4, delay 1.5
        h("Epop[77] syn_projEE_ampa[2397] = new ampa(0.5)")
        h("Epop[29] netConn_projEE_ampa[2397] = new NetCon(&v(0.5), syn_projEE_ampa[2397], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2398: cell 29, seg 0 (0.5) [0.5 on Epop[29]] -> cell 78, seg 0 (0.5) [0.5 on Epop[78]], weight: 4.1363508E-4, delay 1.5
        h("Epop[78] syn_projEE_ampa[2398] = new ampa(0.5)")
        h("Epop[29] netConn_projEE_ampa[2398] = new NetCon(&v(0.5), syn_projEE_ampa[2398], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2399: cell 29, seg 0 (0.5) [0.5 on Epop[29]] -> cell 79, seg 0 (0.5) [0.5 on Epop[79]], weight: 4.1363508E-4, delay 1.5
        h("Epop[79] syn_projEE_ampa[2399] = new ampa(0.5)")
        h("Epop[29] netConn_projEE_ampa[2399] = new NetCon(&v(0.5), syn_projEE_ampa[2399], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2400: cell 30, seg 0 (0.5) [0.5 on Epop[30]] -> cell 0, seg 0 (0.5) [0.5 on Epop[0]], weight: 4.1363508E-4, delay 1.5
        h("Epop[0] syn_projEE_ampa[2400] = new ampa(0.5)")
        h("Epop[30] netConn_projEE_ampa[2400] = new NetCon(&v(0.5), syn_projEE_ampa[2400], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2401: cell 30, seg 0 (0.5) [0.5 on Epop[30]] -> cell 1, seg 0 (0.5) [0.5 on Epop[1]], weight: 4.1363508E-4, delay 1.5
        h("Epop[1] syn_projEE_ampa[2401] = new ampa(0.5)")
        h("Epop[30] netConn_projEE_ampa[2401] = new NetCon(&v(0.5), syn_projEE_ampa[2401], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2402: cell 30, seg 0 (0.5) [0.5 on Epop[30]] -> cell 2, seg 0 (0.5) [0.5 on Epop[2]], weight: 4.1363508E-4, delay 1.5
        h("Epop[2] syn_projEE_ampa[2402] = new ampa(0.5)")
        h("Epop[30] netConn_projEE_ampa[2402] = new NetCon(&v(0.5), syn_projEE_ampa[2402], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2403: cell 30, seg 0 (0.5) [0.5 on Epop[30]] -> cell 3, seg 0 (0.5) [0.5 on Epop[3]], weight: 4.1363508E-4, delay 1.5
        h("Epop[3] syn_projEE_ampa[2403] = new ampa(0.5)")
        h("Epop[30] netConn_projEE_ampa[2403] = new NetCon(&v(0.5), syn_projEE_ampa[2403], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2404: cell 30, seg 0 (0.5) [0.5 on Epop[30]] -> cell 4, seg 0 (0.5) [0.5 on Epop[4]], weight: 4.1363508E-4, delay 1.5
        h("Epop[4] syn_projEE_ampa[2404] = new ampa(0.5)")
        h("Epop[30] netConn_projEE_ampa[2404] = new NetCon(&v(0.5), syn_projEE_ampa[2404], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2405: cell 30, seg 0 (0.5) [0.5 on Epop[30]] -> cell 5, seg 0 (0.5) [0.5 on Epop[5]], weight: 4.1363508E-4, delay 1.5
        h("Epop[5] syn_projEE_ampa[2405] = new ampa(0.5)")
        h("Epop[30] netConn_projEE_ampa[2405] = new NetCon(&v(0.5), syn_projEE_ampa[2405], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2406: cell 30, seg 0 (0.5) [0.5 on Epop[30]] -> cell 6, seg 0 (0.5) [0.5 on Epop[6]], weight: 4.1363508E-4, delay 1.5
        h("Epop[6] syn_projEE_ampa[2406] = new ampa(0.5)")
        h("Epop[30] netConn_projEE_ampa[2406] = new NetCon(&v(0.5), syn_projEE_ampa[2406], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2407: cell 30, seg 0 (0.5) [0.5 on Epop[30]] -> cell 7, seg 0 (0.5) [0.5 on Epop[7]], weight: 4.1363508E-4, delay 1.5
        h("Epop[7] syn_projEE_ampa[2407] = new ampa(0.5)")
        h("Epop[30] netConn_projEE_ampa[2407] = new NetCon(&v(0.5), syn_projEE_ampa[2407], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2408: cell 30, seg 0 (0.5) [0.5 on Epop[30]] -> cell 8, seg 0 (0.5) [0.5 on Epop[8]], weight: 4.1363508E-4, delay 1.5
        h("Epop[8] syn_projEE_ampa[2408] = new ampa(0.5)")
        h("Epop[30] netConn_projEE_ampa[2408] = new NetCon(&v(0.5), syn_projEE_ampa[2408], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2409: cell 30, seg 0 (0.5) [0.5 on Epop[30]] -> cell 9, seg 0 (0.5) [0.5 on Epop[9]], weight: 4.1363508E-4, delay 1.5
        h("Epop[9] syn_projEE_ampa[2409] = new ampa(0.5)")
        h("Epop[30] netConn_projEE_ampa[2409] = new NetCon(&v(0.5), syn_projEE_ampa[2409], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2410: cell 30, seg 0 (0.5) [0.5 on Epop[30]] -> cell 10, seg 0 (0.5) [0.5 on Epop[10]], weight: 4.1363508E-4, delay 1.5
        h("Epop[10] syn_projEE_ampa[2410] = new ampa(0.5)")
        h("Epop[30] netConn_projEE_ampa[2410] = new NetCon(&v(0.5), syn_projEE_ampa[2410], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2411: cell 30, seg 0 (0.5) [0.5 on Epop[30]] -> cell 11, seg 0 (0.5) [0.5 on Epop[11]], weight: 4.1363508E-4, delay 1.5
        h("Epop[11] syn_projEE_ampa[2411] = new ampa(0.5)")
        h("Epop[30] netConn_projEE_ampa[2411] = new NetCon(&v(0.5), syn_projEE_ampa[2411], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2412: cell 30, seg 0 (0.5) [0.5 on Epop[30]] -> cell 12, seg 0 (0.5) [0.5 on Epop[12]], weight: 4.1363508E-4, delay 1.5
        h("Epop[12] syn_projEE_ampa[2412] = new ampa(0.5)")
        h("Epop[30] netConn_projEE_ampa[2412] = new NetCon(&v(0.5), syn_projEE_ampa[2412], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2413: cell 30, seg 0 (0.5) [0.5 on Epop[30]] -> cell 13, seg 0 (0.5) [0.5 on Epop[13]], weight: 4.1363508E-4, delay 1.5
        h("Epop[13] syn_projEE_ampa[2413] = new ampa(0.5)")
        h("Epop[30] netConn_projEE_ampa[2413] = new NetCon(&v(0.5), syn_projEE_ampa[2413], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2414: cell 30, seg 0 (0.5) [0.5 on Epop[30]] -> cell 14, seg 0 (0.5) [0.5 on Epop[14]], weight: 4.1363508E-4, delay 1.5
        h("Epop[14] syn_projEE_ampa[2414] = new ampa(0.5)")
        h("Epop[30] netConn_projEE_ampa[2414] = new NetCon(&v(0.5), syn_projEE_ampa[2414], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2415: cell 30, seg 0 (0.5) [0.5 on Epop[30]] -> cell 15, seg 0 (0.5) [0.5 on Epop[15]], weight: 4.1363508E-4, delay 1.5
        h("Epop[15] syn_projEE_ampa[2415] = new ampa(0.5)")
        h("Epop[30] netConn_projEE_ampa[2415] = new NetCon(&v(0.5), syn_projEE_ampa[2415], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2416: cell 30, seg 0 (0.5) [0.5 on Epop[30]] -> cell 16, seg 0 (0.5) [0.5 on Epop[16]], weight: 4.1363508E-4, delay 1.5
        h("Epop[16] syn_projEE_ampa[2416] = new ampa(0.5)")
        h("Epop[30] netConn_projEE_ampa[2416] = new NetCon(&v(0.5), syn_projEE_ampa[2416], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2417: cell 30, seg 0 (0.5) [0.5 on Epop[30]] -> cell 17, seg 0 (0.5) [0.5 on Epop[17]], weight: 4.1363508E-4, delay 1.5
        h("Epop[17] syn_projEE_ampa[2417] = new ampa(0.5)")
        h("Epop[30] netConn_projEE_ampa[2417] = new NetCon(&v(0.5), syn_projEE_ampa[2417], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2418: cell 30, seg 0 (0.5) [0.5 on Epop[30]] -> cell 18, seg 0 (0.5) [0.5 on Epop[18]], weight: 4.1363508E-4, delay 1.5
        h("Epop[18] syn_projEE_ampa[2418] = new ampa(0.5)")
        h("Epop[30] netConn_projEE_ampa[2418] = new NetCon(&v(0.5), syn_projEE_ampa[2418], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2419: cell 30, seg 0 (0.5) [0.5 on Epop[30]] -> cell 19, seg 0 (0.5) [0.5 on Epop[19]], weight: 4.1363508E-4, delay 1.5
        h("Epop[19] syn_projEE_ampa[2419] = new ampa(0.5)")
        h("Epop[30] netConn_projEE_ampa[2419] = new NetCon(&v(0.5), syn_projEE_ampa[2419], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2420: cell 30, seg 0 (0.5) [0.5 on Epop[30]] -> cell 20, seg 0 (0.5) [0.5 on Epop[20]], weight: 4.1363508E-4, delay 1.5
        h("Epop[20] syn_projEE_ampa[2420] = new ampa(0.5)")
        h("Epop[30] netConn_projEE_ampa[2420] = new NetCon(&v(0.5), syn_projEE_ampa[2420], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2421: cell 30, seg 0 (0.5) [0.5 on Epop[30]] -> cell 21, seg 0 (0.5) [0.5 on Epop[21]], weight: 4.1363508E-4, delay 1.5
        h("Epop[21] syn_projEE_ampa[2421] = new ampa(0.5)")
        h("Epop[30] netConn_projEE_ampa[2421] = new NetCon(&v(0.5), syn_projEE_ampa[2421], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2422: cell 30, seg 0 (0.5) [0.5 on Epop[30]] -> cell 22, seg 0 (0.5) [0.5 on Epop[22]], weight: 4.1363508E-4, delay 1.5
        h("Epop[22] syn_projEE_ampa[2422] = new ampa(0.5)")
        h("Epop[30] netConn_projEE_ampa[2422] = new NetCon(&v(0.5), syn_projEE_ampa[2422], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2423: cell 30, seg 0 (0.5) [0.5 on Epop[30]] -> cell 23, seg 0 (0.5) [0.5 on Epop[23]], weight: 4.1363508E-4, delay 1.5
        h("Epop[23] syn_projEE_ampa[2423] = new ampa(0.5)")
        h("Epop[30] netConn_projEE_ampa[2423] = new NetCon(&v(0.5), syn_projEE_ampa[2423], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2424: cell 30, seg 0 (0.5) [0.5 on Epop[30]] -> cell 24, seg 0 (0.5) [0.5 on Epop[24]], weight: 4.1363508E-4, delay 1.5
        h("Epop[24] syn_projEE_ampa[2424] = new ampa(0.5)")
        h("Epop[30] netConn_projEE_ampa[2424] = new NetCon(&v(0.5), syn_projEE_ampa[2424], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2425: cell 30, seg 0 (0.5) [0.5 on Epop[30]] -> cell 25, seg 0 (0.5) [0.5 on Epop[25]], weight: 4.1363508E-4, delay 1.5
        h("Epop[25] syn_projEE_ampa[2425] = new ampa(0.5)")
        h("Epop[30] netConn_projEE_ampa[2425] = new NetCon(&v(0.5), syn_projEE_ampa[2425], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2426: cell 30, seg 0 (0.5) [0.5 on Epop[30]] -> cell 26, seg 0 (0.5) [0.5 on Epop[26]], weight: 4.1363508E-4, delay 1.5
        h("Epop[26] syn_projEE_ampa[2426] = new ampa(0.5)")
        h("Epop[30] netConn_projEE_ampa[2426] = new NetCon(&v(0.5), syn_projEE_ampa[2426], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2427: cell 30, seg 0 (0.5) [0.5 on Epop[30]] -> cell 27, seg 0 (0.5) [0.5 on Epop[27]], weight: 4.1363508E-4, delay 1.5
        h("Epop[27] syn_projEE_ampa[2427] = new ampa(0.5)")
        h("Epop[30] netConn_projEE_ampa[2427] = new NetCon(&v(0.5), syn_projEE_ampa[2427], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2428: cell 30, seg 0 (0.5) [0.5 on Epop[30]] -> cell 28, seg 0 (0.5) [0.5 on Epop[28]], weight: 4.1363508E-4, delay 1.5
        h("Epop[28] syn_projEE_ampa[2428] = new ampa(0.5)")
        h("Epop[30] netConn_projEE_ampa[2428] = new NetCon(&v(0.5), syn_projEE_ampa[2428], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2429: cell 30, seg 0 (0.5) [0.5 on Epop[30]] -> cell 29, seg 0 (0.5) [0.5 on Epop[29]], weight: 4.1363508E-4, delay 1.5
        h("Epop[29] syn_projEE_ampa[2429] = new ampa(0.5)")
        h("Epop[30] netConn_projEE_ampa[2429] = new NetCon(&v(0.5), syn_projEE_ampa[2429], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2430: cell 30, seg 0 (0.5) [0.5 on Epop[30]] -> cell 30, seg 0 (0.5) [0.5 on Epop[30]], weight: 4.1363508E-4, delay 1.5
        h("Epop[30] syn_projEE_ampa[2430] = new ampa(0.5)")
        h("Epop[30] netConn_projEE_ampa[2430] = new NetCon(&v(0.5), syn_projEE_ampa[2430], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2431: cell 30, seg 0 (0.5) [0.5 on Epop[30]] -> cell 31, seg 0 (0.5) [0.5 on Epop[31]], weight: 4.1363508E-4, delay 1.5
        h("Epop[31] syn_projEE_ampa[2431] = new ampa(0.5)")
        h("Epop[30] netConn_projEE_ampa[2431] = new NetCon(&v(0.5), syn_projEE_ampa[2431], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2432: cell 30, seg 0 (0.5) [0.5 on Epop[30]] -> cell 32, seg 0 (0.5) [0.5 on Epop[32]], weight: 4.1363508E-4, delay 1.5
        h("Epop[32] syn_projEE_ampa[2432] = new ampa(0.5)")
        h("Epop[30] netConn_projEE_ampa[2432] = new NetCon(&v(0.5), syn_projEE_ampa[2432], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2433: cell 30, seg 0 (0.5) [0.5 on Epop[30]] -> cell 33, seg 0 (0.5) [0.5 on Epop[33]], weight: 4.1363508E-4, delay 1.5
        h("Epop[33] syn_projEE_ampa[2433] = new ampa(0.5)")
        h("Epop[30] netConn_projEE_ampa[2433] = new NetCon(&v(0.5), syn_projEE_ampa[2433], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2434: cell 30, seg 0 (0.5) [0.5 on Epop[30]] -> cell 34, seg 0 (0.5) [0.5 on Epop[34]], weight: 4.1363508E-4, delay 1.5
        h("Epop[34] syn_projEE_ampa[2434] = new ampa(0.5)")
        h("Epop[30] netConn_projEE_ampa[2434] = new NetCon(&v(0.5), syn_projEE_ampa[2434], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2435: cell 30, seg 0 (0.5) [0.5 on Epop[30]] -> cell 35, seg 0 (0.5) [0.5 on Epop[35]], weight: 4.1363508E-4, delay 1.5
        h("Epop[35] syn_projEE_ampa[2435] = new ampa(0.5)")
        h("Epop[30] netConn_projEE_ampa[2435] = new NetCon(&v(0.5), syn_projEE_ampa[2435], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2436: cell 30, seg 0 (0.5) [0.5 on Epop[30]] -> cell 36, seg 0 (0.5) [0.5 on Epop[36]], weight: 4.1363508E-4, delay 1.5
        h("Epop[36] syn_projEE_ampa[2436] = new ampa(0.5)")
        h("Epop[30] netConn_projEE_ampa[2436] = new NetCon(&v(0.5), syn_projEE_ampa[2436], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2437: cell 30, seg 0 (0.5) [0.5 on Epop[30]] -> cell 37, seg 0 (0.5) [0.5 on Epop[37]], weight: 4.1363508E-4, delay 1.5
        h("Epop[37] syn_projEE_ampa[2437] = new ampa(0.5)")
        h("Epop[30] netConn_projEE_ampa[2437] = new NetCon(&v(0.5), syn_projEE_ampa[2437], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2438: cell 30, seg 0 (0.5) [0.5 on Epop[30]] -> cell 38, seg 0 (0.5) [0.5 on Epop[38]], weight: 4.1363508E-4, delay 1.5
        h("Epop[38] syn_projEE_ampa[2438] = new ampa(0.5)")
        h("Epop[30] netConn_projEE_ampa[2438] = new NetCon(&v(0.5), syn_projEE_ampa[2438], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2439: cell 30, seg 0 (0.5) [0.5 on Epop[30]] -> cell 39, seg 0 (0.5) [0.5 on Epop[39]], weight: 4.1363508E-4, delay 1.5
        h("Epop[39] syn_projEE_ampa[2439] = new ampa(0.5)")
        h("Epop[30] netConn_projEE_ampa[2439] = new NetCon(&v(0.5), syn_projEE_ampa[2439], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2440: cell 30, seg 0 (0.5) [0.5 on Epop[30]] -> cell 40, seg 0 (0.5) [0.5 on Epop[40]], weight: 4.1363508E-4, delay 1.5
        h("Epop[40] syn_projEE_ampa[2440] = new ampa(0.5)")
        h("Epop[30] netConn_projEE_ampa[2440] = new NetCon(&v(0.5), syn_projEE_ampa[2440], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2441: cell 30, seg 0 (0.5) [0.5 on Epop[30]] -> cell 41, seg 0 (0.5) [0.5 on Epop[41]], weight: 4.1363508E-4, delay 1.5
        h("Epop[41] syn_projEE_ampa[2441] = new ampa(0.5)")
        h("Epop[30] netConn_projEE_ampa[2441] = new NetCon(&v(0.5), syn_projEE_ampa[2441], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2442: cell 30, seg 0 (0.5) [0.5 on Epop[30]] -> cell 42, seg 0 (0.5) [0.5 on Epop[42]], weight: 4.1363508E-4, delay 1.5
        h("Epop[42] syn_projEE_ampa[2442] = new ampa(0.5)")
        h("Epop[30] netConn_projEE_ampa[2442] = new NetCon(&v(0.5), syn_projEE_ampa[2442], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2443: cell 30, seg 0 (0.5) [0.5 on Epop[30]] -> cell 43, seg 0 (0.5) [0.5 on Epop[43]], weight: 4.1363508E-4, delay 1.5
        h("Epop[43] syn_projEE_ampa[2443] = new ampa(0.5)")
        h("Epop[30] netConn_projEE_ampa[2443] = new NetCon(&v(0.5), syn_projEE_ampa[2443], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2444: cell 30, seg 0 (0.5) [0.5 on Epop[30]] -> cell 44, seg 0 (0.5) [0.5 on Epop[44]], weight: 4.1363508E-4, delay 1.5
        h("Epop[44] syn_projEE_ampa[2444] = new ampa(0.5)")
        h("Epop[30] netConn_projEE_ampa[2444] = new NetCon(&v(0.5), syn_projEE_ampa[2444], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2445: cell 30, seg 0 (0.5) [0.5 on Epop[30]] -> cell 45, seg 0 (0.5) [0.5 on Epop[45]], weight: 4.1363508E-4, delay 1.5
        h("Epop[45] syn_projEE_ampa[2445] = new ampa(0.5)")
        h("Epop[30] netConn_projEE_ampa[2445] = new NetCon(&v(0.5), syn_projEE_ampa[2445], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2446: cell 30, seg 0 (0.5) [0.5 on Epop[30]] -> cell 46, seg 0 (0.5) [0.5 on Epop[46]], weight: 4.1363508E-4, delay 1.5
        h("Epop[46] syn_projEE_ampa[2446] = new ampa(0.5)")
        h("Epop[30] netConn_projEE_ampa[2446] = new NetCon(&v(0.5), syn_projEE_ampa[2446], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2447: cell 30, seg 0 (0.5) [0.5 on Epop[30]] -> cell 47, seg 0 (0.5) [0.5 on Epop[47]], weight: 4.1363508E-4, delay 1.5
        h("Epop[47] syn_projEE_ampa[2447] = new ampa(0.5)")
        h("Epop[30] netConn_projEE_ampa[2447] = new NetCon(&v(0.5), syn_projEE_ampa[2447], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2448: cell 30, seg 0 (0.5) [0.5 on Epop[30]] -> cell 48, seg 0 (0.5) [0.5 on Epop[48]], weight: 4.1363508E-4, delay 1.5
        h("Epop[48] syn_projEE_ampa[2448] = new ampa(0.5)")
        h("Epop[30] netConn_projEE_ampa[2448] = new NetCon(&v(0.5), syn_projEE_ampa[2448], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2449: cell 30, seg 0 (0.5) [0.5 on Epop[30]] -> cell 49, seg 0 (0.5) [0.5 on Epop[49]], weight: 4.1363508E-4, delay 1.5
        h("Epop[49] syn_projEE_ampa[2449] = new ampa(0.5)")
        h("Epop[30] netConn_projEE_ampa[2449] = new NetCon(&v(0.5), syn_projEE_ampa[2449], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2450: cell 30, seg 0 (0.5) [0.5 on Epop[30]] -> cell 50, seg 0 (0.5) [0.5 on Epop[50]], weight: 4.1363508E-4, delay 1.5
        h("Epop[50] syn_projEE_ampa[2450] = new ampa(0.5)")
        h("Epop[30] netConn_projEE_ampa[2450] = new NetCon(&v(0.5), syn_projEE_ampa[2450], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2451: cell 30, seg 0 (0.5) [0.5 on Epop[30]] -> cell 51, seg 0 (0.5) [0.5 on Epop[51]], weight: 4.1363508E-4, delay 1.5
        h("Epop[51] syn_projEE_ampa[2451] = new ampa(0.5)")
        h("Epop[30] netConn_projEE_ampa[2451] = new NetCon(&v(0.5), syn_projEE_ampa[2451], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2452: cell 30, seg 0 (0.5) [0.5 on Epop[30]] -> cell 52, seg 0 (0.5) [0.5 on Epop[52]], weight: 4.1363508E-4, delay 1.5
        h("Epop[52] syn_projEE_ampa[2452] = new ampa(0.5)")
        h("Epop[30] netConn_projEE_ampa[2452] = new NetCon(&v(0.5), syn_projEE_ampa[2452], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2453: cell 30, seg 0 (0.5) [0.5 on Epop[30]] -> cell 53, seg 0 (0.5) [0.5 on Epop[53]], weight: 4.1363508E-4, delay 1.5
        h("Epop[53] syn_projEE_ampa[2453] = new ampa(0.5)")
        h("Epop[30] netConn_projEE_ampa[2453] = new NetCon(&v(0.5), syn_projEE_ampa[2453], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2454: cell 30, seg 0 (0.5) [0.5 on Epop[30]] -> cell 54, seg 0 (0.5) [0.5 on Epop[54]], weight: 4.1363508E-4, delay 1.5
        h("Epop[54] syn_projEE_ampa[2454] = new ampa(0.5)")
        h("Epop[30] netConn_projEE_ampa[2454] = new NetCon(&v(0.5), syn_projEE_ampa[2454], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2455: cell 30, seg 0 (0.5) [0.5 on Epop[30]] -> cell 55, seg 0 (0.5) [0.5 on Epop[55]], weight: 4.1363508E-4, delay 1.5
        h("Epop[55] syn_projEE_ampa[2455] = new ampa(0.5)")
        h("Epop[30] netConn_projEE_ampa[2455] = new NetCon(&v(0.5), syn_projEE_ampa[2455], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2456: cell 30, seg 0 (0.5) [0.5 on Epop[30]] -> cell 56, seg 0 (0.5) [0.5 on Epop[56]], weight: 4.1363508E-4, delay 1.5
        h("Epop[56] syn_projEE_ampa[2456] = new ampa(0.5)")
        h("Epop[30] netConn_projEE_ampa[2456] = new NetCon(&v(0.5), syn_projEE_ampa[2456], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2457: cell 30, seg 0 (0.5) [0.5 on Epop[30]] -> cell 57, seg 0 (0.5) [0.5 on Epop[57]], weight: 4.1363508E-4, delay 1.5
        h("Epop[57] syn_projEE_ampa[2457] = new ampa(0.5)")
        h("Epop[30] netConn_projEE_ampa[2457] = new NetCon(&v(0.5), syn_projEE_ampa[2457], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2458: cell 30, seg 0 (0.5) [0.5 on Epop[30]] -> cell 58, seg 0 (0.5) [0.5 on Epop[58]], weight: 4.1363508E-4, delay 1.5
        h("Epop[58] syn_projEE_ampa[2458] = new ampa(0.5)")
        h("Epop[30] netConn_projEE_ampa[2458] = new NetCon(&v(0.5), syn_projEE_ampa[2458], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2459: cell 30, seg 0 (0.5) [0.5 on Epop[30]] -> cell 59, seg 0 (0.5) [0.5 on Epop[59]], weight: 4.1363508E-4, delay 1.5
        h("Epop[59] syn_projEE_ampa[2459] = new ampa(0.5)")
        h("Epop[30] netConn_projEE_ampa[2459] = new NetCon(&v(0.5), syn_projEE_ampa[2459], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2460: cell 30, seg 0 (0.5) [0.5 on Epop[30]] -> cell 60, seg 0 (0.5) [0.5 on Epop[60]], weight: 4.1363508E-4, delay 1.5
        h("Epop[60] syn_projEE_ampa[2460] = new ampa(0.5)")
        h("Epop[30] netConn_projEE_ampa[2460] = new NetCon(&v(0.5), syn_projEE_ampa[2460], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2461: cell 30, seg 0 (0.5) [0.5 on Epop[30]] -> cell 61, seg 0 (0.5) [0.5 on Epop[61]], weight: 4.1363508E-4, delay 1.5
        h("Epop[61] syn_projEE_ampa[2461] = new ampa(0.5)")
        h("Epop[30] netConn_projEE_ampa[2461] = new NetCon(&v(0.5), syn_projEE_ampa[2461], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2462: cell 30, seg 0 (0.5) [0.5 on Epop[30]] -> cell 62, seg 0 (0.5) [0.5 on Epop[62]], weight: 4.1363508E-4, delay 1.5
        h("Epop[62] syn_projEE_ampa[2462] = new ampa(0.5)")
        h("Epop[30] netConn_projEE_ampa[2462] = new NetCon(&v(0.5), syn_projEE_ampa[2462], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2463: cell 30, seg 0 (0.5) [0.5 on Epop[30]] -> cell 63, seg 0 (0.5) [0.5 on Epop[63]], weight: 4.1363508E-4, delay 1.5
        h("Epop[63] syn_projEE_ampa[2463] = new ampa(0.5)")
        h("Epop[30] netConn_projEE_ampa[2463] = new NetCon(&v(0.5), syn_projEE_ampa[2463], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2464: cell 30, seg 0 (0.5) [0.5 on Epop[30]] -> cell 64, seg 0 (0.5) [0.5 on Epop[64]], weight: 4.1363508E-4, delay 1.5
        h("Epop[64] syn_projEE_ampa[2464] = new ampa(0.5)")
        h("Epop[30] netConn_projEE_ampa[2464] = new NetCon(&v(0.5), syn_projEE_ampa[2464], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2465: cell 30, seg 0 (0.5) [0.5 on Epop[30]] -> cell 65, seg 0 (0.5) [0.5 on Epop[65]], weight: 4.1363508E-4, delay 1.5
        h("Epop[65] syn_projEE_ampa[2465] = new ampa(0.5)")
        h("Epop[30] netConn_projEE_ampa[2465] = new NetCon(&v(0.5), syn_projEE_ampa[2465], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2466: cell 30, seg 0 (0.5) [0.5 on Epop[30]] -> cell 66, seg 0 (0.5) [0.5 on Epop[66]], weight: 4.1363508E-4, delay 1.5
        h("Epop[66] syn_projEE_ampa[2466] = new ampa(0.5)")
        h("Epop[30] netConn_projEE_ampa[2466] = new NetCon(&v(0.5), syn_projEE_ampa[2466], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2467: cell 30, seg 0 (0.5) [0.5 on Epop[30]] -> cell 67, seg 0 (0.5) [0.5 on Epop[67]], weight: 4.1363508E-4, delay 1.5
        h("Epop[67] syn_projEE_ampa[2467] = new ampa(0.5)")
        h("Epop[30] netConn_projEE_ampa[2467] = new NetCon(&v(0.5), syn_projEE_ampa[2467], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2468: cell 30, seg 0 (0.5) [0.5 on Epop[30]] -> cell 68, seg 0 (0.5) [0.5 on Epop[68]], weight: 4.1363508E-4, delay 1.5
        h("Epop[68] syn_projEE_ampa[2468] = new ampa(0.5)")
        h("Epop[30] netConn_projEE_ampa[2468] = new NetCon(&v(0.5), syn_projEE_ampa[2468], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2469: cell 30, seg 0 (0.5) [0.5 on Epop[30]] -> cell 69, seg 0 (0.5) [0.5 on Epop[69]], weight: 4.1363508E-4, delay 1.5
        h("Epop[69] syn_projEE_ampa[2469] = new ampa(0.5)")
        h("Epop[30] netConn_projEE_ampa[2469] = new NetCon(&v(0.5), syn_projEE_ampa[2469], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2470: cell 30, seg 0 (0.5) [0.5 on Epop[30]] -> cell 70, seg 0 (0.5) [0.5 on Epop[70]], weight: 4.1363508E-4, delay 1.5
        h("Epop[70] syn_projEE_ampa[2470] = new ampa(0.5)")
        h("Epop[30] netConn_projEE_ampa[2470] = new NetCon(&v(0.5), syn_projEE_ampa[2470], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2471: cell 30, seg 0 (0.5) [0.5 on Epop[30]] -> cell 71, seg 0 (0.5) [0.5 on Epop[71]], weight: 4.1363508E-4, delay 1.5
        h("Epop[71] syn_projEE_ampa[2471] = new ampa(0.5)")
        h("Epop[30] netConn_projEE_ampa[2471] = new NetCon(&v(0.5), syn_projEE_ampa[2471], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2472: cell 30, seg 0 (0.5) [0.5 on Epop[30]] -> cell 72, seg 0 (0.5) [0.5 on Epop[72]], weight: 4.1363508E-4, delay 1.5
        h("Epop[72] syn_projEE_ampa[2472] = new ampa(0.5)")
        h("Epop[30] netConn_projEE_ampa[2472] = new NetCon(&v(0.5), syn_projEE_ampa[2472], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2473: cell 30, seg 0 (0.5) [0.5 on Epop[30]] -> cell 73, seg 0 (0.5) [0.5 on Epop[73]], weight: 4.1363508E-4, delay 1.5
        h("Epop[73] syn_projEE_ampa[2473] = new ampa(0.5)")
        h("Epop[30] netConn_projEE_ampa[2473] = new NetCon(&v(0.5), syn_projEE_ampa[2473], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2474: cell 30, seg 0 (0.5) [0.5 on Epop[30]] -> cell 74, seg 0 (0.5) [0.5 on Epop[74]], weight: 4.1363508E-4, delay 1.5
        h("Epop[74] syn_projEE_ampa[2474] = new ampa(0.5)")
        h("Epop[30] netConn_projEE_ampa[2474] = new NetCon(&v(0.5), syn_projEE_ampa[2474], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2475: cell 30, seg 0 (0.5) [0.5 on Epop[30]] -> cell 75, seg 0 (0.5) [0.5 on Epop[75]], weight: 4.1363508E-4, delay 1.5
        h("Epop[75] syn_projEE_ampa[2475] = new ampa(0.5)")
        h("Epop[30] netConn_projEE_ampa[2475] = new NetCon(&v(0.5), syn_projEE_ampa[2475], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2476: cell 30, seg 0 (0.5) [0.5 on Epop[30]] -> cell 76, seg 0 (0.5) [0.5 on Epop[76]], weight: 4.1363508E-4, delay 1.5
        h("Epop[76] syn_projEE_ampa[2476] = new ampa(0.5)")
        h("Epop[30] netConn_projEE_ampa[2476] = new NetCon(&v(0.5), syn_projEE_ampa[2476], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2477: cell 30, seg 0 (0.5) [0.5 on Epop[30]] -> cell 77, seg 0 (0.5) [0.5 on Epop[77]], weight: 4.1363508E-4, delay 1.5
        h("Epop[77] syn_projEE_ampa[2477] = new ampa(0.5)")
        h("Epop[30] netConn_projEE_ampa[2477] = new NetCon(&v(0.5), syn_projEE_ampa[2477], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2478: cell 30, seg 0 (0.5) [0.5 on Epop[30]] -> cell 78, seg 0 (0.5) [0.5 on Epop[78]], weight: 4.1363508E-4, delay 1.5
        h("Epop[78] syn_projEE_ampa[2478] = new ampa(0.5)")
        h("Epop[30] netConn_projEE_ampa[2478] = new NetCon(&v(0.5), syn_projEE_ampa[2478], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2479: cell 30, seg 0 (0.5) [0.5 on Epop[30]] -> cell 79, seg 0 (0.5) [0.5 on Epop[79]], weight: 4.1363508E-4, delay 1.5
        h("Epop[79] syn_projEE_ampa[2479] = new ampa(0.5)")
        h("Epop[30] netConn_projEE_ampa[2479] = new NetCon(&v(0.5), syn_projEE_ampa[2479], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2480: cell 31, seg 0 (0.5) [0.5 on Epop[31]] -> cell 0, seg 0 (0.5) [0.5 on Epop[0]], weight: 4.1363508E-4, delay 1.5
        h("Epop[0] syn_projEE_ampa[2480] = new ampa(0.5)")
        h("Epop[31] netConn_projEE_ampa[2480] = new NetCon(&v(0.5), syn_projEE_ampa[2480], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2481: cell 31, seg 0 (0.5) [0.5 on Epop[31]] -> cell 1, seg 0 (0.5) [0.5 on Epop[1]], weight: 4.1363508E-4, delay 1.5
        h("Epop[1] syn_projEE_ampa[2481] = new ampa(0.5)")
        h("Epop[31] netConn_projEE_ampa[2481] = new NetCon(&v(0.5), syn_projEE_ampa[2481], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2482: cell 31, seg 0 (0.5) [0.5 on Epop[31]] -> cell 2, seg 0 (0.5) [0.5 on Epop[2]], weight: 4.1363508E-4, delay 1.5
        h("Epop[2] syn_projEE_ampa[2482] = new ampa(0.5)")
        h("Epop[31] netConn_projEE_ampa[2482] = new NetCon(&v(0.5), syn_projEE_ampa[2482], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2483: cell 31, seg 0 (0.5) [0.5 on Epop[31]] -> cell 3, seg 0 (0.5) [0.5 on Epop[3]], weight: 4.1363508E-4, delay 1.5
        h("Epop[3] syn_projEE_ampa[2483] = new ampa(0.5)")
        h("Epop[31] netConn_projEE_ampa[2483] = new NetCon(&v(0.5), syn_projEE_ampa[2483], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2484: cell 31, seg 0 (0.5) [0.5 on Epop[31]] -> cell 4, seg 0 (0.5) [0.5 on Epop[4]], weight: 4.1363508E-4, delay 1.5
        h("Epop[4] syn_projEE_ampa[2484] = new ampa(0.5)")
        h("Epop[31] netConn_projEE_ampa[2484] = new NetCon(&v(0.5), syn_projEE_ampa[2484], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2485: cell 31, seg 0 (0.5) [0.5 on Epop[31]] -> cell 5, seg 0 (0.5) [0.5 on Epop[5]], weight: 4.1363508E-4, delay 1.5
        h("Epop[5] syn_projEE_ampa[2485] = new ampa(0.5)")
        h("Epop[31] netConn_projEE_ampa[2485] = new NetCon(&v(0.5), syn_projEE_ampa[2485], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2486: cell 31, seg 0 (0.5) [0.5 on Epop[31]] -> cell 6, seg 0 (0.5) [0.5 on Epop[6]], weight: 4.1363508E-4, delay 1.5
        h("Epop[6] syn_projEE_ampa[2486] = new ampa(0.5)")
        h("Epop[31] netConn_projEE_ampa[2486] = new NetCon(&v(0.5), syn_projEE_ampa[2486], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2487: cell 31, seg 0 (0.5) [0.5 on Epop[31]] -> cell 7, seg 0 (0.5) [0.5 on Epop[7]], weight: 4.1363508E-4, delay 1.5
        h("Epop[7] syn_projEE_ampa[2487] = new ampa(0.5)")
        h("Epop[31] netConn_projEE_ampa[2487] = new NetCon(&v(0.5), syn_projEE_ampa[2487], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2488: cell 31, seg 0 (0.5) [0.5 on Epop[31]] -> cell 8, seg 0 (0.5) [0.5 on Epop[8]], weight: 4.1363508E-4, delay 1.5
        h("Epop[8] syn_projEE_ampa[2488] = new ampa(0.5)")
        h("Epop[31] netConn_projEE_ampa[2488] = new NetCon(&v(0.5), syn_projEE_ampa[2488], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2489: cell 31, seg 0 (0.5) [0.5 on Epop[31]] -> cell 9, seg 0 (0.5) [0.5 on Epop[9]], weight: 4.1363508E-4, delay 1.5
        h("Epop[9] syn_projEE_ampa[2489] = new ampa(0.5)")
        h("Epop[31] netConn_projEE_ampa[2489] = new NetCon(&v(0.5), syn_projEE_ampa[2489], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2490: cell 31, seg 0 (0.5) [0.5 on Epop[31]] -> cell 10, seg 0 (0.5) [0.5 on Epop[10]], weight: 4.1363508E-4, delay 1.5
        h("Epop[10] syn_projEE_ampa[2490] = new ampa(0.5)")
        h("Epop[31] netConn_projEE_ampa[2490] = new NetCon(&v(0.5), syn_projEE_ampa[2490], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2491: cell 31, seg 0 (0.5) [0.5 on Epop[31]] -> cell 11, seg 0 (0.5) [0.5 on Epop[11]], weight: 4.1363508E-4, delay 1.5
        h("Epop[11] syn_projEE_ampa[2491] = new ampa(0.5)")
        h("Epop[31] netConn_projEE_ampa[2491] = new NetCon(&v(0.5), syn_projEE_ampa[2491], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2492: cell 31, seg 0 (0.5) [0.5 on Epop[31]] -> cell 12, seg 0 (0.5) [0.5 on Epop[12]], weight: 4.1363508E-4, delay 1.5
        h("Epop[12] syn_projEE_ampa[2492] = new ampa(0.5)")
        h("Epop[31] netConn_projEE_ampa[2492] = new NetCon(&v(0.5), syn_projEE_ampa[2492], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2493: cell 31, seg 0 (0.5) [0.5 on Epop[31]] -> cell 13, seg 0 (0.5) [0.5 on Epop[13]], weight: 4.1363508E-4, delay 1.5
        h("Epop[13] syn_projEE_ampa[2493] = new ampa(0.5)")
        h("Epop[31] netConn_projEE_ampa[2493] = new NetCon(&v(0.5), syn_projEE_ampa[2493], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2494: cell 31, seg 0 (0.5) [0.5 on Epop[31]] -> cell 14, seg 0 (0.5) [0.5 on Epop[14]], weight: 4.1363508E-4, delay 1.5
        h("Epop[14] syn_projEE_ampa[2494] = new ampa(0.5)")
        h("Epop[31] netConn_projEE_ampa[2494] = new NetCon(&v(0.5), syn_projEE_ampa[2494], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2495: cell 31, seg 0 (0.5) [0.5 on Epop[31]] -> cell 15, seg 0 (0.5) [0.5 on Epop[15]], weight: 4.1363508E-4, delay 1.5
        h("Epop[15] syn_projEE_ampa[2495] = new ampa(0.5)")
        h("Epop[31] netConn_projEE_ampa[2495] = new NetCon(&v(0.5), syn_projEE_ampa[2495], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2496: cell 31, seg 0 (0.5) [0.5 on Epop[31]] -> cell 16, seg 0 (0.5) [0.5 on Epop[16]], weight: 4.1363508E-4, delay 1.5
        h("Epop[16] syn_projEE_ampa[2496] = new ampa(0.5)")
        h("Epop[31] netConn_projEE_ampa[2496] = new NetCon(&v(0.5), syn_projEE_ampa[2496], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2497: cell 31, seg 0 (0.5) [0.5 on Epop[31]] -> cell 17, seg 0 (0.5) [0.5 on Epop[17]], weight: 4.1363508E-4, delay 1.5
        h("Epop[17] syn_projEE_ampa[2497] = new ampa(0.5)")
        h("Epop[31] netConn_projEE_ampa[2497] = new NetCon(&v(0.5), syn_projEE_ampa[2497], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2498: cell 31, seg 0 (0.5) [0.5 on Epop[31]] -> cell 18, seg 0 (0.5) [0.5 on Epop[18]], weight: 4.1363508E-4, delay 1.5
        h("Epop[18] syn_projEE_ampa[2498] = new ampa(0.5)")
        h("Epop[31] netConn_projEE_ampa[2498] = new NetCon(&v(0.5), syn_projEE_ampa[2498], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2499: cell 31, seg 0 (0.5) [0.5 on Epop[31]] -> cell 19, seg 0 (0.5) [0.5 on Epop[19]], weight: 4.1363508E-4, delay 1.5
        h("Epop[19] syn_projEE_ampa[2499] = new ampa(0.5)")
        h("Epop[31] netConn_projEE_ampa[2499] = new NetCon(&v(0.5), syn_projEE_ampa[2499], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2500: cell 31, seg 0 (0.5) [0.5 on Epop[31]] -> cell 20, seg 0 (0.5) [0.5 on Epop[20]], weight: 4.1363508E-4, delay 1.5
        h("Epop[20] syn_projEE_ampa[2500] = new ampa(0.5)")
        h("Epop[31] netConn_projEE_ampa[2500] = new NetCon(&v(0.5), syn_projEE_ampa[2500], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2501: cell 31, seg 0 (0.5) [0.5 on Epop[31]] -> cell 21, seg 0 (0.5) [0.5 on Epop[21]], weight: 4.1363508E-4, delay 1.5
        h("Epop[21] syn_projEE_ampa[2501] = new ampa(0.5)")
        h("Epop[31] netConn_projEE_ampa[2501] = new NetCon(&v(0.5), syn_projEE_ampa[2501], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2502: cell 31, seg 0 (0.5) [0.5 on Epop[31]] -> cell 22, seg 0 (0.5) [0.5 on Epop[22]], weight: 4.1363508E-4, delay 1.5
        h("Epop[22] syn_projEE_ampa[2502] = new ampa(0.5)")
        h("Epop[31] netConn_projEE_ampa[2502] = new NetCon(&v(0.5), syn_projEE_ampa[2502], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2503: cell 31, seg 0 (0.5) [0.5 on Epop[31]] -> cell 23, seg 0 (0.5) [0.5 on Epop[23]], weight: 4.1363508E-4, delay 1.5
        h("Epop[23] syn_projEE_ampa[2503] = new ampa(0.5)")
        h("Epop[31] netConn_projEE_ampa[2503] = new NetCon(&v(0.5), syn_projEE_ampa[2503], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2504: cell 31, seg 0 (0.5) [0.5 on Epop[31]] -> cell 24, seg 0 (0.5) [0.5 on Epop[24]], weight: 4.1363508E-4, delay 1.5
        h("Epop[24] syn_projEE_ampa[2504] = new ampa(0.5)")
        h("Epop[31] netConn_projEE_ampa[2504] = new NetCon(&v(0.5), syn_projEE_ampa[2504], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2505: cell 31, seg 0 (0.5) [0.5 on Epop[31]] -> cell 25, seg 0 (0.5) [0.5 on Epop[25]], weight: 4.1363508E-4, delay 1.5
        h("Epop[25] syn_projEE_ampa[2505] = new ampa(0.5)")
        h("Epop[31] netConn_projEE_ampa[2505] = new NetCon(&v(0.5), syn_projEE_ampa[2505], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2506: cell 31, seg 0 (0.5) [0.5 on Epop[31]] -> cell 26, seg 0 (0.5) [0.5 on Epop[26]], weight: 4.1363508E-4, delay 1.5
        h("Epop[26] syn_projEE_ampa[2506] = new ampa(0.5)")
        h("Epop[31] netConn_projEE_ampa[2506] = new NetCon(&v(0.5), syn_projEE_ampa[2506], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2507: cell 31, seg 0 (0.5) [0.5 on Epop[31]] -> cell 27, seg 0 (0.5) [0.5 on Epop[27]], weight: 4.1363508E-4, delay 1.5
        h("Epop[27] syn_projEE_ampa[2507] = new ampa(0.5)")
        h("Epop[31] netConn_projEE_ampa[2507] = new NetCon(&v(0.5), syn_projEE_ampa[2507], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2508: cell 31, seg 0 (0.5) [0.5 on Epop[31]] -> cell 28, seg 0 (0.5) [0.5 on Epop[28]], weight: 4.1363508E-4, delay 1.5
        h("Epop[28] syn_projEE_ampa[2508] = new ampa(0.5)")
        h("Epop[31] netConn_projEE_ampa[2508] = new NetCon(&v(0.5), syn_projEE_ampa[2508], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2509: cell 31, seg 0 (0.5) [0.5 on Epop[31]] -> cell 29, seg 0 (0.5) [0.5 on Epop[29]], weight: 4.1363508E-4, delay 1.5
        h("Epop[29] syn_projEE_ampa[2509] = new ampa(0.5)")
        h("Epop[31] netConn_projEE_ampa[2509] = new NetCon(&v(0.5), syn_projEE_ampa[2509], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2510: cell 31, seg 0 (0.5) [0.5 on Epop[31]] -> cell 30, seg 0 (0.5) [0.5 on Epop[30]], weight: 4.1363508E-4, delay 1.5
        h("Epop[30] syn_projEE_ampa[2510] = new ampa(0.5)")
        h("Epop[31] netConn_projEE_ampa[2510] = new NetCon(&v(0.5), syn_projEE_ampa[2510], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2511: cell 31, seg 0 (0.5) [0.5 on Epop[31]] -> cell 31, seg 0 (0.5) [0.5 on Epop[31]], weight: 4.1363508E-4, delay 1.5
        h("Epop[31] syn_projEE_ampa[2511] = new ampa(0.5)")
        h("Epop[31] netConn_projEE_ampa[2511] = new NetCon(&v(0.5), syn_projEE_ampa[2511], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2512: cell 31, seg 0 (0.5) [0.5 on Epop[31]] -> cell 32, seg 0 (0.5) [0.5 on Epop[32]], weight: 4.1363508E-4, delay 1.5
        h("Epop[32] syn_projEE_ampa[2512] = new ampa(0.5)")
        h("Epop[31] netConn_projEE_ampa[2512] = new NetCon(&v(0.5), syn_projEE_ampa[2512], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2513: cell 31, seg 0 (0.5) [0.5 on Epop[31]] -> cell 33, seg 0 (0.5) [0.5 on Epop[33]], weight: 4.1363508E-4, delay 1.5
        h("Epop[33] syn_projEE_ampa[2513] = new ampa(0.5)")
        h("Epop[31] netConn_projEE_ampa[2513] = new NetCon(&v(0.5), syn_projEE_ampa[2513], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2514: cell 31, seg 0 (0.5) [0.5 on Epop[31]] -> cell 34, seg 0 (0.5) [0.5 on Epop[34]], weight: 4.1363508E-4, delay 1.5
        h("Epop[34] syn_projEE_ampa[2514] = new ampa(0.5)")
        h("Epop[31] netConn_projEE_ampa[2514] = new NetCon(&v(0.5), syn_projEE_ampa[2514], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2515: cell 31, seg 0 (0.5) [0.5 on Epop[31]] -> cell 35, seg 0 (0.5) [0.5 on Epop[35]], weight: 4.1363508E-4, delay 1.5
        h("Epop[35] syn_projEE_ampa[2515] = new ampa(0.5)")
        h("Epop[31] netConn_projEE_ampa[2515] = new NetCon(&v(0.5), syn_projEE_ampa[2515], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2516: cell 31, seg 0 (0.5) [0.5 on Epop[31]] -> cell 36, seg 0 (0.5) [0.5 on Epop[36]], weight: 4.1363508E-4, delay 1.5
        h("Epop[36] syn_projEE_ampa[2516] = new ampa(0.5)")
        h("Epop[31] netConn_projEE_ampa[2516] = new NetCon(&v(0.5), syn_projEE_ampa[2516], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2517: cell 31, seg 0 (0.5) [0.5 on Epop[31]] -> cell 37, seg 0 (0.5) [0.5 on Epop[37]], weight: 4.1363508E-4, delay 1.5
        h("Epop[37] syn_projEE_ampa[2517] = new ampa(0.5)")
        h("Epop[31] netConn_projEE_ampa[2517] = new NetCon(&v(0.5), syn_projEE_ampa[2517], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2518: cell 31, seg 0 (0.5) [0.5 on Epop[31]] -> cell 38, seg 0 (0.5) [0.5 on Epop[38]], weight: 4.1363508E-4, delay 1.5
        h("Epop[38] syn_projEE_ampa[2518] = new ampa(0.5)")
        h("Epop[31] netConn_projEE_ampa[2518] = new NetCon(&v(0.5), syn_projEE_ampa[2518], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2519: cell 31, seg 0 (0.5) [0.5 on Epop[31]] -> cell 39, seg 0 (0.5) [0.5 on Epop[39]], weight: 4.1363508E-4, delay 1.5
        h("Epop[39] syn_projEE_ampa[2519] = new ampa(0.5)")
        h("Epop[31] netConn_projEE_ampa[2519] = new NetCon(&v(0.5), syn_projEE_ampa[2519], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2520: cell 31, seg 0 (0.5) [0.5 on Epop[31]] -> cell 40, seg 0 (0.5) [0.5 on Epop[40]], weight: 4.1363508E-4, delay 1.5
        h("Epop[40] syn_projEE_ampa[2520] = new ampa(0.5)")
        h("Epop[31] netConn_projEE_ampa[2520] = new NetCon(&v(0.5), syn_projEE_ampa[2520], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2521: cell 31, seg 0 (0.5) [0.5 on Epop[31]] -> cell 41, seg 0 (0.5) [0.5 on Epop[41]], weight: 4.1363508E-4, delay 1.5
        h("Epop[41] syn_projEE_ampa[2521] = new ampa(0.5)")
        h("Epop[31] netConn_projEE_ampa[2521] = new NetCon(&v(0.5), syn_projEE_ampa[2521], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2522: cell 31, seg 0 (0.5) [0.5 on Epop[31]] -> cell 42, seg 0 (0.5) [0.5 on Epop[42]], weight: 4.1363508E-4, delay 1.5
        h("Epop[42] syn_projEE_ampa[2522] = new ampa(0.5)")
        h("Epop[31] netConn_projEE_ampa[2522] = new NetCon(&v(0.5), syn_projEE_ampa[2522], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2523: cell 31, seg 0 (0.5) [0.5 on Epop[31]] -> cell 43, seg 0 (0.5) [0.5 on Epop[43]], weight: 4.1363508E-4, delay 1.5
        h("Epop[43] syn_projEE_ampa[2523] = new ampa(0.5)")
        h("Epop[31] netConn_projEE_ampa[2523] = new NetCon(&v(0.5), syn_projEE_ampa[2523], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2524: cell 31, seg 0 (0.5) [0.5 on Epop[31]] -> cell 44, seg 0 (0.5) [0.5 on Epop[44]], weight: 4.1363508E-4, delay 1.5
        h("Epop[44] syn_projEE_ampa[2524] = new ampa(0.5)")
        h("Epop[31] netConn_projEE_ampa[2524] = new NetCon(&v(0.5), syn_projEE_ampa[2524], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2525: cell 31, seg 0 (0.5) [0.5 on Epop[31]] -> cell 45, seg 0 (0.5) [0.5 on Epop[45]], weight: 4.1363508E-4, delay 1.5
        h("Epop[45] syn_projEE_ampa[2525] = new ampa(0.5)")
        h("Epop[31] netConn_projEE_ampa[2525] = new NetCon(&v(0.5), syn_projEE_ampa[2525], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2526: cell 31, seg 0 (0.5) [0.5 on Epop[31]] -> cell 46, seg 0 (0.5) [0.5 on Epop[46]], weight: 4.1363508E-4, delay 1.5
        h("Epop[46] syn_projEE_ampa[2526] = new ampa(0.5)")
        h("Epop[31] netConn_projEE_ampa[2526] = new NetCon(&v(0.5), syn_projEE_ampa[2526], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2527: cell 31, seg 0 (0.5) [0.5 on Epop[31]] -> cell 47, seg 0 (0.5) [0.5 on Epop[47]], weight: 4.1363508E-4, delay 1.5
        h("Epop[47] syn_projEE_ampa[2527] = new ampa(0.5)")
        h("Epop[31] netConn_projEE_ampa[2527] = new NetCon(&v(0.5), syn_projEE_ampa[2527], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2528: cell 31, seg 0 (0.5) [0.5 on Epop[31]] -> cell 48, seg 0 (0.5) [0.5 on Epop[48]], weight: 4.1363508E-4, delay 1.5
        h("Epop[48] syn_projEE_ampa[2528] = new ampa(0.5)")
        h("Epop[31] netConn_projEE_ampa[2528] = new NetCon(&v(0.5), syn_projEE_ampa[2528], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2529: cell 31, seg 0 (0.5) [0.5 on Epop[31]] -> cell 49, seg 0 (0.5) [0.5 on Epop[49]], weight: 4.1363508E-4, delay 1.5
        h("Epop[49] syn_projEE_ampa[2529] = new ampa(0.5)")
        h("Epop[31] netConn_projEE_ampa[2529] = new NetCon(&v(0.5), syn_projEE_ampa[2529], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2530: cell 31, seg 0 (0.5) [0.5 on Epop[31]] -> cell 50, seg 0 (0.5) [0.5 on Epop[50]], weight: 4.1363508E-4, delay 1.5
        h("Epop[50] syn_projEE_ampa[2530] = new ampa(0.5)")
        h("Epop[31] netConn_projEE_ampa[2530] = new NetCon(&v(0.5), syn_projEE_ampa[2530], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2531: cell 31, seg 0 (0.5) [0.5 on Epop[31]] -> cell 51, seg 0 (0.5) [0.5 on Epop[51]], weight: 4.1363508E-4, delay 1.5
        h("Epop[51] syn_projEE_ampa[2531] = new ampa(0.5)")
        h("Epop[31] netConn_projEE_ampa[2531] = new NetCon(&v(0.5), syn_projEE_ampa[2531], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2532: cell 31, seg 0 (0.5) [0.5 on Epop[31]] -> cell 52, seg 0 (0.5) [0.5 on Epop[52]], weight: 4.1363508E-4, delay 1.5
        h("Epop[52] syn_projEE_ampa[2532] = new ampa(0.5)")
        h("Epop[31] netConn_projEE_ampa[2532] = new NetCon(&v(0.5), syn_projEE_ampa[2532], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2533: cell 31, seg 0 (0.5) [0.5 on Epop[31]] -> cell 53, seg 0 (0.5) [0.5 on Epop[53]], weight: 4.1363508E-4, delay 1.5
        h("Epop[53] syn_projEE_ampa[2533] = new ampa(0.5)")
        h("Epop[31] netConn_projEE_ampa[2533] = new NetCon(&v(0.5), syn_projEE_ampa[2533], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2534: cell 31, seg 0 (0.5) [0.5 on Epop[31]] -> cell 54, seg 0 (0.5) [0.5 on Epop[54]], weight: 4.1363508E-4, delay 1.5
        h("Epop[54] syn_projEE_ampa[2534] = new ampa(0.5)")
        h("Epop[31] netConn_projEE_ampa[2534] = new NetCon(&v(0.5), syn_projEE_ampa[2534], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2535: cell 31, seg 0 (0.5) [0.5 on Epop[31]] -> cell 55, seg 0 (0.5) [0.5 on Epop[55]], weight: 4.1363508E-4, delay 1.5
        h("Epop[55] syn_projEE_ampa[2535] = new ampa(0.5)")
        h("Epop[31] netConn_projEE_ampa[2535] = new NetCon(&v(0.5), syn_projEE_ampa[2535], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2536: cell 31, seg 0 (0.5) [0.5 on Epop[31]] -> cell 56, seg 0 (0.5) [0.5 on Epop[56]], weight: 4.1363508E-4, delay 1.5
        h("Epop[56] syn_projEE_ampa[2536] = new ampa(0.5)")
        h("Epop[31] netConn_projEE_ampa[2536] = new NetCon(&v(0.5), syn_projEE_ampa[2536], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2537: cell 31, seg 0 (0.5) [0.5 on Epop[31]] -> cell 57, seg 0 (0.5) [0.5 on Epop[57]], weight: 4.1363508E-4, delay 1.5
        h("Epop[57] syn_projEE_ampa[2537] = new ampa(0.5)")
        h("Epop[31] netConn_projEE_ampa[2537] = new NetCon(&v(0.5), syn_projEE_ampa[2537], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2538: cell 31, seg 0 (0.5) [0.5 on Epop[31]] -> cell 58, seg 0 (0.5) [0.5 on Epop[58]], weight: 4.1363508E-4, delay 1.5
        h("Epop[58] syn_projEE_ampa[2538] = new ampa(0.5)")
        h("Epop[31] netConn_projEE_ampa[2538] = new NetCon(&v(0.5), syn_projEE_ampa[2538], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2539: cell 31, seg 0 (0.5) [0.5 on Epop[31]] -> cell 59, seg 0 (0.5) [0.5 on Epop[59]], weight: 4.1363508E-4, delay 1.5
        h("Epop[59] syn_projEE_ampa[2539] = new ampa(0.5)")
        h("Epop[31] netConn_projEE_ampa[2539] = new NetCon(&v(0.5), syn_projEE_ampa[2539], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2540: cell 31, seg 0 (0.5) [0.5 on Epop[31]] -> cell 60, seg 0 (0.5) [0.5 on Epop[60]], weight: 4.1363508E-4, delay 1.5
        h("Epop[60] syn_projEE_ampa[2540] = new ampa(0.5)")
        h("Epop[31] netConn_projEE_ampa[2540] = new NetCon(&v(0.5), syn_projEE_ampa[2540], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2541: cell 31, seg 0 (0.5) [0.5 on Epop[31]] -> cell 61, seg 0 (0.5) [0.5 on Epop[61]], weight: 4.1363508E-4, delay 1.5
        h("Epop[61] syn_projEE_ampa[2541] = new ampa(0.5)")
        h("Epop[31] netConn_projEE_ampa[2541] = new NetCon(&v(0.5), syn_projEE_ampa[2541], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2542: cell 31, seg 0 (0.5) [0.5 on Epop[31]] -> cell 62, seg 0 (0.5) [0.5 on Epop[62]], weight: 4.1363508E-4, delay 1.5
        h("Epop[62] syn_projEE_ampa[2542] = new ampa(0.5)")
        h("Epop[31] netConn_projEE_ampa[2542] = new NetCon(&v(0.5), syn_projEE_ampa[2542], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2543: cell 31, seg 0 (0.5) [0.5 on Epop[31]] -> cell 63, seg 0 (0.5) [0.5 on Epop[63]], weight: 4.1363508E-4, delay 1.5
        h("Epop[63] syn_projEE_ampa[2543] = new ampa(0.5)")
        h("Epop[31] netConn_projEE_ampa[2543] = new NetCon(&v(0.5), syn_projEE_ampa[2543], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2544: cell 31, seg 0 (0.5) [0.5 on Epop[31]] -> cell 64, seg 0 (0.5) [0.5 on Epop[64]], weight: 4.1363508E-4, delay 1.5
        h("Epop[64] syn_projEE_ampa[2544] = new ampa(0.5)")
        h("Epop[31] netConn_projEE_ampa[2544] = new NetCon(&v(0.5), syn_projEE_ampa[2544], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2545: cell 31, seg 0 (0.5) [0.5 on Epop[31]] -> cell 65, seg 0 (0.5) [0.5 on Epop[65]], weight: 4.1363508E-4, delay 1.5
        h("Epop[65] syn_projEE_ampa[2545] = new ampa(0.5)")
        h("Epop[31] netConn_projEE_ampa[2545] = new NetCon(&v(0.5), syn_projEE_ampa[2545], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2546: cell 31, seg 0 (0.5) [0.5 on Epop[31]] -> cell 66, seg 0 (0.5) [0.5 on Epop[66]], weight: 4.1363508E-4, delay 1.5
        h("Epop[66] syn_projEE_ampa[2546] = new ampa(0.5)")
        h("Epop[31] netConn_projEE_ampa[2546] = new NetCon(&v(0.5), syn_projEE_ampa[2546], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2547: cell 31, seg 0 (0.5) [0.5 on Epop[31]] -> cell 67, seg 0 (0.5) [0.5 on Epop[67]], weight: 4.1363508E-4, delay 1.5
        h("Epop[67] syn_projEE_ampa[2547] = new ampa(0.5)")
        h("Epop[31] netConn_projEE_ampa[2547] = new NetCon(&v(0.5), syn_projEE_ampa[2547], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2548: cell 31, seg 0 (0.5) [0.5 on Epop[31]] -> cell 68, seg 0 (0.5) [0.5 on Epop[68]], weight: 4.1363508E-4, delay 1.5
        h("Epop[68] syn_projEE_ampa[2548] = new ampa(0.5)")
        h("Epop[31] netConn_projEE_ampa[2548] = new NetCon(&v(0.5), syn_projEE_ampa[2548], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2549: cell 31, seg 0 (0.5) [0.5 on Epop[31]] -> cell 69, seg 0 (0.5) [0.5 on Epop[69]], weight: 4.1363508E-4, delay 1.5
        h("Epop[69] syn_projEE_ampa[2549] = new ampa(0.5)")
        h("Epop[31] netConn_projEE_ampa[2549] = new NetCon(&v(0.5), syn_projEE_ampa[2549], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2550: cell 31, seg 0 (0.5) [0.5 on Epop[31]] -> cell 70, seg 0 (0.5) [0.5 on Epop[70]], weight: 4.1363508E-4, delay 1.5
        h("Epop[70] syn_projEE_ampa[2550] = new ampa(0.5)")
        h("Epop[31] netConn_projEE_ampa[2550] = new NetCon(&v(0.5), syn_projEE_ampa[2550], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2551: cell 31, seg 0 (0.5) [0.5 on Epop[31]] -> cell 71, seg 0 (0.5) [0.5 on Epop[71]], weight: 4.1363508E-4, delay 1.5
        h("Epop[71] syn_projEE_ampa[2551] = new ampa(0.5)")
        h("Epop[31] netConn_projEE_ampa[2551] = new NetCon(&v(0.5), syn_projEE_ampa[2551], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2552: cell 31, seg 0 (0.5) [0.5 on Epop[31]] -> cell 72, seg 0 (0.5) [0.5 on Epop[72]], weight: 4.1363508E-4, delay 1.5
        h("Epop[72] syn_projEE_ampa[2552] = new ampa(0.5)")
        h("Epop[31] netConn_projEE_ampa[2552] = new NetCon(&v(0.5), syn_projEE_ampa[2552], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2553: cell 31, seg 0 (0.5) [0.5 on Epop[31]] -> cell 73, seg 0 (0.5) [0.5 on Epop[73]], weight: 4.1363508E-4, delay 1.5
        h("Epop[73] syn_projEE_ampa[2553] = new ampa(0.5)")
        h("Epop[31] netConn_projEE_ampa[2553] = new NetCon(&v(0.5), syn_projEE_ampa[2553], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2554: cell 31, seg 0 (0.5) [0.5 on Epop[31]] -> cell 74, seg 0 (0.5) [0.5 on Epop[74]], weight: 4.1363508E-4, delay 1.5
        h("Epop[74] syn_projEE_ampa[2554] = new ampa(0.5)")
        h("Epop[31] netConn_projEE_ampa[2554] = new NetCon(&v(0.5), syn_projEE_ampa[2554], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2555: cell 31, seg 0 (0.5) [0.5 on Epop[31]] -> cell 75, seg 0 (0.5) [0.5 on Epop[75]], weight: 4.1363508E-4, delay 1.5
        h("Epop[75] syn_projEE_ampa[2555] = new ampa(0.5)")
        h("Epop[31] netConn_projEE_ampa[2555] = new NetCon(&v(0.5), syn_projEE_ampa[2555], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2556: cell 31, seg 0 (0.5) [0.5 on Epop[31]] -> cell 76, seg 0 (0.5) [0.5 on Epop[76]], weight: 4.1363508E-4, delay 1.5
        h("Epop[76] syn_projEE_ampa[2556] = new ampa(0.5)")
        h("Epop[31] netConn_projEE_ampa[2556] = new NetCon(&v(0.5), syn_projEE_ampa[2556], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2557: cell 31, seg 0 (0.5) [0.5 on Epop[31]] -> cell 77, seg 0 (0.5) [0.5 on Epop[77]], weight: 4.1363508E-4, delay 1.5
        h("Epop[77] syn_projEE_ampa[2557] = new ampa(0.5)")
        h("Epop[31] netConn_projEE_ampa[2557] = new NetCon(&v(0.5), syn_projEE_ampa[2557], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2558: cell 31, seg 0 (0.5) [0.5 on Epop[31]] -> cell 78, seg 0 (0.5) [0.5 on Epop[78]], weight: 4.1363508E-4, delay 1.5
        h("Epop[78] syn_projEE_ampa[2558] = new ampa(0.5)")
        h("Epop[31] netConn_projEE_ampa[2558] = new NetCon(&v(0.5), syn_projEE_ampa[2558], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2559: cell 31, seg 0 (0.5) [0.5 on Epop[31]] -> cell 79, seg 0 (0.5) [0.5 on Epop[79]], weight: 4.1363508E-4, delay 1.5
        h("Epop[79] syn_projEE_ampa[2559] = new ampa(0.5)")
        h("Epop[31] netConn_projEE_ampa[2559] = new NetCon(&v(0.5), syn_projEE_ampa[2559], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2560: cell 32, seg 0 (0.5) [0.5 on Epop[32]] -> cell 0, seg 0 (0.5) [0.5 on Epop[0]], weight: 4.1363508E-4, delay 1.5
        h("Epop[0] syn_projEE_ampa[2560] = new ampa(0.5)")
        h("Epop[32] netConn_projEE_ampa[2560] = new NetCon(&v(0.5), syn_projEE_ampa[2560], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2561: cell 32, seg 0 (0.5) [0.5 on Epop[32]] -> cell 1, seg 0 (0.5) [0.5 on Epop[1]], weight: 4.1363508E-4, delay 1.5
        h("Epop[1] syn_projEE_ampa[2561] = new ampa(0.5)")
        h("Epop[32] netConn_projEE_ampa[2561] = new NetCon(&v(0.5), syn_projEE_ampa[2561], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2562: cell 32, seg 0 (0.5) [0.5 on Epop[32]] -> cell 2, seg 0 (0.5) [0.5 on Epop[2]], weight: 4.1363508E-4, delay 1.5
        h("Epop[2] syn_projEE_ampa[2562] = new ampa(0.5)")
        h("Epop[32] netConn_projEE_ampa[2562] = new NetCon(&v(0.5), syn_projEE_ampa[2562], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2563: cell 32, seg 0 (0.5) [0.5 on Epop[32]] -> cell 3, seg 0 (0.5) [0.5 on Epop[3]], weight: 4.1363508E-4, delay 1.5
        h("Epop[3] syn_projEE_ampa[2563] = new ampa(0.5)")
        h("Epop[32] netConn_projEE_ampa[2563] = new NetCon(&v(0.5), syn_projEE_ampa[2563], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2564: cell 32, seg 0 (0.5) [0.5 on Epop[32]] -> cell 4, seg 0 (0.5) [0.5 on Epop[4]], weight: 4.1363508E-4, delay 1.5
        h("Epop[4] syn_projEE_ampa[2564] = new ampa(0.5)")
        h("Epop[32] netConn_projEE_ampa[2564] = new NetCon(&v(0.5), syn_projEE_ampa[2564], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2565: cell 32, seg 0 (0.5) [0.5 on Epop[32]] -> cell 5, seg 0 (0.5) [0.5 on Epop[5]], weight: 4.1363508E-4, delay 1.5
        h("Epop[5] syn_projEE_ampa[2565] = new ampa(0.5)")
        h("Epop[32] netConn_projEE_ampa[2565] = new NetCon(&v(0.5), syn_projEE_ampa[2565], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2566: cell 32, seg 0 (0.5) [0.5 on Epop[32]] -> cell 6, seg 0 (0.5) [0.5 on Epop[6]], weight: 4.1363508E-4, delay 1.5
        h("Epop[6] syn_projEE_ampa[2566] = new ampa(0.5)")
        h("Epop[32] netConn_projEE_ampa[2566] = new NetCon(&v(0.5), syn_projEE_ampa[2566], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2567: cell 32, seg 0 (0.5) [0.5 on Epop[32]] -> cell 7, seg 0 (0.5) [0.5 on Epop[7]], weight: 4.1363508E-4, delay 1.5
        h("Epop[7] syn_projEE_ampa[2567] = new ampa(0.5)")
        h("Epop[32] netConn_projEE_ampa[2567] = new NetCon(&v(0.5), syn_projEE_ampa[2567], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2568: cell 32, seg 0 (0.5) [0.5 on Epop[32]] -> cell 8, seg 0 (0.5) [0.5 on Epop[8]], weight: 4.1363508E-4, delay 1.5
        h("Epop[8] syn_projEE_ampa[2568] = new ampa(0.5)")
        h("Epop[32] netConn_projEE_ampa[2568] = new NetCon(&v(0.5), syn_projEE_ampa[2568], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2569: cell 32, seg 0 (0.5) [0.5 on Epop[32]] -> cell 9, seg 0 (0.5) [0.5 on Epop[9]], weight: 4.1363508E-4, delay 1.5
        h("Epop[9] syn_projEE_ampa[2569] = new ampa(0.5)")
        h("Epop[32] netConn_projEE_ampa[2569] = new NetCon(&v(0.5), syn_projEE_ampa[2569], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2570: cell 32, seg 0 (0.5) [0.5 on Epop[32]] -> cell 10, seg 0 (0.5) [0.5 on Epop[10]], weight: 4.1363508E-4, delay 1.5
        h("Epop[10] syn_projEE_ampa[2570] = new ampa(0.5)")
        h("Epop[32] netConn_projEE_ampa[2570] = new NetCon(&v(0.5), syn_projEE_ampa[2570], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2571: cell 32, seg 0 (0.5) [0.5 on Epop[32]] -> cell 11, seg 0 (0.5) [0.5 on Epop[11]], weight: 4.1363508E-4, delay 1.5
        h("Epop[11] syn_projEE_ampa[2571] = new ampa(0.5)")
        h("Epop[32] netConn_projEE_ampa[2571] = new NetCon(&v(0.5), syn_projEE_ampa[2571], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2572: cell 32, seg 0 (0.5) [0.5 on Epop[32]] -> cell 12, seg 0 (0.5) [0.5 on Epop[12]], weight: 4.1363508E-4, delay 1.5
        h("Epop[12] syn_projEE_ampa[2572] = new ampa(0.5)")
        h("Epop[32] netConn_projEE_ampa[2572] = new NetCon(&v(0.5), syn_projEE_ampa[2572], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2573: cell 32, seg 0 (0.5) [0.5 on Epop[32]] -> cell 13, seg 0 (0.5) [0.5 on Epop[13]], weight: 4.1363508E-4, delay 1.5
        h("Epop[13] syn_projEE_ampa[2573] = new ampa(0.5)")
        h("Epop[32] netConn_projEE_ampa[2573] = new NetCon(&v(0.5), syn_projEE_ampa[2573], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2574: cell 32, seg 0 (0.5) [0.5 on Epop[32]] -> cell 14, seg 0 (0.5) [0.5 on Epop[14]], weight: 4.1363508E-4, delay 1.5
        h("Epop[14] syn_projEE_ampa[2574] = new ampa(0.5)")
        h("Epop[32] netConn_projEE_ampa[2574] = new NetCon(&v(0.5), syn_projEE_ampa[2574], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2575: cell 32, seg 0 (0.5) [0.5 on Epop[32]] -> cell 15, seg 0 (0.5) [0.5 on Epop[15]], weight: 4.1363508E-4, delay 1.5
        h("Epop[15] syn_projEE_ampa[2575] = new ampa(0.5)")
        h("Epop[32] netConn_projEE_ampa[2575] = new NetCon(&v(0.5), syn_projEE_ampa[2575], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2576: cell 32, seg 0 (0.5) [0.5 on Epop[32]] -> cell 16, seg 0 (0.5) [0.5 on Epop[16]], weight: 4.1363508E-4, delay 1.5
        h("Epop[16] syn_projEE_ampa[2576] = new ampa(0.5)")
        h("Epop[32] netConn_projEE_ampa[2576] = new NetCon(&v(0.5), syn_projEE_ampa[2576], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2577: cell 32, seg 0 (0.5) [0.5 on Epop[32]] -> cell 17, seg 0 (0.5) [0.5 on Epop[17]], weight: 4.1363508E-4, delay 1.5
        h("Epop[17] syn_projEE_ampa[2577] = new ampa(0.5)")
        h("Epop[32] netConn_projEE_ampa[2577] = new NetCon(&v(0.5), syn_projEE_ampa[2577], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2578: cell 32, seg 0 (0.5) [0.5 on Epop[32]] -> cell 18, seg 0 (0.5) [0.5 on Epop[18]], weight: 4.1363508E-4, delay 1.5
        h("Epop[18] syn_projEE_ampa[2578] = new ampa(0.5)")
        h("Epop[32] netConn_projEE_ampa[2578] = new NetCon(&v(0.5), syn_projEE_ampa[2578], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2579: cell 32, seg 0 (0.5) [0.5 on Epop[32]] -> cell 19, seg 0 (0.5) [0.5 on Epop[19]], weight: 4.1363508E-4, delay 1.5
        h("Epop[19] syn_projEE_ampa[2579] = new ampa(0.5)")
        h("Epop[32] netConn_projEE_ampa[2579] = new NetCon(&v(0.5), syn_projEE_ampa[2579], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2580: cell 32, seg 0 (0.5) [0.5 on Epop[32]] -> cell 20, seg 0 (0.5) [0.5 on Epop[20]], weight: 4.1363508E-4, delay 1.5
        h("Epop[20] syn_projEE_ampa[2580] = new ampa(0.5)")
        h("Epop[32] netConn_projEE_ampa[2580] = new NetCon(&v(0.5), syn_projEE_ampa[2580], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2581: cell 32, seg 0 (0.5) [0.5 on Epop[32]] -> cell 21, seg 0 (0.5) [0.5 on Epop[21]], weight: 4.1363508E-4, delay 1.5
        h("Epop[21] syn_projEE_ampa[2581] = new ampa(0.5)")
        h("Epop[32] netConn_projEE_ampa[2581] = new NetCon(&v(0.5), syn_projEE_ampa[2581], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2582: cell 32, seg 0 (0.5) [0.5 on Epop[32]] -> cell 22, seg 0 (0.5) [0.5 on Epop[22]], weight: 4.1363508E-4, delay 1.5
        h("Epop[22] syn_projEE_ampa[2582] = new ampa(0.5)")
        h("Epop[32] netConn_projEE_ampa[2582] = new NetCon(&v(0.5), syn_projEE_ampa[2582], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2583: cell 32, seg 0 (0.5) [0.5 on Epop[32]] -> cell 23, seg 0 (0.5) [0.5 on Epop[23]], weight: 4.1363508E-4, delay 1.5
        h("Epop[23] syn_projEE_ampa[2583] = new ampa(0.5)")
        h("Epop[32] netConn_projEE_ampa[2583] = new NetCon(&v(0.5), syn_projEE_ampa[2583], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2584: cell 32, seg 0 (0.5) [0.5 on Epop[32]] -> cell 24, seg 0 (0.5) [0.5 on Epop[24]], weight: 4.1363508E-4, delay 1.5
        h("Epop[24] syn_projEE_ampa[2584] = new ampa(0.5)")
        h("Epop[32] netConn_projEE_ampa[2584] = new NetCon(&v(0.5), syn_projEE_ampa[2584], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2585: cell 32, seg 0 (0.5) [0.5 on Epop[32]] -> cell 25, seg 0 (0.5) [0.5 on Epop[25]], weight: 4.1363508E-4, delay 1.5
        h("Epop[25] syn_projEE_ampa[2585] = new ampa(0.5)")
        h("Epop[32] netConn_projEE_ampa[2585] = new NetCon(&v(0.5), syn_projEE_ampa[2585], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2586: cell 32, seg 0 (0.5) [0.5 on Epop[32]] -> cell 26, seg 0 (0.5) [0.5 on Epop[26]], weight: 4.1363508E-4, delay 1.5
        h("Epop[26] syn_projEE_ampa[2586] = new ampa(0.5)")
        h("Epop[32] netConn_projEE_ampa[2586] = new NetCon(&v(0.5), syn_projEE_ampa[2586], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2587: cell 32, seg 0 (0.5) [0.5 on Epop[32]] -> cell 27, seg 0 (0.5) [0.5 on Epop[27]], weight: 4.1363508E-4, delay 1.5
        h("Epop[27] syn_projEE_ampa[2587] = new ampa(0.5)")
        h("Epop[32] netConn_projEE_ampa[2587] = new NetCon(&v(0.5), syn_projEE_ampa[2587], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2588: cell 32, seg 0 (0.5) [0.5 on Epop[32]] -> cell 28, seg 0 (0.5) [0.5 on Epop[28]], weight: 4.1363508E-4, delay 1.5
        h("Epop[28] syn_projEE_ampa[2588] = new ampa(0.5)")
        h("Epop[32] netConn_projEE_ampa[2588] = new NetCon(&v(0.5), syn_projEE_ampa[2588], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2589: cell 32, seg 0 (0.5) [0.5 on Epop[32]] -> cell 29, seg 0 (0.5) [0.5 on Epop[29]], weight: 4.1363508E-4, delay 1.5
        h("Epop[29] syn_projEE_ampa[2589] = new ampa(0.5)")
        h("Epop[32] netConn_projEE_ampa[2589] = new NetCon(&v(0.5), syn_projEE_ampa[2589], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2590: cell 32, seg 0 (0.5) [0.5 on Epop[32]] -> cell 30, seg 0 (0.5) [0.5 on Epop[30]], weight: 4.1363508E-4, delay 1.5
        h("Epop[30] syn_projEE_ampa[2590] = new ampa(0.5)")
        h("Epop[32] netConn_projEE_ampa[2590] = new NetCon(&v(0.5), syn_projEE_ampa[2590], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2591: cell 32, seg 0 (0.5) [0.5 on Epop[32]] -> cell 31, seg 0 (0.5) [0.5 on Epop[31]], weight: 4.1363508E-4, delay 1.5
        h("Epop[31] syn_projEE_ampa[2591] = new ampa(0.5)")
        h("Epop[32] netConn_projEE_ampa[2591] = new NetCon(&v(0.5), syn_projEE_ampa[2591], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2592: cell 32, seg 0 (0.5) [0.5 on Epop[32]] -> cell 32, seg 0 (0.5) [0.5 on Epop[32]], weight: 4.1363508E-4, delay 1.5
        h("Epop[32] syn_projEE_ampa[2592] = new ampa(0.5)")
        h("Epop[32] netConn_projEE_ampa[2592] = new NetCon(&v(0.5), syn_projEE_ampa[2592], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2593: cell 32, seg 0 (0.5) [0.5 on Epop[32]] -> cell 33, seg 0 (0.5) [0.5 on Epop[33]], weight: 4.1363508E-4, delay 1.5
        h("Epop[33] syn_projEE_ampa[2593] = new ampa(0.5)")
        h("Epop[32] netConn_projEE_ampa[2593] = new NetCon(&v(0.5), syn_projEE_ampa[2593], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2594: cell 32, seg 0 (0.5) [0.5 on Epop[32]] -> cell 34, seg 0 (0.5) [0.5 on Epop[34]], weight: 4.1363508E-4, delay 1.5
        h("Epop[34] syn_projEE_ampa[2594] = new ampa(0.5)")
        h("Epop[32] netConn_projEE_ampa[2594] = new NetCon(&v(0.5), syn_projEE_ampa[2594], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2595: cell 32, seg 0 (0.5) [0.5 on Epop[32]] -> cell 35, seg 0 (0.5) [0.5 on Epop[35]], weight: 4.1363508E-4, delay 1.5
        h("Epop[35] syn_projEE_ampa[2595] = new ampa(0.5)")
        h("Epop[32] netConn_projEE_ampa[2595] = new NetCon(&v(0.5), syn_projEE_ampa[2595], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2596: cell 32, seg 0 (0.5) [0.5 on Epop[32]] -> cell 36, seg 0 (0.5) [0.5 on Epop[36]], weight: 4.1363508E-4, delay 1.5
        h("Epop[36] syn_projEE_ampa[2596] = new ampa(0.5)")
        h("Epop[32] netConn_projEE_ampa[2596] = new NetCon(&v(0.5), syn_projEE_ampa[2596], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2597: cell 32, seg 0 (0.5) [0.5 on Epop[32]] -> cell 37, seg 0 (0.5) [0.5 on Epop[37]], weight: 4.1363508E-4, delay 1.5
        h("Epop[37] syn_projEE_ampa[2597] = new ampa(0.5)")
        h("Epop[32] netConn_projEE_ampa[2597] = new NetCon(&v(0.5), syn_projEE_ampa[2597], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2598: cell 32, seg 0 (0.5) [0.5 on Epop[32]] -> cell 38, seg 0 (0.5) [0.5 on Epop[38]], weight: 4.1363508E-4, delay 1.5
        h("Epop[38] syn_projEE_ampa[2598] = new ampa(0.5)")
        h("Epop[32] netConn_projEE_ampa[2598] = new NetCon(&v(0.5), syn_projEE_ampa[2598], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2599: cell 32, seg 0 (0.5) [0.5 on Epop[32]] -> cell 39, seg 0 (0.5) [0.5 on Epop[39]], weight: 4.1363508E-4, delay 1.5
        h("Epop[39] syn_projEE_ampa[2599] = new ampa(0.5)")
        h("Epop[32] netConn_projEE_ampa[2599] = new NetCon(&v(0.5), syn_projEE_ampa[2599], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2600: cell 32, seg 0 (0.5) [0.5 on Epop[32]] -> cell 40, seg 0 (0.5) [0.5 on Epop[40]], weight: 4.1363508E-4, delay 1.5
        h("Epop[40] syn_projEE_ampa[2600] = new ampa(0.5)")
        h("Epop[32] netConn_projEE_ampa[2600] = new NetCon(&v(0.5), syn_projEE_ampa[2600], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2601: cell 32, seg 0 (0.5) [0.5 on Epop[32]] -> cell 41, seg 0 (0.5) [0.5 on Epop[41]], weight: 4.1363508E-4, delay 1.5
        h("Epop[41] syn_projEE_ampa[2601] = new ampa(0.5)")
        h("Epop[32] netConn_projEE_ampa[2601] = new NetCon(&v(0.5), syn_projEE_ampa[2601], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2602: cell 32, seg 0 (0.5) [0.5 on Epop[32]] -> cell 42, seg 0 (0.5) [0.5 on Epop[42]], weight: 4.1363508E-4, delay 1.5
        h("Epop[42] syn_projEE_ampa[2602] = new ampa(0.5)")
        h("Epop[32] netConn_projEE_ampa[2602] = new NetCon(&v(0.5), syn_projEE_ampa[2602], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2603: cell 32, seg 0 (0.5) [0.5 on Epop[32]] -> cell 43, seg 0 (0.5) [0.5 on Epop[43]], weight: 4.1363508E-4, delay 1.5
        h("Epop[43] syn_projEE_ampa[2603] = new ampa(0.5)")
        h("Epop[32] netConn_projEE_ampa[2603] = new NetCon(&v(0.5), syn_projEE_ampa[2603], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2604: cell 32, seg 0 (0.5) [0.5 on Epop[32]] -> cell 44, seg 0 (0.5) [0.5 on Epop[44]], weight: 4.1363508E-4, delay 1.5
        h("Epop[44] syn_projEE_ampa[2604] = new ampa(0.5)")
        h("Epop[32] netConn_projEE_ampa[2604] = new NetCon(&v(0.5), syn_projEE_ampa[2604], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2605: cell 32, seg 0 (0.5) [0.5 on Epop[32]] -> cell 45, seg 0 (0.5) [0.5 on Epop[45]], weight: 4.1363508E-4, delay 1.5
        h("Epop[45] syn_projEE_ampa[2605] = new ampa(0.5)")
        h("Epop[32] netConn_projEE_ampa[2605] = new NetCon(&v(0.5), syn_projEE_ampa[2605], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2606: cell 32, seg 0 (0.5) [0.5 on Epop[32]] -> cell 46, seg 0 (0.5) [0.5 on Epop[46]], weight: 4.1363508E-4, delay 1.5
        h("Epop[46] syn_projEE_ampa[2606] = new ampa(0.5)")
        h("Epop[32] netConn_projEE_ampa[2606] = new NetCon(&v(0.5), syn_projEE_ampa[2606], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2607: cell 32, seg 0 (0.5) [0.5 on Epop[32]] -> cell 47, seg 0 (0.5) [0.5 on Epop[47]], weight: 4.1363508E-4, delay 1.5
        h("Epop[47] syn_projEE_ampa[2607] = new ampa(0.5)")
        h("Epop[32] netConn_projEE_ampa[2607] = new NetCon(&v(0.5), syn_projEE_ampa[2607], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2608: cell 32, seg 0 (0.5) [0.5 on Epop[32]] -> cell 48, seg 0 (0.5) [0.5 on Epop[48]], weight: 4.1363508E-4, delay 1.5
        h("Epop[48] syn_projEE_ampa[2608] = new ampa(0.5)")
        h("Epop[32] netConn_projEE_ampa[2608] = new NetCon(&v(0.5), syn_projEE_ampa[2608], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2609: cell 32, seg 0 (0.5) [0.5 on Epop[32]] -> cell 49, seg 0 (0.5) [0.5 on Epop[49]], weight: 4.1363508E-4, delay 1.5
        h("Epop[49] syn_projEE_ampa[2609] = new ampa(0.5)")
        h("Epop[32] netConn_projEE_ampa[2609] = new NetCon(&v(0.5), syn_projEE_ampa[2609], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2610: cell 32, seg 0 (0.5) [0.5 on Epop[32]] -> cell 50, seg 0 (0.5) [0.5 on Epop[50]], weight: 4.1363508E-4, delay 1.5
        h("Epop[50] syn_projEE_ampa[2610] = new ampa(0.5)")
        h("Epop[32] netConn_projEE_ampa[2610] = new NetCon(&v(0.5), syn_projEE_ampa[2610], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2611: cell 32, seg 0 (0.5) [0.5 on Epop[32]] -> cell 51, seg 0 (0.5) [0.5 on Epop[51]], weight: 4.1363508E-4, delay 1.5
        h("Epop[51] syn_projEE_ampa[2611] = new ampa(0.5)")
        h("Epop[32] netConn_projEE_ampa[2611] = new NetCon(&v(0.5), syn_projEE_ampa[2611], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2612: cell 32, seg 0 (0.5) [0.5 on Epop[32]] -> cell 52, seg 0 (0.5) [0.5 on Epop[52]], weight: 4.1363508E-4, delay 1.5
        h("Epop[52] syn_projEE_ampa[2612] = new ampa(0.5)")
        h("Epop[32] netConn_projEE_ampa[2612] = new NetCon(&v(0.5), syn_projEE_ampa[2612], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2613: cell 32, seg 0 (0.5) [0.5 on Epop[32]] -> cell 53, seg 0 (0.5) [0.5 on Epop[53]], weight: 4.1363508E-4, delay 1.5
        h("Epop[53] syn_projEE_ampa[2613] = new ampa(0.5)")
        h("Epop[32] netConn_projEE_ampa[2613] = new NetCon(&v(0.5), syn_projEE_ampa[2613], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2614: cell 32, seg 0 (0.5) [0.5 on Epop[32]] -> cell 54, seg 0 (0.5) [0.5 on Epop[54]], weight: 4.1363508E-4, delay 1.5
        h("Epop[54] syn_projEE_ampa[2614] = new ampa(0.5)")
        h("Epop[32] netConn_projEE_ampa[2614] = new NetCon(&v(0.5), syn_projEE_ampa[2614], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2615: cell 32, seg 0 (0.5) [0.5 on Epop[32]] -> cell 55, seg 0 (0.5) [0.5 on Epop[55]], weight: 4.1363508E-4, delay 1.5
        h("Epop[55] syn_projEE_ampa[2615] = new ampa(0.5)")
        h("Epop[32] netConn_projEE_ampa[2615] = new NetCon(&v(0.5), syn_projEE_ampa[2615], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2616: cell 32, seg 0 (0.5) [0.5 on Epop[32]] -> cell 56, seg 0 (0.5) [0.5 on Epop[56]], weight: 4.1363508E-4, delay 1.5
        h("Epop[56] syn_projEE_ampa[2616] = new ampa(0.5)")
        h("Epop[32] netConn_projEE_ampa[2616] = new NetCon(&v(0.5), syn_projEE_ampa[2616], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2617: cell 32, seg 0 (0.5) [0.5 on Epop[32]] -> cell 57, seg 0 (0.5) [0.5 on Epop[57]], weight: 4.1363508E-4, delay 1.5
        h("Epop[57] syn_projEE_ampa[2617] = new ampa(0.5)")
        h("Epop[32] netConn_projEE_ampa[2617] = new NetCon(&v(0.5), syn_projEE_ampa[2617], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2618: cell 32, seg 0 (0.5) [0.5 on Epop[32]] -> cell 58, seg 0 (0.5) [0.5 on Epop[58]], weight: 4.1363508E-4, delay 1.5
        h("Epop[58] syn_projEE_ampa[2618] = new ampa(0.5)")
        h("Epop[32] netConn_projEE_ampa[2618] = new NetCon(&v(0.5), syn_projEE_ampa[2618], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2619: cell 32, seg 0 (0.5) [0.5 on Epop[32]] -> cell 59, seg 0 (0.5) [0.5 on Epop[59]], weight: 4.1363508E-4, delay 1.5
        h("Epop[59] syn_projEE_ampa[2619] = new ampa(0.5)")
        h("Epop[32] netConn_projEE_ampa[2619] = new NetCon(&v(0.5), syn_projEE_ampa[2619], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2620: cell 32, seg 0 (0.5) [0.5 on Epop[32]] -> cell 60, seg 0 (0.5) [0.5 on Epop[60]], weight: 4.1363508E-4, delay 1.5
        h("Epop[60] syn_projEE_ampa[2620] = new ampa(0.5)")
        h("Epop[32] netConn_projEE_ampa[2620] = new NetCon(&v(0.5), syn_projEE_ampa[2620], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2621: cell 32, seg 0 (0.5) [0.5 on Epop[32]] -> cell 61, seg 0 (0.5) [0.5 on Epop[61]], weight: 4.1363508E-4, delay 1.5
        h("Epop[61] syn_projEE_ampa[2621] = new ampa(0.5)")
        h("Epop[32] netConn_projEE_ampa[2621] = new NetCon(&v(0.5), syn_projEE_ampa[2621], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2622: cell 32, seg 0 (0.5) [0.5 on Epop[32]] -> cell 62, seg 0 (0.5) [0.5 on Epop[62]], weight: 4.1363508E-4, delay 1.5
        h("Epop[62] syn_projEE_ampa[2622] = new ampa(0.5)")
        h("Epop[32] netConn_projEE_ampa[2622] = new NetCon(&v(0.5), syn_projEE_ampa[2622], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2623: cell 32, seg 0 (0.5) [0.5 on Epop[32]] -> cell 63, seg 0 (0.5) [0.5 on Epop[63]], weight: 4.1363508E-4, delay 1.5
        h("Epop[63] syn_projEE_ampa[2623] = new ampa(0.5)")
        h("Epop[32] netConn_projEE_ampa[2623] = new NetCon(&v(0.5), syn_projEE_ampa[2623], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2624: cell 32, seg 0 (0.5) [0.5 on Epop[32]] -> cell 64, seg 0 (0.5) [0.5 on Epop[64]], weight: 4.1363508E-4, delay 1.5
        h("Epop[64] syn_projEE_ampa[2624] = new ampa(0.5)")
        h("Epop[32] netConn_projEE_ampa[2624] = new NetCon(&v(0.5), syn_projEE_ampa[2624], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2625: cell 32, seg 0 (0.5) [0.5 on Epop[32]] -> cell 65, seg 0 (0.5) [0.5 on Epop[65]], weight: 4.1363508E-4, delay 1.5
        h("Epop[65] syn_projEE_ampa[2625] = new ampa(0.5)")
        h("Epop[32] netConn_projEE_ampa[2625] = new NetCon(&v(0.5), syn_projEE_ampa[2625], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2626: cell 32, seg 0 (0.5) [0.5 on Epop[32]] -> cell 66, seg 0 (0.5) [0.5 on Epop[66]], weight: 4.1363508E-4, delay 1.5
        h("Epop[66] syn_projEE_ampa[2626] = new ampa(0.5)")
        h("Epop[32] netConn_projEE_ampa[2626] = new NetCon(&v(0.5), syn_projEE_ampa[2626], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2627: cell 32, seg 0 (0.5) [0.5 on Epop[32]] -> cell 67, seg 0 (0.5) [0.5 on Epop[67]], weight: 4.1363508E-4, delay 1.5
        h("Epop[67] syn_projEE_ampa[2627] = new ampa(0.5)")
        h("Epop[32] netConn_projEE_ampa[2627] = new NetCon(&v(0.5), syn_projEE_ampa[2627], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2628: cell 32, seg 0 (0.5) [0.5 on Epop[32]] -> cell 68, seg 0 (0.5) [0.5 on Epop[68]], weight: 4.1363508E-4, delay 1.5
        h("Epop[68] syn_projEE_ampa[2628] = new ampa(0.5)")
        h("Epop[32] netConn_projEE_ampa[2628] = new NetCon(&v(0.5), syn_projEE_ampa[2628], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2629: cell 32, seg 0 (0.5) [0.5 on Epop[32]] -> cell 69, seg 0 (0.5) [0.5 on Epop[69]], weight: 4.1363508E-4, delay 1.5
        h("Epop[69] syn_projEE_ampa[2629] = new ampa(0.5)")
        h("Epop[32] netConn_projEE_ampa[2629] = new NetCon(&v(0.5), syn_projEE_ampa[2629], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2630: cell 32, seg 0 (0.5) [0.5 on Epop[32]] -> cell 70, seg 0 (0.5) [0.5 on Epop[70]], weight: 4.1363508E-4, delay 1.5
        h("Epop[70] syn_projEE_ampa[2630] = new ampa(0.5)")
        h("Epop[32] netConn_projEE_ampa[2630] = new NetCon(&v(0.5), syn_projEE_ampa[2630], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2631: cell 32, seg 0 (0.5) [0.5 on Epop[32]] -> cell 71, seg 0 (0.5) [0.5 on Epop[71]], weight: 4.1363508E-4, delay 1.5
        h("Epop[71] syn_projEE_ampa[2631] = new ampa(0.5)")
        h("Epop[32] netConn_projEE_ampa[2631] = new NetCon(&v(0.5), syn_projEE_ampa[2631], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2632: cell 32, seg 0 (0.5) [0.5 on Epop[32]] -> cell 72, seg 0 (0.5) [0.5 on Epop[72]], weight: 4.1363508E-4, delay 1.5
        h("Epop[72] syn_projEE_ampa[2632] = new ampa(0.5)")
        h("Epop[32] netConn_projEE_ampa[2632] = new NetCon(&v(0.5), syn_projEE_ampa[2632], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2633: cell 32, seg 0 (0.5) [0.5 on Epop[32]] -> cell 73, seg 0 (0.5) [0.5 on Epop[73]], weight: 4.1363508E-4, delay 1.5
        h("Epop[73] syn_projEE_ampa[2633] = new ampa(0.5)")
        h("Epop[32] netConn_projEE_ampa[2633] = new NetCon(&v(0.5), syn_projEE_ampa[2633], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2634: cell 32, seg 0 (0.5) [0.5 on Epop[32]] -> cell 74, seg 0 (0.5) [0.5 on Epop[74]], weight: 4.1363508E-4, delay 1.5
        h("Epop[74] syn_projEE_ampa[2634] = new ampa(0.5)")
        h("Epop[32] netConn_projEE_ampa[2634] = new NetCon(&v(0.5), syn_projEE_ampa[2634], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2635: cell 32, seg 0 (0.5) [0.5 on Epop[32]] -> cell 75, seg 0 (0.5) [0.5 on Epop[75]], weight: 4.1363508E-4, delay 1.5
        h("Epop[75] syn_projEE_ampa[2635] = new ampa(0.5)")
        h("Epop[32] netConn_projEE_ampa[2635] = new NetCon(&v(0.5), syn_projEE_ampa[2635], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2636: cell 32, seg 0 (0.5) [0.5 on Epop[32]] -> cell 76, seg 0 (0.5) [0.5 on Epop[76]], weight: 4.1363508E-4, delay 1.5
        h("Epop[76] syn_projEE_ampa[2636] = new ampa(0.5)")
        h("Epop[32] netConn_projEE_ampa[2636] = new NetCon(&v(0.5), syn_projEE_ampa[2636], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2637: cell 32, seg 0 (0.5) [0.5 on Epop[32]] -> cell 77, seg 0 (0.5) [0.5 on Epop[77]], weight: 4.1363508E-4, delay 1.5
        h("Epop[77] syn_projEE_ampa[2637] = new ampa(0.5)")
        h("Epop[32] netConn_projEE_ampa[2637] = new NetCon(&v(0.5), syn_projEE_ampa[2637], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2638: cell 32, seg 0 (0.5) [0.5 on Epop[32]] -> cell 78, seg 0 (0.5) [0.5 on Epop[78]], weight: 4.1363508E-4, delay 1.5
        h("Epop[78] syn_projEE_ampa[2638] = new ampa(0.5)")
        h("Epop[32] netConn_projEE_ampa[2638] = new NetCon(&v(0.5), syn_projEE_ampa[2638], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2639: cell 32, seg 0 (0.5) [0.5 on Epop[32]] -> cell 79, seg 0 (0.5) [0.5 on Epop[79]], weight: 4.1363508E-4, delay 1.5
        h("Epop[79] syn_projEE_ampa[2639] = new ampa(0.5)")
        h("Epop[32] netConn_projEE_ampa[2639] = new NetCon(&v(0.5), syn_projEE_ampa[2639], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2640: cell 33, seg 0 (0.5) [0.5 on Epop[33]] -> cell 0, seg 0 (0.5) [0.5 on Epop[0]], weight: 4.1363508E-4, delay 1.5
        h("Epop[0] syn_projEE_ampa[2640] = new ampa(0.5)")
        h("Epop[33] netConn_projEE_ampa[2640] = new NetCon(&v(0.5), syn_projEE_ampa[2640], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2641: cell 33, seg 0 (0.5) [0.5 on Epop[33]] -> cell 1, seg 0 (0.5) [0.5 on Epop[1]], weight: 4.1363508E-4, delay 1.5
        h("Epop[1] syn_projEE_ampa[2641] = new ampa(0.5)")
        h("Epop[33] netConn_projEE_ampa[2641] = new NetCon(&v(0.5), syn_projEE_ampa[2641], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2642: cell 33, seg 0 (0.5) [0.5 on Epop[33]] -> cell 2, seg 0 (0.5) [0.5 on Epop[2]], weight: 4.1363508E-4, delay 1.5
        h("Epop[2] syn_projEE_ampa[2642] = new ampa(0.5)")
        h("Epop[33] netConn_projEE_ampa[2642] = new NetCon(&v(0.5), syn_projEE_ampa[2642], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2643: cell 33, seg 0 (0.5) [0.5 on Epop[33]] -> cell 3, seg 0 (0.5) [0.5 on Epop[3]], weight: 4.1363508E-4, delay 1.5
        h("Epop[3] syn_projEE_ampa[2643] = new ampa(0.5)")
        h("Epop[33] netConn_projEE_ampa[2643] = new NetCon(&v(0.5), syn_projEE_ampa[2643], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2644: cell 33, seg 0 (0.5) [0.5 on Epop[33]] -> cell 4, seg 0 (0.5) [0.5 on Epop[4]], weight: 4.1363508E-4, delay 1.5
        h("Epop[4] syn_projEE_ampa[2644] = new ampa(0.5)")
        h("Epop[33] netConn_projEE_ampa[2644] = new NetCon(&v(0.5), syn_projEE_ampa[2644], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2645: cell 33, seg 0 (0.5) [0.5 on Epop[33]] -> cell 5, seg 0 (0.5) [0.5 on Epop[5]], weight: 4.1363508E-4, delay 1.5
        h("Epop[5] syn_projEE_ampa[2645] = new ampa(0.5)")
        h("Epop[33] netConn_projEE_ampa[2645] = new NetCon(&v(0.5), syn_projEE_ampa[2645], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2646: cell 33, seg 0 (0.5) [0.5 on Epop[33]] -> cell 6, seg 0 (0.5) [0.5 on Epop[6]], weight: 4.1363508E-4, delay 1.5
        h("Epop[6] syn_projEE_ampa[2646] = new ampa(0.5)")
        h("Epop[33] netConn_projEE_ampa[2646] = new NetCon(&v(0.5), syn_projEE_ampa[2646], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2647: cell 33, seg 0 (0.5) [0.5 on Epop[33]] -> cell 7, seg 0 (0.5) [0.5 on Epop[7]], weight: 4.1363508E-4, delay 1.5
        h("Epop[7] syn_projEE_ampa[2647] = new ampa(0.5)")
        h("Epop[33] netConn_projEE_ampa[2647] = new NetCon(&v(0.5), syn_projEE_ampa[2647], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2648: cell 33, seg 0 (0.5) [0.5 on Epop[33]] -> cell 8, seg 0 (0.5) [0.5 on Epop[8]], weight: 4.1363508E-4, delay 1.5
        h("Epop[8] syn_projEE_ampa[2648] = new ampa(0.5)")
        h("Epop[33] netConn_projEE_ampa[2648] = new NetCon(&v(0.5), syn_projEE_ampa[2648], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2649: cell 33, seg 0 (0.5) [0.5 on Epop[33]] -> cell 9, seg 0 (0.5) [0.5 on Epop[9]], weight: 4.1363508E-4, delay 1.5
        h("Epop[9] syn_projEE_ampa[2649] = new ampa(0.5)")
        h("Epop[33] netConn_projEE_ampa[2649] = new NetCon(&v(0.5), syn_projEE_ampa[2649], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2650: cell 33, seg 0 (0.5) [0.5 on Epop[33]] -> cell 10, seg 0 (0.5) [0.5 on Epop[10]], weight: 4.1363508E-4, delay 1.5
        h("Epop[10] syn_projEE_ampa[2650] = new ampa(0.5)")
        h("Epop[33] netConn_projEE_ampa[2650] = new NetCon(&v(0.5), syn_projEE_ampa[2650], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2651: cell 33, seg 0 (0.5) [0.5 on Epop[33]] -> cell 11, seg 0 (0.5) [0.5 on Epop[11]], weight: 4.1363508E-4, delay 1.5
        h("Epop[11] syn_projEE_ampa[2651] = new ampa(0.5)")
        h("Epop[33] netConn_projEE_ampa[2651] = new NetCon(&v(0.5), syn_projEE_ampa[2651], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2652: cell 33, seg 0 (0.5) [0.5 on Epop[33]] -> cell 12, seg 0 (0.5) [0.5 on Epop[12]], weight: 4.1363508E-4, delay 1.5
        h("Epop[12] syn_projEE_ampa[2652] = new ampa(0.5)")
        h("Epop[33] netConn_projEE_ampa[2652] = new NetCon(&v(0.5), syn_projEE_ampa[2652], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2653: cell 33, seg 0 (0.5) [0.5 on Epop[33]] -> cell 13, seg 0 (0.5) [0.5 on Epop[13]], weight: 4.1363508E-4, delay 1.5
        h("Epop[13] syn_projEE_ampa[2653] = new ampa(0.5)")
        h("Epop[33] netConn_projEE_ampa[2653] = new NetCon(&v(0.5), syn_projEE_ampa[2653], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2654: cell 33, seg 0 (0.5) [0.5 on Epop[33]] -> cell 14, seg 0 (0.5) [0.5 on Epop[14]], weight: 4.1363508E-4, delay 1.5
        h("Epop[14] syn_projEE_ampa[2654] = new ampa(0.5)")
        h("Epop[33] netConn_projEE_ampa[2654] = new NetCon(&v(0.5), syn_projEE_ampa[2654], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2655: cell 33, seg 0 (0.5) [0.5 on Epop[33]] -> cell 15, seg 0 (0.5) [0.5 on Epop[15]], weight: 4.1363508E-4, delay 1.5
        h("Epop[15] syn_projEE_ampa[2655] = new ampa(0.5)")
        h("Epop[33] netConn_projEE_ampa[2655] = new NetCon(&v(0.5), syn_projEE_ampa[2655], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2656: cell 33, seg 0 (0.5) [0.5 on Epop[33]] -> cell 16, seg 0 (0.5) [0.5 on Epop[16]], weight: 4.1363508E-4, delay 1.5
        h("Epop[16] syn_projEE_ampa[2656] = new ampa(0.5)")
        h("Epop[33] netConn_projEE_ampa[2656] = new NetCon(&v(0.5), syn_projEE_ampa[2656], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2657: cell 33, seg 0 (0.5) [0.5 on Epop[33]] -> cell 17, seg 0 (0.5) [0.5 on Epop[17]], weight: 4.1363508E-4, delay 1.5
        h("Epop[17] syn_projEE_ampa[2657] = new ampa(0.5)")
        h("Epop[33] netConn_projEE_ampa[2657] = new NetCon(&v(0.5), syn_projEE_ampa[2657], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2658: cell 33, seg 0 (0.5) [0.5 on Epop[33]] -> cell 18, seg 0 (0.5) [0.5 on Epop[18]], weight: 4.1363508E-4, delay 1.5
        h("Epop[18] syn_projEE_ampa[2658] = new ampa(0.5)")
        h("Epop[33] netConn_projEE_ampa[2658] = new NetCon(&v(0.5), syn_projEE_ampa[2658], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2659: cell 33, seg 0 (0.5) [0.5 on Epop[33]] -> cell 19, seg 0 (0.5) [0.5 on Epop[19]], weight: 4.1363508E-4, delay 1.5
        h("Epop[19] syn_projEE_ampa[2659] = new ampa(0.5)")
        h("Epop[33] netConn_projEE_ampa[2659] = new NetCon(&v(0.5), syn_projEE_ampa[2659], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2660: cell 33, seg 0 (0.5) [0.5 on Epop[33]] -> cell 20, seg 0 (0.5) [0.5 on Epop[20]], weight: 4.1363508E-4, delay 1.5
        h("Epop[20] syn_projEE_ampa[2660] = new ampa(0.5)")
        h("Epop[33] netConn_projEE_ampa[2660] = new NetCon(&v(0.5), syn_projEE_ampa[2660], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2661: cell 33, seg 0 (0.5) [0.5 on Epop[33]] -> cell 21, seg 0 (0.5) [0.5 on Epop[21]], weight: 4.1363508E-4, delay 1.5
        h("Epop[21] syn_projEE_ampa[2661] = new ampa(0.5)")
        h("Epop[33] netConn_projEE_ampa[2661] = new NetCon(&v(0.5), syn_projEE_ampa[2661], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2662: cell 33, seg 0 (0.5) [0.5 on Epop[33]] -> cell 22, seg 0 (0.5) [0.5 on Epop[22]], weight: 4.1363508E-4, delay 1.5
        h("Epop[22] syn_projEE_ampa[2662] = new ampa(0.5)")
        h("Epop[33] netConn_projEE_ampa[2662] = new NetCon(&v(0.5), syn_projEE_ampa[2662], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2663: cell 33, seg 0 (0.5) [0.5 on Epop[33]] -> cell 23, seg 0 (0.5) [0.5 on Epop[23]], weight: 4.1363508E-4, delay 1.5
        h("Epop[23] syn_projEE_ampa[2663] = new ampa(0.5)")
        h("Epop[33] netConn_projEE_ampa[2663] = new NetCon(&v(0.5), syn_projEE_ampa[2663], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2664: cell 33, seg 0 (0.5) [0.5 on Epop[33]] -> cell 24, seg 0 (0.5) [0.5 on Epop[24]], weight: 4.1363508E-4, delay 1.5
        h("Epop[24] syn_projEE_ampa[2664] = new ampa(0.5)")
        h("Epop[33] netConn_projEE_ampa[2664] = new NetCon(&v(0.5), syn_projEE_ampa[2664], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2665: cell 33, seg 0 (0.5) [0.5 on Epop[33]] -> cell 25, seg 0 (0.5) [0.5 on Epop[25]], weight: 4.1363508E-4, delay 1.5
        h("Epop[25] syn_projEE_ampa[2665] = new ampa(0.5)")
        h("Epop[33] netConn_projEE_ampa[2665] = new NetCon(&v(0.5), syn_projEE_ampa[2665], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2666: cell 33, seg 0 (0.5) [0.5 on Epop[33]] -> cell 26, seg 0 (0.5) [0.5 on Epop[26]], weight: 4.1363508E-4, delay 1.5
        h("Epop[26] syn_projEE_ampa[2666] = new ampa(0.5)")
        h("Epop[33] netConn_projEE_ampa[2666] = new NetCon(&v(0.5), syn_projEE_ampa[2666], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2667: cell 33, seg 0 (0.5) [0.5 on Epop[33]] -> cell 27, seg 0 (0.5) [0.5 on Epop[27]], weight: 4.1363508E-4, delay 1.5
        h("Epop[27] syn_projEE_ampa[2667] = new ampa(0.5)")
        h("Epop[33] netConn_projEE_ampa[2667] = new NetCon(&v(0.5), syn_projEE_ampa[2667], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2668: cell 33, seg 0 (0.5) [0.5 on Epop[33]] -> cell 28, seg 0 (0.5) [0.5 on Epop[28]], weight: 4.1363508E-4, delay 1.5
        h("Epop[28] syn_projEE_ampa[2668] = new ampa(0.5)")
        h("Epop[33] netConn_projEE_ampa[2668] = new NetCon(&v(0.5), syn_projEE_ampa[2668], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2669: cell 33, seg 0 (0.5) [0.5 on Epop[33]] -> cell 29, seg 0 (0.5) [0.5 on Epop[29]], weight: 4.1363508E-4, delay 1.5
        h("Epop[29] syn_projEE_ampa[2669] = new ampa(0.5)")
        h("Epop[33] netConn_projEE_ampa[2669] = new NetCon(&v(0.5), syn_projEE_ampa[2669], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2670: cell 33, seg 0 (0.5) [0.5 on Epop[33]] -> cell 30, seg 0 (0.5) [0.5 on Epop[30]], weight: 4.1363508E-4, delay 1.5
        h("Epop[30] syn_projEE_ampa[2670] = new ampa(0.5)")
        h("Epop[33] netConn_projEE_ampa[2670] = new NetCon(&v(0.5), syn_projEE_ampa[2670], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2671: cell 33, seg 0 (0.5) [0.5 on Epop[33]] -> cell 31, seg 0 (0.5) [0.5 on Epop[31]], weight: 4.1363508E-4, delay 1.5
        h("Epop[31] syn_projEE_ampa[2671] = new ampa(0.5)")
        h("Epop[33] netConn_projEE_ampa[2671] = new NetCon(&v(0.5), syn_projEE_ampa[2671], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2672: cell 33, seg 0 (0.5) [0.5 on Epop[33]] -> cell 32, seg 0 (0.5) [0.5 on Epop[32]], weight: 4.1363508E-4, delay 1.5
        h("Epop[32] syn_projEE_ampa[2672] = new ampa(0.5)")
        h("Epop[33] netConn_projEE_ampa[2672] = new NetCon(&v(0.5), syn_projEE_ampa[2672], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2673: cell 33, seg 0 (0.5) [0.5 on Epop[33]] -> cell 33, seg 0 (0.5) [0.5 on Epop[33]], weight: 4.1363508E-4, delay 1.5
        h("Epop[33] syn_projEE_ampa[2673] = new ampa(0.5)")
        h("Epop[33] netConn_projEE_ampa[2673] = new NetCon(&v(0.5), syn_projEE_ampa[2673], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2674: cell 33, seg 0 (0.5) [0.5 on Epop[33]] -> cell 34, seg 0 (0.5) [0.5 on Epop[34]], weight: 4.1363508E-4, delay 1.5
        h("Epop[34] syn_projEE_ampa[2674] = new ampa(0.5)")
        h("Epop[33] netConn_projEE_ampa[2674] = new NetCon(&v(0.5), syn_projEE_ampa[2674], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2675: cell 33, seg 0 (0.5) [0.5 on Epop[33]] -> cell 35, seg 0 (0.5) [0.5 on Epop[35]], weight: 4.1363508E-4, delay 1.5
        h("Epop[35] syn_projEE_ampa[2675] = new ampa(0.5)")
        h("Epop[33] netConn_projEE_ampa[2675] = new NetCon(&v(0.5), syn_projEE_ampa[2675], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2676: cell 33, seg 0 (0.5) [0.5 on Epop[33]] -> cell 36, seg 0 (0.5) [0.5 on Epop[36]], weight: 4.1363508E-4, delay 1.5
        h("Epop[36] syn_projEE_ampa[2676] = new ampa(0.5)")
        h("Epop[33] netConn_projEE_ampa[2676] = new NetCon(&v(0.5), syn_projEE_ampa[2676], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2677: cell 33, seg 0 (0.5) [0.5 on Epop[33]] -> cell 37, seg 0 (0.5) [0.5 on Epop[37]], weight: 4.1363508E-4, delay 1.5
        h("Epop[37] syn_projEE_ampa[2677] = new ampa(0.5)")
        h("Epop[33] netConn_projEE_ampa[2677] = new NetCon(&v(0.5), syn_projEE_ampa[2677], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2678: cell 33, seg 0 (0.5) [0.5 on Epop[33]] -> cell 38, seg 0 (0.5) [0.5 on Epop[38]], weight: 4.1363508E-4, delay 1.5
        h("Epop[38] syn_projEE_ampa[2678] = new ampa(0.5)")
        h("Epop[33] netConn_projEE_ampa[2678] = new NetCon(&v(0.5), syn_projEE_ampa[2678], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2679: cell 33, seg 0 (0.5) [0.5 on Epop[33]] -> cell 39, seg 0 (0.5) [0.5 on Epop[39]], weight: 4.1363508E-4, delay 1.5
        h("Epop[39] syn_projEE_ampa[2679] = new ampa(0.5)")
        h("Epop[33] netConn_projEE_ampa[2679] = new NetCon(&v(0.5), syn_projEE_ampa[2679], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2680: cell 33, seg 0 (0.5) [0.5 on Epop[33]] -> cell 40, seg 0 (0.5) [0.5 on Epop[40]], weight: 4.1363508E-4, delay 1.5
        h("Epop[40] syn_projEE_ampa[2680] = new ampa(0.5)")
        h("Epop[33] netConn_projEE_ampa[2680] = new NetCon(&v(0.5), syn_projEE_ampa[2680], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2681: cell 33, seg 0 (0.5) [0.5 on Epop[33]] -> cell 41, seg 0 (0.5) [0.5 on Epop[41]], weight: 4.1363508E-4, delay 1.5
        h("Epop[41] syn_projEE_ampa[2681] = new ampa(0.5)")
        h("Epop[33] netConn_projEE_ampa[2681] = new NetCon(&v(0.5), syn_projEE_ampa[2681], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2682: cell 33, seg 0 (0.5) [0.5 on Epop[33]] -> cell 42, seg 0 (0.5) [0.5 on Epop[42]], weight: 4.1363508E-4, delay 1.5
        h("Epop[42] syn_projEE_ampa[2682] = new ampa(0.5)")
        h("Epop[33] netConn_projEE_ampa[2682] = new NetCon(&v(0.5), syn_projEE_ampa[2682], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2683: cell 33, seg 0 (0.5) [0.5 on Epop[33]] -> cell 43, seg 0 (0.5) [0.5 on Epop[43]], weight: 4.1363508E-4, delay 1.5
        h("Epop[43] syn_projEE_ampa[2683] = new ampa(0.5)")
        h("Epop[33] netConn_projEE_ampa[2683] = new NetCon(&v(0.5), syn_projEE_ampa[2683], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2684: cell 33, seg 0 (0.5) [0.5 on Epop[33]] -> cell 44, seg 0 (0.5) [0.5 on Epop[44]], weight: 4.1363508E-4, delay 1.5
        h("Epop[44] syn_projEE_ampa[2684] = new ampa(0.5)")
        h("Epop[33] netConn_projEE_ampa[2684] = new NetCon(&v(0.5), syn_projEE_ampa[2684], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2685: cell 33, seg 0 (0.5) [0.5 on Epop[33]] -> cell 45, seg 0 (0.5) [0.5 on Epop[45]], weight: 4.1363508E-4, delay 1.5
        h("Epop[45] syn_projEE_ampa[2685] = new ampa(0.5)")
        h("Epop[33] netConn_projEE_ampa[2685] = new NetCon(&v(0.5), syn_projEE_ampa[2685], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2686: cell 33, seg 0 (0.5) [0.5 on Epop[33]] -> cell 46, seg 0 (0.5) [0.5 on Epop[46]], weight: 4.1363508E-4, delay 1.5
        h("Epop[46] syn_projEE_ampa[2686] = new ampa(0.5)")
        h("Epop[33] netConn_projEE_ampa[2686] = new NetCon(&v(0.5), syn_projEE_ampa[2686], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2687: cell 33, seg 0 (0.5) [0.5 on Epop[33]] -> cell 47, seg 0 (0.5) [0.5 on Epop[47]], weight: 4.1363508E-4, delay 1.5
        h("Epop[47] syn_projEE_ampa[2687] = new ampa(0.5)")
        h("Epop[33] netConn_projEE_ampa[2687] = new NetCon(&v(0.5), syn_projEE_ampa[2687], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2688: cell 33, seg 0 (0.5) [0.5 on Epop[33]] -> cell 48, seg 0 (0.5) [0.5 on Epop[48]], weight: 4.1363508E-4, delay 1.5
        h("Epop[48] syn_projEE_ampa[2688] = new ampa(0.5)")
        h("Epop[33] netConn_projEE_ampa[2688] = new NetCon(&v(0.5), syn_projEE_ampa[2688], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2689: cell 33, seg 0 (0.5) [0.5 on Epop[33]] -> cell 49, seg 0 (0.5) [0.5 on Epop[49]], weight: 4.1363508E-4, delay 1.5
        h("Epop[49] syn_projEE_ampa[2689] = new ampa(0.5)")
        h("Epop[33] netConn_projEE_ampa[2689] = new NetCon(&v(0.5), syn_projEE_ampa[2689], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2690: cell 33, seg 0 (0.5) [0.5 on Epop[33]] -> cell 50, seg 0 (0.5) [0.5 on Epop[50]], weight: 4.1363508E-4, delay 1.5
        h("Epop[50] syn_projEE_ampa[2690] = new ampa(0.5)")
        h("Epop[33] netConn_projEE_ampa[2690] = new NetCon(&v(0.5), syn_projEE_ampa[2690], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2691: cell 33, seg 0 (0.5) [0.5 on Epop[33]] -> cell 51, seg 0 (0.5) [0.5 on Epop[51]], weight: 4.1363508E-4, delay 1.5
        h("Epop[51] syn_projEE_ampa[2691] = new ampa(0.5)")
        h("Epop[33] netConn_projEE_ampa[2691] = new NetCon(&v(0.5), syn_projEE_ampa[2691], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2692: cell 33, seg 0 (0.5) [0.5 on Epop[33]] -> cell 52, seg 0 (0.5) [0.5 on Epop[52]], weight: 4.1363508E-4, delay 1.5
        h("Epop[52] syn_projEE_ampa[2692] = new ampa(0.5)")
        h("Epop[33] netConn_projEE_ampa[2692] = new NetCon(&v(0.5), syn_projEE_ampa[2692], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2693: cell 33, seg 0 (0.5) [0.5 on Epop[33]] -> cell 53, seg 0 (0.5) [0.5 on Epop[53]], weight: 4.1363508E-4, delay 1.5
        h("Epop[53] syn_projEE_ampa[2693] = new ampa(0.5)")
        h("Epop[33] netConn_projEE_ampa[2693] = new NetCon(&v(0.5), syn_projEE_ampa[2693], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2694: cell 33, seg 0 (0.5) [0.5 on Epop[33]] -> cell 54, seg 0 (0.5) [0.5 on Epop[54]], weight: 4.1363508E-4, delay 1.5
        h("Epop[54] syn_projEE_ampa[2694] = new ampa(0.5)")
        h("Epop[33] netConn_projEE_ampa[2694] = new NetCon(&v(0.5), syn_projEE_ampa[2694], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2695: cell 33, seg 0 (0.5) [0.5 on Epop[33]] -> cell 55, seg 0 (0.5) [0.5 on Epop[55]], weight: 4.1363508E-4, delay 1.5
        h("Epop[55] syn_projEE_ampa[2695] = new ampa(0.5)")
        h("Epop[33] netConn_projEE_ampa[2695] = new NetCon(&v(0.5), syn_projEE_ampa[2695], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2696: cell 33, seg 0 (0.5) [0.5 on Epop[33]] -> cell 56, seg 0 (0.5) [0.5 on Epop[56]], weight: 4.1363508E-4, delay 1.5
        h("Epop[56] syn_projEE_ampa[2696] = new ampa(0.5)")
        h("Epop[33] netConn_projEE_ampa[2696] = new NetCon(&v(0.5), syn_projEE_ampa[2696], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2697: cell 33, seg 0 (0.5) [0.5 on Epop[33]] -> cell 57, seg 0 (0.5) [0.5 on Epop[57]], weight: 4.1363508E-4, delay 1.5
        h("Epop[57] syn_projEE_ampa[2697] = new ampa(0.5)")
        h("Epop[33] netConn_projEE_ampa[2697] = new NetCon(&v(0.5), syn_projEE_ampa[2697], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2698: cell 33, seg 0 (0.5) [0.5 on Epop[33]] -> cell 58, seg 0 (0.5) [0.5 on Epop[58]], weight: 4.1363508E-4, delay 1.5
        h("Epop[58] syn_projEE_ampa[2698] = new ampa(0.5)")
        h("Epop[33] netConn_projEE_ampa[2698] = new NetCon(&v(0.5), syn_projEE_ampa[2698], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2699: cell 33, seg 0 (0.5) [0.5 on Epop[33]] -> cell 59, seg 0 (0.5) [0.5 on Epop[59]], weight: 4.1363508E-4, delay 1.5
        h("Epop[59] syn_projEE_ampa[2699] = new ampa(0.5)")
        h("Epop[33] netConn_projEE_ampa[2699] = new NetCon(&v(0.5), syn_projEE_ampa[2699], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2700: cell 33, seg 0 (0.5) [0.5 on Epop[33]] -> cell 60, seg 0 (0.5) [0.5 on Epop[60]], weight: 4.1363508E-4, delay 1.5
        h("Epop[60] syn_projEE_ampa[2700] = new ampa(0.5)")
        h("Epop[33] netConn_projEE_ampa[2700] = new NetCon(&v(0.5), syn_projEE_ampa[2700], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2701: cell 33, seg 0 (0.5) [0.5 on Epop[33]] -> cell 61, seg 0 (0.5) [0.5 on Epop[61]], weight: 4.1363508E-4, delay 1.5
        h("Epop[61] syn_projEE_ampa[2701] = new ampa(0.5)")
        h("Epop[33] netConn_projEE_ampa[2701] = new NetCon(&v(0.5), syn_projEE_ampa[2701], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2702: cell 33, seg 0 (0.5) [0.5 on Epop[33]] -> cell 62, seg 0 (0.5) [0.5 on Epop[62]], weight: 4.1363508E-4, delay 1.5
        h("Epop[62] syn_projEE_ampa[2702] = new ampa(0.5)")
        h("Epop[33] netConn_projEE_ampa[2702] = new NetCon(&v(0.5), syn_projEE_ampa[2702], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2703: cell 33, seg 0 (0.5) [0.5 on Epop[33]] -> cell 63, seg 0 (0.5) [0.5 on Epop[63]], weight: 4.1363508E-4, delay 1.5
        h("Epop[63] syn_projEE_ampa[2703] = new ampa(0.5)")
        h("Epop[33] netConn_projEE_ampa[2703] = new NetCon(&v(0.5), syn_projEE_ampa[2703], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2704: cell 33, seg 0 (0.5) [0.5 on Epop[33]] -> cell 64, seg 0 (0.5) [0.5 on Epop[64]], weight: 4.1363508E-4, delay 1.5
        h("Epop[64] syn_projEE_ampa[2704] = new ampa(0.5)")
        h("Epop[33] netConn_projEE_ampa[2704] = new NetCon(&v(0.5), syn_projEE_ampa[2704], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2705: cell 33, seg 0 (0.5) [0.5 on Epop[33]] -> cell 65, seg 0 (0.5) [0.5 on Epop[65]], weight: 4.1363508E-4, delay 1.5
        h("Epop[65] syn_projEE_ampa[2705] = new ampa(0.5)")
        h("Epop[33] netConn_projEE_ampa[2705] = new NetCon(&v(0.5), syn_projEE_ampa[2705], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2706: cell 33, seg 0 (0.5) [0.5 on Epop[33]] -> cell 66, seg 0 (0.5) [0.5 on Epop[66]], weight: 4.1363508E-4, delay 1.5
        h("Epop[66] syn_projEE_ampa[2706] = new ampa(0.5)")
        h("Epop[33] netConn_projEE_ampa[2706] = new NetCon(&v(0.5), syn_projEE_ampa[2706], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2707: cell 33, seg 0 (0.5) [0.5 on Epop[33]] -> cell 67, seg 0 (0.5) [0.5 on Epop[67]], weight: 4.1363508E-4, delay 1.5
        h("Epop[67] syn_projEE_ampa[2707] = new ampa(0.5)")
        h("Epop[33] netConn_projEE_ampa[2707] = new NetCon(&v(0.5), syn_projEE_ampa[2707], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2708: cell 33, seg 0 (0.5) [0.5 on Epop[33]] -> cell 68, seg 0 (0.5) [0.5 on Epop[68]], weight: 4.1363508E-4, delay 1.5
        h("Epop[68] syn_projEE_ampa[2708] = new ampa(0.5)")
        h("Epop[33] netConn_projEE_ampa[2708] = new NetCon(&v(0.5), syn_projEE_ampa[2708], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2709: cell 33, seg 0 (0.5) [0.5 on Epop[33]] -> cell 69, seg 0 (0.5) [0.5 on Epop[69]], weight: 4.1363508E-4, delay 1.5
        h("Epop[69] syn_projEE_ampa[2709] = new ampa(0.5)")
        h("Epop[33] netConn_projEE_ampa[2709] = new NetCon(&v(0.5), syn_projEE_ampa[2709], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2710: cell 33, seg 0 (0.5) [0.5 on Epop[33]] -> cell 70, seg 0 (0.5) [0.5 on Epop[70]], weight: 4.1363508E-4, delay 1.5
        h("Epop[70] syn_projEE_ampa[2710] = new ampa(0.5)")
        h("Epop[33] netConn_projEE_ampa[2710] = new NetCon(&v(0.5), syn_projEE_ampa[2710], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2711: cell 33, seg 0 (0.5) [0.5 on Epop[33]] -> cell 71, seg 0 (0.5) [0.5 on Epop[71]], weight: 4.1363508E-4, delay 1.5
        h("Epop[71] syn_projEE_ampa[2711] = new ampa(0.5)")
        h("Epop[33] netConn_projEE_ampa[2711] = new NetCon(&v(0.5), syn_projEE_ampa[2711], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2712: cell 33, seg 0 (0.5) [0.5 on Epop[33]] -> cell 72, seg 0 (0.5) [0.5 on Epop[72]], weight: 4.1363508E-4, delay 1.5
        h("Epop[72] syn_projEE_ampa[2712] = new ampa(0.5)")
        h("Epop[33] netConn_projEE_ampa[2712] = new NetCon(&v(0.5), syn_projEE_ampa[2712], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2713: cell 33, seg 0 (0.5) [0.5 on Epop[33]] -> cell 73, seg 0 (0.5) [0.5 on Epop[73]], weight: 4.1363508E-4, delay 1.5
        h("Epop[73] syn_projEE_ampa[2713] = new ampa(0.5)")
        h("Epop[33] netConn_projEE_ampa[2713] = new NetCon(&v(0.5), syn_projEE_ampa[2713], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2714: cell 33, seg 0 (0.5) [0.5 on Epop[33]] -> cell 74, seg 0 (0.5) [0.5 on Epop[74]], weight: 4.1363508E-4, delay 1.5
        h("Epop[74] syn_projEE_ampa[2714] = new ampa(0.5)")
        h("Epop[33] netConn_projEE_ampa[2714] = new NetCon(&v(0.5), syn_projEE_ampa[2714], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2715: cell 33, seg 0 (0.5) [0.5 on Epop[33]] -> cell 75, seg 0 (0.5) [0.5 on Epop[75]], weight: 4.1363508E-4, delay 1.5
        h("Epop[75] syn_projEE_ampa[2715] = new ampa(0.5)")
        h("Epop[33] netConn_projEE_ampa[2715] = new NetCon(&v(0.5), syn_projEE_ampa[2715], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2716: cell 33, seg 0 (0.5) [0.5 on Epop[33]] -> cell 76, seg 0 (0.5) [0.5 on Epop[76]], weight: 4.1363508E-4, delay 1.5
        h("Epop[76] syn_projEE_ampa[2716] = new ampa(0.5)")
        h("Epop[33] netConn_projEE_ampa[2716] = new NetCon(&v(0.5), syn_projEE_ampa[2716], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2717: cell 33, seg 0 (0.5) [0.5 on Epop[33]] -> cell 77, seg 0 (0.5) [0.5 on Epop[77]], weight: 4.1363508E-4, delay 1.5
        h("Epop[77] syn_projEE_ampa[2717] = new ampa(0.5)")
        h("Epop[33] netConn_projEE_ampa[2717] = new NetCon(&v(0.5), syn_projEE_ampa[2717], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2718: cell 33, seg 0 (0.5) [0.5 on Epop[33]] -> cell 78, seg 0 (0.5) [0.5 on Epop[78]], weight: 4.1363508E-4, delay 1.5
        h("Epop[78] syn_projEE_ampa[2718] = new ampa(0.5)")
        h("Epop[33] netConn_projEE_ampa[2718] = new NetCon(&v(0.5), syn_projEE_ampa[2718], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2719: cell 33, seg 0 (0.5) [0.5 on Epop[33]] -> cell 79, seg 0 (0.5) [0.5 on Epop[79]], weight: 4.1363508E-4, delay 1.5
        h("Epop[79] syn_projEE_ampa[2719] = new ampa(0.5)")
        h("Epop[33] netConn_projEE_ampa[2719] = new NetCon(&v(0.5), syn_projEE_ampa[2719], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2720: cell 34, seg 0 (0.5) [0.5 on Epop[34]] -> cell 0, seg 0 (0.5) [0.5 on Epop[0]], weight: 4.1363508E-4, delay 1.5
        h("Epop[0] syn_projEE_ampa[2720] = new ampa(0.5)")
        h("Epop[34] netConn_projEE_ampa[2720] = new NetCon(&v(0.5), syn_projEE_ampa[2720], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2721: cell 34, seg 0 (0.5) [0.5 on Epop[34]] -> cell 1, seg 0 (0.5) [0.5 on Epop[1]], weight: 4.1363508E-4, delay 1.5
        h("Epop[1] syn_projEE_ampa[2721] = new ampa(0.5)")
        h("Epop[34] netConn_projEE_ampa[2721] = new NetCon(&v(0.5), syn_projEE_ampa[2721], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2722: cell 34, seg 0 (0.5) [0.5 on Epop[34]] -> cell 2, seg 0 (0.5) [0.5 on Epop[2]], weight: 4.1363508E-4, delay 1.5
        h("Epop[2] syn_projEE_ampa[2722] = new ampa(0.5)")
        h("Epop[34] netConn_projEE_ampa[2722] = new NetCon(&v(0.5), syn_projEE_ampa[2722], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2723: cell 34, seg 0 (0.5) [0.5 on Epop[34]] -> cell 3, seg 0 (0.5) [0.5 on Epop[3]], weight: 4.1363508E-4, delay 1.5
        h("Epop[3] syn_projEE_ampa[2723] = new ampa(0.5)")
        h("Epop[34] netConn_projEE_ampa[2723] = new NetCon(&v(0.5), syn_projEE_ampa[2723], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2724: cell 34, seg 0 (0.5) [0.5 on Epop[34]] -> cell 4, seg 0 (0.5) [0.5 on Epop[4]], weight: 4.1363508E-4, delay 1.5
        h("Epop[4] syn_projEE_ampa[2724] = new ampa(0.5)")
        h("Epop[34] netConn_projEE_ampa[2724] = new NetCon(&v(0.5), syn_projEE_ampa[2724], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2725: cell 34, seg 0 (0.5) [0.5 on Epop[34]] -> cell 5, seg 0 (0.5) [0.5 on Epop[5]], weight: 4.1363508E-4, delay 1.5
        h("Epop[5] syn_projEE_ampa[2725] = new ampa(0.5)")
        h("Epop[34] netConn_projEE_ampa[2725] = new NetCon(&v(0.5), syn_projEE_ampa[2725], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2726: cell 34, seg 0 (0.5) [0.5 on Epop[34]] -> cell 6, seg 0 (0.5) [0.5 on Epop[6]], weight: 4.1363508E-4, delay 1.5
        h("Epop[6] syn_projEE_ampa[2726] = new ampa(0.5)")
        h("Epop[34] netConn_projEE_ampa[2726] = new NetCon(&v(0.5), syn_projEE_ampa[2726], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2727: cell 34, seg 0 (0.5) [0.5 on Epop[34]] -> cell 7, seg 0 (0.5) [0.5 on Epop[7]], weight: 4.1363508E-4, delay 1.5
        h("Epop[7] syn_projEE_ampa[2727] = new ampa(0.5)")
        h("Epop[34] netConn_projEE_ampa[2727] = new NetCon(&v(0.5), syn_projEE_ampa[2727], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2728: cell 34, seg 0 (0.5) [0.5 on Epop[34]] -> cell 8, seg 0 (0.5) [0.5 on Epop[8]], weight: 4.1363508E-4, delay 1.5
        h("Epop[8] syn_projEE_ampa[2728] = new ampa(0.5)")
        h("Epop[34] netConn_projEE_ampa[2728] = new NetCon(&v(0.5), syn_projEE_ampa[2728], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2729: cell 34, seg 0 (0.5) [0.5 on Epop[34]] -> cell 9, seg 0 (0.5) [0.5 on Epop[9]], weight: 4.1363508E-4, delay 1.5
        h("Epop[9] syn_projEE_ampa[2729] = new ampa(0.5)")
        h("Epop[34] netConn_projEE_ampa[2729] = new NetCon(&v(0.5), syn_projEE_ampa[2729], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2730: cell 34, seg 0 (0.5) [0.5 on Epop[34]] -> cell 10, seg 0 (0.5) [0.5 on Epop[10]], weight: 4.1363508E-4, delay 1.5
        h("Epop[10] syn_projEE_ampa[2730] = new ampa(0.5)")
        h("Epop[34] netConn_projEE_ampa[2730] = new NetCon(&v(0.5), syn_projEE_ampa[2730], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2731: cell 34, seg 0 (0.5) [0.5 on Epop[34]] -> cell 11, seg 0 (0.5) [0.5 on Epop[11]], weight: 4.1363508E-4, delay 1.5
        h("Epop[11] syn_projEE_ampa[2731] = new ampa(0.5)")
        h("Epop[34] netConn_projEE_ampa[2731] = new NetCon(&v(0.5), syn_projEE_ampa[2731], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2732: cell 34, seg 0 (0.5) [0.5 on Epop[34]] -> cell 12, seg 0 (0.5) [0.5 on Epop[12]], weight: 4.1363508E-4, delay 1.5
        h("Epop[12] syn_projEE_ampa[2732] = new ampa(0.5)")
        h("Epop[34] netConn_projEE_ampa[2732] = new NetCon(&v(0.5), syn_projEE_ampa[2732], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2733: cell 34, seg 0 (0.5) [0.5 on Epop[34]] -> cell 13, seg 0 (0.5) [0.5 on Epop[13]], weight: 4.1363508E-4, delay 1.5
        h("Epop[13] syn_projEE_ampa[2733] = new ampa(0.5)")
        h("Epop[34] netConn_projEE_ampa[2733] = new NetCon(&v(0.5), syn_projEE_ampa[2733], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2734: cell 34, seg 0 (0.5) [0.5 on Epop[34]] -> cell 14, seg 0 (0.5) [0.5 on Epop[14]], weight: 4.1363508E-4, delay 1.5
        h("Epop[14] syn_projEE_ampa[2734] = new ampa(0.5)")
        h("Epop[34] netConn_projEE_ampa[2734] = new NetCon(&v(0.5), syn_projEE_ampa[2734], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2735: cell 34, seg 0 (0.5) [0.5 on Epop[34]] -> cell 15, seg 0 (0.5) [0.5 on Epop[15]], weight: 4.1363508E-4, delay 1.5
        h("Epop[15] syn_projEE_ampa[2735] = new ampa(0.5)")
        h("Epop[34] netConn_projEE_ampa[2735] = new NetCon(&v(0.5), syn_projEE_ampa[2735], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2736: cell 34, seg 0 (0.5) [0.5 on Epop[34]] -> cell 16, seg 0 (0.5) [0.5 on Epop[16]], weight: 4.1363508E-4, delay 1.5
        h("Epop[16] syn_projEE_ampa[2736] = new ampa(0.5)")
        h("Epop[34] netConn_projEE_ampa[2736] = new NetCon(&v(0.5), syn_projEE_ampa[2736], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2737: cell 34, seg 0 (0.5) [0.5 on Epop[34]] -> cell 17, seg 0 (0.5) [0.5 on Epop[17]], weight: 4.1363508E-4, delay 1.5
        h("Epop[17] syn_projEE_ampa[2737] = new ampa(0.5)")
        h("Epop[34] netConn_projEE_ampa[2737] = new NetCon(&v(0.5), syn_projEE_ampa[2737], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2738: cell 34, seg 0 (0.5) [0.5 on Epop[34]] -> cell 18, seg 0 (0.5) [0.5 on Epop[18]], weight: 4.1363508E-4, delay 1.5
        h("Epop[18] syn_projEE_ampa[2738] = new ampa(0.5)")
        h("Epop[34] netConn_projEE_ampa[2738] = new NetCon(&v(0.5), syn_projEE_ampa[2738], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2739: cell 34, seg 0 (0.5) [0.5 on Epop[34]] -> cell 19, seg 0 (0.5) [0.5 on Epop[19]], weight: 4.1363508E-4, delay 1.5
        h("Epop[19] syn_projEE_ampa[2739] = new ampa(0.5)")
        h("Epop[34] netConn_projEE_ampa[2739] = new NetCon(&v(0.5), syn_projEE_ampa[2739], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2740: cell 34, seg 0 (0.5) [0.5 on Epop[34]] -> cell 20, seg 0 (0.5) [0.5 on Epop[20]], weight: 4.1363508E-4, delay 1.5
        h("Epop[20] syn_projEE_ampa[2740] = new ampa(0.5)")
        h("Epop[34] netConn_projEE_ampa[2740] = new NetCon(&v(0.5), syn_projEE_ampa[2740], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2741: cell 34, seg 0 (0.5) [0.5 on Epop[34]] -> cell 21, seg 0 (0.5) [0.5 on Epop[21]], weight: 4.1363508E-4, delay 1.5
        h("Epop[21] syn_projEE_ampa[2741] = new ampa(0.5)")
        h("Epop[34] netConn_projEE_ampa[2741] = new NetCon(&v(0.5), syn_projEE_ampa[2741], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2742: cell 34, seg 0 (0.5) [0.5 on Epop[34]] -> cell 22, seg 0 (0.5) [0.5 on Epop[22]], weight: 4.1363508E-4, delay 1.5
        h("Epop[22] syn_projEE_ampa[2742] = new ampa(0.5)")
        h("Epop[34] netConn_projEE_ampa[2742] = new NetCon(&v(0.5), syn_projEE_ampa[2742], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2743: cell 34, seg 0 (0.5) [0.5 on Epop[34]] -> cell 23, seg 0 (0.5) [0.5 on Epop[23]], weight: 4.1363508E-4, delay 1.5
        h("Epop[23] syn_projEE_ampa[2743] = new ampa(0.5)")
        h("Epop[34] netConn_projEE_ampa[2743] = new NetCon(&v(0.5), syn_projEE_ampa[2743], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2744: cell 34, seg 0 (0.5) [0.5 on Epop[34]] -> cell 24, seg 0 (0.5) [0.5 on Epop[24]], weight: 4.1363508E-4, delay 1.5
        h("Epop[24] syn_projEE_ampa[2744] = new ampa(0.5)")
        h("Epop[34] netConn_projEE_ampa[2744] = new NetCon(&v(0.5), syn_projEE_ampa[2744], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2745: cell 34, seg 0 (0.5) [0.5 on Epop[34]] -> cell 25, seg 0 (0.5) [0.5 on Epop[25]], weight: 4.1363508E-4, delay 1.5
        h("Epop[25] syn_projEE_ampa[2745] = new ampa(0.5)")
        h("Epop[34] netConn_projEE_ampa[2745] = new NetCon(&v(0.5), syn_projEE_ampa[2745], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2746: cell 34, seg 0 (0.5) [0.5 on Epop[34]] -> cell 26, seg 0 (0.5) [0.5 on Epop[26]], weight: 4.1363508E-4, delay 1.5
        h("Epop[26] syn_projEE_ampa[2746] = new ampa(0.5)")
        h("Epop[34] netConn_projEE_ampa[2746] = new NetCon(&v(0.5), syn_projEE_ampa[2746], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2747: cell 34, seg 0 (0.5) [0.5 on Epop[34]] -> cell 27, seg 0 (0.5) [0.5 on Epop[27]], weight: 4.1363508E-4, delay 1.5
        h("Epop[27] syn_projEE_ampa[2747] = new ampa(0.5)")
        h("Epop[34] netConn_projEE_ampa[2747] = new NetCon(&v(0.5), syn_projEE_ampa[2747], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2748: cell 34, seg 0 (0.5) [0.5 on Epop[34]] -> cell 28, seg 0 (0.5) [0.5 on Epop[28]], weight: 4.1363508E-4, delay 1.5
        h("Epop[28] syn_projEE_ampa[2748] = new ampa(0.5)")
        h("Epop[34] netConn_projEE_ampa[2748] = new NetCon(&v(0.5), syn_projEE_ampa[2748], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2749: cell 34, seg 0 (0.5) [0.5 on Epop[34]] -> cell 29, seg 0 (0.5) [0.5 on Epop[29]], weight: 4.1363508E-4, delay 1.5
        h("Epop[29] syn_projEE_ampa[2749] = new ampa(0.5)")
        h("Epop[34] netConn_projEE_ampa[2749] = new NetCon(&v(0.5), syn_projEE_ampa[2749], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2750: cell 34, seg 0 (0.5) [0.5 on Epop[34]] -> cell 30, seg 0 (0.5) [0.5 on Epop[30]], weight: 4.1363508E-4, delay 1.5
        h("Epop[30] syn_projEE_ampa[2750] = new ampa(0.5)")
        h("Epop[34] netConn_projEE_ampa[2750] = new NetCon(&v(0.5), syn_projEE_ampa[2750], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2751: cell 34, seg 0 (0.5) [0.5 on Epop[34]] -> cell 31, seg 0 (0.5) [0.5 on Epop[31]], weight: 4.1363508E-4, delay 1.5
        h("Epop[31] syn_projEE_ampa[2751] = new ampa(0.5)")
        h("Epop[34] netConn_projEE_ampa[2751] = new NetCon(&v(0.5), syn_projEE_ampa[2751], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2752: cell 34, seg 0 (0.5) [0.5 on Epop[34]] -> cell 32, seg 0 (0.5) [0.5 on Epop[32]], weight: 4.1363508E-4, delay 1.5
        h("Epop[32] syn_projEE_ampa[2752] = new ampa(0.5)")
        h("Epop[34] netConn_projEE_ampa[2752] = new NetCon(&v(0.5), syn_projEE_ampa[2752], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2753: cell 34, seg 0 (0.5) [0.5 on Epop[34]] -> cell 33, seg 0 (0.5) [0.5 on Epop[33]], weight: 4.1363508E-4, delay 1.5
        h("Epop[33] syn_projEE_ampa[2753] = new ampa(0.5)")
        h("Epop[34] netConn_projEE_ampa[2753] = new NetCon(&v(0.5), syn_projEE_ampa[2753], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2754: cell 34, seg 0 (0.5) [0.5 on Epop[34]] -> cell 34, seg 0 (0.5) [0.5 on Epop[34]], weight: 4.1363508E-4, delay 1.5
        h("Epop[34] syn_projEE_ampa[2754] = new ampa(0.5)")
        h("Epop[34] netConn_projEE_ampa[2754] = new NetCon(&v(0.5), syn_projEE_ampa[2754], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2755: cell 34, seg 0 (0.5) [0.5 on Epop[34]] -> cell 35, seg 0 (0.5) [0.5 on Epop[35]], weight: 4.1363508E-4, delay 1.5
        h("Epop[35] syn_projEE_ampa[2755] = new ampa(0.5)")
        h("Epop[34] netConn_projEE_ampa[2755] = new NetCon(&v(0.5), syn_projEE_ampa[2755], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2756: cell 34, seg 0 (0.5) [0.5 on Epop[34]] -> cell 36, seg 0 (0.5) [0.5 on Epop[36]], weight: 4.1363508E-4, delay 1.5
        h("Epop[36] syn_projEE_ampa[2756] = new ampa(0.5)")
        h("Epop[34] netConn_projEE_ampa[2756] = new NetCon(&v(0.5), syn_projEE_ampa[2756], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2757: cell 34, seg 0 (0.5) [0.5 on Epop[34]] -> cell 37, seg 0 (0.5) [0.5 on Epop[37]], weight: 4.1363508E-4, delay 1.5
        h("Epop[37] syn_projEE_ampa[2757] = new ampa(0.5)")
        h("Epop[34] netConn_projEE_ampa[2757] = new NetCon(&v(0.5), syn_projEE_ampa[2757], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2758: cell 34, seg 0 (0.5) [0.5 on Epop[34]] -> cell 38, seg 0 (0.5) [0.5 on Epop[38]], weight: 4.1363508E-4, delay 1.5
        h("Epop[38] syn_projEE_ampa[2758] = new ampa(0.5)")
        h("Epop[34] netConn_projEE_ampa[2758] = new NetCon(&v(0.5), syn_projEE_ampa[2758], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2759: cell 34, seg 0 (0.5) [0.5 on Epop[34]] -> cell 39, seg 0 (0.5) [0.5 on Epop[39]], weight: 4.1363508E-4, delay 1.5
        h("Epop[39] syn_projEE_ampa[2759] = new ampa(0.5)")
        h("Epop[34] netConn_projEE_ampa[2759] = new NetCon(&v(0.5), syn_projEE_ampa[2759], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2760: cell 34, seg 0 (0.5) [0.5 on Epop[34]] -> cell 40, seg 0 (0.5) [0.5 on Epop[40]], weight: 4.1363508E-4, delay 1.5
        h("Epop[40] syn_projEE_ampa[2760] = new ampa(0.5)")
        h("Epop[34] netConn_projEE_ampa[2760] = new NetCon(&v(0.5), syn_projEE_ampa[2760], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2761: cell 34, seg 0 (0.5) [0.5 on Epop[34]] -> cell 41, seg 0 (0.5) [0.5 on Epop[41]], weight: 4.1363508E-4, delay 1.5
        h("Epop[41] syn_projEE_ampa[2761] = new ampa(0.5)")
        h("Epop[34] netConn_projEE_ampa[2761] = new NetCon(&v(0.5), syn_projEE_ampa[2761], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2762: cell 34, seg 0 (0.5) [0.5 on Epop[34]] -> cell 42, seg 0 (0.5) [0.5 on Epop[42]], weight: 4.1363508E-4, delay 1.5
        h("Epop[42] syn_projEE_ampa[2762] = new ampa(0.5)")
        h("Epop[34] netConn_projEE_ampa[2762] = new NetCon(&v(0.5), syn_projEE_ampa[2762], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2763: cell 34, seg 0 (0.5) [0.5 on Epop[34]] -> cell 43, seg 0 (0.5) [0.5 on Epop[43]], weight: 4.1363508E-4, delay 1.5
        h("Epop[43] syn_projEE_ampa[2763] = new ampa(0.5)")
        h("Epop[34] netConn_projEE_ampa[2763] = new NetCon(&v(0.5), syn_projEE_ampa[2763], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2764: cell 34, seg 0 (0.5) [0.5 on Epop[34]] -> cell 44, seg 0 (0.5) [0.5 on Epop[44]], weight: 4.1363508E-4, delay 1.5
        h("Epop[44] syn_projEE_ampa[2764] = new ampa(0.5)")
        h("Epop[34] netConn_projEE_ampa[2764] = new NetCon(&v(0.5), syn_projEE_ampa[2764], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2765: cell 34, seg 0 (0.5) [0.5 on Epop[34]] -> cell 45, seg 0 (0.5) [0.5 on Epop[45]], weight: 4.1363508E-4, delay 1.5
        h("Epop[45] syn_projEE_ampa[2765] = new ampa(0.5)")
        h("Epop[34] netConn_projEE_ampa[2765] = new NetCon(&v(0.5), syn_projEE_ampa[2765], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2766: cell 34, seg 0 (0.5) [0.5 on Epop[34]] -> cell 46, seg 0 (0.5) [0.5 on Epop[46]], weight: 4.1363508E-4, delay 1.5
        h("Epop[46] syn_projEE_ampa[2766] = new ampa(0.5)")
        h("Epop[34] netConn_projEE_ampa[2766] = new NetCon(&v(0.5), syn_projEE_ampa[2766], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2767: cell 34, seg 0 (0.5) [0.5 on Epop[34]] -> cell 47, seg 0 (0.5) [0.5 on Epop[47]], weight: 4.1363508E-4, delay 1.5
        h("Epop[47] syn_projEE_ampa[2767] = new ampa(0.5)")
        h("Epop[34] netConn_projEE_ampa[2767] = new NetCon(&v(0.5), syn_projEE_ampa[2767], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2768: cell 34, seg 0 (0.5) [0.5 on Epop[34]] -> cell 48, seg 0 (0.5) [0.5 on Epop[48]], weight: 4.1363508E-4, delay 1.5
        h("Epop[48] syn_projEE_ampa[2768] = new ampa(0.5)")
        h("Epop[34] netConn_projEE_ampa[2768] = new NetCon(&v(0.5), syn_projEE_ampa[2768], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2769: cell 34, seg 0 (0.5) [0.5 on Epop[34]] -> cell 49, seg 0 (0.5) [0.5 on Epop[49]], weight: 4.1363508E-4, delay 1.5
        h("Epop[49] syn_projEE_ampa[2769] = new ampa(0.5)")
        h("Epop[34] netConn_projEE_ampa[2769] = new NetCon(&v(0.5), syn_projEE_ampa[2769], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2770: cell 34, seg 0 (0.5) [0.5 on Epop[34]] -> cell 50, seg 0 (0.5) [0.5 on Epop[50]], weight: 4.1363508E-4, delay 1.5
        h("Epop[50] syn_projEE_ampa[2770] = new ampa(0.5)")
        h("Epop[34] netConn_projEE_ampa[2770] = new NetCon(&v(0.5), syn_projEE_ampa[2770], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2771: cell 34, seg 0 (0.5) [0.5 on Epop[34]] -> cell 51, seg 0 (0.5) [0.5 on Epop[51]], weight: 4.1363508E-4, delay 1.5
        h("Epop[51] syn_projEE_ampa[2771] = new ampa(0.5)")
        h("Epop[34] netConn_projEE_ampa[2771] = new NetCon(&v(0.5), syn_projEE_ampa[2771], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2772: cell 34, seg 0 (0.5) [0.5 on Epop[34]] -> cell 52, seg 0 (0.5) [0.5 on Epop[52]], weight: 4.1363508E-4, delay 1.5
        h("Epop[52] syn_projEE_ampa[2772] = new ampa(0.5)")
        h("Epop[34] netConn_projEE_ampa[2772] = new NetCon(&v(0.5), syn_projEE_ampa[2772], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2773: cell 34, seg 0 (0.5) [0.5 on Epop[34]] -> cell 53, seg 0 (0.5) [0.5 on Epop[53]], weight: 4.1363508E-4, delay 1.5
        h("Epop[53] syn_projEE_ampa[2773] = new ampa(0.5)")
        h("Epop[34] netConn_projEE_ampa[2773] = new NetCon(&v(0.5), syn_projEE_ampa[2773], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2774: cell 34, seg 0 (0.5) [0.5 on Epop[34]] -> cell 54, seg 0 (0.5) [0.5 on Epop[54]], weight: 4.1363508E-4, delay 1.5
        h("Epop[54] syn_projEE_ampa[2774] = new ampa(0.5)")
        h("Epop[34] netConn_projEE_ampa[2774] = new NetCon(&v(0.5), syn_projEE_ampa[2774], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2775: cell 34, seg 0 (0.5) [0.5 on Epop[34]] -> cell 55, seg 0 (0.5) [0.5 on Epop[55]], weight: 4.1363508E-4, delay 1.5
        h("Epop[55] syn_projEE_ampa[2775] = new ampa(0.5)")
        h("Epop[34] netConn_projEE_ampa[2775] = new NetCon(&v(0.5), syn_projEE_ampa[2775], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2776: cell 34, seg 0 (0.5) [0.5 on Epop[34]] -> cell 56, seg 0 (0.5) [0.5 on Epop[56]], weight: 4.1363508E-4, delay 1.5
        h("Epop[56] syn_projEE_ampa[2776] = new ampa(0.5)")
        h("Epop[34] netConn_projEE_ampa[2776] = new NetCon(&v(0.5), syn_projEE_ampa[2776], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2777: cell 34, seg 0 (0.5) [0.5 on Epop[34]] -> cell 57, seg 0 (0.5) [0.5 on Epop[57]], weight: 4.1363508E-4, delay 1.5
        h("Epop[57] syn_projEE_ampa[2777] = new ampa(0.5)")
        h("Epop[34] netConn_projEE_ampa[2777] = new NetCon(&v(0.5), syn_projEE_ampa[2777], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2778: cell 34, seg 0 (0.5) [0.5 on Epop[34]] -> cell 58, seg 0 (0.5) [0.5 on Epop[58]], weight: 4.1363508E-4, delay 1.5
        h("Epop[58] syn_projEE_ampa[2778] = new ampa(0.5)")
        h("Epop[34] netConn_projEE_ampa[2778] = new NetCon(&v(0.5), syn_projEE_ampa[2778], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2779: cell 34, seg 0 (0.5) [0.5 on Epop[34]] -> cell 59, seg 0 (0.5) [0.5 on Epop[59]], weight: 4.1363508E-4, delay 1.5
        h("Epop[59] syn_projEE_ampa[2779] = new ampa(0.5)")
        h("Epop[34] netConn_projEE_ampa[2779] = new NetCon(&v(0.5), syn_projEE_ampa[2779], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2780: cell 34, seg 0 (0.5) [0.5 on Epop[34]] -> cell 60, seg 0 (0.5) [0.5 on Epop[60]], weight: 4.1363508E-4, delay 1.5
        h("Epop[60] syn_projEE_ampa[2780] = new ampa(0.5)")
        h("Epop[34] netConn_projEE_ampa[2780] = new NetCon(&v(0.5), syn_projEE_ampa[2780], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2781: cell 34, seg 0 (0.5) [0.5 on Epop[34]] -> cell 61, seg 0 (0.5) [0.5 on Epop[61]], weight: 4.1363508E-4, delay 1.5
        h("Epop[61] syn_projEE_ampa[2781] = new ampa(0.5)")
        h("Epop[34] netConn_projEE_ampa[2781] = new NetCon(&v(0.5), syn_projEE_ampa[2781], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2782: cell 34, seg 0 (0.5) [0.5 on Epop[34]] -> cell 62, seg 0 (0.5) [0.5 on Epop[62]], weight: 4.1363508E-4, delay 1.5
        h("Epop[62] syn_projEE_ampa[2782] = new ampa(0.5)")
        h("Epop[34] netConn_projEE_ampa[2782] = new NetCon(&v(0.5), syn_projEE_ampa[2782], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2783: cell 34, seg 0 (0.5) [0.5 on Epop[34]] -> cell 63, seg 0 (0.5) [0.5 on Epop[63]], weight: 4.1363508E-4, delay 1.5
        h("Epop[63] syn_projEE_ampa[2783] = new ampa(0.5)")
        h("Epop[34] netConn_projEE_ampa[2783] = new NetCon(&v(0.5), syn_projEE_ampa[2783], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2784: cell 34, seg 0 (0.5) [0.5 on Epop[34]] -> cell 64, seg 0 (0.5) [0.5 on Epop[64]], weight: 4.1363508E-4, delay 1.5
        h("Epop[64] syn_projEE_ampa[2784] = new ampa(0.5)")
        h("Epop[34] netConn_projEE_ampa[2784] = new NetCon(&v(0.5), syn_projEE_ampa[2784], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2785: cell 34, seg 0 (0.5) [0.5 on Epop[34]] -> cell 65, seg 0 (0.5) [0.5 on Epop[65]], weight: 4.1363508E-4, delay 1.5
        h("Epop[65] syn_projEE_ampa[2785] = new ampa(0.5)")
        h("Epop[34] netConn_projEE_ampa[2785] = new NetCon(&v(0.5), syn_projEE_ampa[2785], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2786: cell 34, seg 0 (0.5) [0.5 on Epop[34]] -> cell 66, seg 0 (0.5) [0.5 on Epop[66]], weight: 4.1363508E-4, delay 1.5
        h("Epop[66] syn_projEE_ampa[2786] = new ampa(0.5)")
        h("Epop[34] netConn_projEE_ampa[2786] = new NetCon(&v(0.5), syn_projEE_ampa[2786], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2787: cell 34, seg 0 (0.5) [0.5 on Epop[34]] -> cell 67, seg 0 (0.5) [0.5 on Epop[67]], weight: 4.1363508E-4, delay 1.5
        h("Epop[67] syn_projEE_ampa[2787] = new ampa(0.5)")
        h("Epop[34] netConn_projEE_ampa[2787] = new NetCon(&v(0.5), syn_projEE_ampa[2787], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2788: cell 34, seg 0 (0.5) [0.5 on Epop[34]] -> cell 68, seg 0 (0.5) [0.5 on Epop[68]], weight: 4.1363508E-4, delay 1.5
        h("Epop[68] syn_projEE_ampa[2788] = new ampa(0.5)")
        h("Epop[34] netConn_projEE_ampa[2788] = new NetCon(&v(0.5), syn_projEE_ampa[2788], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2789: cell 34, seg 0 (0.5) [0.5 on Epop[34]] -> cell 69, seg 0 (0.5) [0.5 on Epop[69]], weight: 4.1363508E-4, delay 1.5
        h("Epop[69] syn_projEE_ampa[2789] = new ampa(0.5)")
        h("Epop[34] netConn_projEE_ampa[2789] = new NetCon(&v(0.5), syn_projEE_ampa[2789], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2790: cell 34, seg 0 (0.5) [0.5 on Epop[34]] -> cell 70, seg 0 (0.5) [0.5 on Epop[70]], weight: 4.1363508E-4, delay 1.5
        h("Epop[70] syn_projEE_ampa[2790] = new ampa(0.5)")
        h("Epop[34] netConn_projEE_ampa[2790] = new NetCon(&v(0.5), syn_projEE_ampa[2790], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2791: cell 34, seg 0 (0.5) [0.5 on Epop[34]] -> cell 71, seg 0 (0.5) [0.5 on Epop[71]], weight: 4.1363508E-4, delay 1.5
        h("Epop[71] syn_projEE_ampa[2791] = new ampa(0.5)")
        h("Epop[34] netConn_projEE_ampa[2791] = new NetCon(&v(0.5), syn_projEE_ampa[2791], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2792: cell 34, seg 0 (0.5) [0.5 on Epop[34]] -> cell 72, seg 0 (0.5) [0.5 on Epop[72]], weight: 4.1363508E-4, delay 1.5
        h("Epop[72] syn_projEE_ampa[2792] = new ampa(0.5)")
        h("Epop[34] netConn_projEE_ampa[2792] = new NetCon(&v(0.5), syn_projEE_ampa[2792], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2793: cell 34, seg 0 (0.5) [0.5 on Epop[34]] -> cell 73, seg 0 (0.5) [0.5 on Epop[73]], weight: 4.1363508E-4, delay 1.5
        h("Epop[73] syn_projEE_ampa[2793] = new ampa(0.5)")
        h("Epop[34] netConn_projEE_ampa[2793] = new NetCon(&v(0.5), syn_projEE_ampa[2793], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2794: cell 34, seg 0 (0.5) [0.5 on Epop[34]] -> cell 74, seg 0 (0.5) [0.5 on Epop[74]], weight: 4.1363508E-4, delay 1.5
        h("Epop[74] syn_projEE_ampa[2794] = new ampa(0.5)")
        h("Epop[34] netConn_projEE_ampa[2794] = new NetCon(&v(0.5), syn_projEE_ampa[2794], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2795: cell 34, seg 0 (0.5) [0.5 on Epop[34]] -> cell 75, seg 0 (0.5) [0.5 on Epop[75]], weight: 4.1363508E-4, delay 1.5
        h("Epop[75] syn_projEE_ampa[2795] = new ampa(0.5)")
        h("Epop[34] netConn_projEE_ampa[2795] = new NetCon(&v(0.5), syn_projEE_ampa[2795], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2796: cell 34, seg 0 (0.5) [0.5 on Epop[34]] -> cell 76, seg 0 (0.5) [0.5 on Epop[76]], weight: 4.1363508E-4, delay 1.5
        h("Epop[76] syn_projEE_ampa[2796] = new ampa(0.5)")
        h("Epop[34] netConn_projEE_ampa[2796] = new NetCon(&v(0.5), syn_projEE_ampa[2796], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2797: cell 34, seg 0 (0.5) [0.5 on Epop[34]] -> cell 77, seg 0 (0.5) [0.5 on Epop[77]], weight: 4.1363508E-4, delay 1.5
        h("Epop[77] syn_projEE_ampa[2797] = new ampa(0.5)")
        h("Epop[34] netConn_projEE_ampa[2797] = new NetCon(&v(0.5), syn_projEE_ampa[2797], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2798: cell 34, seg 0 (0.5) [0.5 on Epop[34]] -> cell 78, seg 0 (0.5) [0.5 on Epop[78]], weight: 4.1363508E-4, delay 1.5
        h("Epop[78] syn_projEE_ampa[2798] = new ampa(0.5)")
        h("Epop[34] netConn_projEE_ampa[2798] = new NetCon(&v(0.5), syn_projEE_ampa[2798], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2799: cell 34, seg 0 (0.5) [0.5 on Epop[34]] -> cell 79, seg 0 (0.5) [0.5 on Epop[79]], weight: 4.1363508E-4, delay 1.5
        h("Epop[79] syn_projEE_ampa[2799] = new ampa(0.5)")
        h("Epop[34] netConn_projEE_ampa[2799] = new NetCon(&v(0.5), syn_projEE_ampa[2799], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2800: cell 35, seg 0 (0.5) [0.5 on Epop[35]] -> cell 0, seg 0 (0.5) [0.5 on Epop[0]], weight: 4.1363508E-4, delay 1.5
        h("Epop[0] syn_projEE_ampa[2800] = new ampa(0.5)")
        h("Epop[35] netConn_projEE_ampa[2800] = new NetCon(&v(0.5), syn_projEE_ampa[2800], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2801: cell 35, seg 0 (0.5) [0.5 on Epop[35]] -> cell 1, seg 0 (0.5) [0.5 on Epop[1]], weight: 4.1363508E-4, delay 1.5
        h("Epop[1] syn_projEE_ampa[2801] = new ampa(0.5)")
        h("Epop[35] netConn_projEE_ampa[2801] = new NetCon(&v(0.5), syn_projEE_ampa[2801], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2802: cell 35, seg 0 (0.5) [0.5 on Epop[35]] -> cell 2, seg 0 (0.5) [0.5 on Epop[2]], weight: 4.1363508E-4, delay 1.5
        h("Epop[2] syn_projEE_ampa[2802] = new ampa(0.5)")
        h("Epop[35] netConn_projEE_ampa[2802] = new NetCon(&v(0.5), syn_projEE_ampa[2802], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2803: cell 35, seg 0 (0.5) [0.5 on Epop[35]] -> cell 3, seg 0 (0.5) [0.5 on Epop[3]], weight: 4.1363508E-4, delay 1.5
        h("Epop[3] syn_projEE_ampa[2803] = new ampa(0.5)")
        h("Epop[35] netConn_projEE_ampa[2803] = new NetCon(&v(0.5), syn_projEE_ampa[2803], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2804: cell 35, seg 0 (0.5) [0.5 on Epop[35]] -> cell 4, seg 0 (0.5) [0.5 on Epop[4]], weight: 4.1363508E-4, delay 1.5
        h("Epop[4] syn_projEE_ampa[2804] = new ampa(0.5)")
        h("Epop[35] netConn_projEE_ampa[2804] = new NetCon(&v(0.5), syn_projEE_ampa[2804], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2805: cell 35, seg 0 (0.5) [0.5 on Epop[35]] -> cell 5, seg 0 (0.5) [0.5 on Epop[5]], weight: 4.1363508E-4, delay 1.5
        h("Epop[5] syn_projEE_ampa[2805] = new ampa(0.5)")
        h("Epop[35] netConn_projEE_ampa[2805] = new NetCon(&v(0.5), syn_projEE_ampa[2805], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2806: cell 35, seg 0 (0.5) [0.5 on Epop[35]] -> cell 6, seg 0 (0.5) [0.5 on Epop[6]], weight: 4.1363508E-4, delay 1.5
        h("Epop[6] syn_projEE_ampa[2806] = new ampa(0.5)")
        h("Epop[35] netConn_projEE_ampa[2806] = new NetCon(&v(0.5), syn_projEE_ampa[2806], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2807: cell 35, seg 0 (0.5) [0.5 on Epop[35]] -> cell 7, seg 0 (0.5) [0.5 on Epop[7]], weight: 4.1363508E-4, delay 1.5
        h("Epop[7] syn_projEE_ampa[2807] = new ampa(0.5)")
        h("Epop[35] netConn_projEE_ampa[2807] = new NetCon(&v(0.5), syn_projEE_ampa[2807], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2808: cell 35, seg 0 (0.5) [0.5 on Epop[35]] -> cell 8, seg 0 (0.5) [0.5 on Epop[8]], weight: 4.1363508E-4, delay 1.5
        h("Epop[8] syn_projEE_ampa[2808] = new ampa(0.5)")
        h("Epop[35] netConn_projEE_ampa[2808] = new NetCon(&v(0.5), syn_projEE_ampa[2808], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2809: cell 35, seg 0 (0.5) [0.5 on Epop[35]] -> cell 9, seg 0 (0.5) [0.5 on Epop[9]], weight: 4.1363508E-4, delay 1.5
        h("Epop[9] syn_projEE_ampa[2809] = new ampa(0.5)")
        h("Epop[35] netConn_projEE_ampa[2809] = new NetCon(&v(0.5), syn_projEE_ampa[2809], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2810: cell 35, seg 0 (0.5) [0.5 on Epop[35]] -> cell 10, seg 0 (0.5) [0.5 on Epop[10]], weight: 4.1363508E-4, delay 1.5
        h("Epop[10] syn_projEE_ampa[2810] = new ampa(0.5)")
        h("Epop[35] netConn_projEE_ampa[2810] = new NetCon(&v(0.5), syn_projEE_ampa[2810], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2811: cell 35, seg 0 (0.5) [0.5 on Epop[35]] -> cell 11, seg 0 (0.5) [0.5 on Epop[11]], weight: 4.1363508E-4, delay 1.5
        h("Epop[11] syn_projEE_ampa[2811] = new ampa(0.5)")
        h("Epop[35] netConn_projEE_ampa[2811] = new NetCon(&v(0.5), syn_projEE_ampa[2811], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2812: cell 35, seg 0 (0.5) [0.5 on Epop[35]] -> cell 12, seg 0 (0.5) [0.5 on Epop[12]], weight: 4.1363508E-4, delay 1.5
        h("Epop[12] syn_projEE_ampa[2812] = new ampa(0.5)")
        h("Epop[35] netConn_projEE_ampa[2812] = new NetCon(&v(0.5), syn_projEE_ampa[2812], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2813: cell 35, seg 0 (0.5) [0.5 on Epop[35]] -> cell 13, seg 0 (0.5) [0.5 on Epop[13]], weight: 4.1363508E-4, delay 1.5
        h("Epop[13] syn_projEE_ampa[2813] = new ampa(0.5)")
        h("Epop[35] netConn_projEE_ampa[2813] = new NetCon(&v(0.5), syn_projEE_ampa[2813], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2814: cell 35, seg 0 (0.5) [0.5 on Epop[35]] -> cell 14, seg 0 (0.5) [0.5 on Epop[14]], weight: 4.1363508E-4, delay 1.5
        h("Epop[14] syn_projEE_ampa[2814] = new ampa(0.5)")
        h("Epop[35] netConn_projEE_ampa[2814] = new NetCon(&v(0.5), syn_projEE_ampa[2814], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2815: cell 35, seg 0 (0.5) [0.5 on Epop[35]] -> cell 15, seg 0 (0.5) [0.5 on Epop[15]], weight: 4.1363508E-4, delay 1.5
        h("Epop[15] syn_projEE_ampa[2815] = new ampa(0.5)")
        h("Epop[35] netConn_projEE_ampa[2815] = new NetCon(&v(0.5), syn_projEE_ampa[2815], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2816: cell 35, seg 0 (0.5) [0.5 on Epop[35]] -> cell 16, seg 0 (0.5) [0.5 on Epop[16]], weight: 4.1363508E-4, delay 1.5
        h("Epop[16] syn_projEE_ampa[2816] = new ampa(0.5)")
        h("Epop[35] netConn_projEE_ampa[2816] = new NetCon(&v(0.5), syn_projEE_ampa[2816], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2817: cell 35, seg 0 (0.5) [0.5 on Epop[35]] -> cell 17, seg 0 (0.5) [0.5 on Epop[17]], weight: 4.1363508E-4, delay 1.5
        h("Epop[17] syn_projEE_ampa[2817] = new ampa(0.5)")
        h("Epop[35] netConn_projEE_ampa[2817] = new NetCon(&v(0.5), syn_projEE_ampa[2817], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2818: cell 35, seg 0 (0.5) [0.5 on Epop[35]] -> cell 18, seg 0 (0.5) [0.5 on Epop[18]], weight: 4.1363508E-4, delay 1.5
        h("Epop[18] syn_projEE_ampa[2818] = new ampa(0.5)")
        h("Epop[35] netConn_projEE_ampa[2818] = new NetCon(&v(0.5), syn_projEE_ampa[2818], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2819: cell 35, seg 0 (0.5) [0.5 on Epop[35]] -> cell 19, seg 0 (0.5) [0.5 on Epop[19]], weight: 4.1363508E-4, delay 1.5
        h("Epop[19] syn_projEE_ampa[2819] = new ampa(0.5)")
        h("Epop[35] netConn_projEE_ampa[2819] = new NetCon(&v(0.5), syn_projEE_ampa[2819], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2820: cell 35, seg 0 (0.5) [0.5 on Epop[35]] -> cell 20, seg 0 (0.5) [0.5 on Epop[20]], weight: 4.1363508E-4, delay 1.5
        h("Epop[20] syn_projEE_ampa[2820] = new ampa(0.5)")
        h("Epop[35] netConn_projEE_ampa[2820] = new NetCon(&v(0.5), syn_projEE_ampa[2820], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2821: cell 35, seg 0 (0.5) [0.5 on Epop[35]] -> cell 21, seg 0 (0.5) [0.5 on Epop[21]], weight: 4.1363508E-4, delay 1.5
        h("Epop[21] syn_projEE_ampa[2821] = new ampa(0.5)")
        h("Epop[35] netConn_projEE_ampa[2821] = new NetCon(&v(0.5), syn_projEE_ampa[2821], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2822: cell 35, seg 0 (0.5) [0.5 on Epop[35]] -> cell 22, seg 0 (0.5) [0.5 on Epop[22]], weight: 4.1363508E-4, delay 1.5
        h("Epop[22] syn_projEE_ampa[2822] = new ampa(0.5)")
        h("Epop[35] netConn_projEE_ampa[2822] = new NetCon(&v(0.5), syn_projEE_ampa[2822], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2823: cell 35, seg 0 (0.5) [0.5 on Epop[35]] -> cell 23, seg 0 (0.5) [0.5 on Epop[23]], weight: 4.1363508E-4, delay 1.5
        h("Epop[23] syn_projEE_ampa[2823] = new ampa(0.5)")
        h("Epop[35] netConn_projEE_ampa[2823] = new NetCon(&v(0.5), syn_projEE_ampa[2823], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2824: cell 35, seg 0 (0.5) [0.5 on Epop[35]] -> cell 24, seg 0 (0.5) [0.5 on Epop[24]], weight: 4.1363508E-4, delay 1.5
        h("Epop[24] syn_projEE_ampa[2824] = new ampa(0.5)")
        h("Epop[35] netConn_projEE_ampa[2824] = new NetCon(&v(0.5), syn_projEE_ampa[2824], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2825: cell 35, seg 0 (0.5) [0.5 on Epop[35]] -> cell 25, seg 0 (0.5) [0.5 on Epop[25]], weight: 4.1363508E-4, delay 1.5
        h("Epop[25] syn_projEE_ampa[2825] = new ampa(0.5)")
        h("Epop[35] netConn_projEE_ampa[2825] = new NetCon(&v(0.5), syn_projEE_ampa[2825], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2826: cell 35, seg 0 (0.5) [0.5 on Epop[35]] -> cell 26, seg 0 (0.5) [0.5 on Epop[26]], weight: 4.1363508E-4, delay 1.5
        h("Epop[26] syn_projEE_ampa[2826] = new ampa(0.5)")
        h("Epop[35] netConn_projEE_ampa[2826] = new NetCon(&v(0.5), syn_projEE_ampa[2826], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2827: cell 35, seg 0 (0.5) [0.5 on Epop[35]] -> cell 27, seg 0 (0.5) [0.5 on Epop[27]], weight: 4.1363508E-4, delay 1.5
        h("Epop[27] syn_projEE_ampa[2827] = new ampa(0.5)")
        h("Epop[35] netConn_projEE_ampa[2827] = new NetCon(&v(0.5), syn_projEE_ampa[2827], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2828: cell 35, seg 0 (0.5) [0.5 on Epop[35]] -> cell 28, seg 0 (0.5) [0.5 on Epop[28]], weight: 4.1363508E-4, delay 1.5
        h("Epop[28] syn_projEE_ampa[2828] = new ampa(0.5)")
        h("Epop[35] netConn_projEE_ampa[2828] = new NetCon(&v(0.5), syn_projEE_ampa[2828], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2829: cell 35, seg 0 (0.5) [0.5 on Epop[35]] -> cell 29, seg 0 (0.5) [0.5 on Epop[29]], weight: 4.1363508E-4, delay 1.5
        h("Epop[29] syn_projEE_ampa[2829] = new ampa(0.5)")
        h("Epop[35] netConn_projEE_ampa[2829] = new NetCon(&v(0.5), syn_projEE_ampa[2829], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2830: cell 35, seg 0 (0.5) [0.5 on Epop[35]] -> cell 30, seg 0 (0.5) [0.5 on Epop[30]], weight: 4.1363508E-4, delay 1.5
        h("Epop[30] syn_projEE_ampa[2830] = new ampa(0.5)")
        h("Epop[35] netConn_projEE_ampa[2830] = new NetCon(&v(0.5), syn_projEE_ampa[2830], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2831: cell 35, seg 0 (0.5) [0.5 on Epop[35]] -> cell 31, seg 0 (0.5) [0.5 on Epop[31]], weight: 4.1363508E-4, delay 1.5
        h("Epop[31] syn_projEE_ampa[2831] = new ampa(0.5)")
        h("Epop[35] netConn_projEE_ampa[2831] = new NetCon(&v(0.5), syn_projEE_ampa[2831], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2832: cell 35, seg 0 (0.5) [0.5 on Epop[35]] -> cell 32, seg 0 (0.5) [0.5 on Epop[32]], weight: 4.1363508E-4, delay 1.5
        h("Epop[32] syn_projEE_ampa[2832] = new ampa(0.5)")
        h("Epop[35] netConn_projEE_ampa[2832] = new NetCon(&v(0.5), syn_projEE_ampa[2832], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2833: cell 35, seg 0 (0.5) [0.5 on Epop[35]] -> cell 33, seg 0 (0.5) [0.5 on Epop[33]], weight: 4.1363508E-4, delay 1.5
        h("Epop[33] syn_projEE_ampa[2833] = new ampa(0.5)")
        h("Epop[35] netConn_projEE_ampa[2833] = new NetCon(&v(0.5), syn_projEE_ampa[2833], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2834: cell 35, seg 0 (0.5) [0.5 on Epop[35]] -> cell 34, seg 0 (0.5) [0.5 on Epop[34]], weight: 4.1363508E-4, delay 1.5
        h("Epop[34] syn_projEE_ampa[2834] = new ampa(0.5)")
        h("Epop[35] netConn_projEE_ampa[2834] = new NetCon(&v(0.5), syn_projEE_ampa[2834], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2835: cell 35, seg 0 (0.5) [0.5 on Epop[35]] -> cell 35, seg 0 (0.5) [0.5 on Epop[35]], weight: 4.1363508E-4, delay 1.5
        h("Epop[35] syn_projEE_ampa[2835] = new ampa(0.5)")
        h("Epop[35] netConn_projEE_ampa[2835] = new NetCon(&v(0.5), syn_projEE_ampa[2835], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2836: cell 35, seg 0 (0.5) [0.5 on Epop[35]] -> cell 36, seg 0 (0.5) [0.5 on Epop[36]], weight: 4.1363508E-4, delay 1.5
        h("Epop[36] syn_projEE_ampa[2836] = new ampa(0.5)")
        h("Epop[35] netConn_projEE_ampa[2836] = new NetCon(&v(0.5), syn_projEE_ampa[2836], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2837: cell 35, seg 0 (0.5) [0.5 on Epop[35]] -> cell 37, seg 0 (0.5) [0.5 on Epop[37]], weight: 4.1363508E-4, delay 1.5
        h("Epop[37] syn_projEE_ampa[2837] = new ampa(0.5)")
        h("Epop[35] netConn_projEE_ampa[2837] = new NetCon(&v(0.5), syn_projEE_ampa[2837], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2838: cell 35, seg 0 (0.5) [0.5 on Epop[35]] -> cell 38, seg 0 (0.5) [0.5 on Epop[38]], weight: 4.1363508E-4, delay 1.5
        h("Epop[38] syn_projEE_ampa[2838] = new ampa(0.5)")
        h("Epop[35] netConn_projEE_ampa[2838] = new NetCon(&v(0.5), syn_projEE_ampa[2838], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2839: cell 35, seg 0 (0.5) [0.5 on Epop[35]] -> cell 39, seg 0 (0.5) [0.5 on Epop[39]], weight: 4.1363508E-4, delay 1.5
        h("Epop[39] syn_projEE_ampa[2839] = new ampa(0.5)")
        h("Epop[35] netConn_projEE_ampa[2839] = new NetCon(&v(0.5), syn_projEE_ampa[2839], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2840: cell 35, seg 0 (0.5) [0.5 on Epop[35]] -> cell 40, seg 0 (0.5) [0.5 on Epop[40]], weight: 4.1363508E-4, delay 1.5
        h("Epop[40] syn_projEE_ampa[2840] = new ampa(0.5)")
        h("Epop[35] netConn_projEE_ampa[2840] = new NetCon(&v(0.5), syn_projEE_ampa[2840], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2841: cell 35, seg 0 (0.5) [0.5 on Epop[35]] -> cell 41, seg 0 (0.5) [0.5 on Epop[41]], weight: 4.1363508E-4, delay 1.5
        h("Epop[41] syn_projEE_ampa[2841] = new ampa(0.5)")
        h("Epop[35] netConn_projEE_ampa[2841] = new NetCon(&v(0.5), syn_projEE_ampa[2841], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2842: cell 35, seg 0 (0.5) [0.5 on Epop[35]] -> cell 42, seg 0 (0.5) [0.5 on Epop[42]], weight: 4.1363508E-4, delay 1.5
        h("Epop[42] syn_projEE_ampa[2842] = new ampa(0.5)")
        h("Epop[35] netConn_projEE_ampa[2842] = new NetCon(&v(0.5), syn_projEE_ampa[2842], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2843: cell 35, seg 0 (0.5) [0.5 on Epop[35]] -> cell 43, seg 0 (0.5) [0.5 on Epop[43]], weight: 4.1363508E-4, delay 1.5
        h("Epop[43] syn_projEE_ampa[2843] = new ampa(0.5)")
        h("Epop[35] netConn_projEE_ampa[2843] = new NetCon(&v(0.5), syn_projEE_ampa[2843], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2844: cell 35, seg 0 (0.5) [0.5 on Epop[35]] -> cell 44, seg 0 (0.5) [0.5 on Epop[44]], weight: 4.1363508E-4, delay 1.5
        h("Epop[44] syn_projEE_ampa[2844] = new ampa(0.5)")
        h("Epop[35] netConn_projEE_ampa[2844] = new NetCon(&v(0.5), syn_projEE_ampa[2844], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2845: cell 35, seg 0 (0.5) [0.5 on Epop[35]] -> cell 45, seg 0 (0.5) [0.5 on Epop[45]], weight: 4.1363508E-4, delay 1.5
        h("Epop[45] syn_projEE_ampa[2845] = new ampa(0.5)")
        h("Epop[35] netConn_projEE_ampa[2845] = new NetCon(&v(0.5), syn_projEE_ampa[2845], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2846: cell 35, seg 0 (0.5) [0.5 on Epop[35]] -> cell 46, seg 0 (0.5) [0.5 on Epop[46]], weight: 4.1363508E-4, delay 1.5
        h("Epop[46] syn_projEE_ampa[2846] = new ampa(0.5)")
        h("Epop[35] netConn_projEE_ampa[2846] = new NetCon(&v(0.5), syn_projEE_ampa[2846], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2847: cell 35, seg 0 (0.5) [0.5 on Epop[35]] -> cell 47, seg 0 (0.5) [0.5 on Epop[47]], weight: 4.1363508E-4, delay 1.5
        h("Epop[47] syn_projEE_ampa[2847] = new ampa(0.5)")
        h("Epop[35] netConn_projEE_ampa[2847] = new NetCon(&v(0.5), syn_projEE_ampa[2847], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2848: cell 35, seg 0 (0.5) [0.5 on Epop[35]] -> cell 48, seg 0 (0.5) [0.5 on Epop[48]], weight: 4.1363508E-4, delay 1.5
        h("Epop[48] syn_projEE_ampa[2848] = new ampa(0.5)")
        h("Epop[35] netConn_projEE_ampa[2848] = new NetCon(&v(0.5), syn_projEE_ampa[2848], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2849: cell 35, seg 0 (0.5) [0.5 on Epop[35]] -> cell 49, seg 0 (0.5) [0.5 on Epop[49]], weight: 4.1363508E-4, delay 1.5
        h("Epop[49] syn_projEE_ampa[2849] = new ampa(0.5)")
        h("Epop[35] netConn_projEE_ampa[2849] = new NetCon(&v(0.5), syn_projEE_ampa[2849], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2850: cell 35, seg 0 (0.5) [0.5 on Epop[35]] -> cell 50, seg 0 (0.5) [0.5 on Epop[50]], weight: 4.1363508E-4, delay 1.5
        h("Epop[50] syn_projEE_ampa[2850] = new ampa(0.5)")
        h("Epop[35] netConn_projEE_ampa[2850] = new NetCon(&v(0.5), syn_projEE_ampa[2850], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2851: cell 35, seg 0 (0.5) [0.5 on Epop[35]] -> cell 51, seg 0 (0.5) [0.5 on Epop[51]], weight: 4.1363508E-4, delay 1.5
        h("Epop[51] syn_projEE_ampa[2851] = new ampa(0.5)")
        h("Epop[35] netConn_projEE_ampa[2851] = new NetCon(&v(0.5), syn_projEE_ampa[2851], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2852: cell 35, seg 0 (0.5) [0.5 on Epop[35]] -> cell 52, seg 0 (0.5) [0.5 on Epop[52]], weight: 4.1363508E-4, delay 1.5
        h("Epop[52] syn_projEE_ampa[2852] = new ampa(0.5)")
        h("Epop[35] netConn_projEE_ampa[2852] = new NetCon(&v(0.5), syn_projEE_ampa[2852], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2853: cell 35, seg 0 (0.5) [0.5 on Epop[35]] -> cell 53, seg 0 (0.5) [0.5 on Epop[53]], weight: 4.1363508E-4, delay 1.5
        h("Epop[53] syn_projEE_ampa[2853] = new ampa(0.5)")
        h("Epop[35] netConn_projEE_ampa[2853] = new NetCon(&v(0.5), syn_projEE_ampa[2853], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2854: cell 35, seg 0 (0.5) [0.5 on Epop[35]] -> cell 54, seg 0 (0.5) [0.5 on Epop[54]], weight: 4.1363508E-4, delay 1.5
        h("Epop[54] syn_projEE_ampa[2854] = new ampa(0.5)")
        h("Epop[35] netConn_projEE_ampa[2854] = new NetCon(&v(0.5), syn_projEE_ampa[2854], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2855: cell 35, seg 0 (0.5) [0.5 on Epop[35]] -> cell 55, seg 0 (0.5) [0.5 on Epop[55]], weight: 4.1363508E-4, delay 1.5
        h("Epop[55] syn_projEE_ampa[2855] = new ampa(0.5)")
        h("Epop[35] netConn_projEE_ampa[2855] = new NetCon(&v(0.5), syn_projEE_ampa[2855], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2856: cell 35, seg 0 (0.5) [0.5 on Epop[35]] -> cell 56, seg 0 (0.5) [0.5 on Epop[56]], weight: 4.1363508E-4, delay 1.5
        h("Epop[56] syn_projEE_ampa[2856] = new ampa(0.5)")
        h("Epop[35] netConn_projEE_ampa[2856] = new NetCon(&v(0.5), syn_projEE_ampa[2856], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2857: cell 35, seg 0 (0.5) [0.5 on Epop[35]] -> cell 57, seg 0 (0.5) [0.5 on Epop[57]], weight: 4.1363508E-4, delay 1.5
        h("Epop[57] syn_projEE_ampa[2857] = new ampa(0.5)")
        h("Epop[35] netConn_projEE_ampa[2857] = new NetCon(&v(0.5), syn_projEE_ampa[2857], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2858: cell 35, seg 0 (0.5) [0.5 on Epop[35]] -> cell 58, seg 0 (0.5) [0.5 on Epop[58]], weight: 4.1363508E-4, delay 1.5
        h("Epop[58] syn_projEE_ampa[2858] = new ampa(0.5)")
        h("Epop[35] netConn_projEE_ampa[2858] = new NetCon(&v(0.5), syn_projEE_ampa[2858], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2859: cell 35, seg 0 (0.5) [0.5 on Epop[35]] -> cell 59, seg 0 (0.5) [0.5 on Epop[59]], weight: 4.1363508E-4, delay 1.5
        h("Epop[59] syn_projEE_ampa[2859] = new ampa(0.5)")
        h("Epop[35] netConn_projEE_ampa[2859] = new NetCon(&v(0.5), syn_projEE_ampa[2859], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2860: cell 35, seg 0 (0.5) [0.5 on Epop[35]] -> cell 60, seg 0 (0.5) [0.5 on Epop[60]], weight: 4.1363508E-4, delay 1.5
        h("Epop[60] syn_projEE_ampa[2860] = new ampa(0.5)")
        h("Epop[35] netConn_projEE_ampa[2860] = new NetCon(&v(0.5), syn_projEE_ampa[2860], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2861: cell 35, seg 0 (0.5) [0.5 on Epop[35]] -> cell 61, seg 0 (0.5) [0.5 on Epop[61]], weight: 4.1363508E-4, delay 1.5
        h("Epop[61] syn_projEE_ampa[2861] = new ampa(0.5)")
        h("Epop[35] netConn_projEE_ampa[2861] = new NetCon(&v(0.5), syn_projEE_ampa[2861], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2862: cell 35, seg 0 (0.5) [0.5 on Epop[35]] -> cell 62, seg 0 (0.5) [0.5 on Epop[62]], weight: 4.1363508E-4, delay 1.5
        h("Epop[62] syn_projEE_ampa[2862] = new ampa(0.5)")
        h("Epop[35] netConn_projEE_ampa[2862] = new NetCon(&v(0.5), syn_projEE_ampa[2862], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2863: cell 35, seg 0 (0.5) [0.5 on Epop[35]] -> cell 63, seg 0 (0.5) [0.5 on Epop[63]], weight: 4.1363508E-4, delay 1.5
        h("Epop[63] syn_projEE_ampa[2863] = new ampa(0.5)")
        h("Epop[35] netConn_projEE_ampa[2863] = new NetCon(&v(0.5), syn_projEE_ampa[2863], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2864: cell 35, seg 0 (0.5) [0.5 on Epop[35]] -> cell 64, seg 0 (0.5) [0.5 on Epop[64]], weight: 4.1363508E-4, delay 1.5
        h("Epop[64] syn_projEE_ampa[2864] = new ampa(0.5)")
        h("Epop[35] netConn_projEE_ampa[2864] = new NetCon(&v(0.5), syn_projEE_ampa[2864], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2865: cell 35, seg 0 (0.5) [0.5 on Epop[35]] -> cell 65, seg 0 (0.5) [0.5 on Epop[65]], weight: 4.1363508E-4, delay 1.5
        h("Epop[65] syn_projEE_ampa[2865] = new ampa(0.5)")
        h("Epop[35] netConn_projEE_ampa[2865] = new NetCon(&v(0.5), syn_projEE_ampa[2865], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2866: cell 35, seg 0 (0.5) [0.5 on Epop[35]] -> cell 66, seg 0 (0.5) [0.5 on Epop[66]], weight: 4.1363508E-4, delay 1.5
        h("Epop[66] syn_projEE_ampa[2866] = new ampa(0.5)")
        h("Epop[35] netConn_projEE_ampa[2866] = new NetCon(&v(0.5), syn_projEE_ampa[2866], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2867: cell 35, seg 0 (0.5) [0.5 on Epop[35]] -> cell 67, seg 0 (0.5) [0.5 on Epop[67]], weight: 4.1363508E-4, delay 1.5
        h("Epop[67] syn_projEE_ampa[2867] = new ampa(0.5)")
        h("Epop[35] netConn_projEE_ampa[2867] = new NetCon(&v(0.5), syn_projEE_ampa[2867], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2868: cell 35, seg 0 (0.5) [0.5 on Epop[35]] -> cell 68, seg 0 (0.5) [0.5 on Epop[68]], weight: 4.1363508E-4, delay 1.5
        h("Epop[68] syn_projEE_ampa[2868] = new ampa(0.5)")
        h("Epop[35] netConn_projEE_ampa[2868] = new NetCon(&v(0.5), syn_projEE_ampa[2868], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2869: cell 35, seg 0 (0.5) [0.5 on Epop[35]] -> cell 69, seg 0 (0.5) [0.5 on Epop[69]], weight: 4.1363508E-4, delay 1.5
        h("Epop[69] syn_projEE_ampa[2869] = new ampa(0.5)")
        h("Epop[35] netConn_projEE_ampa[2869] = new NetCon(&v(0.5), syn_projEE_ampa[2869], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2870: cell 35, seg 0 (0.5) [0.5 on Epop[35]] -> cell 70, seg 0 (0.5) [0.5 on Epop[70]], weight: 4.1363508E-4, delay 1.5
        h("Epop[70] syn_projEE_ampa[2870] = new ampa(0.5)")
        h("Epop[35] netConn_projEE_ampa[2870] = new NetCon(&v(0.5), syn_projEE_ampa[2870], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2871: cell 35, seg 0 (0.5) [0.5 on Epop[35]] -> cell 71, seg 0 (0.5) [0.5 on Epop[71]], weight: 4.1363508E-4, delay 1.5
        h("Epop[71] syn_projEE_ampa[2871] = new ampa(0.5)")
        h("Epop[35] netConn_projEE_ampa[2871] = new NetCon(&v(0.5), syn_projEE_ampa[2871], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2872: cell 35, seg 0 (0.5) [0.5 on Epop[35]] -> cell 72, seg 0 (0.5) [0.5 on Epop[72]], weight: 4.1363508E-4, delay 1.5
        h("Epop[72] syn_projEE_ampa[2872] = new ampa(0.5)")
        h("Epop[35] netConn_projEE_ampa[2872] = new NetCon(&v(0.5), syn_projEE_ampa[2872], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2873: cell 35, seg 0 (0.5) [0.5 on Epop[35]] -> cell 73, seg 0 (0.5) [0.5 on Epop[73]], weight: 4.1363508E-4, delay 1.5
        h("Epop[73] syn_projEE_ampa[2873] = new ampa(0.5)")
        h("Epop[35] netConn_projEE_ampa[2873] = new NetCon(&v(0.5), syn_projEE_ampa[2873], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2874: cell 35, seg 0 (0.5) [0.5 on Epop[35]] -> cell 74, seg 0 (0.5) [0.5 on Epop[74]], weight: 4.1363508E-4, delay 1.5
        h("Epop[74] syn_projEE_ampa[2874] = new ampa(0.5)")
        h("Epop[35] netConn_projEE_ampa[2874] = new NetCon(&v(0.5), syn_projEE_ampa[2874], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2875: cell 35, seg 0 (0.5) [0.5 on Epop[35]] -> cell 75, seg 0 (0.5) [0.5 on Epop[75]], weight: 4.1363508E-4, delay 1.5
        h("Epop[75] syn_projEE_ampa[2875] = new ampa(0.5)")
        h("Epop[35] netConn_projEE_ampa[2875] = new NetCon(&v(0.5), syn_projEE_ampa[2875], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2876: cell 35, seg 0 (0.5) [0.5 on Epop[35]] -> cell 76, seg 0 (0.5) [0.5 on Epop[76]], weight: 4.1363508E-4, delay 1.5
        h("Epop[76] syn_projEE_ampa[2876] = new ampa(0.5)")
        h("Epop[35] netConn_projEE_ampa[2876] = new NetCon(&v(0.5), syn_projEE_ampa[2876], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2877: cell 35, seg 0 (0.5) [0.5 on Epop[35]] -> cell 77, seg 0 (0.5) [0.5 on Epop[77]], weight: 4.1363508E-4, delay 1.5
        h("Epop[77] syn_projEE_ampa[2877] = new ampa(0.5)")
        h("Epop[35] netConn_projEE_ampa[2877] = new NetCon(&v(0.5), syn_projEE_ampa[2877], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2878: cell 35, seg 0 (0.5) [0.5 on Epop[35]] -> cell 78, seg 0 (0.5) [0.5 on Epop[78]], weight: 4.1363508E-4, delay 1.5
        h("Epop[78] syn_projEE_ampa[2878] = new ampa(0.5)")
        h("Epop[35] netConn_projEE_ampa[2878] = new NetCon(&v(0.5), syn_projEE_ampa[2878], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2879: cell 35, seg 0 (0.5) [0.5 on Epop[35]] -> cell 79, seg 0 (0.5) [0.5 on Epop[79]], weight: 4.1363508E-4, delay 1.5
        h("Epop[79] syn_projEE_ampa[2879] = new ampa(0.5)")
        h("Epop[35] netConn_projEE_ampa[2879] = new NetCon(&v(0.5), syn_projEE_ampa[2879], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2880: cell 36, seg 0 (0.5) [0.5 on Epop[36]] -> cell 0, seg 0 (0.5) [0.5 on Epop[0]], weight: 4.1363508E-4, delay 1.5
        h("Epop[0] syn_projEE_ampa[2880] = new ampa(0.5)")
        h("Epop[36] netConn_projEE_ampa[2880] = new NetCon(&v(0.5), syn_projEE_ampa[2880], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2881: cell 36, seg 0 (0.5) [0.5 on Epop[36]] -> cell 1, seg 0 (0.5) [0.5 on Epop[1]], weight: 4.1363508E-4, delay 1.5
        h("Epop[1] syn_projEE_ampa[2881] = new ampa(0.5)")
        h("Epop[36] netConn_projEE_ampa[2881] = new NetCon(&v(0.5), syn_projEE_ampa[2881], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2882: cell 36, seg 0 (0.5) [0.5 on Epop[36]] -> cell 2, seg 0 (0.5) [0.5 on Epop[2]], weight: 4.1363508E-4, delay 1.5
        h("Epop[2] syn_projEE_ampa[2882] = new ampa(0.5)")
        h("Epop[36] netConn_projEE_ampa[2882] = new NetCon(&v(0.5), syn_projEE_ampa[2882], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2883: cell 36, seg 0 (0.5) [0.5 on Epop[36]] -> cell 3, seg 0 (0.5) [0.5 on Epop[3]], weight: 4.1363508E-4, delay 1.5
        h("Epop[3] syn_projEE_ampa[2883] = new ampa(0.5)")
        h("Epop[36] netConn_projEE_ampa[2883] = new NetCon(&v(0.5), syn_projEE_ampa[2883], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2884: cell 36, seg 0 (0.5) [0.5 on Epop[36]] -> cell 4, seg 0 (0.5) [0.5 on Epop[4]], weight: 4.1363508E-4, delay 1.5
        h("Epop[4] syn_projEE_ampa[2884] = new ampa(0.5)")
        h("Epop[36] netConn_projEE_ampa[2884] = new NetCon(&v(0.5), syn_projEE_ampa[2884], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2885: cell 36, seg 0 (0.5) [0.5 on Epop[36]] -> cell 5, seg 0 (0.5) [0.5 on Epop[5]], weight: 4.1363508E-4, delay 1.5
        h("Epop[5] syn_projEE_ampa[2885] = new ampa(0.5)")
        h("Epop[36] netConn_projEE_ampa[2885] = new NetCon(&v(0.5), syn_projEE_ampa[2885], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2886: cell 36, seg 0 (0.5) [0.5 on Epop[36]] -> cell 6, seg 0 (0.5) [0.5 on Epop[6]], weight: 4.1363508E-4, delay 1.5
        h("Epop[6] syn_projEE_ampa[2886] = new ampa(0.5)")
        h("Epop[36] netConn_projEE_ampa[2886] = new NetCon(&v(0.5), syn_projEE_ampa[2886], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2887: cell 36, seg 0 (0.5) [0.5 on Epop[36]] -> cell 7, seg 0 (0.5) [0.5 on Epop[7]], weight: 4.1363508E-4, delay 1.5
        h("Epop[7] syn_projEE_ampa[2887] = new ampa(0.5)")
        h("Epop[36] netConn_projEE_ampa[2887] = new NetCon(&v(0.5), syn_projEE_ampa[2887], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2888: cell 36, seg 0 (0.5) [0.5 on Epop[36]] -> cell 8, seg 0 (0.5) [0.5 on Epop[8]], weight: 4.1363508E-4, delay 1.5
        h("Epop[8] syn_projEE_ampa[2888] = new ampa(0.5)")
        h("Epop[36] netConn_projEE_ampa[2888] = new NetCon(&v(0.5), syn_projEE_ampa[2888], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2889: cell 36, seg 0 (0.5) [0.5 on Epop[36]] -> cell 9, seg 0 (0.5) [0.5 on Epop[9]], weight: 4.1363508E-4, delay 1.5
        h("Epop[9] syn_projEE_ampa[2889] = new ampa(0.5)")
        h("Epop[36] netConn_projEE_ampa[2889] = new NetCon(&v(0.5), syn_projEE_ampa[2889], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2890: cell 36, seg 0 (0.5) [0.5 on Epop[36]] -> cell 10, seg 0 (0.5) [0.5 on Epop[10]], weight: 4.1363508E-4, delay 1.5
        h("Epop[10] syn_projEE_ampa[2890] = new ampa(0.5)")
        h("Epop[36] netConn_projEE_ampa[2890] = new NetCon(&v(0.5), syn_projEE_ampa[2890], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2891: cell 36, seg 0 (0.5) [0.5 on Epop[36]] -> cell 11, seg 0 (0.5) [0.5 on Epop[11]], weight: 4.1363508E-4, delay 1.5
        h("Epop[11] syn_projEE_ampa[2891] = new ampa(0.5)")
        h("Epop[36] netConn_projEE_ampa[2891] = new NetCon(&v(0.5), syn_projEE_ampa[2891], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2892: cell 36, seg 0 (0.5) [0.5 on Epop[36]] -> cell 12, seg 0 (0.5) [0.5 on Epop[12]], weight: 4.1363508E-4, delay 1.5
        h("Epop[12] syn_projEE_ampa[2892] = new ampa(0.5)")
        h("Epop[36] netConn_projEE_ampa[2892] = new NetCon(&v(0.5), syn_projEE_ampa[2892], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2893: cell 36, seg 0 (0.5) [0.5 on Epop[36]] -> cell 13, seg 0 (0.5) [0.5 on Epop[13]], weight: 4.1363508E-4, delay 1.5
        h("Epop[13] syn_projEE_ampa[2893] = new ampa(0.5)")
        h("Epop[36] netConn_projEE_ampa[2893] = new NetCon(&v(0.5), syn_projEE_ampa[2893], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2894: cell 36, seg 0 (0.5) [0.5 on Epop[36]] -> cell 14, seg 0 (0.5) [0.5 on Epop[14]], weight: 4.1363508E-4, delay 1.5
        h("Epop[14] syn_projEE_ampa[2894] = new ampa(0.5)")
        h("Epop[36] netConn_projEE_ampa[2894] = new NetCon(&v(0.5), syn_projEE_ampa[2894], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2895: cell 36, seg 0 (0.5) [0.5 on Epop[36]] -> cell 15, seg 0 (0.5) [0.5 on Epop[15]], weight: 4.1363508E-4, delay 1.5
        h("Epop[15] syn_projEE_ampa[2895] = new ampa(0.5)")
        h("Epop[36] netConn_projEE_ampa[2895] = new NetCon(&v(0.5), syn_projEE_ampa[2895], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2896: cell 36, seg 0 (0.5) [0.5 on Epop[36]] -> cell 16, seg 0 (0.5) [0.5 on Epop[16]], weight: 4.1363508E-4, delay 1.5
        h("Epop[16] syn_projEE_ampa[2896] = new ampa(0.5)")
        h("Epop[36] netConn_projEE_ampa[2896] = new NetCon(&v(0.5), syn_projEE_ampa[2896], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2897: cell 36, seg 0 (0.5) [0.5 on Epop[36]] -> cell 17, seg 0 (0.5) [0.5 on Epop[17]], weight: 4.1363508E-4, delay 1.5
        h("Epop[17] syn_projEE_ampa[2897] = new ampa(0.5)")
        h("Epop[36] netConn_projEE_ampa[2897] = new NetCon(&v(0.5), syn_projEE_ampa[2897], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2898: cell 36, seg 0 (0.5) [0.5 on Epop[36]] -> cell 18, seg 0 (0.5) [0.5 on Epop[18]], weight: 4.1363508E-4, delay 1.5
        h("Epop[18] syn_projEE_ampa[2898] = new ampa(0.5)")
        h("Epop[36] netConn_projEE_ampa[2898] = new NetCon(&v(0.5), syn_projEE_ampa[2898], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2899: cell 36, seg 0 (0.5) [0.5 on Epop[36]] -> cell 19, seg 0 (0.5) [0.5 on Epop[19]], weight: 4.1363508E-4, delay 1.5
        h("Epop[19] syn_projEE_ampa[2899] = new ampa(0.5)")
        h("Epop[36] netConn_projEE_ampa[2899] = new NetCon(&v(0.5), syn_projEE_ampa[2899], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2900: cell 36, seg 0 (0.5) [0.5 on Epop[36]] -> cell 20, seg 0 (0.5) [0.5 on Epop[20]], weight: 4.1363508E-4, delay 1.5
        h("Epop[20] syn_projEE_ampa[2900] = new ampa(0.5)")
        h("Epop[36] netConn_projEE_ampa[2900] = new NetCon(&v(0.5), syn_projEE_ampa[2900], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2901: cell 36, seg 0 (0.5) [0.5 on Epop[36]] -> cell 21, seg 0 (0.5) [0.5 on Epop[21]], weight: 4.1363508E-4, delay 1.5
        h("Epop[21] syn_projEE_ampa[2901] = new ampa(0.5)")
        h("Epop[36] netConn_projEE_ampa[2901] = new NetCon(&v(0.5), syn_projEE_ampa[2901], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2902: cell 36, seg 0 (0.5) [0.5 on Epop[36]] -> cell 22, seg 0 (0.5) [0.5 on Epop[22]], weight: 4.1363508E-4, delay 1.5
        h("Epop[22] syn_projEE_ampa[2902] = new ampa(0.5)")
        h("Epop[36] netConn_projEE_ampa[2902] = new NetCon(&v(0.5), syn_projEE_ampa[2902], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2903: cell 36, seg 0 (0.5) [0.5 on Epop[36]] -> cell 23, seg 0 (0.5) [0.5 on Epop[23]], weight: 4.1363508E-4, delay 1.5
        h("Epop[23] syn_projEE_ampa[2903] = new ampa(0.5)")
        h("Epop[36] netConn_projEE_ampa[2903] = new NetCon(&v(0.5), syn_projEE_ampa[2903], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2904: cell 36, seg 0 (0.5) [0.5 on Epop[36]] -> cell 24, seg 0 (0.5) [0.5 on Epop[24]], weight: 4.1363508E-4, delay 1.5
        h("Epop[24] syn_projEE_ampa[2904] = new ampa(0.5)")
        h("Epop[36] netConn_projEE_ampa[2904] = new NetCon(&v(0.5), syn_projEE_ampa[2904], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2905: cell 36, seg 0 (0.5) [0.5 on Epop[36]] -> cell 25, seg 0 (0.5) [0.5 on Epop[25]], weight: 4.1363508E-4, delay 1.5
        h("Epop[25] syn_projEE_ampa[2905] = new ampa(0.5)")
        h("Epop[36] netConn_projEE_ampa[2905] = new NetCon(&v(0.5), syn_projEE_ampa[2905], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2906: cell 36, seg 0 (0.5) [0.5 on Epop[36]] -> cell 26, seg 0 (0.5) [0.5 on Epop[26]], weight: 4.1363508E-4, delay 1.5
        h("Epop[26] syn_projEE_ampa[2906] = new ampa(0.5)")
        h("Epop[36] netConn_projEE_ampa[2906] = new NetCon(&v(0.5), syn_projEE_ampa[2906], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2907: cell 36, seg 0 (0.5) [0.5 on Epop[36]] -> cell 27, seg 0 (0.5) [0.5 on Epop[27]], weight: 4.1363508E-4, delay 1.5
        h("Epop[27] syn_projEE_ampa[2907] = new ampa(0.5)")
        h("Epop[36] netConn_projEE_ampa[2907] = new NetCon(&v(0.5), syn_projEE_ampa[2907], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2908: cell 36, seg 0 (0.5) [0.5 on Epop[36]] -> cell 28, seg 0 (0.5) [0.5 on Epop[28]], weight: 4.1363508E-4, delay 1.5
        h("Epop[28] syn_projEE_ampa[2908] = new ampa(0.5)")
        h("Epop[36] netConn_projEE_ampa[2908] = new NetCon(&v(0.5), syn_projEE_ampa[2908], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2909: cell 36, seg 0 (0.5) [0.5 on Epop[36]] -> cell 29, seg 0 (0.5) [0.5 on Epop[29]], weight: 4.1363508E-4, delay 1.5
        h("Epop[29] syn_projEE_ampa[2909] = new ampa(0.5)")
        h("Epop[36] netConn_projEE_ampa[2909] = new NetCon(&v(0.5), syn_projEE_ampa[2909], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2910: cell 36, seg 0 (0.5) [0.5 on Epop[36]] -> cell 30, seg 0 (0.5) [0.5 on Epop[30]], weight: 4.1363508E-4, delay 1.5
        h("Epop[30] syn_projEE_ampa[2910] = new ampa(0.5)")
        h("Epop[36] netConn_projEE_ampa[2910] = new NetCon(&v(0.5), syn_projEE_ampa[2910], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2911: cell 36, seg 0 (0.5) [0.5 on Epop[36]] -> cell 31, seg 0 (0.5) [0.5 on Epop[31]], weight: 4.1363508E-4, delay 1.5
        h("Epop[31] syn_projEE_ampa[2911] = new ampa(0.5)")
        h("Epop[36] netConn_projEE_ampa[2911] = new NetCon(&v(0.5), syn_projEE_ampa[2911], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2912: cell 36, seg 0 (0.5) [0.5 on Epop[36]] -> cell 32, seg 0 (0.5) [0.5 on Epop[32]], weight: 4.1363508E-4, delay 1.5
        h("Epop[32] syn_projEE_ampa[2912] = new ampa(0.5)")
        h("Epop[36] netConn_projEE_ampa[2912] = new NetCon(&v(0.5), syn_projEE_ampa[2912], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2913: cell 36, seg 0 (0.5) [0.5 on Epop[36]] -> cell 33, seg 0 (0.5) [0.5 on Epop[33]], weight: 4.1363508E-4, delay 1.5
        h("Epop[33] syn_projEE_ampa[2913] = new ampa(0.5)")
        h("Epop[36] netConn_projEE_ampa[2913] = new NetCon(&v(0.5), syn_projEE_ampa[2913], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2914: cell 36, seg 0 (0.5) [0.5 on Epop[36]] -> cell 34, seg 0 (0.5) [0.5 on Epop[34]], weight: 4.1363508E-4, delay 1.5
        h("Epop[34] syn_projEE_ampa[2914] = new ampa(0.5)")
        h("Epop[36] netConn_projEE_ampa[2914] = new NetCon(&v(0.5), syn_projEE_ampa[2914], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2915: cell 36, seg 0 (0.5) [0.5 on Epop[36]] -> cell 35, seg 0 (0.5) [0.5 on Epop[35]], weight: 4.1363508E-4, delay 1.5
        h("Epop[35] syn_projEE_ampa[2915] = new ampa(0.5)")
        h("Epop[36] netConn_projEE_ampa[2915] = new NetCon(&v(0.5), syn_projEE_ampa[2915], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2916: cell 36, seg 0 (0.5) [0.5 on Epop[36]] -> cell 36, seg 0 (0.5) [0.5 on Epop[36]], weight: 4.1363508E-4, delay 1.5
        h("Epop[36] syn_projEE_ampa[2916] = new ampa(0.5)")
        h("Epop[36] netConn_projEE_ampa[2916] = new NetCon(&v(0.5), syn_projEE_ampa[2916], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2917: cell 36, seg 0 (0.5) [0.5 on Epop[36]] -> cell 37, seg 0 (0.5) [0.5 on Epop[37]], weight: 4.1363508E-4, delay 1.5
        h("Epop[37] syn_projEE_ampa[2917] = new ampa(0.5)")
        h("Epop[36] netConn_projEE_ampa[2917] = new NetCon(&v(0.5), syn_projEE_ampa[2917], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2918: cell 36, seg 0 (0.5) [0.5 on Epop[36]] -> cell 38, seg 0 (0.5) [0.5 on Epop[38]], weight: 4.1363508E-4, delay 1.5
        h("Epop[38] syn_projEE_ampa[2918] = new ampa(0.5)")
        h("Epop[36] netConn_projEE_ampa[2918] = new NetCon(&v(0.5), syn_projEE_ampa[2918], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2919: cell 36, seg 0 (0.5) [0.5 on Epop[36]] -> cell 39, seg 0 (0.5) [0.5 on Epop[39]], weight: 4.1363508E-4, delay 1.5
        h("Epop[39] syn_projEE_ampa[2919] = new ampa(0.5)")
        h("Epop[36] netConn_projEE_ampa[2919] = new NetCon(&v(0.5), syn_projEE_ampa[2919], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2920: cell 36, seg 0 (0.5) [0.5 on Epop[36]] -> cell 40, seg 0 (0.5) [0.5 on Epop[40]], weight: 4.1363508E-4, delay 1.5
        h("Epop[40] syn_projEE_ampa[2920] = new ampa(0.5)")
        h("Epop[36] netConn_projEE_ampa[2920] = new NetCon(&v(0.5), syn_projEE_ampa[2920], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2921: cell 36, seg 0 (0.5) [0.5 on Epop[36]] -> cell 41, seg 0 (0.5) [0.5 on Epop[41]], weight: 4.1363508E-4, delay 1.5
        h("Epop[41] syn_projEE_ampa[2921] = new ampa(0.5)")
        h("Epop[36] netConn_projEE_ampa[2921] = new NetCon(&v(0.5), syn_projEE_ampa[2921], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2922: cell 36, seg 0 (0.5) [0.5 on Epop[36]] -> cell 42, seg 0 (0.5) [0.5 on Epop[42]], weight: 4.1363508E-4, delay 1.5
        h("Epop[42] syn_projEE_ampa[2922] = new ampa(0.5)")
        h("Epop[36] netConn_projEE_ampa[2922] = new NetCon(&v(0.5), syn_projEE_ampa[2922], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2923: cell 36, seg 0 (0.5) [0.5 on Epop[36]] -> cell 43, seg 0 (0.5) [0.5 on Epop[43]], weight: 4.1363508E-4, delay 1.5
        h("Epop[43] syn_projEE_ampa[2923] = new ampa(0.5)")
        h("Epop[36] netConn_projEE_ampa[2923] = new NetCon(&v(0.5), syn_projEE_ampa[2923], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2924: cell 36, seg 0 (0.5) [0.5 on Epop[36]] -> cell 44, seg 0 (0.5) [0.5 on Epop[44]], weight: 4.1363508E-4, delay 1.5
        h("Epop[44] syn_projEE_ampa[2924] = new ampa(0.5)")
        h("Epop[36] netConn_projEE_ampa[2924] = new NetCon(&v(0.5), syn_projEE_ampa[2924], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2925: cell 36, seg 0 (0.5) [0.5 on Epop[36]] -> cell 45, seg 0 (0.5) [0.5 on Epop[45]], weight: 4.1363508E-4, delay 1.5
        h("Epop[45] syn_projEE_ampa[2925] = new ampa(0.5)")
        h("Epop[36] netConn_projEE_ampa[2925] = new NetCon(&v(0.5), syn_projEE_ampa[2925], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2926: cell 36, seg 0 (0.5) [0.5 on Epop[36]] -> cell 46, seg 0 (0.5) [0.5 on Epop[46]], weight: 4.1363508E-4, delay 1.5
        h("Epop[46] syn_projEE_ampa[2926] = new ampa(0.5)")
        h("Epop[36] netConn_projEE_ampa[2926] = new NetCon(&v(0.5), syn_projEE_ampa[2926], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2927: cell 36, seg 0 (0.5) [0.5 on Epop[36]] -> cell 47, seg 0 (0.5) [0.5 on Epop[47]], weight: 4.1363508E-4, delay 1.5
        h("Epop[47] syn_projEE_ampa[2927] = new ampa(0.5)")
        h("Epop[36] netConn_projEE_ampa[2927] = new NetCon(&v(0.5), syn_projEE_ampa[2927], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2928: cell 36, seg 0 (0.5) [0.5 on Epop[36]] -> cell 48, seg 0 (0.5) [0.5 on Epop[48]], weight: 4.1363508E-4, delay 1.5
        h("Epop[48] syn_projEE_ampa[2928] = new ampa(0.5)")
        h("Epop[36] netConn_projEE_ampa[2928] = new NetCon(&v(0.5), syn_projEE_ampa[2928], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2929: cell 36, seg 0 (0.5) [0.5 on Epop[36]] -> cell 49, seg 0 (0.5) [0.5 on Epop[49]], weight: 4.1363508E-4, delay 1.5
        h("Epop[49] syn_projEE_ampa[2929] = new ampa(0.5)")
        h("Epop[36] netConn_projEE_ampa[2929] = new NetCon(&v(0.5), syn_projEE_ampa[2929], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2930: cell 36, seg 0 (0.5) [0.5 on Epop[36]] -> cell 50, seg 0 (0.5) [0.5 on Epop[50]], weight: 4.1363508E-4, delay 1.5
        h("Epop[50] syn_projEE_ampa[2930] = new ampa(0.5)")
        h("Epop[36] netConn_projEE_ampa[2930] = new NetCon(&v(0.5), syn_projEE_ampa[2930], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2931: cell 36, seg 0 (0.5) [0.5 on Epop[36]] -> cell 51, seg 0 (0.5) [0.5 on Epop[51]], weight: 4.1363508E-4, delay 1.5
        h("Epop[51] syn_projEE_ampa[2931] = new ampa(0.5)")
        h("Epop[36] netConn_projEE_ampa[2931] = new NetCon(&v(0.5), syn_projEE_ampa[2931], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2932: cell 36, seg 0 (0.5) [0.5 on Epop[36]] -> cell 52, seg 0 (0.5) [0.5 on Epop[52]], weight: 4.1363508E-4, delay 1.5
        h("Epop[52] syn_projEE_ampa[2932] = new ampa(0.5)")
        h("Epop[36] netConn_projEE_ampa[2932] = new NetCon(&v(0.5), syn_projEE_ampa[2932], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2933: cell 36, seg 0 (0.5) [0.5 on Epop[36]] -> cell 53, seg 0 (0.5) [0.5 on Epop[53]], weight: 4.1363508E-4, delay 1.5
        h("Epop[53] syn_projEE_ampa[2933] = new ampa(0.5)")
        h("Epop[36] netConn_projEE_ampa[2933] = new NetCon(&v(0.5), syn_projEE_ampa[2933], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2934: cell 36, seg 0 (0.5) [0.5 on Epop[36]] -> cell 54, seg 0 (0.5) [0.5 on Epop[54]], weight: 4.1363508E-4, delay 1.5
        h("Epop[54] syn_projEE_ampa[2934] = new ampa(0.5)")
        h("Epop[36] netConn_projEE_ampa[2934] = new NetCon(&v(0.5), syn_projEE_ampa[2934], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2935: cell 36, seg 0 (0.5) [0.5 on Epop[36]] -> cell 55, seg 0 (0.5) [0.5 on Epop[55]], weight: 4.1363508E-4, delay 1.5
        h("Epop[55] syn_projEE_ampa[2935] = new ampa(0.5)")
        h("Epop[36] netConn_projEE_ampa[2935] = new NetCon(&v(0.5), syn_projEE_ampa[2935], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2936: cell 36, seg 0 (0.5) [0.5 on Epop[36]] -> cell 56, seg 0 (0.5) [0.5 on Epop[56]], weight: 4.1363508E-4, delay 1.5
        h("Epop[56] syn_projEE_ampa[2936] = new ampa(0.5)")
        h("Epop[36] netConn_projEE_ampa[2936] = new NetCon(&v(0.5), syn_projEE_ampa[2936], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2937: cell 36, seg 0 (0.5) [0.5 on Epop[36]] -> cell 57, seg 0 (0.5) [0.5 on Epop[57]], weight: 4.1363508E-4, delay 1.5
        h("Epop[57] syn_projEE_ampa[2937] = new ampa(0.5)")
        h("Epop[36] netConn_projEE_ampa[2937] = new NetCon(&v(0.5), syn_projEE_ampa[2937], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2938: cell 36, seg 0 (0.5) [0.5 on Epop[36]] -> cell 58, seg 0 (0.5) [0.5 on Epop[58]], weight: 4.1363508E-4, delay 1.5
        h("Epop[58] syn_projEE_ampa[2938] = new ampa(0.5)")
        h("Epop[36] netConn_projEE_ampa[2938] = new NetCon(&v(0.5), syn_projEE_ampa[2938], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2939: cell 36, seg 0 (0.5) [0.5 on Epop[36]] -> cell 59, seg 0 (0.5) [0.5 on Epop[59]], weight: 4.1363508E-4, delay 1.5
        h("Epop[59] syn_projEE_ampa[2939] = new ampa(0.5)")
        h("Epop[36] netConn_projEE_ampa[2939] = new NetCon(&v(0.5), syn_projEE_ampa[2939], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2940: cell 36, seg 0 (0.5) [0.5 on Epop[36]] -> cell 60, seg 0 (0.5) [0.5 on Epop[60]], weight: 4.1363508E-4, delay 1.5
        h("Epop[60] syn_projEE_ampa[2940] = new ampa(0.5)")
        h("Epop[36] netConn_projEE_ampa[2940] = new NetCon(&v(0.5), syn_projEE_ampa[2940], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2941: cell 36, seg 0 (0.5) [0.5 on Epop[36]] -> cell 61, seg 0 (0.5) [0.5 on Epop[61]], weight: 4.1363508E-4, delay 1.5
        h("Epop[61] syn_projEE_ampa[2941] = new ampa(0.5)")
        h("Epop[36] netConn_projEE_ampa[2941] = new NetCon(&v(0.5), syn_projEE_ampa[2941], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2942: cell 36, seg 0 (0.5) [0.5 on Epop[36]] -> cell 62, seg 0 (0.5) [0.5 on Epop[62]], weight: 4.1363508E-4, delay 1.5
        h("Epop[62] syn_projEE_ampa[2942] = new ampa(0.5)")
        h("Epop[36] netConn_projEE_ampa[2942] = new NetCon(&v(0.5), syn_projEE_ampa[2942], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2943: cell 36, seg 0 (0.5) [0.5 on Epop[36]] -> cell 63, seg 0 (0.5) [0.5 on Epop[63]], weight: 4.1363508E-4, delay 1.5
        h("Epop[63] syn_projEE_ampa[2943] = new ampa(0.5)")
        h("Epop[36] netConn_projEE_ampa[2943] = new NetCon(&v(0.5), syn_projEE_ampa[2943], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2944: cell 36, seg 0 (0.5) [0.5 on Epop[36]] -> cell 64, seg 0 (0.5) [0.5 on Epop[64]], weight: 4.1363508E-4, delay 1.5
        h("Epop[64] syn_projEE_ampa[2944] = new ampa(0.5)")
        h("Epop[36] netConn_projEE_ampa[2944] = new NetCon(&v(0.5), syn_projEE_ampa[2944], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2945: cell 36, seg 0 (0.5) [0.5 on Epop[36]] -> cell 65, seg 0 (0.5) [0.5 on Epop[65]], weight: 4.1363508E-4, delay 1.5
        h("Epop[65] syn_projEE_ampa[2945] = new ampa(0.5)")
        h("Epop[36] netConn_projEE_ampa[2945] = new NetCon(&v(0.5), syn_projEE_ampa[2945], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2946: cell 36, seg 0 (0.5) [0.5 on Epop[36]] -> cell 66, seg 0 (0.5) [0.5 on Epop[66]], weight: 4.1363508E-4, delay 1.5
        h("Epop[66] syn_projEE_ampa[2946] = new ampa(0.5)")
        h("Epop[36] netConn_projEE_ampa[2946] = new NetCon(&v(0.5), syn_projEE_ampa[2946], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2947: cell 36, seg 0 (0.5) [0.5 on Epop[36]] -> cell 67, seg 0 (0.5) [0.5 on Epop[67]], weight: 4.1363508E-4, delay 1.5
        h("Epop[67] syn_projEE_ampa[2947] = new ampa(0.5)")
        h("Epop[36] netConn_projEE_ampa[2947] = new NetCon(&v(0.5), syn_projEE_ampa[2947], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2948: cell 36, seg 0 (0.5) [0.5 on Epop[36]] -> cell 68, seg 0 (0.5) [0.5 on Epop[68]], weight: 4.1363508E-4, delay 1.5
        h("Epop[68] syn_projEE_ampa[2948] = new ampa(0.5)")
        h("Epop[36] netConn_projEE_ampa[2948] = new NetCon(&v(0.5), syn_projEE_ampa[2948], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2949: cell 36, seg 0 (0.5) [0.5 on Epop[36]] -> cell 69, seg 0 (0.5) [0.5 on Epop[69]], weight: 4.1363508E-4, delay 1.5
        h("Epop[69] syn_projEE_ampa[2949] = new ampa(0.5)")
        h("Epop[36] netConn_projEE_ampa[2949] = new NetCon(&v(0.5), syn_projEE_ampa[2949], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2950: cell 36, seg 0 (0.5) [0.5 on Epop[36]] -> cell 70, seg 0 (0.5) [0.5 on Epop[70]], weight: 4.1363508E-4, delay 1.5
        h("Epop[70] syn_projEE_ampa[2950] = new ampa(0.5)")
        h("Epop[36] netConn_projEE_ampa[2950] = new NetCon(&v(0.5), syn_projEE_ampa[2950], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2951: cell 36, seg 0 (0.5) [0.5 on Epop[36]] -> cell 71, seg 0 (0.5) [0.5 on Epop[71]], weight: 4.1363508E-4, delay 1.5
        h("Epop[71] syn_projEE_ampa[2951] = new ampa(0.5)")
        h("Epop[36] netConn_projEE_ampa[2951] = new NetCon(&v(0.5), syn_projEE_ampa[2951], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2952: cell 36, seg 0 (0.5) [0.5 on Epop[36]] -> cell 72, seg 0 (0.5) [0.5 on Epop[72]], weight: 4.1363508E-4, delay 1.5
        h("Epop[72] syn_projEE_ampa[2952] = new ampa(0.5)")
        h("Epop[36] netConn_projEE_ampa[2952] = new NetCon(&v(0.5), syn_projEE_ampa[2952], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2953: cell 36, seg 0 (0.5) [0.5 on Epop[36]] -> cell 73, seg 0 (0.5) [0.5 on Epop[73]], weight: 4.1363508E-4, delay 1.5
        h("Epop[73] syn_projEE_ampa[2953] = new ampa(0.5)")
        h("Epop[36] netConn_projEE_ampa[2953] = new NetCon(&v(0.5), syn_projEE_ampa[2953], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2954: cell 36, seg 0 (0.5) [0.5 on Epop[36]] -> cell 74, seg 0 (0.5) [0.5 on Epop[74]], weight: 4.1363508E-4, delay 1.5
        h("Epop[74] syn_projEE_ampa[2954] = new ampa(0.5)")
        h("Epop[36] netConn_projEE_ampa[2954] = new NetCon(&v(0.5), syn_projEE_ampa[2954], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2955: cell 36, seg 0 (0.5) [0.5 on Epop[36]] -> cell 75, seg 0 (0.5) [0.5 on Epop[75]], weight: 4.1363508E-4, delay 1.5
        h("Epop[75] syn_projEE_ampa[2955] = new ampa(0.5)")
        h("Epop[36] netConn_projEE_ampa[2955] = new NetCon(&v(0.5), syn_projEE_ampa[2955], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2956: cell 36, seg 0 (0.5) [0.5 on Epop[36]] -> cell 76, seg 0 (0.5) [0.5 on Epop[76]], weight: 4.1363508E-4, delay 1.5
        h("Epop[76] syn_projEE_ampa[2956] = new ampa(0.5)")
        h("Epop[36] netConn_projEE_ampa[2956] = new NetCon(&v(0.5), syn_projEE_ampa[2956], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2957: cell 36, seg 0 (0.5) [0.5 on Epop[36]] -> cell 77, seg 0 (0.5) [0.5 on Epop[77]], weight: 4.1363508E-4, delay 1.5
        h("Epop[77] syn_projEE_ampa[2957] = new ampa(0.5)")
        h("Epop[36] netConn_projEE_ampa[2957] = new NetCon(&v(0.5), syn_projEE_ampa[2957], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2958: cell 36, seg 0 (0.5) [0.5 on Epop[36]] -> cell 78, seg 0 (0.5) [0.5 on Epop[78]], weight: 4.1363508E-4, delay 1.5
        h("Epop[78] syn_projEE_ampa[2958] = new ampa(0.5)")
        h("Epop[36] netConn_projEE_ampa[2958] = new NetCon(&v(0.5), syn_projEE_ampa[2958], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2959: cell 36, seg 0 (0.5) [0.5 on Epop[36]] -> cell 79, seg 0 (0.5) [0.5 on Epop[79]], weight: 4.1363508E-4, delay 1.5
        h("Epop[79] syn_projEE_ampa[2959] = new ampa(0.5)")
        h("Epop[36] netConn_projEE_ampa[2959] = new NetCon(&v(0.5), syn_projEE_ampa[2959], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2960: cell 37, seg 0 (0.5) [0.5 on Epop[37]] -> cell 0, seg 0 (0.5) [0.5 on Epop[0]], weight: 4.1363508E-4, delay 1.5
        h("Epop[0] syn_projEE_ampa[2960] = new ampa(0.5)")
        h("Epop[37] netConn_projEE_ampa[2960] = new NetCon(&v(0.5), syn_projEE_ampa[2960], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2961: cell 37, seg 0 (0.5) [0.5 on Epop[37]] -> cell 1, seg 0 (0.5) [0.5 on Epop[1]], weight: 4.1363508E-4, delay 1.5
        h("Epop[1] syn_projEE_ampa[2961] = new ampa(0.5)")
        h("Epop[37] netConn_projEE_ampa[2961] = new NetCon(&v(0.5), syn_projEE_ampa[2961], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2962: cell 37, seg 0 (0.5) [0.5 on Epop[37]] -> cell 2, seg 0 (0.5) [0.5 on Epop[2]], weight: 4.1363508E-4, delay 1.5
        h("Epop[2] syn_projEE_ampa[2962] = new ampa(0.5)")
        h("Epop[37] netConn_projEE_ampa[2962] = new NetCon(&v(0.5), syn_projEE_ampa[2962], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2963: cell 37, seg 0 (0.5) [0.5 on Epop[37]] -> cell 3, seg 0 (0.5) [0.5 on Epop[3]], weight: 4.1363508E-4, delay 1.5
        h("Epop[3] syn_projEE_ampa[2963] = new ampa(0.5)")
        h("Epop[37] netConn_projEE_ampa[2963] = new NetCon(&v(0.5), syn_projEE_ampa[2963], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2964: cell 37, seg 0 (0.5) [0.5 on Epop[37]] -> cell 4, seg 0 (0.5) [0.5 on Epop[4]], weight: 4.1363508E-4, delay 1.5
        h("Epop[4] syn_projEE_ampa[2964] = new ampa(0.5)")
        h("Epop[37] netConn_projEE_ampa[2964] = new NetCon(&v(0.5), syn_projEE_ampa[2964], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2965: cell 37, seg 0 (0.5) [0.5 on Epop[37]] -> cell 5, seg 0 (0.5) [0.5 on Epop[5]], weight: 4.1363508E-4, delay 1.5
        h("Epop[5] syn_projEE_ampa[2965] = new ampa(0.5)")
        h("Epop[37] netConn_projEE_ampa[2965] = new NetCon(&v(0.5), syn_projEE_ampa[2965], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2966: cell 37, seg 0 (0.5) [0.5 on Epop[37]] -> cell 6, seg 0 (0.5) [0.5 on Epop[6]], weight: 4.1363508E-4, delay 1.5
        h("Epop[6] syn_projEE_ampa[2966] = new ampa(0.5)")
        h("Epop[37] netConn_projEE_ampa[2966] = new NetCon(&v(0.5), syn_projEE_ampa[2966], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2967: cell 37, seg 0 (0.5) [0.5 on Epop[37]] -> cell 7, seg 0 (0.5) [0.5 on Epop[7]], weight: 4.1363508E-4, delay 1.5
        h("Epop[7] syn_projEE_ampa[2967] = new ampa(0.5)")
        h("Epop[37] netConn_projEE_ampa[2967] = new NetCon(&v(0.5), syn_projEE_ampa[2967], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2968: cell 37, seg 0 (0.5) [0.5 on Epop[37]] -> cell 8, seg 0 (0.5) [0.5 on Epop[8]], weight: 4.1363508E-4, delay 1.5
        h("Epop[8] syn_projEE_ampa[2968] = new ampa(0.5)")
        h("Epop[37] netConn_projEE_ampa[2968] = new NetCon(&v(0.5), syn_projEE_ampa[2968], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2969: cell 37, seg 0 (0.5) [0.5 on Epop[37]] -> cell 9, seg 0 (0.5) [0.5 on Epop[9]], weight: 4.1363508E-4, delay 1.5
        h("Epop[9] syn_projEE_ampa[2969] = new ampa(0.5)")
        h("Epop[37] netConn_projEE_ampa[2969] = new NetCon(&v(0.5), syn_projEE_ampa[2969], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2970: cell 37, seg 0 (0.5) [0.5 on Epop[37]] -> cell 10, seg 0 (0.5) [0.5 on Epop[10]], weight: 4.1363508E-4, delay 1.5
        h("Epop[10] syn_projEE_ampa[2970] = new ampa(0.5)")
        h("Epop[37] netConn_projEE_ampa[2970] = new NetCon(&v(0.5), syn_projEE_ampa[2970], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2971: cell 37, seg 0 (0.5) [0.5 on Epop[37]] -> cell 11, seg 0 (0.5) [0.5 on Epop[11]], weight: 4.1363508E-4, delay 1.5
        h("Epop[11] syn_projEE_ampa[2971] = new ampa(0.5)")
        h("Epop[37] netConn_projEE_ampa[2971] = new NetCon(&v(0.5), syn_projEE_ampa[2971], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2972: cell 37, seg 0 (0.5) [0.5 on Epop[37]] -> cell 12, seg 0 (0.5) [0.5 on Epop[12]], weight: 4.1363508E-4, delay 1.5
        h("Epop[12] syn_projEE_ampa[2972] = new ampa(0.5)")
        h("Epop[37] netConn_projEE_ampa[2972] = new NetCon(&v(0.5), syn_projEE_ampa[2972], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2973: cell 37, seg 0 (0.5) [0.5 on Epop[37]] -> cell 13, seg 0 (0.5) [0.5 on Epop[13]], weight: 4.1363508E-4, delay 1.5
        h("Epop[13] syn_projEE_ampa[2973] = new ampa(0.5)")
        h("Epop[37] netConn_projEE_ampa[2973] = new NetCon(&v(0.5), syn_projEE_ampa[2973], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2974: cell 37, seg 0 (0.5) [0.5 on Epop[37]] -> cell 14, seg 0 (0.5) [0.5 on Epop[14]], weight: 4.1363508E-4, delay 1.5
        h("Epop[14] syn_projEE_ampa[2974] = new ampa(0.5)")
        h("Epop[37] netConn_projEE_ampa[2974] = new NetCon(&v(0.5), syn_projEE_ampa[2974], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2975: cell 37, seg 0 (0.5) [0.5 on Epop[37]] -> cell 15, seg 0 (0.5) [0.5 on Epop[15]], weight: 4.1363508E-4, delay 1.5
        h("Epop[15] syn_projEE_ampa[2975] = new ampa(0.5)")
        h("Epop[37] netConn_projEE_ampa[2975] = new NetCon(&v(0.5), syn_projEE_ampa[2975], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2976: cell 37, seg 0 (0.5) [0.5 on Epop[37]] -> cell 16, seg 0 (0.5) [0.5 on Epop[16]], weight: 4.1363508E-4, delay 1.5
        h("Epop[16] syn_projEE_ampa[2976] = new ampa(0.5)")
        h("Epop[37] netConn_projEE_ampa[2976] = new NetCon(&v(0.5), syn_projEE_ampa[2976], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2977: cell 37, seg 0 (0.5) [0.5 on Epop[37]] -> cell 17, seg 0 (0.5) [0.5 on Epop[17]], weight: 4.1363508E-4, delay 1.5
        h("Epop[17] syn_projEE_ampa[2977] = new ampa(0.5)")
        h("Epop[37] netConn_projEE_ampa[2977] = new NetCon(&v(0.5), syn_projEE_ampa[2977], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2978: cell 37, seg 0 (0.5) [0.5 on Epop[37]] -> cell 18, seg 0 (0.5) [0.5 on Epop[18]], weight: 4.1363508E-4, delay 1.5
        h("Epop[18] syn_projEE_ampa[2978] = new ampa(0.5)")
        h("Epop[37] netConn_projEE_ampa[2978] = new NetCon(&v(0.5), syn_projEE_ampa[2978], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2979: cell 37, seg 0 (0.5) [0.5 on Epop[37]] -> cell 19, seg 0 (0.5) [0.5 on Epop[19]], weight: 4.1363508E-4, delay 1.5
        h("Epop[19] syn_projEE_ampa[2979] = new ampa(0.5)")
        h("Epop[37] netConn_projEE_ampa[2979] = new NetCon(&v(0.5), syn_projEE_ampa[2979], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2980: cell 37, seg 0 (0.5) [0.5 on Epop[37]] -> cell 20, seg 0 (0.5) [0.5 on Epop[20]], weight: 4.1363508E-4, delay 1.5
        h("Epop[20] syn_projEE_ampa[2980] = new ampa(0.5)")
        h("Epop[37] netConn_projEE_ampa[2980] = new NetCon(&v(0.5), syn_projEE_ampa[2980], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2981: cell 37, seg 0 (0.5) [0.5 on Epop[37]] -> cell 21, seg 0 (0.5) [0.5 on Epop[21]], weight: 4.1363508E-4, delay 1.5
        h("Epop[21] syn_projEE_ampa[2981] = new ampa(0.5)")
        h("Epop[37] netConn_projEE_ampa[2981] = new NetCon(&v(0.5), syn_projEE_ampa[2981], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2982: cell 37, seg 0 (0.5) [0.5 on Epop[37]] -> cell 22, seg 0 (0.5) [0.5 on Epop[22]], weight: 4.1363508E-4, delay 1.5
        h("Epop[22] syn_projEE_ampa[2982] = new ampa(0.5)")
        h("Epop[37] netConn_projEE_ampa[2982] = new NetCon(&v(0.5), syn_projEE_ampa[2982], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2983: cell 37, seg 0 (0.5) [0.5 on Epop[37]] -> cell 23, seg 0 (0.5) [0.5 on Epop[23]], weight: 4.1363508E-4, delay 1.5
        h("Epop[23] syn_projEE_ampa[2983] = new ampa(0.5)")
        h("Epop[37] netConn_projEE_ampa[2983] = new NetCon(&v(0.5), syn_projEE_ampa[2983], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2984: cell 37, seg 0 (0.5) [0.5 on Epop[37]] -> cell 24, seg 0 (0.5) [0.5 on Epop[24]], weight: 4.1363508E-4, delay 1.5
        h("Epop[24] syn_projEE_ampa[2984] = new ampa(0.5)")
        h("Epop[37] netConn_projEE_ampa[2984] = new NetCon(&v(0.5), syn_projEE_ampa[2984], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2985: cell 37, seg 0 (0.5) [0.5 on Epop[37]] -> cell 25, seg 0 (0.5) [0.5 on Epop[25]], weight: 4.1363508E-4, delay 1.5
        h("Epop[25] syn_projEE_ampa[2985] = new ampa(0.5)")
        h("Epop[37] netConn_projEE_ampa[2985] = new NetCon(&v(0.5), syn_projEE_ampa[2985], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2986: cell 37, seg 0 (0.5) [0.5 on Epop[37]] -> cell 26, seg 0 (0.5) [0.5 on Epop[26]], weight: 4.1363508E-4, delay 1.5
        h("Epop[26] syn_projEE_ampa[2986] = new ampa(0.5)")
        h("Epop[37] netConn_projEE_ampa[2986] = new NetCon(&v(0.5), syn_projEE_ampa[2986], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2987: cell 37, seg 0 (0.5) [0.5 on Epop[37]] -> cell 27, seg 0 (0.5) [0.5 on Epop[27]], weight: 4.1363508E-4, delay 1.5
        h("Epop[27] syn_projEE_ampa[2987] = new ampa(0.5)")
        h("Epop[37] netConn_projEE_ampa[2987] = new NetCon(&v(0.5), syn_projEE_ampa[2987], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2988: cell 37, seg 0 (0.5) [0.5 on Epop[37]] -> cell 28, seg 0 (0.5) [0.5 on Epop[28]], weight: 4.1363508E-4, delay 1.5
        h("Epop[28] syn_projEE_ampa[2988] = new ampa(0.5)")
        h("Epop[37] netConn_projEE_ampa[2988] = new NetCon(&v(0.5), syn_projEE_ampa[2988], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2989: cell 37, seg 0 (0.5) [0.5 on Epop[37]] -> cell 29, seg 0 (0.5) [0.5 on Epop[29]], weight: 4.1363508E-4, delay 1.5
        h("Epop[29] syn_projEE_ampa[2989] = new ampa(0.5)")
        h("Epop[37] netConn_projEE_ampa[2989] = new NetCon(&v(0.5), syn_projEE_ampa[2989], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2990: cell 37, seg 0 (0.5) [0.5 on Epop[37]] -> cell 30, seg 0 (0.5) [0.5 on Epop[30]], weight: 4.1363508E-4, delay 1.5
        h("Epop[30] syn_projEE_ampa[2990] = new ampa(0.5)")
        h("Epop[37] netConn_projEE_ampa[2990] = new NetCon(&v(0.5), syn_projEE_ampa[2990], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2991: cell 37, seg 0 (0.5) [0.5 on Epop[37]] -> cell 31, seg 0 (0.5) [0.5 on Epop[31]], weight: 4.1363508E-4, delay 1.5
        h("Epop[31] syn_projEE_ampa[2991] = new ampa(0.5)")
        h("Epop[37] netConn_projEE_ampa[2991] = new NetCon(&v(0.5), syn_projEE_ampa[2991], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2992: cell 37, seg 0 (0.5) [0.5 on Epop[37]] -> cell 32, seg 0 (0.5) [0.5 on Epop[32]], weight: 4.1363508E-4, delay 1.5
        h("Epop[32] syn_projEE_ampa[2992] = new ampa(0.5)")
        h("Epop[37] netConn_projEE_ampa[2992] = new NetCon(&v(0.5), syn_projEE_ampa[2992], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2993: cell 37, seg 0 (0.5) [0.5 on Epop[37]] -> cell 33, seg 0 (0.5) [0.5 on Epop[33]], weight: 4.1363508E-4, delay 1.5
        h("Epop[33] syn_projEE_ampa[2993] = new ampa(0.5)")
        h("Epop[37] netConn_projEE_ampa[2993] = new NetCon(&v(0.5), syn_projEE_ampa[2993], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2994: cell 37, seg 0 (0.5) [0.5 on Epop[37]] -> cell 34, seg 0 (0.5) [0.5 on Epop[34]], weight: 4.1363508E-4, delay 1.5
        h("Epop[34] syn_projEE_ampa[2994] = new ampa(0.5)")
        h("Epop[37] netConn_projEE_ampa[2994] = new NetCon(&v(0.5), syn_projEE_ampa[2994], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2995: cell 37, seg 0 (0.5) [0.5 on Epop[37]] -> cell 35, seg 0 (0.5) [0.5 on Epop[35]], weight: 4.1363508E-4, delay 1.5
        h("Epop[35] syn_projEE_ampa[2995] = new ampa(0.5)")
        h("Epop[37] netConn_projEE_ampa[2995] = new NetCon(&v(0.5), syn_projEE_ampa[2995], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2996: cell 37, seg 0 (0.5) [0.5 on Epop[37]] -> cell 36, seg 0 (0.5) [0.5 on Epop[36]], weight: 4.1363508E-4, delay 1.5
        h("Epop[36] syn_projEE_ampa[2996] = new ampa(0.5)")
        h("Epop[37] netConn_projEE_ampa[2996] = new NetCon(&v(0.5), syn_projEE_ampa[2996], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2997: cell 37, seg 0 (0.5) [0.5 on Epop[37]] -> cell 37, seg 0 (0.5) [0.5 on Epop[37]], weight: 4.1363508E-4, delay 1.5
        h("Epop[37] syn_projEE_ampa[2997] = new ampa(0.5)")
        h("Epop[37] netConn_projEE_ampa[2997] = new NetCon(&v(0.5), syn_projEE_ampa[2997], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2998: cell 37, seg 0 (0.5) [0.5 on Epop[37]] -> cell 38, seg 0 (0.5) [0.5 on Epop[38]], weight: 4.1363508E-4, delay 1.5
        h("Epop[38] syn_projEE_ampa[2998] = new ampa(0.5)")
        h("Epop[37] netConn_projEE_ampa[2998] = new NetCon(&v(0.5), syn_projEE_ampa[2998], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2999: cell 37, seg 0 (0.5) [0.5 on Epop[37]] -> cell 39, seg 0 (0.5) [0.5 on Epop[39]], weight: 4.1363508E-4, delay 1.5
        h("Epop[39] syn_projEE_ampa[2999] = new ampa(0.5)")
        h("Epop[37] netConn_projEE_ampa[2999] = new NetCon(&v(0.5), syn_projEE_ampa[2999], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3000: cell 37, seg 0 (0.5) [0.5 on Epop[37]] -> cell 40, seg 0 (0.5) [0.5 on Epop[40]], weight: 4.1363508E-4, delay 1.5
        h("Epop[40] syn_projEE_ampa[3000] = new ampa(0.5)")
        h("Epop[37] netConn_projEE_ampa[3000] = new NetCon(&v(0.5), syn_projEE_ampa[3000], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3001: cell 37, seg 0 (0.5) [0.5 on Epop[37]] -> cell 41, seg 0 (0.5) [0.5 on Epop[41]], weight: 4.1363508E-4, delay 1.5
        h("Epop[41] syn_projEE_ampa[3001] = new ampa(0.5)")
        h("Epop[37] netConn_projEE_ampa[3001] = new NetCon(&v(0.5), syn_projEE_ampa[3001], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3002: cell 37, seg 0 (0.5) [0.5 on Epop[37]] -> cell 42, seg 0 (0.5) [0.5 on Epop[42]], weight: 4.1363508E-4, delay 1.5
        h("Epop[42] syn_projEE_ampa[3002] = new ampa(0.5)")
        h("Epop[37] netConn_projEE_ampa[3002] = new NetCon(&v(0.5), syn_projEE_ampa[3002], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3003: cell 37, seg 0 (0.5) [0.5 on Epop[37]] -> cell 43, seg 0 (0.5) [0.5 on Epop[43]], weight: 4.1363508E-4, delay 1.5
        h("Epop[43] syn_projEE_ampa[3003] = new ampa(0.5)")
        h("Epop[37] netConn_projEE_ampa[3003] = new NetCon(&v(0.5), syn_projEE_ampa[3003], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3004: cell 37, seg 0 (0.5) [0.5 on Epop[37]] -> cell 44, seg 0 (0.5) [0.5 on Epop[44]], weight: 4.1363508E-4, delay 1.5
        h("Epop[44] syn_projEE_ampa[3004] = new ampa(0.5)")
        h("Epop[37] netConn_projEE_ampa[3004] = new NetCon(&v(0.5), syn_projEE_ampa[3004], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3005: cell 37, seg 0 (0.5) [0.5 on Epop[37]] -> cell 45, seg 0 (0.5) [0.5 on Epop[45]], weight: 4.1363508E-4, delay 1.5
        h("Epop[45] syn_projEE_ampa[3005] = new ampa(0.5)")
        h("Epop[37] netConn_projEE_ampa[3005] = new NetCon(&v(0.5), syn_projEE_ampa[3005], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3006: cell 37, seg 0 (0.5) [0.5 on Epop[37]] -> cell 46, seg 0 (0.5) [0.5 on Epop[46]], weight: 4.1363508E-4, delay 1.5
        h("Epop[46] syn_projEE_ampa[3006] = new ampa(0.5)")
        h("Epop[37] netConn_projEE_ampa[3006] = new NetCon(&v(0.5), syn_projEE_ampa[3006], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3007: cell 37, seg 0 (0.5) [0.5 on Epop[37]] -> cell 47, seg 0 (0.5) [0.5 on Epop[47]], weight: 4.1363508E-4, delay 1.5
        h("Epop[47] syn_projEE_ampa[3007] = new ampa(0.5)")
        h("Epop[37] netConn_projEE_ampa[3007] = new NetCon(&v(0.5), syn_projEE_ampa[3007], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3008: cell 37, seg 0 (0.5) [0.5 on Epop[37]] -> cell 48, seg 0 (0.5) [0.5 on Epop[48]], weight: 4.1363508E-4, delay 1.5
        h("Epop[48] syn_projEE_ampa[3008] = new ampa(0.5)")
        h("Epop[37] netConn_projEE_ampa[3008] = new NetCon(&v(0.5), syn_projEE_ampa[3008], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3009: cell 37, seg 0 (0.5) [0.5 on Epop[37]] -> cell 49, seg 0 (0.5) [0.5 on Epop[49]], weight: 4.1363508E-4, delay 1.5
        h("Epop[49] syn_projEE_ampa[3009] = new ampa(0.5)")
        h("Epop[37] netConn_projEE_ampa[3009] = new NetCon(&v(0.5), syn_projEE_ampa[3009], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3010: cell 37, seg 0 (0.5) [0.5 on Epop[37]] -> cell 50, seg 0 (0.5) [0.5 on Epop[50]], weight: 4.1363508E-4, delay 1.5
        h("Epop[50] syn_projEE_ampa[3010] = new ampa(0.5)")
        h("Epop[37] netConn_projEE_ampa[3010] = new NetCon(&v(0.5), syn_projEE_ampa[3010], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3011: cell 37, seg 0 (0.5) [0.5 on Epop[37]] -> cell 51, seg 0 (0.5) [0.5 on Epop[51]], weight: 4.1363508E-4, delay 1.5
        h("Epop[51] syn_projEE_ampa[3011] = new ampa(0.5)")
        h("Epop[37] netConn_projEE_ampa[3011] = new NetCon(&v(0.5), syn_projEE_ampa[3011], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3012: cell 37, seg 0 (0.5) [0.5 on Epop[37]] -> cell 52, seg 0 (0.5) [0.5 on Epop[52]], weight: 4.1363508E-4, delay 1.5
        h("Epop[52] syn_projEE_ampa[3012] = new ampa(0.5)")
        h("Epop[37] netConn_projEE_ampa[3012] = new NetCon(&v(0.5), syn_projEE_ampa[3012], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3013: cell 37, seg 0 (0.5) [0.5 on Epop[37]] -> cell 53, seg 0 (0.5) [0.5 on Epop[53]], weight: 4.1363508E-4, delay 1.5
        h("Epop[53] syn_projEE_ampa[3013] = new ampa(0.5)")
        h("Epop[37] netConn_projEE_ampa[3013] = new NetCon(&v(0.5), syn_projEE_ampa[3013], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3014: cell 37, seg 0 (0.5) [0.5 on Epop[37]] -> cell 54, seg 0 (0.5) [0.5 on Epop[54]], weight: 4.1363508E-4, delay 1.5
        h("Epop[54] syn_projEE_ampa[3014] = new ampa(0.5)")
        h("Epop[37] netConn_projEE_ampa[3014] = new NetCon(&v(0.5), syn_projEE_ampa[3014], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3015: cell 37, seg 0 (0.5) [0.5 on Epop[37]] -> cell 55, seg 0 (0.5) [0.5 on Epop[55]], weight: 4.1363508E-4, delay 1.5
        h("Epop[55] syn_projEE_ampa[3015] = new ampa(0.5)")
        h("Epop[37] netConn_projEE_ampa[3015] = new NetCon(&v(0.5), syn_projEE_ampa[3015], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3016: cell 37, seg 0 (0.5) [0.5 on Epop[37]] -> cell 56, seg 0 (0.5) [0.5 on Epop[56]], weight: 4.1363508E-4, delay 1.5
        h("Epop[56] syn_projEE_ampa[3016] = new ampa(0.5)")
        h("Epop[37] netConn_projEE_ampa[3016] = new NetCon(&v(0.5), syn_projEE_ampa[3016], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3017: cell 37, seg 0 (0.5) [0.5 on Epop[37]] -> cell 57, seg 0 (0.5) [0.5 on Epop[57]], weight: 4.1363508E-4, delay 1.5
        h("Epop[57] syn_projEE_ampa[3017] = new ampa(0.5)")
        h("Epop[37] netConn_projEE_ampa[3017] = new NetCon(&v(0.5), syn_projEE_ampa[3017], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3018: cell 37, seg 0 (0.5) [0.5 on Epop[37]] -> cell 58, seg 0 (0.5) [0.5 on Epop[58]], weight: 4.1363508E-4, delay 1.5
        h("Epop[58] syn_projEE_ampa[3018] = new ampa(0.5)")
        h("Epop[37] netConn_projEE_ampa[3018] = new NetCon(&v(0.5), syn_projEE_ampa[3018], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3019: cell 37, seg 0 (0.5) [0.5 on Epop[37]] -> cell 59, seg 0 (0.5) [0.5 on Epop[59]], weight: 4.1363508E-4, delay 1.5
        h("Epop[59] syn_projEE_ampa[3019] = new ampa(0.5)")
        h("Epop[37] netConn_projEE_ampa[3019] = new NetCon(&v(0.5), syn_projEE_ampa[3019], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3020: cell 37, seg 0 (0.5) [0.5 on Epop[37]] -> cell 60, seg 0 (0.5) [0.5 on Epop[60]], weight: 4.1363508E-4, delay 1.5
        h("Epop[60] syn_projEE_ampa[3020] = new ampa(0.5)")
        h("Epop[37] netConn_projEE_ampa[3020] = new NetCon(&v(0.5), syn_projEE_ampa[3020], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3021: cell 37, seg 0 (0.5) [0.5 on Epop[37]] -> cell 61, seg 0 (0.5) [0.5 on Epop[61]], weight: 4.1363508E-4, delay 1.5
        h("Epop[61] syn_projEE_ampa[3021] = new ampa(0.5)")
        h("Epop[37] netConn_projEE_ampa[3021] = new NetCon(&v(0.5), syn_projEE_ampa[3021], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3022: cell 37, seg 0 (0.5) [0.5 on Epop[37]] -> cell 62, seg 0 (0.5) [0.5 on Epop[62]], weight: 4.1363508E-4, delay 1.5
        h("Epop[62] syn_projEE_ampa[3022] = new ampa(0.5)")
        h("Epop[37] netConn_projEE_ampa[3022] = new NetCon(&v(0.5), syn_projEE_ampa[3022], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3023: cell 37, seg 0 (0.5) [0.5 on Epop[37]] -> cell 63, seg 0 (0.5) [0.5 on Epop[63]], weight: 4.1363508E-4, delay 1.5
        h("Epop[63] syn_projEE_ampa[3023] = new ampa(0.5)")
        h("Epop[37] netConn_projEE_ampa[3023] = new NetCon(&v(0.5), syn_projEE_ampa[3023], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3024: cell 37, seg 0 (0.5) [0.5 on Epop[37]] -> cell 64, seg 0 (0.5) [0.5 on Epop[64]], weight: 4.1363508E-4, delay 1.5
        h("Epop[64] syn_projEE_ampa[3024] = new ampa(0.5)")
        h("Epop[37] netConn_projEE_ampa[3024] = new NetCon(&v(0.5), syn_projEE_ampa[3024], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3025: cell 37, seg 0 (0.5) [0.5 on Epop[37]] -> cell 65, seg 0 (0.5) [0.5 on Epop[65]], weight: 4.1363508E-4, delay 1.5
        h("Epop[65] syn_projEE_ampa[3025] = new ampa(0.5)")
        h("Epop[37] netConn_projEE_ampa[3025] = new NetCon(&v(0.5), syn_projEE_ampa[3025], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3026: cell 37, seg 0 (0.5) [0.5 on Epop[37]] -> cell 66, seg 0 (0.5) [0.5 on Epop[66]], weight: 4.1363508E-4, delay 1.5
        h("Epop[66] syn_projEE_ampa[3026] = new ampa(0.5)")
        h("Epop[37] netConn_projEE_ampa[3026] = new NetCon(&v(0.5), syn_projEE_ampa[3026], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3027: cell 37, seg 0 (0.5) [0.5 on Epop[37]] -> cell 67, seg 0 (0.5) [0.5 on Epop[67]], weight: 4.1363508E-4, delay 1.5
        h("Epop[67] syn_projEE_ampa[3027] = new ampa(0.5)")
        h("Epop[37] netConn_projEE_ampa[3027] = new NetCon(&v(0.5), syn_projEE_ampa[3027], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3028: cell 37, seg 0 (0.5) [0.5 on Epop[37]] -> cell 68, seg 0 (0.5) [0.5 on Epop[68]], weight: 4.1363508E-4, delay 1.5
        h("Epop[68] syn_projEE_ampa[3028] = new ampa(0.5)")
        h("Epop[37] netConn_projEE_ampa[3028] = new NetCon(&v(0.5), syn_projEE_ampa[3028], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3029: cell 37, seg 0 (0.5) [0.5 on Epop[37]] -> cell 69, seg 0 (0.5) [0.5 on Epop[69]], weight: 4.1363508E-4, delay 1.5
        h("Epop[69] syn_projEE_ampa[3029] = new ampa(0.5)")
        h("Epop[37] netConn_projEE_ampa[3029] = new NetCon(&v(0.5), syn_projEE_ampa[3029], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3030: cell 37, seg 0 (0.5) [0.5 on Epop[37]] -> cell 70, seg 0 (0.5) [0.5 on Epop[70]], weight: 4.1363508E-4, delay 1.5
        h("Epop[70] syn_projEE_ampa[3030] = new ampa(0.5)")
        h("Epop[37] netConn_projEE_ampa[3030] = new NetCon(&v(0.5), syn_projEE_ampa[3030], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3031: cell 37, seg 0 (0.5) [0.5 on Epop[37]] -> cell 71, seg 0 (0.5) [0.5 on Epop[71]], weight: 4.1363508E-4, delay 1.5
        h("Epop[71] syn_projEE_ampa[3031] = new ampa(0.5)")
        h("Epop[37] netConn_projEE_ampa[3031] = new NetCon(&v(0.5), syn_projEE_ampa[3031], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3032: cell 37, seg 0 (0.5) [0.5 on Epop[37]] -> cell 72, seg 0 (0.5) [0.5 on Epop[72]], weight: 4.1363508E-4, delay 1.5
        h("Epop[72] syn_projEE_ampa[3032] = new ampa(0.5)")
        h("Epop[37] netConn_projEE_ampa[3032] = new NetCon(&v(0.5), syn_projEE_ampa[3032], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3033: cell 37, seg 0 (0.5) [0.5 on Epop[37]] -> cell 73, seg 0 (0.5) [0.5 on Epop[73]], weight: 4.1363508E-4, delay 1.5
        h("Epop[73] syn_projEE_ampa[3033] = new ampa(0.5)")
        h("Epop[37] netConn_projEE_ampa[3033] = new NetCon(&v(0.5), syn_projEE_ampa[3033], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3034: cell 37, seg 0 (0.5) [0.5 on Epop[37]] -> cell 74, seg 0 (0.5) [0.5 on Epop[74]], weight: 4.1363508E-4, delay 1.5
        h("Epop[74] syn_projEE_ampa[3034] = new ampa(0.5)")
        h("Epop[37] netConn_projEE_ampa[3034] = new NetCon(&v(0.5), syn_projEE_ampa[3034], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3035: cell 37, seg 0 (0.5) [0.5 on Epop[37]] -> cell 75, seg 0 (0.5) [0.5 on Epop[75]], weight: 4.1363508E-4, delay 1.5
        h("Epop[75] syn_projEE_ampa[3035] = new ampa(0.5)")
        h("Epop[37] netConn_projEE_ampa[3035] = new NetCon(&v(0.5), syn_projEE_ampa[3035], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3036: cell 37, seg 0 (0.5) [0.5 on Epop[37]] -> cell 76, seg 0 (0.5) [0.5 on Epop[76]], weight: 4.1363508E-4, delay 1.5
        h("Epop[76] syn_projEE_ampa[3036] = new ampa(0.5)")
        h("Epop[37] netConn_projEE_ampa[3036] = new NetCon(&v(0.5), syn_projEE_ampa[3036], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3037: cell 37, seg 0 (0.5) [0.5 on Epop[37]] -> cell 77, seg 0 (0.5) [0.5 on Epop[77]], weight: 4.1363508E-4, delay 1.5
        h("Epop[77] syn_projEE_ampa[3037] = new ampa(0.5)")
        h("Epop[37] netConn_projEE_ampa[3037] = new NetCon(&v(0.5), syn_projEE_ampa[3037], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3038: cell 37, seg 0 (0.5) [0.5 on Epop[37]] -> cell 78, seg 0 (0.5) [0.5 on Epop[78]], weight: 4.1363508E-4, delay 1.5
        h("Epop[78] syn_projEE_ampa[3038] = new ampa(0.5)")
        h("Epop[37] netConn_projEE_ampa[3038] = new NetCon(&v(0.5), syn_projEE_ampa[3038], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3039: cell 37, seg 0 (0.5) [0.5 on Epop[37]] -> cell 79, seg 0 (0.5) [0.5 on Epop[79]], weight: 4.1363508E-4, delay 1.5
        h("Epop[79] syn_projEE_ampa[3039] = new ampa(0.5)")
        h("Epop[37] netConn_projEE_ampa[3039] = new NetCon(&v(0.5), syn_projEE_ampa[3039], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3040: cell 38, seg 0 (0.5) [0.5 on Epop[38]] -> cell 0, seg 0 (0.5) [0.5 on Epop[0]], weight: 4.1363508E-4, delay 1.5
        h("Epop[0] syn_projEE_ampa[3040] = new ampa(0.5)")
        h("Epop[38] netConn_projEE_ampa[3040] = new NetCon(&v(0.5), syn_projEE_ampa[3040], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3041: cell 38, seg 0 (0.5) [0.5 on Epop[38]] -> cell 1, seg 0 (0.5) [0.5 on Epop[1]], weight: 4.1363508E-4, delay 1.5
        h("Epop[1] syn_projEE_ampa[3041] = new ampa(0.5)")
        h("Epop[38] netConn_projEE_ampa[3041] = new NetCon(&v(0.5), syn_projEE_ampa[3041], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3042: cell 38, seg 0 (0.5) [0.5 on Epop[38]] -> cell 2, seg 0 (0.5) [0.5 on Epop[2]], weight: 4.1363508E-4, delay 1.5
        h("Epop[2] syn_projEE_ampa[3042] = new ampa(0.5)")
        h("Epop[38] netConn_projEE_ampa[3042] = new NetCon(&v(0.5), syn_projEE_ampa[3042], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3043: cell 38, seg 0 (0.5) [0.5 on Epop[38]] -> cell 3, seg 0 (0.5) [0.5 on Epop[3]], weight: 4.1363508E-4, delay 1.5
        h("Epop[3] syn_projEE_ampa[3043] = new ampa(0.5)")
        h("Epop[38] netConn_projEE_ampa[3043] = new NetCon(&v(0.5), syn_projEE_ampa[3043], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3044: cell 38, seg 0 (0.5) [0.5 on Epop[38]] -> cell 4, seg 0 (0.5) [0.5 on Epop[4]], weight: 4.1363508E-4, delay 1.5
        h("Epop[4] syn_projEE_ampa[3044] = new ampa(0.5)")
        h("Epop[38] netConn_projEE_ampa[3044] = new NetCon(&v(0.5), syn_projEE_ampa[3044], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3045: cell 38, seg 0 (0.5) [0.5 on Epop[38]] -> cell 5, seg 0 (0.5) [0.5 on Epop[5]], weight: 4.1363508E-4, delay 1.5
        h("Epop[5] syn_projEE_ampa[3045] = new ampa(0.5)")
        h("Epop[38] netConn_projEE_ampa[3045] = new NetCon(&v(0.5), syn_projEE_ampa[3045], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3046: cell 38, seg 0 (0.5) [0.5 on Epop[38]] -> cell 6, seg 0 (0.5) [0.5 on Epop[6]], weight: 4.1363508E-4, delay 1.5
        h("Epop[6] syn_projEE_ampa[3046] = new ampa(0.5)")
        h("Epop[38] netConn_projEE_ampa[3046] = new NetCon(&v(0.5), syn_projEE_ampa[3046], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3047: cell 38, seg 0 (0.5) [0.5 on Epop[38]] -> cell 7, seg 0 (0.5) [0.5 on Epop[7]], weight: 4.1363508E-4, delay 1.5
        h("Epop[7] syn_projEE_ampa[3047] = new ampa(0.5)")
        h("Epop[38] netConn_projEE_ampa[3047] = new NetCon(&v(0.5), syn_projEE_ampa[3047], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3048: cell 38, seg 0 (0.5) [0.5 on Epop[38]] -> cell 8, seg 0 (0.5) [0.5 on Epop[8]], weight: 4.1363508E-4, delay 1.5
        h("Epop[8] syn_projEE_ampa[3048] = new ampa(0.5)")
        h("Epop[38] netConn_projEE_ampa[3048] = new NetCon(&v(0.5), syn_projEE_ampa[3048], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3049: cell 38, seg 0 (0.5) [0.5 on Epop[38]] -> cell 9, seg 0 (0.5) [0.5 on Epop[9]], weight: 4.1363508E-4, delay 1.5
        h("Epop[9] syn_projEE_ampa[3049] = new ampa(0.5)")
        h("Epop[38] netConn_projEE_ampa[3049] = new NetCon(&v(0.5), syn_projEE_ampa[3049], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3050: cell 38, seg 0 (0.5) [0.5 on Epop[38]] -> cell 10, seg 0 (0.5) [0.5 on Epop[10]], weight: 4.1363508E-4, delay 1.5
        h("Epop[10] syn_projEE_ampa[3050] = new ampa(0.5)")
        h("Epop[38] netConn_projEE_ampa[3050] = new NetCon(&v(0.5), syn_projEE_ampa[3050], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3051: cell 38, seg 0 (0.5) [0.5 on Epop[38]] -> cell 11, seg 0 (0.5) [0.5 on Epop[11]], weight: 4.1363508E-4, delay 1.5
        h("Epop[11] syn_projEE_ampa[3051] = new ampa(0.5)")
        h("Epop[38] netConn_projEE_ampa[3051] = new NetCon(&v(0.5), syn_projEE_ampa[3051], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3052: cell 38, seg 0 (0.5) [0.5 on Epop[38]] -> cell 12, seg 0 (0.5) [0.5 on Epop[12]], weight: 4.1363508E-4, delay 1.5
        h("Epop[12] syn_projEE_ampa[3052] = new ampa(0.5)")
        h("Epop[38] netConn_projEE_ampa[3052] = new NetCon(&v(0.5), syn_projEE_ampa[3052], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3053: cell 38, seg 0 (0.5) [0.5 on Epop[38]] -> cell 13, seg 0 (0.5) [0.5 on Epop[13]], weight: 4.1363508E-4, delay 1.5
        h("Epop[13] syn_projEE_ampa[3053] = new ampa(0.5)")
        h("Epop[38] netConn_projEE_ampa[3053] = new NetCon(&v(0.5), syn_projEE_ampa[3053], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3054: cell 38, seg 0 (0.5) [0.5 on Epop[38]] -> cell 14, seg 0 (0.5) [0.5 on Epop[14]], weight: 4.1363508E-4, delay 1.5
        h("Epop[14] syn_projEE_ampa[3054] = new ampa(0.5)")
        h("Epop[38] netConn_projEE_ampa[3054] = new NetCon(&v(0.5), syn_projEE_ampa[3054], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3055: cell 38, seg 0 (0.5) [0.5 on Epop[38]] -> cell 15, seg 0 (0.5) [0.5 on Epop[15]], weight: 4.1363508E-4, delay 1.5
        h("Epop[15] syn_projEE_ampa[3055] = new ampa(0.5)")
        h("Epop[38] netConn_projEE_ampa[3055] = new NetCon(&v(0.5), syn_projEE_ampa[3055], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3056: cell 38, seg 0 (0.5) [0.5 on Epop[38]] -> cell 16, seg 0 (0.5) [0.5 on Epop[16]], weight: 4.1363508E-4, delay 1.5
        h("Epop[16] syn_projEE_ampa[3056] = new ampa(0.5)")
        h("Epop[38] netConn_projEE_ampa[3056] = new NetCon(&v(0.5), syn_projEE_ampa[3056], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3057: cell 38, seg 0 (0.5) [0.5 on Epop[38]] -> cell 17, seg 0 (0.5) [0.5 on Epop[17]], weight: 4.1363508E-4, delay 1.5
        h("Epop[17] syn_projEE_ampa[3057] = new ampa(0.5)")
        h("Epop[38] netConn_projEE_ampa[3057] = new NetCon(&v(0.5), syn_projEE_ampa[3057], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3058: cell 38, seg 0 (0.5) [0.5 on Epop[38]] -> cell 18, seg 0 (0.5) [0.5 on Epop[18]], weight: 4.1363508E-4, delay 1.5
        h("Epop[18] syn_projEE_ampa[3058] = new ampa(0.5)")
        h("Epop[38] netConn_projEE_ampa[3058] = new NetCon(&v(0.5), syn_projEE_ampa[3058], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3059: cell 38, seg 0 (0.5) [0.5 on Epop[38]] -> cell 19, seg 0 (0.5) [0.5 on Epop[19]], weight: 4.1363508E-4, delay 1.5
        h("Epop[19] syn_projEE_ampa[3059] = new ampa(0.5)")
        h("Epop[38] netConn_projEE_ampa[3059] = new NetCon(&v(0.5), syn_projEE_ampa[3059], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3060: cell 38, seg 0 (0.5) [0.5 on Epop[38]] -> cell 20, seg 0 (0.5) [0.5 on Epop[20]], weight: 4.1363508E-4, delay 1.5
        h("Epop[20] syn_projEE_ampa[3060] = new ampa(0.5)")
        h("Epop[38] netConn_projEE_ampa[3060] = new NetCon(&v(0.5), syn_projEE_ampa[3060], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3061: cell 38, seg 0 (0.5) [0.5 on Epop[38]] -> cell 21, seg 0 (0.5) [0.5 on Epop[21]], weight: 4.1363508E-4, delay 1.5
        h("Epop[21] syn_projEE_ampa[3061] = new ampa(0.5)")
        h("Epop[38] netConn_projEE_ampa[3061] = new NetCon(&v(0.5), syn_projEE_ampa[3061], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3062: cell 38, seg 0 (0.5) [0.5 on Epop[38]] -> cell 22, seg 0 (0.5) [0.5 on Epop[22]], weight: 4.1363508E-4, delay 1.5
        h("Epop[22] syn_projEE_ampa[3062] = new ampa(0.5)")
        h("Epop[38] netConn_projEE_ampa[3062] = new NetCon(&v(0.5), syn_projEE_ampa[3062], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3063: cell 38, seg 0 (0.5) [0.5 on Epop[38]] -> cell 23, seg 0 (0.5) [0.5 on Epop[23]], weight: 4.1363508E-4, delay 1.5
        h("Epop[23] syn_projEE_ampa[3063] = new ampa(0.5)")
        h("Epop[38] netConn_projEE_ampa[3063] = new NetCon(&v(0.5), syn_projEE_ampa[3063], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3064: cell 38, seg 0 (0.5) [0.5 on Epop[38]] -> cell 24, seg 0 (0.5) [0.5 on Epop[24]], weight: 4.1363508E-4, delay 1.5
        h("Epop[24] syn_projEE_ampa[3064] = new ampa(0.5)")
        h("Epop[38] netConn_projEE_ampa[3064] = new NetCon(&v(0.5), syn_projEE_ampa[3064], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3065: cell 38, seg 0 (0.5) [0.5 on Epop[38]] -> cell 25, seg 0 (0.5) [0.5 on Epop[25]], weight: 4.1363508E-4, delay 1.5
        h("Epop[25] syn_projEE_ampa[3065] = new ampa(0.5)")
        h("Epop[38] netConn_projEE_ampa[3065] = new NetCon(&v(0.5), syn_projEE_ampa[3065], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3066: cell 38, seg 0 (0.5) [0.5 on Epop[38]] -> cell 26, seg 0 (0.5) [0.5 on Epop[26]], weight: 4.1363508E-4, delay 1.5
        h("Epop[26] syn_projEE_ampa[3066] = new ampa(0.5)")
        h("Epop[38] netConn_projEE_ampa[3066] = new NetCon(&v(0.5), syn_projEE_ampa[3066], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3067: cell 38, seg 0 (0.5) [0.5 on Epop[38]] -> cell 27, seg 0 (0.5) [0.5 on Epop[27]], weight: 4.1363508E-4, delay 1.5
        h("Epop[27] syn_projEE_ampa[3067] = new ampa(0.5)")
        h("Epop[38] netConn_projEE_ampa[3067] = new NetCon(&v(0.5), syn_projEE_ampa[3067], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3068: cell 38, seg 0 (0.5) [0.5 on Epop[38]] -> cell 28, seg 0 (0.5) [0.5 on Epop[28]], weight: 4.1363508E-4, delay 1.5
        h("Epop[28] syn_projEE_ampa[3068] = new ampa(0.5)")
        h("Epop[38] netConn_projEE_ampa[3068] = new NetCon(&v(0.5), syn_projEE_ampa[3068], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3069: cell 38, seg 0 (0.5) [0.5 on Epop[38]] -> cell 29, seg 0 (0.5) [0.5 on Epop[29]], weight: 4.1363508E-4, delay 1.5
        h("Epop[29] syn_projEE_ampa[3069] = new ampa(0.5)")
        h("Epop[38] netConn_projEE_ampa[3069] = new NetCon(&v(0.5), syn_projEE_ampa[3069], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3070: cell 38, seg 0 (0.5) [0.5 on Epop[38]] -> cell 30, seg 0 (0.5) [0.5 on Epop[30]], weight: 4.1363508E-4, delay 1.5
        h("Epop[30] syn_projEE_ampa[3070] = new ampa(0.5)")
        h("Epop[38] netConn_projEE_ampa[3070] = new NetCon(&v(0.5), syn_projEE_ampa[3070], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3071: cell 38, seg 0 (0.5) [0.5 on Epop[38]] -> cell 31, seg 0 (0.5) [0.5 on Epop[31]], weight: 4.1363508E-4, delay 1.5
        h("Epop[31] syn_projEE_ampa[3071] = new ampa(0.5)")
        h("Epop[38] netConn_projEE_ampa[3071] = new NetCon(&v(0.5), syn_projEE_ampa[3071], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3072: cell 38, seg 0 (0.5) [0.5 on Epop[38]] -> cell 32, seg 0 (0.5) [0.5 on Epop[32]], weight: 4.1363508E-4, delay 1.5
        h("Epop[32] syn_projEE_ampa[3072] = new ampa(0.5)")
        h("Epop[38] netConn_projEE_ampa[3072] = new NetCon(&v(0.5), syn_projEE_ampa[3072], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3073: cell 38, seg 0 (0.5) [0.5 on Epop[38]] -> cell 33, seg 0 (0.5) [0.5 on Epop[33]], weight: 4.1363508E-4, delay 1.5
        h("Epop[33] syn_projEE_ampa[3073] = new ampa(0.5)")
        h("Epop[38] netConn_projEE_ampa[3073] = new NetCon(&v(0.5), syn_projEE_ampa[3073], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3074: cell 38, seg 0 (0.5) [0.5 on Epop[38]] -> cell 34, seg 0 (0.5) [0.5 on Epop[34]], weight: 4.1363508E-4, delay 1.5
        h("Epop[34] syn_projEE_ampa[3074] = new ampa(0.5)")
        h("Epop[38] netConn_projEE_ampa[3074] = new NetCon(&v(0.5), syn_projEE_ampa[3074], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3075: cell 38, seg 0 (0.5) [0.5 on Epop[38]] -> cell 35, seg 0 (0.5) [0.5 on Epop[35]], weight: 4.1363508E-4, delay 1.5
        h("Epop[35] syn_projEE_ampa[3075] = new ampa(0.5)")
        h("Epop[38] netConn_projEE_ampa[3075] = new NetCon(&v(0.5), syn_projEE_ampa[3075], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3076: cell 38, seg 0 (0.5) [0.5 on Epop[38]] -> cell 36, seg 0 (0.5) [0.5 on Epop[36]], weight: 4.1363508E-4, delay 1.5
        h("Epop[36] syn_projEE_ampa[3076] = new ampa(0.5)")
        h("Epop[38] netConn_projEE_ampa[3076] = new NetCon(&v(0.5), syn_projEE_ampa[3076], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3077: cell 38, seg 0 (0.5) [0.5 on Epop[38]] -> cell 37, seg 0 (0.5) [0.5 on Epop[37]], weight: 4.1363508E-4, delay 1.5
        h("Epop[37] syn_projEE_ampa[3077] = new ampa(0.5)")
        h("Epop[38] netConn_projEE_ampa[3077] = new NetCon(&v(0.5), syn_projEE_ampa[3077], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3078: cell 38, seg 0 (0.5) [0.5 on Epop[38]] -> cell 38, seg 0 (0.5) [0.5 on Epop[38]], weight: 4.1363508E-4, delay 1.5
        h("Epop[38] syn_projEE_ampa[3078] = new ampa(0.5)")
        h("Epop[38] netConn_projEE_ampa[3078] = new NetCon(&v(0.5), syn_projEE_ampa[3078], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3079: cell 38, seg 0 (0.5) [0.5 on Epop[38]] -> cell 39, seg 0 (0.5) [0.5 on Epop[39]], weight: 4.1363508E-4, delay 1.5
        h("Epop[39] syn_projEE_ampa[3079] = new ampa(0.5)")
        h("Epop[38] netConn_projEE_ampa[3079] = new NetCon(&v(0.5), syn_projEE_ampa[3079], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3080: cell 38, seg 0 (0.5) [0.5 on Epop[38]] -> cell 40, seg 0 (0.5) [0.5 on Epop[40]], weight: 4.1363508E-4, delay 1.5
        h("Epop[40] syn_projEE_ampa[3080] = new ampa(0.5)")
        h("Epop[38] netConn_projEE_ampa[3080] = new NetCon(&v(0.5), syn_projEE_ampa[3080], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3081: cell 38, seg 0 (0.5) [0.5 on Epop[38]] -> cell 41, seg 0 (0.5) [0.5 on Epop[41]], weight: 4.1363508E-4, delay 1.5
        h("Epop[41] syn_projEE_ampa[3081] = new ampa(0.5)")
        h("Epop[38] netConn_projEE_ampa[3081] = new NetCon(&v(0.5), syn_projEE_ampa[3081], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3082: cell 38, seg 0 (0.5) [0.5 on Epop[38]] -> cell 42, seg 0 (0.5) [0.5 on Epop[42]], weight: 4.1363508E-4, delay 1.5
        h("Epop[42] syn_projEE_ampa[3082] = new ampa(0.5)")
        h("Epop[38] netConn_projEE_ampa[3082] = new NetCon(&v(0.5), syn_projEE_ampa[3082], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3083: cell 38, seg 0 (0.5) [0.5 on Epop[38]] -> cell 43, seg 0 (0.5) [0.5 on Epop[43]], weight: 4.1363508E-4, delay 1.5
        h("Epop[43] syn_projEE_ampa[3083] = new ampa(0.5)")
        h("Epop[38] netConn_projEE_ampa[3083] = new NetCon(&v(0.5), syn_projEE_ampa[3083], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3084: cell 38, seg 0 (0.5) [0.5 on Epop[38]] -> cell 44, seg 0 (0.5) [0.5 on Epop[44]], weight: 4.1363508E-4, delay 1.5
        h("Epop[44] syn_projEE_ampa[3084] = new ampa(0.5)")
        h("Epop[38] netConn_projEE_ampa[3084] = new NetCon(&v(0.5), syn_projEE_ampa[3084], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3085: cell 38, seg 0 (0.5) [0.5 on Epop[38]] -> cell 45, seg 0 (0.5) [0.5 on Epop[45]], weight: 4.1363508E-4, delay 1.5
        h("Epop[45] syn_projEE_ampa[3085] = new ampa(0.5)")
        h("Epop[38] netConn_projEE_ampa[3085] = new NetCon(&v(0.5), syn_projEE_ampa[3085], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3086: cell 38, seg 0 (0.5) [0.5 on Epop[38]] -> cell 46, seg 0 (0.5) [0.5 on Epop[46]], weight: 4.1363508E-4, delay 1.5
        h("Epop[46] syn_projEE_ampa[3086] = new ampa(0.5)")
        h("Epop[38] netConn_projEE_ampa[3086] = new NetCon(&v(0.5), syn_projEE_ampa[3086], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3087: cell 38, seg 0 (0.5) [0.5 on Epop[38]] -> cell 47, seg 0 (0.5) [0.5 on Epop[47]], weight: 4.1363508E-4, delay 1.5
        h("Epop[47] syn_projEE_ampa[3087] = new ampa(0.5)")
        h("Epop[38] netConn_projEE_ampa[3087] = new NetCon(&v(0.5), syn_projEE_ampa[3087], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3088: cell 38, seg 0 (0.5) [0.5 on Epop[38]] -> cell 48, seg 0 (0.5) [0.5 on Epop[48]], weight: 4.1363508E-4, delay 1.5
        h("Epop[48] syn_projEE_ampa[3088] = new ampa(0.5)")
        h("Epop[38] netConn_projEE_ampa[3088] = new NetCon(&v(0.5), syn_projEE_ampa[3088], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3089: cell 38, seg 0 (0.5) [0.5 on Epop[38]] -> cell 49, seg 0 (0.5) [0.5 on Epop[49]], weight: 4.1363508E-4, delay 1.5
        h("Epop[49] syn_projEE_ampa[3089] = new ampa(0.5)")
        h("Epop[38] netConn_projEE_ampa[3089] = new NetCon(&v(0.5), syn_projEE_ampa[3089], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3090: cell 38, seg 0 (0.5) [0.5 on Epop[38]] -> cell 50, seg 0 (0.5) [0.5 on Epop[50]], weight: 4.1363508E-4, delay 1.5
        h("Epop[50] syn_projEE_ampa[3090] = new ampa(0.5)")
        h("Epop[38] netConn_projEE_ampa[3090] = new NetCon(&v(0.5), syn_projEE_ampa[3090], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3091: cell 38, seg 0 (0.5) [0.5 on Epop[38]] -> cell 51, seg 0 (0.5) [0.5 on Epop[51]], weight: 4.1363508E-4, delay 1.5
        h("Epop[51] syn_projEE_ampa[3091] = new ampa(0.5)")
        h("Epop[38] netConn_projEE_ampa[3091] = new NetCon(&v(0.5), syn_projEE_ampa[3091], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3092: cell 38, seg 0 (0.5) [0.5 on Epop[38]] -> cell 52, seg 0 (0.5) [0.5 on Epop[52]], weight: 4.1363508E-4, delay 1.5
        h("Epop[52] syn_projEE_ampa[3092] = new ampa(0.5)")
        h("Epop[38] netConn_projEE_ampa[3092] = new NetCon(&v(0.5), syn_projEE_ampa[3092], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3093: cell 38, seg 0 (0.5) [0.5 on Epop[38]] -> cell 53, seg 0 (0.5) [0.5 on Epop[53]], weight: 4.1363508E-4, delay 1.5
        h("Epop[53] syn_projEE_ampa[3093] = new ampa(0.5)")
        h("Epop[38] netConn_projEE_ampa[3093] = new NetCon(&v(0.5), syn_projEE_ampa[3093], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3094: cell 38, seg 0 (0.5) [0.5 on Epop[38]] -> cell 54, seg 0 (0.5) [0.5 on Epop[54]], weight: 4.1363508E-4, delay 1.5
        h("Epop[54] syn_projEE_ampa[3094] = new ampa(0.5)")
        h("Epop[38] netConn_projEE_ampa[3094] = new NetCon(&v(0.5), syn_projEE_ampa[3094], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3095: cell 38, seg 0 (0.5) [0.5 on Epop[38]] -> cell 55, seg 0 (0.5) [0.5 on Epop[55]], weight: 4.1363508E-4, delay 1.5
        h("Epop[55] syn_projEE_ampa[3095] = new ampa(0.5)")
        h("Epop[38] netConn_projEE_ampa[3095] = new NetCon(&v(0.5), syn_projEE_ampa[3095], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3096: cell 38, seg 0 (0.5) [0.5 on Epop[38]] -> cell 56, seg 0 (0.5) [0.5 on Epop[56]], weight: 4.1363508E-4, delay 1.5
        h("Epop[56] syn_projEE_ampa[3096] = new ampa(0.5)")
        h("Epop[38] netConn_projEE_ampa[3096] = new NetCon(&v(0.5), syn_projEE_ampa[3096], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3097: cell 38, seg 0 (0.5) [0.5 on Epop[38]] -> cell 57, seg 0 (0.5) [0.5 on Epop[57]], weight: 4.1363508E-4, delay 1.5
        h("Epop[57] syn_projEE_ampa[3097] = new ampa(0.5)")
        h("Epop[38] netConn_projEE_ampa[3097] = new NetCon(&v(0.5), syn_projEE_ampa[3097], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3098: cell 38, seg 0 (0.5) [0.5 on Epop[38]] -> cell 58, seg 0 (0.5) [0.5 on Epop[58]], weight: 4.1363508E-4, delay 1.5
        h("Epop[58] syn_projEE_ampa[3098] = new ampa(0.5)")
        h("Epop[38] netConn_projEE_ampa[3098] = new NetCon(&v(0.5), syn_projEE_ampa[3098], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3099: cell 38, seg 0 (0.5) [0.5 on Epop[38]] -> cell 59, seg 0 (0.5) [0.5 on Epop[59]], weight: 4.1363508E-4, delay 1.5
        h("Epop[59] syn_projEE_ampa[3099] = new ampa(0.5)")
        h("Epop[38] netConn_projEE_ampa[3099] = new NetCon(&v(0.5), syn_projEE_ampa[3099], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3100: cell 38, seg 0 (0.5) [0.5 on Epop[38]] -> cell 60, seg 0 (0.5) [0.5 on Epop[60]], weight: 4.1363508E-4, delay 1.5
        h("Epop[60] syn_projEE_ampa[3100] = new ampa(0.5)")
        h("Epop[38] netConn_projEE_ampa[3100] = new NetCon(&v(0.5), syn_projEE_ampa[3100], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3101: cell 38, seg 0 (0.5) [0.5 on Epop[38]] -> cell 61, seg 0 (0.5) [0.5 on Epop[61]], weight: 4.1363508E-4, delay 1.5
        h("Epop[61] syn_projEE_ampa[3101] = new ampa(0.5)")
        h("Epop[38] netConn_projEE_ampa[3101] = new NetCon(&v(0.5), syn_projEE_ampa[3101], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3102: cell 38, seg 0 (0.5) [0.5 on Epop[38]] -> cell 62, seg 0 (0.5) [0.5 on Epop[62]], weight: 4.1363508E-4, delay 1.5
        h("Epop[62] syn_projEE_ampa[3102] = new ampa(0.5)")
        h("Epop[38] netConn_projEE_ampa[3102] = new NetCon(&v(0.5), syn_projEE_ampa[3102], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3103: cell 38, seg 0 (0.5) [0.5 on Epop[38]] -> cell 63, seg 0 (0.5) [0.5 on Epop[63]], weight: 4.1363508E-4, delay 1.5
        h("Epop[63] syn_projEE_ampa[3103] = new ampa(0.5)")
        h("Epop[38] netConn_projEE_ampa[3103] = new NetCon(&v(0.5), syn_projEE_ampa[3103], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3104: cell 38, seg 0 (0.5) [0.5 on Epop[38]] -> cell 64, seg 0 (0.5) [0.5 on Epop[64]], weight: 4.1363508E-4, delay 1.5
        h("Epop[64] syn_projEE_ampa[3104] = new ampa(0.5)")
        h("Epop[38] netConn_projEE_ampa[3104] = new NetCon(&v(0.5), syn_projEE_ampa[3104], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3105: cell 38, seg 0 (0.5) [0.5 on Epop[38]] -> cell 65, seg 0 (0.5) [0.5 on Epop[65]], weight: 4.1363508E-4, delay 1.5
        h("Epop[65] syn_projEE_ampa[3105] = new ampa(0.5)")
        h("Epop[38] netConn_projEE_ampa[3105] = new NetCon(&v(0.5), syn_projEE_ampa[3105], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3106: cell 38, seg 0 (0.5) [0.5 on Epop[38]] -> cell 66, seg 0 (0.5) [0.5 on Epop[66]], weight: 4.1363508E-4, delay 1.5
        h("Epop[66] syn_projEE_ampa[3106] = new ampa(0.5)")
        h("Epop[38] netConn_projEE_ampa[3106] = new NetCon(&v(0.5), syn_projEE_ampa[3106], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3107: cell 38, seg 0 (0.5) [0.5 on Epop[38]] -> cell 67, seg 0 (0.5) [0.5 on Epop[67]], weight: 4.1363508E-4, delay 1.5
        h("Epop[67] syn_projEE_ampa[3107] = new ampa(0.5)")
        h("Epop[38] netConn_projEE_ampa[3107] = new NetCon(&v(0.5), syn_projEE_ampa[3107], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3108: cell 38, seg 0 (0.5) [0.5 on Epop[38]] -> cell 68, seg 0 (0.5) [0.5 on Epop[68]], weight: 4.1363508E-4, delay 1.5
        h("Epop[68] syn_projEE_ampa[3108] = new ampa(0.5)")
        h("Epop[38] netConn_projEE_ampa[3108] = new NetCon(&v(0.5), syn_projEE_ampa[3108], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3109: cell 38, seg 0 (0.5) [0.5 on Epop[38]] -> cell 69, seg 0 (0.5) [0.5 on Epop[69]], weight: 4.1363508E-4, delay 1.5
        h("Epop[69] syn_projEE_ampa[3109] = new ampa(0.5)")
        h("Epop[38] netConn_projEE_ampa[3109] = new NetCon(&v(0.5), syn_projEE_ampa[3109], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3110: cell 38, seg 0 (0.5) [0.5 on Epop[38]] -> cell 70, seg 0 (0.5) [0.5 on Epop[70]], weight: 4.1363508E-4, delay 1.5
        h("Epop[70] syn_projEE_ampa[3110] = new ampa(0.5)")
        h("Epop[38] netConn_projEE_ampa[3110] = new NetCon(&v(0.5), syn_projEE_ampa[3110], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3111: cell 38, seg 0 (0.5) [0.5 on Epop[38]] -> cell 71, seg 0 (0.5) [0.5 on Epop[71]], weight: 4.1363508E-4, delay 1.5
        h("Epop[71] syn_projEE_ampa[3111] = new ampa(0.5)")
        h("Epop[38] netConn_projEE_ampa[3111] = new NetCon(&v(0.5), syn_projEE_ampa[3111], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3112: cell 38, seg 0 (0.5) [0.5 on Epop[38]] -> cell 72, seg 0 (0.5) [0.5 on Epop[72]], weight: 4.1363508E-4, delay 1.5
        h("Epop[72] syn_projEE_ampa[3112] = new ampa(0.5)")
        h("Epop[38] netConn_projEE_ampa[3112] = new NetCon(&v(0.5), syn_projEE_ampa[3112], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3113: cell 38, seg 0 (0.5) [0.5 on Epop[38]] -> cell 73, seg 0 (0.5) [0.5 on Epop[73]], weight: 4.1363508E-4, delay 1.5
        h("Epop[73] syn_projEE_ampa[3113] = new ampa(0.5)")
        h("Epop[38] netConn_projEE_ampa[3113] = new NetCon(&v(0.5), syn_projEE_ampa[3113], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3114: cell 38, seg 0 (0.5) [0.5 on Epop[38]] -> cell 74, seg 0 (0.5) [0.5 on Epop[74]], weight: 4.1363508E-4, delay 1.5
        h("Epop[74] syn_projEE_ampa[3114] = new ampa(0.5)")
        h("Epop[38] netConn_projEE_ampa[3114] = new NetCon(&v(0.5), syn_projEE_ampa[3114], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3115: cell 38, seg 0 (0.5) [0.5 on Epop[38]] -> cell 75, seg 0 (0.5) [0.5 on Epop[75]], weight: 4.1363508E-4, delay 1.5
        h("Epop[75] syn_projEE_ampa[3115] = new ampa(0.5)")
        h("Epop[38] netConn_projEE_ampa[3115] = new NetCon(&v(0.5), syn_projEE_ampa[3115], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3116: cell 38, seg 0 (0.5) [0.5 on Epop[38]] -> cell 76, seg 0 (0.5) [0.5 on Epop[76]], weight: 4.1363508E-4, delay 1.5
        h("Epop[76] syn_projEE_ampa[3116] = new ampa(0.5)")
        h("Epop[38] netConn_projEE_ampa[3116] = new NetCon(&v(0.5), syn_projEE_ampa[3116], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3117: cell 38, seg 0 (0.5) [0.5 on Epop[38]] -> cell 77, seg 0 (0.5) [0.5 on Epop[77]], weight: 4.1363508E-4, delay 1.5
        h("Epop[77] syn_projEE_ampa[3117] = new ampa(0.5)")
        h("Epop[38] netConn_projEE_ampa[3117] = new NetCon(&v(0.5), syn_projEE_ampa[3117], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3118: cell 38, seg 0 (0.5) [0.5 on Epop[38]] -> cell 78, seg 0 (0.5) [0.5 on Epop[78]], weight: 4.1363508E-4, delay 1.5
        h("Epop[78] syn_projEE_ampa[3118] = new ampa(0.5)")
        h("Epop[38] netConn_projEE_ampa[3118] = new NetCon(&v(0.5), syn_projEE_ampa[3118], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3119: cell 38, seg 0 (0.5) [0.5 on Epop[38]] -> cell 79, seg 0 (0.5) [0.5 on Epop[79]], weight: 4.1363508E-4, delay 1.5
        h("Epop[79] syn_projEE_ampa[3119] = new ampa(0.5)")
        h("Epop[38] netConn_projEE_ampa[3119] = new NetCon(&v(0.5), syn_projEE_ampa[3119], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3120: cell 39, seg 0 (0.5) [0.5 on Epop[39]] -> cell 0, seg 0 (0.5) [0.5 on Epop[0]], weight: 4.1363508E-4, delay 1.5
        h("Epop[0] syn_projEE_ampa[3120] = new ampa(0.5)")
        h("Epop[39] netConn_projEE_ampa[3120] = new NetCon(&v(0.5), syn_projEE_ampa[3120], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3121: cell 39, seg 0 (0.5) [0.5 on Epop[39]] -> cell 1, seg 0 (0.5) [0.5 on Epop[1]], weight: 4.1363508E-4, delay 1.5
        h("Epop[1] syn_projEE_ampa[3121] = new ampa(0.5)")
        h("Epop[39] netConn_projEE_ampa[3121] = new NetCon(&v(0.5), syn_projEE_ampa[3121], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3122: cell 39, seg 0 (0.5) [0.5 on Epop[39]] -> cell 2, seg 0 (0.5) [0.5 on Epop[2]], weight: 4.1363508E-4, delay 1.5
        h("Epop[2] syn_projEE_ampa[3122] = new ampa(0.5)")
        h("Epop[39] netConn_projEE_ampa[3122] = new NetCon(&v(0.5), syn_projEE_ampa[3122], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3123: cell 39, seg 0 (0.5) [0.5 on Epop[39]] -> cell 3, seg 0 (0.5) [0.5 on Epop[3]], weight: 4.1363508E-4, delay 1.5
        h("Epop[3] syn_projEE_ampa[3123] = new ampa(0.5)")
        h("Epop[39] netConn_projEE_ampa[3123] = new NetCon(&v(0.5), syn_projEE_ampa[3123], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3124: cell 39, seg 0 (0.5) [0.5 on Epop[39]] -> cell 4, seg 0 (0.5) [0.5 on Epop[4]], weight: 4.1363508E-4, delay 1.5
        h("Epop[4] syn_projEE_ampa[3124] = new ampa(0.5)")
        h("Epop[39] netConn_projEE_ampa[3124] = new NetCon(&v(0.5), syn_projEE_ampa[3124], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3125: cell 39, seg 0 (0.5) [0.5 on Epop[39]] -> cell 5, seg 0 (0.5) [0.5 on Epop[5]], weight: 4.1363508E-4, delay 1.5
        h("Epop[5] syn_projEE_ampa[3125] = new ampa(0.5)")
        h("Epop[39] netConn_projEE_ampa[3125] = new NetCon(&v(0.5), syn_projEE_ampa[3125], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3126: cell 39, seg 0 (0.5) [0.5 on Epop[39]] -> cell 6, seg 0 (0.5) [0.5 on Epop[6]], weight: 4.1363508E-4, delay 1.5
        h("Epop[6] syn_projEE_ampa[3126] = new ampa(0.5)")
        h("Epop[39] netConn_projEE_ampa[3126] = new NetCon(&v(0.5), syn_projEE_ampa[3126], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3127: cell 39, seg 0 (0.5) [0.5 on Epop[39]] -> cell 7, seg 0 (0.5) [0.5 on Epop[7]], weight: 4.1363508E-4, delay 1.5
        h("Epop[7] syn_projEE_ampa[3127] = new ampa(0.5)")
        h("Epop[39] netConn_projEE_ampa[3127] = new NetCon(&v(0.5), syn_projEE_ampa[3127], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3128: cell 39, seg 0 (0.5) [0.5 on Epop[39]] -> cell 8, seg 0 (0.5) [0.5 on Epop[8]], weight: 4.1363508E-4, delay 1.5
        h("Epop[8] syn_projEE_ampa[3128] = new ampa(0.5)")
        h("Epop[39] netConn_projEE_ampa[3128] = new NetCon(&v(0.5), syn_projEE_ampa[3128], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3129: cell 39, seg 0 (0.5) [0.5 on Epop[39]] -> cell 9, seg 0 (0.5) [0.5 on Epop[9]], weight: 4.1363508E-4, delay 1.5
        h("Epop[9] syn_projEE_ampa[3129] = new ampa(0.5)")
        h("Epop[39] netConn_projEE_ampa[3129] = new NetCon(&v(0.5), syn_projEE_ampa[3129], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3130: cell 39, seg 0 (0.5) [0.5 on Epop[39]] -> cell 10, seg 0 (0.5) [0.5 on Epop[10]], weight: 4.1363508E-4, delay 1.5
        h("Epop[10] syn_projEE_ampa[3130] = new ampa(0.5)")
        h("Epop[39] netConn_projEE_ampa[3130] = new NetCon(&v(0.5), syn_projEE_ampa[3130], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3131: cell 39, seg 0 (0.5) [0.5 on Epop[39]] -> cell 11, seg 0 (0.5) [0.5 on Epop[11]], weight: 4.1363508E-4, delay 1.5
        h("Epop[11] syn_projEE_ampa[3131] = new ampa(0.5)")
        h("Epop[39] netConn_projEE_ampa[3131] = new NetCon(&v(0.5), syn_projEE_ampa[3131], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3132: cell 39, seg 0 (0.5) [0.5 on Epop[39]] -> cell 12, seg 0 (0.5) [0.5 on Epop[12]], weight: 4.1363508E-4, delay 1.5
        h("Epop[12] syn_projEE_ampa[3132] = new ampa(0.5)")
        h("Epop[39] netConn_projEE_ampa[3132] = new NetCon(&v(0.5), syn_projEE_ampa[3132], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3133: cell 39, seg 0 (0.5) [0.5 on Epop[39]] -> cell 13, seg 0 (0.5) [0.5 on Epop[13]], weight: 4.1363508E-4, delay 1.5
        h("Epop[13] syn_projEE_ampa[3133] = new ampa(0.5)")
        h("Epop[39] netConn_projEE_ampa[3133] = new NetCon(&v(0.5), syn_projEE_ampa[3133], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3134: cell 39, seg 0 (0.5) [0.5 on Epop[39]] -> cell 14, seg 0 (0.5) [0.5 on Epop[14]], weight: 4.1363508E-4, delay 1.5
        h("Epop[14] syn_projEE_ampa[3134] = new ampa(0.5)")
        h("Epop[39] netConn_projEE_ampa[3134] = new NetCon(&v(0.5), syn_projEE_ampa[3134], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3135: cell 39, seg 0 (0.5) [0.5 on Epop[39]] -> cell 15, seg 0 (0.5) [0.5 on Epop[15]], weight: 4.1363508E-4, delay 1.5
        h("Epop[15] syn_projEE_ampa[3135] = new ampa(0.5)")
        h("Epop[39] netConn_projEE_ampa[3135] = new NetCon(&v(0.5), syn_projEE_ampa[3135], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3136: cell 39, seg 0 (0.5) [0.5 on Epop[39]] -> cell 16, seg 0 (0.5) [0.5 on Epop[16]], weight: 4.1363508E-4, delay 1.5
        h("Epop[16] syn_projEE_ampa[3136] = new ampa(0.5)")
        h("Epop[39] netConn_projEE_ampa[3136] = new NetCon(&v(0.5), syn_projEE_ampa[3136], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3137: cell 39, seg 0 (0.5) [0.5 on Epop[39]] -> cell 17, seg 0 (0.5) [0.5 on Epop[17]], weight: 4.1363508E-4, delay 1.5
        h("Epop[17] syn_projEE_ampa[3137] = new ampa(0.5)")
        h("Epop[39] netConn_projEE_ampa[3137] = new NetCon(&v(0.5), syn_projEE_ampa[3137], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3138: cell 39, seg 0 (0.5) [0.5 on Epop[39]] -> cell 18, seg 0 (0.5) [0.5 on Epop[18]], weight: 4.1363508E-4, delay 1.5
        h("Epop[18] syn_projEE_ampa[3138] = new ampa(0.5)")
        h("Epop[39] netConn_projEE_ampa[3138] = new NetCon(&v(0.5), syn_projEE_ampa[3138], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3139: cell 39, seg 0 (0.5) [0.5 on Epop[39]] -> cell 19, seg 0 (0.5) [0.5 on Epop[19]], weight: 4.1363508E-4, delay 1.5
        h("Epop[19] syn_projEE_ampa[3139] = new ampa(0.5)")
        h("Epop[39] netConn_projEE_ampa[3139] = new NetCon(&v(0.5), syn_projEE_ampa[3139], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3140: cell 39, seg 0 (0.5) [0.5 on Epop[39]] -> cell 20, seg 0 (0.5) [0.5 on Epop[20]], weight: 4.1363508E-4, delay 1.5
        h("Epop[20] syn_projEE_ampa[3140] = new ampa(0.5)")
        h("Epop[39] netConn_projEE_ampa[3140] = new NetCon(&v(0.5), syn_projEE_ampa[3140], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3141: cell 39, seg 0 (0.5) [0.5 on Epop[39]] -> cell 21, seg 0 (0.5) [0.5 on Epop[21]], weight: 4.1363508E-4, delay 1.5
        h("Epop[21] syn_projEE_ampa[3141] = new ampa(0.5)")
        h("Epop[39] netConn_projEE_ampa[3141] = new NetCon(&v(0.5), syn_projEE_ampa[3141], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3142: cell 39, seg 0 (0.5) [0.5 on Epop[39]] -> cell 22, seg 0 (0.5) [0.5 on Epop[22]], weight: 4.1363508E-4, delay 1.5
        h("Epop[22] syn_projEE_ampa[3142] = new ampa(0.5)")
        h("Epop[39] netConn_projEE_ampa[3142] = new NetCon(&v(0.5), syn_projEE_ampa[3142], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3143: cell 39, seg 0 (0.5) [0.5 on Epop[39]] -> cell 23, seg 0 (0.5) [0.5 on Epop[23]], weight: 4.1363508E-4, delay 1.5
        h("Epop[23] syn_projEE_ampa[3143] = new ampa(0.5)")
        h("Epop[39] netConn_projEE_ampa[3143] = new NetCon(&v(0.5), syn_projEE_ampa[3143], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3144: cell 39, seg 0 (0.5) [0.5 on Epop[39]] -> cell 24, seg 0 (0.5) [0.5 on Epop[24]], weight: 4.1363508E-4, delay 1.5
        h("Epop[24] syn_projEE_ampa[3144] = new ampa(0.5)")
        h("Epop[39] netConn_projEE_ampa[3144] = new NetCon(&v(0.5), syn_projEE_ampa[3144], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3145: cell 39, seg 0 (0.5) [0.5 on Epop[39]] -> cell 25, seg 0 (0.5) [0.5 on Epop[25]], weight: 4.1363508E-4, delay 1.5
        h("Epop[25] syn_projEE_ampa[3145] = new ampa(0.5)")
        h("Epop[39] netConn_projEE_ampa[3145] = new NetCon(&v(0.5), syn_projEE_ampa[3145], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3146: cell 39, seg 0 (0.5) [0.5 on Epop[39]] -> cell 26, seg 0 (0.5) [0.5 on Epop[26]], weight: 4.1363508E-4, delay 1.5
        h("Epop[26] syn_projEE_ampa[3146] = new ampa(0.5)")
        h("Epop[39] netConn_projEE_ampa[3146] = new NetCon(&v(0.5), syn_projEE_ampa[3146], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3147: cell 39, seg 0 (0.5) [0.5 on Epop[39]] -> cell 27, seg 0 (0.5) [0.5 on Epop[27]], weight: 4.1363508E-4, delay 1.5
        h("Epop[27] syn_projEE_ampa[3147] = new ampa(0.5)")
        h("Epop[39] netConn_projEE_ampa[3147] = new NetCon(&v(0.5), syn_projEE_ampa[3147], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3148: cell 39, seg 0 (0.5) [0.5 on Epop[39]] -> cell 28, seg 0 (0.5) [0.5 on Epop[28]], weight: 4.1363508E-4, delay 1.5
        h("Epop[28] syn_projEE_ampa[3148] = new ampa(0.5)")
        h("Epop[39] netConn_projEE_ampa[3148] = new NetCon(&v(0.5), syn_projEE_ampa[3148], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3149: cell 39, seg 0 (0.5) [0.5 on Epop[39]] -> cell 29, seg 0 (0.5) [0.5 on Epop[29]], weight: 4.1363508E-4, delay 1.5
        h("Epop[29] syn_projEE_ampa[3149] = new ampa(0.5)")
        h("Epop[39] netConn_projEE_ampa[3149] = new NetCon(&v(0.5), syn_projEE_ampa[3149], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3150: cell 39, seg 0 (0.5) [0.5 on Epop[39]] -> cell 30, seg 0 (0.5) [0.5 on Epop[30]], weight: 4.1363508E-4, delay 1.5
        h("Epop[30] syn_projEE_ampa[3150] = new ampa(0.5)")
        h("Epop[39] netConn_projEE_ampa[3150] = new NetCon(&v(0.5), syn_projEE_ampa[3150], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3151: cell 39, seg 0 (0.5) [0.5 on Epop[39]] -> cell 31, seg 0 (0.5) [0.5 on Epop[31]], weight: 4.1363508E-4, delay 1.5
        h("Epop[31] syn_projEE_ampa[3151] = new ampa(0.5)")
        h("Epop[39] netConn_projEE_ampa[3151] = new NetCon(&v(0.5), syn_projEE_ampa[3151], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3152: cell 39, seg 0 (0.5) [0.5 on Epop[39]] -> cell 32, seg 0 (0.5) [0.5 on Epop[32]], weight: 4.1363508E-4, delay 1.5
        h("Epop[32] syn_projEE_ampa[3152] = new ampa(0.5)")
        h("Epop[39] netConn_projEE_ampa[3152] = new NetCon(&v(0.5), syn_projEE_ampa[3152], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3153: cell 39, seg 0 (0.5) [0.5 on Epop[39]] -> cell 33, seg 0 (0.5) [0.5 on Epop[33]], weight: 4.1363508E-4, delay 1.5
        h("Epop[33] syn_projEE_ampa[3153] = new ampa(0.5)")
        h("Epop[39] netConn_projEE_ampa[3153] = new NetCon(&v(0.5), syn_projEE_ampa[3153], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3154: cell 39, seg 0 (0.5) [0.5 on Epop[39]] -> cell 34, seg 0 (0.5) [0.5 on Epop[34]], weight: 4.1363508E-4, delay 1.5
        h("Epop[34] syn_projEE_ampa[3154] = new ampa(0.5)")
        h("Epop[39] netConn_projEE_ampa[3154] = new NetCon(&v(0.5), syn_projEE_ampa[3154], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3155: cell 39, seg 0 (0.5) [0.5 on Epop[39]] -> cell 35, seg 0 (0.5) [0.5 on Epop[35]], weight: 4.1363508E-4, delay 1.5
        h("Epop[35] syn_projEE_ampa[3155] = new ampa(0.5)")
        h("Epop[39] netConn_projEE_ampa[3155] = new NetCon(&v(0.5), syn_projEE_ampa[3155], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3156: cell 39, seg 0 (0.5) [0.5 on Epop[39]] -> cell 36, seg 0 (0.5) [0.5 on Epop[36]], weight: 4.1363508E-4, delay 1.5
        h("Epop[36] syn_projEE_ampa[3156] = new ampa(0.5)")
        h("Epop[39] netConn_projEE_ampa[3156] = new NetCon(&v(0.5), syn_projEE_ampa[3156], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3157: cell 39, seg 0 (0.5) [0.5 on Epop[39]] -> cell 37, seg 0 (0.5) [0.5 on Epop[37]], weight: 4.1363508E-4, delay 1.5
        h("Epop[37] syn_projEE_ampa[3157] = new ampa(0.5)")
        h("Epop[39] netConn_projEE_ampa[3157] = new NetCon(&v(0.5), syn_projEE_ampa[3157], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3158: cell 39, seg 0 (0.5) [0.5 on Epop[39]] -> cell 38, seg 0 (0.5) [0.5 on Epop[38]], weight: 4.1363508E-4, delay 1.5
        h("Epop[38] syn_projEE_ampa[3158] = new ampa(0.5)")
        h("Epop[39] netConn_projEE_ampa[3158] = new NetCon(&v(0.5), syn_projEE_ampa[3158], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3159: cell 39, seg 0 (0.5) [0.5 on Epop[39]] -> cell 39, seg 0 (0.5) [0.5 on Epop[39]], weight: 4.1363508E-4, delay 1.5
        h("Epop[39] syn_projEE_ampa[3159] = new ampa(0.5)")
        h("Epop[39] netConn_projEE_ampa[3159] = new NetCon(&v(0.5), syn_projEE_ampa[3159], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3160: cell 39, seg 0 (0.5) [0.5 on Epop[39]] -> cell 40, seg 0 (0.5) [0.5 on Epop[40]], weight: 4.1363508E-4, delay 1.5
        h("Epop[40] syn_projEE_ampa[3160] = new ampa(0.5)")
        h("Epop[39] netConn_projEE_ampa[3160] = new NetCon(&v(0.5), syn_projEE_ampa[3160], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3161: cell 39, seg 0 (0.5) [0.5 on Epop[39]] -> cell 41, seg 0 (0.5) [0.5 on Epop[41]], weight: 4.1363508E-4, delay 1.5
        h("Epop[41] syn_projEE_ampa[3161] = new ampa(0.5)")
        h("Epop[39] netConn_projEE_ampa[3161] = new NetCon(&v(0.5), syn_projEE_ampa[3161], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3162: cell 39, seg 0 (0.5) [0.5 on Epop[39]] -> cell 42, seg 0 (0.5) [0.5 on Epop[42]], weight: 4.1363508E-4, delay 1.5
        h("Epop[42] syn_projEE_ampa[3162] = new ampa(0.5)")
        h("Epop[39] netConn_projEE_ampa[3162] = new NetCon(&v(0.5), syn_projEE_ampa[3162], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3163: cell 39, seg 0 (0.5) [0.5 on Epop[39]] -> cell 43, seg 0 (0.5) [0.5 on Epop[43]], weight: 4.1363508E-4, delay 1.5
        h("Epop[43] syn_projEE_ampa[3163] = new ampa(0.5)")
        h("Epop[39] netConn_projEE_ampa[3163] = new NetCon(&v(0.5), syn_projEE_ampa[3163], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3164: cell 39, seg 0 (0.5) [0.5 on Epop[39]] -> cell 44, seg 0 (0.5) [0.5 on Epop[44]], weight: 4.1363508E-4, delay 1.5
        h("Epop[44] syn_projEE_ampa[3164] = new ampa(0.5)")
        h("Epop[39] netConn_projEE_ampa[3164] = new NetCon(&v(0.5), syn_projEE_ampa[3164], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3165: cell 39, seg 0 (0.5) [0.5 on Epop[39]] -> cell 45, seg 0 (0.5) [0.5 on Epop[45]], weight: 4.1363508E-4, delay 1.5
        h("Epop[45] syn_projEE_ampa[3165] = new ampa(0.5)")
        h("Epop[39] netConn_projEE_ampa[3165] = new NetCon(&v(0.5), syn_projEE_ampa[3165], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3166: cell 39, seg 0 (0.5) [0.5 on Epop[39]] -> cell 46, seg 0 (0.5) [0.5 on Epop[46]], weight: 4.1363508E-4, delay 1.5
        h("Epop[46] syn_projEE_ampa[3166] = new ampa(0.5)")
        h("Epop[39] netConn_projEE_ampa[3166] = new NetCon(&v(0.5), syn_projEE_ampa[3166], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3167: cell 39, seg 0 (0.5) [0.5 on Epop[39]] -> cell 47, seg 0 (0.5) [0.5 on Epop[47]], weight: 4.1363508E-4, delay 1.5
        h("Epop[47] syn_projEE_ampa[3167] = new ampa(0.5)")
        h("Epop[39] netConn_projEE_ampa[3167] = new NetCon(&v(0.5), syn_projEE_ampa[3167], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3168: cell 39, seg 0 (0.5) [0.5 on Epop[39]] -> cell 48, seg 0 (0.5) [0.5 on Epop[48]], weight: 4.1363508E-4, delay 1.5
        h("Epop[48] syn_projEE_ampa[3168] = new ampa(0.5)")
        h("Epop[39] netConn_projEE_ampa[3168] = new NetCon(&v(0.5), syn_projEE_ampa[3168], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3169: cell 39, seg 0 (0.5) [0.5 on Epop[39]] -> cell 49, seg 0 (0.5) [0.5 on Epop[49]], weight: 4.1363508E-4, delay 1.5
        h("Epop[49] syn_projEE_ampa[3169] = new ampa(0.5)")
        h("Epop[39] netConn_projEE_ampa[3169] = new NetCon(&v(0.5), syn_projEE_ampa[3169], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3170: cell 39, seg 0 (0.5) [0.5 on Epop[39]] -> cell 50, seg 0 (0.5) [0.5 on Epop[50]], weight: 4.1363508E-4, delay 1.5
        h("Epop[50] syn_projEE_ampa[3170] = new ampa(0.5)")
        h("Epop[39] netConn_projEE_ampa[3170] = new NetCon(&v(0.5), syn_projEE_ampa[3170], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3171: cell 39, seg 0 (0.5) [0.5 on Epop[39]] -> cell 51, seg 0 (0.5) [0.5 on Epop[51]], weight: 4.1363508E-4, delay 1.5
        h("Epop[51] syn_projEE_ampa[3171] = new ampa(0.5)")
        h("Epop[39] netConn_projEE_ampa[3171] = new NetCon(&v(0.5), syn_projEE_ampa[3171], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3172: cell 39, seg 0 (0.5) [0.5 on Epop[39]] -> cell 52, seg 0 (0.5) [0.5 on Epop[52]], weight: 4.1363508E-4, delay 1.5
        h("Epop[52] syn_projEE_ampa[3172] = new ampa(0.5)")
        h("Epop[39] netConn_projEE_ampa[3172] = new NetCon(&v(0.5), syn_projEE_ampa[3172], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3173: cell 39, seg 0 (0.5) [0.5 on Epop[39]] -> cell 53, seg 0 (0.5) [0.5 on Epop[53]], weight: 4.1363508E-4, delay 1.5
        h("Epop[53] syn_projEE_ampa[3173] = new ampa(0.5)")
        h("Epop[39] netConn_projEE_ampa[3173] = new NetCon(&v(0.5), syn_projEE_ampa[3173], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3174: cell 39, seg 0 (0.5) [0.5 on Epop[39]] -> cell 54, seg 0 (0.5) [0.5 on Epop[54]], weight: 4.1363508E-4, delay 1.5
        h("Epop[54] syn_projEE_ampa[3174] = new ampa(0.5)")
        h("Epop[39] netConn_projEE_ampa[3174] = new NetCon(&v(0.5), syn_projEE_ampa[3174], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3175: cell 39, seg 0 (0.5) [0.5 on Epop[39]] -> cell 55, seg 0 (0.5) [0.5 on Epop[55]], weight: 4.1363508E-4, delay 1.5
        h("Epop[55] syn_projEE_ampa[3175] = new ampa(0.5)")
        h("Epop[39] netConn_projEE_ampa[3175] = new NetCon(&v(0.5), syn_projEE_ampa[3175], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3176: cell 39, seg 0 (0.5) [0.5 on Epop[39]] -> cell 56, seg 0 (0.5) [0.5 on Epop[56]], weight: 4.1363508E-4, delay 1.5
        h("Epop[56] syn_projEE_ampa[3176] = new ampa(0.5)")
        h("Epop[39] netConn_projEE_ampa[3176] = new NetCon(&v(0.5), syn_projEE_ampa[3176], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3177: cell 39, seg 0 (0.5) [0.5 on Epop[39]] -> cell 57, seg 0 (0.5) [0.5 on Epop[57]], weight: 4.1363508E-4, delay 1.5
        h("Epop[57] syn_projEE_ampa[3177] = new ampa(0.5)")
        h("Epop[39] netConn_projEE_ampa[3177] = new NetCon(&v(0.5), syn_projEE_ampa[3177], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3178: cell 39, seg 0 (0.5) [0.5 on Epop[39]] -> cell 58, seg 0 (0.5) [0.5 on Epop[58]], weight: 4.1363508E-4, delay 1.5
        h("Epop[58] syn_projEE_ampa[3178] = new ampa(0.5)")
        h("Epop[39] netConn_projEE_ampa[3178] = new NetCon(&v(0.5), syn_projEE_ampa[3178], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3179: cell 39, seg 0 (0.5) [0.5 on Epop[39]] -> cell 59, seg 0 (0.5) [0.5 on Epop[59]], weight: 4.1363508E-4, delay 1.5
        h("Epop[59] syn_projEE_ampa[3179] = new ampa(0.5)")
        h("Epop[39] netConn_projEE_ampa[3179] = new NetCon(&v(0.5), syn_projEE_ampa[3179], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3180: cell 39, seg 0 (0.5) [0.5 on Epop[39]] -> cell 60, seg 0 (0.5) [0.5 on Epop[60]], weight: 4.1363508E-4, delay 1.5
        h("Epop[60] syn_projEE_ampa[3180] = new ampa(0.5)")
        h("Epop[39] netConn_projEE_ampa[3180] = new NetCon(&v(0.5), syn_projEE_ampa[3180], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3181: cell 39, seg 0 (0.5) [0.5 on Epop[39]] -> cell 61, seg 0 (0.5) [0.5 on Epop[61]], weight: 4.1363508E-4, delay 1.5
        h("Epop[61] syn_projEE_ampa[3181] = new ampa(0.5)")
        h("Epop[39] netConn_projEE_ampa[3181] = new NetCon(&v(0.5), syn_projEE_ampa[3181], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3182: cell 39, seg 0 (0.5) [0.5 on Epop[39]] -> cell 62, seg 0 (0.5) [0.5 on Epop[62]], weight: 4.1363508E-4, delay 1.5
        h("Epop[62] syn_projEE_ampa[3182] = new ampa(0.5)")
        h("Epop[39] netConn_projEE_ampa[3182] = new NetCon(&v(0.5), syn_projEE_ampa[3182], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3183: cell 39, seg 0 (0.5) [0.5 on Epop[39]] -> cell 63, seg 0 (0.5) [0.5 on Epop[63]], weight: 4.1363508E-4, delay 1.5
        h("Epop[63] syn_projEE_ampa[3183] = new ampa(0.5)")
        h("Epop[39] netConn_projEE_ampa[3183] = new NetCon(&v(0.5), syn_projEE_ampa[3183], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3184: cell 39, seg 0 (0.5) [0.5 on Epop[39]] -> cell 64, seg 0 (0.5) [0.5 on Epop[64]], weight: 4.1363508E-4, delay 1.5
        h("Epop[64] syn_projEE_ampa[3184] = new ampa(0.5)")
        h("Epop[39] netConn_projEE_ampa[3184] = new NetCon(&v(0.5), syn_projEE_ampa[3184], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3185: cell 39, seg 0 (0.5) [0.5 on Epop[39]] -> cell 65, seg 0 (0.5) [0.5 on Epop[65]], weight: 4.1363508E-4, delay 1.5
        h("Epop[65] syn_projEE_ampa[3185] = new ampa(0.5)")
        h("Epop[39] netConn_projEE_ampa[3185] = new NetCon(&v(0.5), syn_projEE_ampa[3185], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3186: cell 39, seg 0 (0.5) [0.5 on Epop[39]] -> cell 66, seg 0 (0.5) [0.5 on Epop[66]], weight: 4.1363508E-4, delay 1.5
        h("Epop[66] syn_projEE_ampa[3186] = new ampa(0.5)")
        h("Epop[39] netConn_projEE_ampa[3186] = new NetCon(&v(0.5), syn_projEE_ampa[3186], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3187: cell 39, seg 0 (0.5) [0.5 on Epop[39]] -> cell 67, seg 0 (0.5) [0.5 on Epop[67]], weight: 4.1363508E-4, delay 1.5
        h("Epop[67] syn_projEE_ampa[3187] = new ampa(0.5)")
        h("Epop[39] netConn_projEE_ampa[3187] = new NetCon(&v(0.5), syn_projEE_ampa[3187], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3188: cell 39, seg 0 (0.5) [0.5 on Epop[39]] -> cell 68, seg 0 (0.5) [0.5 on Epop[68]], weight: 4.1363508E-4, delay 1.5
        h("Epop[68] syn_projEE_ampa[3188] = new ampa(0.5)")
        h("Epop[39] netConn_projEE_ampa[3188] = new NetCon(&v(0.5), syn_projEE_ampa[3188], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3189: cell 39, seg 0 (0.5) [0.5 on Epop[39]] -> cell 69, seg 0 (0.5) [0.5 on Epop[69]], weight: 4.1363508E-4, delay 1.5
        h("Epop[69] syn_projEE_ampa[3189] = new ampa(0.5)")
        h("Epop[39] netConn_projEE_ampa[3189] = new NetCon(&v(0.5), syn_projEE_ampa[3189], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3190: cell 39, seg 0 (0.5) [0.5 on Epop[39]] -> cell 70, seg 0 (0.5) [0.5 on Epop[70]], weight: 4.1363508E-4, delay 1.5
        h("Epop[70] syn_projEE_ampa[3190] = new ampa(0.5)")
        h("Epop[39] netConn_projEE_ampa[3190] = new NetCon(&v(0.5), syn_projEE_ampa[3190], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3191: cell 39, seg 0 (0.5) [0.5 on Epop[39]] -> cell 71, seg 0 (0.5) [0.5 on Epop[71]], weight: 4.1363508E-4, delay 1.5
        h("Epop[71] syn_projEE_ampa[3191] = new ampa(0.5)")
        h("Epop[39] netConn_projEE_ampa[3191] = new NetCon(&v(0.5), syn_projEE_ampa[3191], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3192: cell 39, seg 0 (0.5) [0.5 on Epop[39]] -> cell 72, seg 0 (0.5) [0.5 on Epop[72]], weight: 4.1363508E-4, delay 1.5
        h("Epop[72] syn_projEE_ampa[3192] = new ampa(0.5)")
        h("Epop[39] netConn_projEE_ampa[3192] = new NetCon(&v(0.5), syn_projEE_ampa[3192], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3193: cell 39, seg 0 (0.5) [0.5 on Epop[39]] -> cell 73, seg 0 (0.5) [0.5 on Epop[73]], weight: 4.1363508E-4, delay 1.5
        h("Epop[73] syn_projEE_ampa[3193] = new ampa(0.5)")
        h("Epop[39] netConn_projEE_ampa[3193] = new NetCon(&v(0.5), syn_projEE_ampa[3193], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3194: cell 39, seg 0 (0.5) [0.5 on Epop[39]] -> cell 74, seg 0 (0.5) [0.5 on Epop[74]], weight: 4.1363508E-4, delay 1.5
        h("Epop[74] syn_projEE_ampa[3194] = new ampa(0.5)")
        h("Epop[39] netConn_projEE_ampa[3194] = new NetCon(&v(0.5), syn_projEE_ampa[3194], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3195: cell 39, seg 0 (0.5) [0.5 on Epop[39]] -> cell 75, seg 0 (0.5) [0.5 on Epop[75]], weight: 4.1363508E-4, delay 1.5
        h("Epop[75] syn_projEE_ampa[3195] = new ampa(0.5)")
        h("Epop[39] netConn_projEE_ampa[3195] = new NetCon(&v(0.5), syn_projEE_ampa[3195], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3196: cell 39, seg 0 (0.5) [0.5 on Epop[39]] -> cell 76, seg 0 (0.5) [0.5 on Epop[76]], weight: 4.1363508E-4, delay 1.5
        h("Epop[76] syn_projEE_ampa[3196] = new ampa(0.5)")
        h("Epop[39] netConn_projEE_ampa[3196] = new NetCon(&v(0.5), syn_projEE_ampa[3196], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3197: cell 39, seg 0 (0.5) [0.5 on Epop[39]] -> cell 77, seg 0 (0.5) [0.5 on Epop[77]], weight: 4.1363508E-4, delay 1.5
        h("Epop[77] syn_projEE_ampa[3197] = new ampa(0.5)")
        h("Epop[39] netConn_projEE_ampa[3197] = new NetCon(&v(0.5), syn_projEE_ampa[3197], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3198: cell 39, seg 0 (0.5) [0.5 on Epop[39]] -> cell 78, seg 0 (0.5) [0.5 on Epop[78]], weight: 4.1363508E-4, delay 1.5
        h("Epop[78] syn_projEE_ampa[3198] = new ampa(0.5)")
        h("Epop[39] netConn_projEE_ampa[3198] = new NetCon(&v(0.5), syn_projEE_ampa[3198], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3199: cell 39, seg 0 (0.5) [0.5 on Epop[39]] -> cell 79, seg 0 (0.5) [0.5 on Epop[79]], weight: 4.1363508E-4, delay 1.5
        h("Epop[79] syn_projEE_ampa[3199] = new ampa(0.5)")
        h("Epop[39] netConn_projEE_ampa[3199] = new NetCon(&v(0.5), syn_projEE_ampa[3199], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3200: cell 40, seg 0 (0.5) [0.5 on Epop[40]] -> cell 0, seg 0 (0.5) [0.5 on Epop[0]], weight: 4.1363508E-4, delay 1.5
        h("Epop[0] syn_projEE_ampa[3200] = new ampa(0.5)")
        h("Epop[40] netConn_projEE_ampa[3200] = new NetCon(&v(0.5), syn_projEE_ampa[3200], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3201: cell 40, seg 0 (0.5) [0.5 on Epop[40]] -> cell 1, seg 0 (0.5) [0.5 on Epop[1]], weight: 4.1363508E-4, delay 1.5
        h("Epop[1] syn_projEE_ampa[3201] = new ampa(0.5)")
        h("Epop[40] netConn_projEE_ampa[3201] = new NetCon(&v(0.5), syn_projEE_ampa[3201], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3202: cell 40, seg 0 (0.5) [0.5 on Epop[40]] -> cell 2, seg 0 (0.5) [0.5 on Epop[2]], weight: 4.1363508E-4, delay 1.5
        h("Epop[2] syn_projEE_ampa[3202] = new ampa(0.5)")
        h("Epop[40] netConn_projEE_ampa[3202] = new NetCon(&v(0.5), syn_projEE_ampa[3202], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3203: cell 40, seg 0 (0.5) [0.5 on Epop[40]] -> cell 3, seg 0 (0.5) [0.5 on Epop[3]], weight: 4.1363508E-4, delay 1.5
        h("Epop[3] syn_projEE_ampa[3203] = new ampa(0.5)")
        h("Epop[40] netConn_projEE_ampa[3203] = new NetCon(&v(0.5), syn_projEE_ampa[3203], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3204: cell 40, seg 0 (0.5) [0.5 on Epop[40]] -> cell 4, seg 0 (0.5) [0.5 on Epop[4]], weight: 4.1363508E-4, delay 1.5
        h("Epop[4] syn_projEE_ampa[3204] = new ampa(0.5)")
        h("Epop[40] netConn_projEE_ampa[3204] = new NetCon(&v(0.5), syn_projEE_ampa[3204], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3205: cell 40, seg 0 (0.5) [0.5 on Epop[40]] -> cell 5, seg 0 (0.5) [0.5 on Epop[5]], weight: 4.1363508E-4, delay 1.5
        h("Epop[5] syn_projEE_ampa[3205] = new ampa(0.5)")
        h("Epop[40] netConn_projEE_ampa[3205] = new NetCon(&v(0.5), syn_projEE_ampa[3205], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3206: cell 40, seg 0 (0.5) [0.5 on Epop[40]] -> cell 6, seg 0 (0.5) [0.5 on Epop[6]], weight: 4.1363508E-4, delay 1.5
        h("Epop[6] syn_projEE_ampa[3206] = new ampa(0.5)")
        h("Epop[40] netConn_projEE_ampa[3206] = new NetCon(&v(0.5), syn_projEE_ampa[3206], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3207: cell 40, seg 0 (0.5) [0.5 on Epop[40]] -> cell 7, seg 0 (0.5) [0.5 on Epop[7]], weight: 4.1363508E-4, delay 1.5
        h("Epop[7] syn_projEE_ampa[3207] = new ampa(0.5)")
        h("Epop[40] netConn_projEE_ampa[3207] = new NetCon(&v(0.5), syn_projEE_ampa[3207], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3208: cell 40, seg 0 (0.5) [0.5 on Epop[40]] -> cell 8, seg 0 (0.5) [0.5 on Epop[8]], weight: 4.1363508E-4, delay 1.5
        h("Epop[8] syn_projEE_ampa[3208] = new ampa(0.5)")
        h("Epop[40] netConn_projEE_ampa[3208] = new NetCon(&v(0.5), syn_projEE_ampa[3208], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3209: cell 40, seg 0 (0.5) [0.5 on Epop[40]] -> cell 9, seg 0 (0.5) [0.5 on Epop[9]], weight: 4.1363508E-4, delay 1.5
        h("Epop[9] syn_projEE_ampa[3209] = new ampa(0.5)")
        h("Epop[40] netConn_projEE_ampa[3209] = new NetCon(&v(0.5), syn_projEE_ampa[3209], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3210: cell 40, seg 0 (0.5) [0.5 on Epop[40]] -> cell 10, seg 0 (0.5) [0.5 on Epop[10]], weight: 4.1363508E-4, delay 1.5
        h("Epop[10] syn_projEE_ampa[3210] = new ampa(0.5)")
        h("Epop[40] netConn_projEE_ampa[3210] = new NetCon(&v(0.5), syn_projEE_ampa[3210], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3211: cell 40, seg 0 (0.5) [0.5 on Epop[40]] -> cell 11, seg 0 (0.5) [0.5 on Epop[11]], weight: 4.1363508E-4, delay 1.5
        h("Epop[11] syn_projEE_ampa[3211] = new ampa(0.5)")
        h("Epop[40] netConn_projEE_ampa[3211] = new NetCon(&v(0.5), syn_projEE_ampa[3211], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3212: cell 40, seg 0 (0.5) [0.5 on Epop[40]] -> cell 12, seg 0 (0.5) [0.5 on Epop[12]], weight: 4.1363508E-4, delay 1.5
        h("Epop[12] syn_projEE_ampa[3212] = new ampa(0.5)")
        h("Epop[40] netConn_projEE_ampa[3212] = new NetCon(&v(0.5), syn_projEE_ampa[3212], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3213: cell 40, seg 0 (0.5) [0.5 on Epop[40]] -> cell 13, seg 0 (0.5) [0.5 on Epop[13]], weight: 4.1363508E-4, delay 1.5
        h("Epop[13] syn_projEE_ampa[3213] = new ampa(0.5)")
        h("Epop[40] netConn_projEE_ampa[3213] = new NetCon(&v(0.5), syn_projEE_ampa[3213], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3214: cell 40, seg 0 (0.5) [0.5 on Epop[40]] -> cell 14, seg 0 (0.5) [0.5 on Epop[14]], weight: 4.1363508E-4, delay 1.5
        h("Epop[14] syn_projEE_ampa[3214] = new ampa(0.5)")
        h("Epop[40] netConn_projEE_ampa[3214] = new NetCon(&v(0.5), syn_projEE_ampa[3214], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3215: cell 40, seg 0 (0.5) [0.5 on Epop[40]] -> cell 15, seg 0 (0.5) [0.5 on Epop[15]], weight: 4.1363508E-4, delay 1.5
        h("Epop[15] syn_projEE_ampa[3215] = new ampa(0.5)")
        h("Epop[40] netConn_projEE_ampa[3215] = new NetCon(&v(0.5), syn_projEE_ampa[3215], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3216: cell 40, seg 0 (0.5) [0.5 on Epop[40]] -> cell 16, seg 0 (0.5) [0.5 on Epop[16]], weight: 4.1363508E-4, delay 1.5
        h("Epop[16] syn_projEE_ampa[3216] = new ampa(0.5)")
        h("Epop[40] netConn_projEE_ampa[3216] = new NetCon(&v(0.5), syn_projEE_ampa[3216], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3217: cell 40, seg 0 (0.5) [0.5 on Epop[40]] -> cell 17, seg 0 (0.5) [0.5 on Epop[17]], weight: 4.1363508E-4, delay 1.5
        h("Epop[17] syn_projEE_ampa[3217] = new ampa(0.5)")
        h("Epop[40] netConn_projEE_ampa[3217] = new NetCon(&v(0.5), syn_projEE_ampa[3217], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3218: cell 40, seg 0 (0.5) [0.5 on Epop[40]] -> cell 18, seg 0 (0.5) [0.5 on Epop[18]], weight: 4.1363508E-4, delay 1.5
        h("Epop[18] syn_projEE_ampa[3218] = new ampa(0.5)")
        h("Epop[40] netConn_projEE_ampa[3218] = new NetCon(&v(0.5), syn_projEE_ampa[3218], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3219: cell 40, seg 0 (0.5) [0.5 on Epop[40]] -> cell 19, seg 0 (0.5) [0.5 on Epop[19]], weight: 4.1363508E-4, delay 1.5
        h("Epop[19] syn_projEE_ampa[3219] = new ampa(0.5)")
        h("Epop[40] netConn_projEE_ampa[3219] = new NetCon(&v(0.5), syn_projEE_ampa[3219], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3220: cell 40, seg 0 (0.5) [0.5 on Epop[40]] -> cell 20, seg 0 (0.5) [0.5 on Epop[20]], weight: 4.1363508E-4, delay 1.5
        h("Epop[20] syn_projEE_ampa[3220] = new ampa(0.5)")
        h("Epop[40] netConn_projEE_ampa[3220] = new NetCon(&v(0.5), syn_projEE_ampa[3220], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3221: cell 40, seg 0 (0.5) [0.5 on Epop[40]] -> cell 21, seg 0 (0.5) [0.5 on Epop[21]], weight: 4.1363508E-4, delay 1.5
        h("Epop[21] syn_projEE_ampa[3221] = new ampa(0.5)")
        h("Epop[40] netConn_projEE_ampa[3221] = new NetCon(&v(0.5), syn_projEE_ampa[3221], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3222: cell 40, seg 0 (0.5) [0.5 on Epop[40]] -> cell 22, seg 0 (0.5) [0.5 on Epop[22]], weight: 4.1363508E-4, delay 1.5
        h("Epop[22] syn_projEE_ampa[3222] = new ampa(0.5)")
        h("Epop[40] netConn_projEE_ampa[3222] = new NetCon(&v(0.5), syn_projEE_ampa[3222], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3223: cell 40, seg 0 (0.5) [0.5 on Epop[40]] -> cell 23, seg 0 (0.5) [0.5 on Epop[23]], weight: 4.1363508E-4, delay 1.5
        h("Epop[23] syn_projEE_ampa[3223] = new ampa(0.5)")
        h("Epop[40] netConn_projEE_ampa[3223] = new NetCon(&v(0.5), syn_projEE_ampa[3223], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3224: cell 40, seg 0 (0.5) [0.5 on Epop[40]] -> cell 24, seg 0 (0.5) [0.5 on Epop[24]], weight: 4.1363508E-4, delay 1.5
        h("Epop[24] syn_projEE_ampa[3224] = new ampa(0.5)")
        h("Epop[40] netConn_projEE_ampa[3224] = new NetCon(&v(0.5), syn_projEE_ampa[3224], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3225: cell 40, seg 0 (0.5) [0.5 on Epop[40]] -> cell 25, seg 0 (0.5) [0.5 on Epop[25]], weight: 4.1363508E-4, delay 1.5
        h("Epop[25] syn_projEE_ampa[3225] = new ampa(0.5)")
        h("Epop[40] netConn_projEE_ampa[3225] = new NetCon(&v(0.5), syn_projEE_ampa[3225], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3226: cell 40, seg 0 (0.5) [0.5 on Epop[40]] -> cell 26, seg 0 (0.5) [0.5 on Epop[26]], weight: 4.1363508E-4, delay 1.5
        h("Epop[26] syn_projEE_ampa[3226] = new ampa(0.5)")
        h("Epop[40] netConn_projEE_ampa[3226] = new NetCon(&v(0.5), syn_projEE_ampa[3226], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3227: cell 40, seg 0 (0.5) [0.5 on Epop[40]] -> cell 27, seg 0 (0.5) [0.5 on Epop[27]], weight: 4.1363508E-4, delay 1.5
        h("Epop[27] syn_projEE_ampa[3227] = new ampa(0.5)")
        h("Epop[40] netConn_projEE_ampa[3227] = new NetCon(&v(0.5), syn_projEE_ampa[3227], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3228: cell 40, seg 0 (0.5) [0.5 on Epop[40]] -> cell 28, seg 0 (0.5) [0.5 on Epop[28]], weight: 4.1363508E-4, delay 1.5
        h("Epop[28] syn_projEE_ampa[3228] = new ampa(0.5)")
        h("Epop[40] netConn_projEE_ampa[3228] = new NetCon(&v(0.5), syn_projEE_ampa[3228], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3229: cell 40, seg 0 (0.5) [0.5 on Epop[40]] -> cell 29, seg 0 (0.5) [0.5 on Epop[29]], weight: 4.1363508E-4, delay 1.5
        h("Epop[29] syn_projEE_ampa[3229] = new ampa(0.5)")
        h("Epop[40] netConn_projEE_ampa[3229] = new NetCon(&v(0.5), syn_projEE_ampa[3229], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3230: cell 40, seg 0 (0.5) [0.5 on Epop[40]] -> cell 30, seg 0 (0.5) [0.5 on Epop[30]], weight: 4.1363508E-4, delay 1.5
        h("Epop[30] syn_projEE_ampa[3230] = new ampa(0.5)")
        h("Epop[40] netConn_projEE_ampa[3230] = new NetCon(&v(0.5), syn_projEE_ampa[3230], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3231: cell 40, seg 0 (0.5) [0.5 on Epop[40]] -> cell 31, seg 0 (0.5) [0.5 on Epop[31]], weight: 4.1363508E-4, delay 1.5
        h("Epop[31] syn_projEE_ampa[3231] = new ampa(0.5)")
        h("Epop[40] netConn_projEE_ampa[3231] = new NetCon(&v(0.5), syn_projEE_ampa[3231], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3232: cell 40, seg 0 (0.5) [0.5 on Epop[40]] -> cell 32, seg 0 (0.5) [0.5 on Epop[32]], weight: 4.1363508E-4, delay 1.5
        h("Epop[32] syn_projEE_ampa[3232] = new ampa(0.5)")
        h("Epop[40] netConn_projEE_ampa[3232] = new NetCon(&v(0.5), syn_projEE_ampa[3232], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3233: cell 40, seg 0 (0.5) [0.5 on Epop[40]] -> cell 33, seg 0 (0.5) [0.5 on Epop[33]], weight: 4.1363508E-4, delay 1.5
        h("Epop[33] syn_projEE_ampa[3233] = new ampa(0.5)")
        h("Epop[40] netConn_projEE_ampa[3233] = new NetCon(&v(0.5), syn_projEE_ampa[3233], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3234: cell 40, seg 0 (0.5) [0.5 on Epop[40]] -> cell 34, seg 0 (0.5) [0.5 on Epop[34]], weight: 4.1363508E-4, delay 1.5
        h("Epop[34] syn_projEE_ampa[3234] = new ampa(0.5)")
        h("Epop[40] netConn_projEE_ampa[3234] = new NetCon(&v(0.5), syn_projEE_ampa[3234], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3235: cell 40, seg 0 (0.5) [0.5 on Epop[40]] -> cell 35, seg 0 (0.5) [0.5 on Epop[35]], weight: 4.1363508E-4, delay 1.5
        h("Epop[35] syn_projEE_ampa[3235] = new ampa(0.5)")
        h("Epop[40] netConn_projEE_ampa[3235] = new NetCon(&v(0.5), syn_projEE_ampa[3235], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3236: cell 40, seg 0 (0.5) [0.5 on Epop[40]] -> cell 36, seg 0 (0.5) [0.5 on Epop[36]], weight: 4.1363508E-4, delay 1.5
        h("Epop[36] syn_projEE_ampa[3236] = new ampa(0.5)")
        h("Epop[40] netConn_projEE_ampa[3236] = new NetCon(&v(0.5), syn_projEE_ampa[3236], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3237: cell 40, seg 0 (0.5) [0.5 on Epop[40]] -> cell 37, seg 0 (0.5) [0.5 on Epop[37]], weight: 4.1363508E-4, delay 1.5
        h("Epop[37] syn_projEE_ampa[3237] = new ampa(0.5)")
        h("Epop[40] netConn_projEE_ampa[3237] = new NetCon(&v(0.5), syn_projEE_ampa[3237], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3238: cell 40, seg 0 (0.5) [0.5 on Epop[40]] -> cell 38, seg 0 (0.5) [0.5 on Epop[38]], weight: 4.1363508E-4, delay 1.5
        h("Epop[38] syn_projEE_ampa[3238] = new ampa(0.5)")
        h("Epop[40] netConn_projEE_ampa[3238] = new NetCon(&v(0.5), syn_projEE_ampa[3238], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3239: cell 40, seg 0 (0.5) [0.5 on Epop[40]] -> cell 39, seg 0 (0.5) [0.5 on Epop[39]], weight: 4.1363508E-4, delay 1.5
        h("Epop[39] syn_projEE_ampa[3239] = new ampa(0.5)")
        h("Epop[40] netConn_projEE_ampa[3239] = new NetCon(&v(0.5), syn_projEE_ampa[3239], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3240: cell 40, seg 0 (0.5) [0.5 on Epop[40]] -> cell 40, seg 0 (0.5) [0.5 on Epop[40]], weight: 4.1363508E-4, delay 1.5
        h("Epop[40] syn_projEE_ampa[3240] = new ampa(0.5)")
        h("Epop[40] netConn_projEE_ampa[3240] = new NetCon(&v(0.5), syn_projEE_ampa[3240], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3241: cell 40, seg 0 (0.5) [0.5 on Epop[40]] -> cell 41, seg 0 (0.5) [0.5 on Epop[41]], weight: 4.1363508E-4, delay 1.5
        h("Epop[41] syn_projEE_ampa[3241] = new ampa(0.5)")
        h("Epop[40] netConn_projEE_ampa[3241] = new NetCon(&v(0.5), syn_projEE_ampa[3241], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3242: cell 40, seg 0 (0.5) [0.5 on Epop[40]] -> cell 42, seg 0 (0.5) [0.5 on Epop[42]], weight: 4.1363508E-4, delay 1.5
        h("Epop[42] syn_projEE_ampa[3242] = new ampa(0.5)")
        h("Epop[40] netConn_projEE_ampa[3242] = new NetCon(&v(0.5), syn_projEE_ampa[3242], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3243: cell 40, seg 0 (0.5) [0.5 on Epop[40]] -> cell 43, seg 0 (0.5) [0.5 on Epop[43]], weight: 4.1363508E-4, delay 1.5
        h("Epop[43] syn_projEE_ampa[3243] = new ampa(0.5)")
        h("Epop[40] netConn_projEE_ampa[3243] = new NetCon(&v(0.5), syn_projEE_ampa[3243], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3244: cell 40, seg 0 (0.5) [0.5 on Epop[40]] -> cell 44, seg 0 (0.5) [0.5 on Epop[44]], weight: 4.1363508E-4, delay 1.5
        h("Epop[44] syn_projEE_ampa[3244] = new ampa(0.5)")
        h("Epop[40] netConn_projEE_ampa[3244] = new NetCon(&v(0.5), syn_projEE_ampa[3244], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3245: cell 40, seg 0 (0.5) [0.5 on Epop[40]] -> cell 45, seg 0 (0.5) [0.5 on Epop[45]], weight: 4.1363508E-4, delay 1.5
        h("Epop[45] syn_projEE_ampa[3245] = new ampa(0.5)")
        h("Epop[40] netConn_projEE_ampa[3245] = new NetCon(&v(0.5), syn_projEE_ampa[3245], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3246: cell 40, seg 0 (0.5) [0.5 on Epop[40]] -> cell 46, seg 0 (0.5) [0.5 on Epop[46]], weight: 4.1363508E-4, delay 1.5
        h("Epop[46] syn_projEE_ampa[3246] = new ampa(0.5)")
        h("Epop[40] netConn_projEE_ampa[3246] = new NetCon(&v(0.5), syn_projEE_ampa[3246], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3247: cell 40, seg 0 (0.5) [0.5 on Epop[40]] -> cell 47, seg 0 (0.5) [0.5 on Epop[47]], weight: 4.1363508E-4, delay 1.5
        h("Epop[47] syn_projEE_ampa[3247] = new ampa(0.5)")
        h("Epop[40] netConn_projEE_ampa[3247] = new NetCon(&v(0.5), syn_projEE_ampa[3247], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3248: cell 40, seg 0 (0.5) [0.5 on Epop[40]] -> cell 48, seg 0 (0.5) [0.5 on Epop[48]], weight: 4.1363508E-4, delay 1.5
        h("Epop[48] syn_projEE_ampa[3248] = new ampa(0.5)")
        h("Epop[40] netConn_projEE_ampa[3248] = new NetCon(&v(0.5), syn_projEE_ampa[3248], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3249: cell 40, seg 0 (0.5) [0.5 on Epop[40]] -> cell 49, seg 0 (0.5) [0.5 on Epop[49]], weight: 4.1363508E-4, delay 1.5
        h("Epop[49] syn_projEE_ampa[3249] = new ampa(0.5)")
        h("Epop[40] netConn_projEE_ampa[3249] = new NetCon(&v(0.5), syn_projEE_ampa[3249], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3250: cell 40, seg 0 (0.5) [0.5 on Epop[40]] -> cell 50, seg 0 (0.5) [0.5 on Epop[50]], weight: 4.1363508E-4, delay 1.5
        h("Epop[50] syn_projEE_ampa[3250] = new ampa(0.5)")
        h("Epop[40] netConn_projEE_ampa[3250] = new NetCon(&v(0.5), syn_projEE_ampa[3250], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3251: cell 40, seg 0 (0.5) [0.5 on Epop[40]] -> cell 51, seg 0 (0.5) [0.5 on Epop[51]], weight: 4.1363508E-4, delay 1.5
        h("Epop[51] syn_projEE_ampa[3251] = new ampa(0.5)")
        h("Epop[40] netConn_projEE_ampa[3251] = new NetCon(&v(0.5), syn_projEE_ampa[3251], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3252: cell 40, seg 0 (0.5) [0.5 on Epop[40]] -> cell 52, seg 0 (0.5) [0.5 on Epop[52]], weight: 4.1363508E-4, delay 1.5
        h("Epop[52] syn_projEE_ampa[3252] = new ampa(0.5)")
        h("Epop[40] netConn_projEE_ampa[3252] = new NetCon(&v(0.5), syn_projEE_ampa[3252], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3253: cell 40, seg 0 (0.5) [0.5 on Epop[40]] -> cell 53, seg 0 (0.5) [0.5 on Epop[53]], weight: 4.1363508E-4, delay 1.5
        h("Epop[53] syn_projEE_ampa[3253] = new ampa(0.5)")
        h("Epop[40] netConn_projEE_ampa[3253] = new NetCon(&v(0.5), syn_projEE_ampa[3253], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3254: cell 40, seg 0 (0.5) [0.5 on Epop[40]] -> cell 54, seg 0 (0.5) [0.5 on Epop[54]], weight: 4.1363508E-4, delay 1.5
        h("Epop[54] syn_projEE_ampa[3254] = new ampa(0.5)")
        h("Epop[40] netConn_projEE_ampa[3254] = new NetCon(&v(0.5), syn_projEE_ampa[3254], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3255: cell 40, seg 0 (0.5) [0.5 on Epop[40]] -> cell 55, seg 0 (0.5) [0.5 on Epop[55]], weight: 4.1363508E-4, delay 1.5
        h("Epop[55] syn_projEE_ampa[3255] = new ampa(0.5)")
        h("Epop[40] netConn_projEE_ampa[3255] = new NetCon(&v(0.5), syn_projEE_ampa[3255], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3256: cell 40, seg 0 (0.5) [0.5 on Epop[40]] -> cell 56, seg 0 (0.5) [0.5 on Epop[56]], weight: 4.1363508E-4, delay 1.5
        h("Epop[56] syn_projEE_ampa[3256] = new ampa(0.5)")
        h("Epop[40] netConn_projEE_ampa[3256] = new NetCon(&v(0.5), syn_projEE_ampa[3256], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3257: cell 40, seg 0 (0.5) [0.5 on Epop[40]] -> cell 57, seg 0 (0.5) [0.5 on Epop[57]], weight: 4.1363508E-4, delay 1.5
        h("Epop[57] syn_projEE_ampa[3257] = new ampa(0.5)")
        h("Epop[40] netConn_projEE_ampa[3257] = new NetCon(&v(0.5), syn_projEE_ampa[3257], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3258: cell 40, seg 0 (0.5) [0.5 on Epop[40]] -> cell 58, seg 0 (0.5) [0.5 on Epop[58]], weight: 4.1363508E-4, delay 1.5
        h("Epop[58] syn_projEE_ampa[3258] = new ampa(0.5)")
        h("Epop[40] netConn_projEE_ampa[3258] = new NetCon(&v(0.5), syn_projEE_ampa[3258], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3259: cell 40, seg 0 (0.5) [0.5 on Epop[40]] -> cell 59, seg 0 (0.5) [0.5 on Epop[59]], weight: 4.1363508E-4, delay 1.5
        h("Epop[59] syn_projEE_ampa[3259] = new ampa(0.5)")
        h("Epop[40] netConn_projEE_ampa[3259] = new NetCon(&v(0.5), syn_projEE_ampa[3259], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3260: cell 40, seg 0 (0.5) [0.5 on Epop[40]] -> cell 60, seg 0 (0.5) [0.5 on Epop[60]], weight: 4.1363508E-4, delay 1.5
        h("Epop[60] syn_projEE_ampa[3260] = new ampa(0.5)")
        h("Epop[40] netConn_projEE_ampa[3260] = new NetCon(&v(0.5), syn_projEE_ampa[3260], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3261: cell 40, seg 0 (0.5) [0.5 on Epop[40]] -> cell 61, seg 0 (0.5) [0.5 on Epop[61]], weight: 4.1363508E-4, delay 1.5
        h("Epop[61] syn_projEE_ampa[3261] = new ampa(0.5)")
        h("Epop[40] netConn_projEE_ampa[3261] = new NetCon(&v(0.5), syn_projEE_ampa[3261], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3262: cell 40, seg 0 (0.5) [0.5 on Epop[40]] -> cell 62, seg 0 (0.5) [0.5 on Epop[62]], weight: 4.1363508E-4, delay 1.5
        h("Epop[62] syn_projEE_ampa[3262] = new ampa(0.5)")
        h("Epop[40] netConn_projEE_ampa[3262] = new NetCon(&v(0.5), syn_projEE_ampa[3262], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3263: cell 40, seg 0 (0.5) [0.5 on Epop[40]] -> cell 63, seg 0 (0.5) [0.5 on Epop[63]], weight: 4.1363508E-4, delay 1.5
        h("Epop[63] syn_projEE_ampa[3263] = new ampa(0.5)")
        h("Epop[40] netConn_projEE_ampa[3263] = new NetCon(&v(0.5), syn_projEE_ampa[3263], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3264: cell 40, seg 0 (0.5) [0.5 on Epop[40]] -> cell 64, seg 0 (0.5) [0.5 on Epop[64]], weight: 4.1363508E-4, delay 1.5
        h("Epop[64] syn_projEE_ampa[3264] = new ampa(0.5)")
        h("Epop[40] netConn_projEE_ampa[3264] = new NetCon(&v(0.5), syn_projEE_ampa[3264], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3265: cell 40, seg 0 (0.5) [0.5 on Epop[40]] -> cell 65, seg 0 (0.5) [0.5 on Epop[65]], weight: 4.1363508E-4, delay 1.5
        h("Epop[65] syn_projEE_ampa[3265] = new ampa(0.5)")
        h("Epop[40] netConn_projEE_ampa[3265] = new NetCon(&v(0.5), syn_projEE_ampa[3265], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3266: cell 40, seg 0 (0.5) [0.5 on Epop[40]] -> cell 66, seg 0 (0.5) [0.5 on Epop[66]], weight: 4.1363508E-4, delay 1.5
        h("Epop[66] syn_projEE_ampa[3266] = new ampa(0.5)")
        h("Epop[40] netConn_projEE_ampa[3266] = new NetCon(&v(0.5), syn_projEE_ampa[3266], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3267: cell 40, seg 0 (0.5) [0.5 on Epop[40]] -> cell 67, seg 0 (0.5) [0.5 on Epop[67]], weight: 4.1363508E-4, delay 1.5
        h("Epop[67] syn_projEE_ampa[3267] = new ampa(0.5)")
        h("Epop[40] netConn_projEE_ampa[3267] = new NetCon(&v(0.5), syn_projEE_ampa[3267], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3268: cell 40, seg 0 (0.5) [0.5 on Epop[40]] -> cell 68, seg 0 (0.5) [0.5 on Epop[68]], weight: 4.1363508E-4, delay 1.5
        h("Epop[68] syn_projEE_ampa[3268] = new ampa(0.5)")
        h("Epop[40] netConn_projEE_ampa[3268] = new NetCon(&v(0.5), syn_projEE_ampa[3268], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3269: cell 40, seg 0 (0.5) [0.5 on Epop[40]] -> cell 69, seg 0 (0.5) [0.5 on Epop[69]], weight: 4.1363508E-4, delay 1.5
        h("Epop[69] syn_projEE_ampa[3269] = new ampa(0.5)")
        h("Epop[40] netConn_projEE_ampa[3269] = new NetCon(&v(0.5), syn_projEE_ampa[3269], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3270: cell 40, seg 0 (0.5) [0.5 on Epop[40]] -> cell 70, seg 0 (0.5) [0.5 on Epop[70]], weight: 4.1363508E-4, delay 1.5
        h("Epop[70] syn_projEE_ampa[3270] = new ampa(0.5)")
        h("Epop[40] netConn_projEE_ampa[3270] = new NetCon(&v(0.5), syn_projEE_ampa[3270], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3271: cell 40, seg 0 (0.5) [0.5 on Epop[40]] -> cell 71, seg 0 (0.5) [0.5 on Epop[71]], weight: 4.1363508E-4, delay 1.5
        h("Epop[71] syn_projEE_ampa[3271] = new ampa(0.5)")
        h("Epop[40] netConn_projEE_ampa[3271] = new NetCon(&v(0.5), syn_projEE_ampa[3271], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3272: cell 40, seg 0 (0.5) [0.5 on Epop[40]] -> cell 72, seg 0 (0.5) [0.5 on Epop[72]], weight: 4.1363508E-4, delay 1.5
        h("Epop[72] syn_projEE_ampa[3272] = new ampa(0.5)")
        h("Epop[40] netConn_projEE_ampa[3272] = new NetCon(&v(0.5), syn_projEE_ampa[3272], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3273: cell 40, seg 0 (0.5) [0.5 on Epop[40]] -> cell 73, seg 0 (0.5) [0.5 on Epop[73]], weight: 4.1363508E-4, delay 1.5
        h("Epop[73] syn_projEE_ampa[3273] = new ampa(0.5)")
        h("Epop[40] netConn_projEE_ampa[3273] = new NetCon(&v(0.5), syn_projEE_ampa[3273], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3274: cell 40, seg 0 (0.5) [0.5 on Epop[40]] -> cell 74, seg 0 (0.5) [0.5 on Epop[74]], weight: 4.1363508E-4, delay 1.5
        h("Epop[74] syn_projEE_ampa[3274] = new ampa(0.5)")
        h("Epop[40] netConn_projEE_ampa[3274] = new NetCon(&v(0.5), syn_projEE_ampa[3274], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3275: cell 40, seg 0 (0.5) [0.5 on Epop[40]] -> cell 75, seg 0 (0.5) [0.5 on Epop[75]], weight: 4.1363508E-4, delay 1.5
        h("Epop[75] syn_projEE_ampa[3275] = new ampa(0.5)")
        h("Epop[40] netConn_projEE_ampa[3275] = new NetCon(&v(0.5), syn_projEE_ampa[3275], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3276: cell 40, seg 0 (0.5) [0.5 on Epop[40]] -> cell 76, seg 0 (0.5) [0.5 on Epop[76]], weight: 4.1363508E-4, delay 1.5
        h("Epop[76] syn_projEE_ampa[3276] = new ampa(0.5)")
        h("Epop[40] netConn_projEE_ampa[3276] = new NetCon(&v(0.5), syn_projEE_ampa[3276], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3277: cell 40, seg 0 (0.5) [0.5 on Epop[40]] -> cell 77, seg 0 (0.5) [0.5 on Epop[77]], weight: 4.1363508E-4, delay 1.5
        h("Epop[77] syn_projEE_ampa[3277] = new ampa(0.5)")
        h("Epop[40] netConn_projEE_ampa[3277] = new NetCon(&v(0.5), syn_projEE_ampa[3277], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3278: cell 40, seg 0 (0.5) [0.5 on Epop[40]] -> cell 78, seg 0 (0.5) [0.5 on Epop[78]], weight: 4.1363508E-4, delay 1.5
        h("Epop[78] syn_projEE_ampa[3278] = new ampa(0.5)")
        h("Epop[40] netConn_projEE_ampa[3278] = new NetCon(&v(0.5), syn_projEE_ampa[3278], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3279: cell 40, seg 0 (0.5) [0.5 on Epop[40]] -> cell 79, seg 0 (0.5) [0.5 on Epop[79]], weight: 4.1363508E-4, delay 1.5
        h("Epop[79] syn_projEE_ampa[3279] = new ampa(0.5)")
        h("Epop[40] netConn_projEE_ampa[3279] = new NetCon(&v(0.5), syn_projEE_ampa[3279], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3280: cell 41, seg 0 (0.5) [0.5 on Epop[41]] -> cell 0, seg 0 (0.5) [0.5 on Epop[0]], weight: 4.1363508E-4, delay 1.5
        h("Epop[0] syn_projEE_ampa[3280] = new ampa(0.5)")
        h("Epop[41] netConn_projEE_ampa[3280] = new NetCon(&v(0.5), syn_projEE_ampa[3280], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3281: cell 41, seg 0 (0.5) [0.5 on Epop[41]] -> cell 1, seg 0 (0.5) [0.5 on Epop[1]], weight: 4.1363508E-4, delay 1.5
        h("Epop[1] syn_projEE_ampa[3281] = new ampa(0.5)")
        h("Epop[41] netConn_projEE_ampa[3281] = new NetCon(&v(0.5), syn_projEE_ampa[3281], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3282: cell 41, seg 0 (0.5) [0.5 on Epop[41]] -> cell 2, seg 0 (0.5) [0.5 on Epop[2]], weight: 4.1363508E-4, delay 1.5
        h("Epop[2] syn_projEE_ampa[3282] = new ampa(0.5)")
        h("Epop[41] netConn_projEE_ampa[3282] = new NetCon(&v(0.5), syn_projEE_ampa[3282], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3283: cell 41, seg 0 (0.5) [0.5 on Epop[41]] -> cell 3, seg 0 (0.5) [0.5 on Epop[3]], weight: 4.1363508E-4, delay 1.5
        h("Epop[3] syn_projEE_ampa[3283] = new ampa(0.5)")
        h("Epop[41] netConn_projEE_ampa[3283] = new NetCon(&v(0.5), syn_projEE_ampa[3283], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3284: cell 41, seg 0 (0.5) [0.5 on Epop[41]] -> cell 4, seg 0 (0.5) [0.5 on Epop[4]], weight: 4.1363508E-4, delay 1.5
        h("Epop[4] syn_projEE_ampa[3284] = new ampa(0.5)")
        h("Epop[41] netConn_projEE_ampa[3284] = new NetCon(&v(0.5), syn_projEE_ampa[3284], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3285: cell 41, seg 0 (0.5) [0.5 on Epop[41]] -> cell 5, seg 0 (0.5) [0.5 on Epop[5]], weight: 4.1363508E-4, delay 1.5
        h("Epop[5] syn_projEE_ampa[3285] = new ampa(0.5)")
        h("Epop[41] netConn_projEE_ampa[3285] = new NetCon(&v(0.5), syn_projEE_ampa[3285], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3286: cell 41, seg 0 (0.5) [0.5 on Epop[41]] -> cell 6, seg 0 (0.5) [0.5 on Epop[6]], weight: 4.1363508E-4, delay 1.5
        h("Epop[6] syn_projEE_ampa[3286] = new ampa(0.5)")
        h("Epop[41] netConn_projEE_ampa[3286] = new NetCon(&v(0.5), syn_projEE_ampa[3286], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3287: cell 41, seg 0 (0.5) [0.5 on Epop[41]] -> cell 7, seg 0 (0.5) [0.5 on Epop[7]], weight: 4.1363508E-4, delay 1.5
        h("Epop[7] syn_projEE_ampa[3287] = new ampa(0.5)")
        h("Epop[41] netConn_projEE_ampa[3287] = new NetCon(&v(0.5), syn_projEE_ampa[3287], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3288: cell 41, seg 0 (0.5) [0.5 on Epop[41]] -> cell 8, seg 0 (0.5) [0.5 on Epop[8]], weight: 4.1363508E-4, delay 1.5
        h("Epop[8] syn_projEE_ampa[3288] = new ampa(0.5)")
        h("Epop[41] netConn_projEE_ampa[3288] = new NetCon(&v(0.5), syn_projEE_ampa[3288], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3289: cell 41, seg 0 (0.5) [0.5 on Epop[41]] -> cell 9, seg 0 (0.5) [0.5 on Epop[9]], weight: 4.1363508E-4, delay 1.5
        h("Epop[9] syn_projEE_ampa[3289] = new ampa(0.5)")
        h("Epop[41] netConn_projEE_ampa[3289] = new NetCon(&v(0.5), syn_projEE_ampa[3289], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3290: cell 41, seg 0 (0.5) [0.5 on Epop[41]] -> cell 10, seg 0 (0.5) [0.5 on Epop[10]], weight: 4.1363508E-4, delay 1.5
        h("Epop[10] syn_projEE_ampa[3290] = new ampa(0.5)")
        h("Epop[41] netConn_projEE_ampa[3290] = new NetCon(&v(0.5), syn_projEE_ampa[3290], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3291: cell 41, seg 0 (0.5) [0.5 on Epop[41]] -> cell 11, seg 0 (0.5) [0.5 on Epop[11]], weight: 4.1363508E-4, delay 1.5
        h("Epop[11] syn_projEE_ampa[3291] = new ampa(0.5)")
        h("Epop[41] netConn_projEE_ampa[3291] = new NetCon(&v(0.5), syn_projEE_ampa[3291], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3292: cell 41, seg 0 (0.5) [0.5 on Epop[41]] -> cell 12, seg 0 (0.5) [0.5 on Epop[12]], weight: 4.1363508E-4, delay 1.5
        h("Epop[12] syn_projEE_ampa[3292] = new ampa(0.5)")
        h("Epop[41] netConn_projEE_ampa[3292] = new NetCon(&v(0.5), syn_projEE_ampa[3292], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3293: cell 41, seg 0 (0.5) [0.5 on Epop[41]] -> cell 13, seg 0 (0.5) [0.5 on Epop[13]], weight: 4.1363508E-4, delay 1.5
        h("Epop[13] syn_projEE_ampa[3293] = new ampa(0.5)")
        h("Epop[41] netConn_projEE_ampa[3293] = new NetCon(&v(0.5), syn_projEE_ampa[3293], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3294: cell 41, seg 0 (0.5) [0.5 on Epop[41]] -> cell 14, seg 0 (0.5) [0.5 on Epop[14]], weight: 4.1363508E-4, delay 1.5
        h("Epop[14] syn_projEE_ampa[3294] = new ampa(0.5)")
        h("Epop[41] netConn_projEE_ampa[3294] = new NetCon(&v(0.5), syn_projEE_ampa[3294], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3295: cell 41, seg 0 (0.5) [0.5 on Epop[41]] -> cell 15, seg 0 (0.5) [0.5 on Epop[15]], weight: 4.1363508E-4, delay 1.5
        h("Epop[15] syn_projEE_ampa[3295] = new ampa(0.5)")
        h("Epop[41] netConn_projEE_ampa[3295] = new NetCon(&v(0.5), syn_projEE_ampa[3295], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3296: cell 41, seg 0 (0.5) [0.5 on Epop[41]] -> cell 16, seg 0 (0.5) [0.5 on Epop[16]], weight: 4.1363508E-4, delay 1.5
        h("Epop[16] syn_projEE_ampa[3296] = new ampa(0.5)")
        h("Epop[41] netConn_projEE_ampa[3296] = new NetCon(&v(0.5), syn_projEE_ampa[3296], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3297: cell 41, seg 0 (0.5) [0.5 on Epop[41]] -> cell 17, seg 0 (0.5) [0.5 on Epop[17]], weight: 4.1363508E-4, delay 1.5
        h("Epop[17] syn_projEE_ampa[3297] = new ampa(0.5)")
        h("Epop[41] netConn_projEE_ampa[3297] = new NetCon(&v(0.5), syn_projEE_ampa[3297], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3298: cell 41, seg 0 (0.5) [0.5 on Epop[41]] -> cell 18, seg 0 (0.5) [0.5 on Epop[18]], weight: 4.1363508E-4, delay 1.5
        h("Epop[18] syn_projEE_ampa[3298] = new ampa(0.5)")
        h("Epop[41] netConn_projEE_ampa[3298] = new NetCon(&v(0.5), syn_projEE_ampa[3298], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3299: cell 41, seg 0 (0.5) [0.5 on Epop[41]] -> cell 19, seg 0 (0.5) [0.5 on Epop[19]], weight: 4.1363508E-4, delay 1.5
        h("Epop[19] syn_projEE_ampa[3299] = new ampa(0.5)")
        h("Epop[41] netConn_projEE_ampa[3299] = new NetCon(&v(0.5), syn_projEE_ampa[3299], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3300: cell 41, seg 0 (0.5) [0.5 on Epop[41]] -> cell 20, seg 0 (0.5) [0.5 on Epop[20]], weight: 4.1363508E-4, delay 1.5
        h("Epop[20] syn_projEE_ampa[3300] = new ampa(0.5)")
        h("Epop[41] netConn_projEE_ampa[3300] = new NetCon(&v(0.5), syn_projEE_ampa[3300], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3301: cell 41, seg 0 (0.5) [0.5 on Epop[41]] -> cell 21, seg 0 (0.5) [0.5 on Epop[21]], weight: 4.1363508E-4, delay 1.5
        h("Epop[21] syn_projEE_ampa[3301] = new ampa(0.5)")
        h("Epop[41] netConn_projEE_ampa[3301] = new NetCon(&v(0.5), syn_projEE_ampa[3301], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3302: cell 41, seg 0 (0.5) [0.5 on Epop[41]] -> cell 22, seg 0 (0.5) [0.5 on Epop[22]], weight: 4.1363508E-4, delay 1.5
        h("Epop[22] syn_projEE_ampa[3302] = new ampa(0.5)")
        h("Epop[41] netConn_projEE_ampa[3302] = new NetCon(&v(0.5), syn_projEE_ampa[3302], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3303: cell 41, seg 0 (0.5) [0.5 on Epop[41]] -> cell 23, seg 0 (0.5) [0.5 on Epop[23]], weight: 4.1363508E-4, delay 1.5
        h("Epop[23] syn_projEE_ampa[3303] = new ampa(0.5)")
        h("Epop[41] netConn_projEE_ampa[3303] = new NetCon(&v(0.5), syn_projEE_ampa[3303], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3304: cell 41, seg 0 (0.5) [0.5 on Epop[41]] -> cell 24, seg 0 (0.5) [0.5 on Epop[24]], weight: 4.1363508E-4, delay 1.5
        h("Epop[24] syn_projEE_ampa[3304] = new ampa(0.5)")
        h("Epop[41] netConn_projEE_ampa[3304] = new NetCon(&v(0.5), syn_projEE_ampa[3304], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3305: cell 41, seg 0 (0.5) [0.5 on Epop[41]] -> cell 25, seg 0 (0.5) [0.5 on Epop[25]], weight: 4.1363508E-4, delay 1.5
        h("Epop[25] syn_projEE_ampa[3305] = new ampa(0.5)")
        h("Epop[41] netConn_projEE_ampa[3305] = new NetCon(&v(0.5), syn_projEE_ampa[3305], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3306: cell 41, seg 0 (0.5) [0.5 on Epop[41]] -> cell 26, seg 0 (0.5) [0.5 on Epop[26]], weight: 4.1363508E-4, delay 1.5
        h("Epop[26] syn_projEE_ampa[3306] = new ampa(0.5)")
        h("Epop[41] netConn_projEE_ampa[3306] = new NetCon(&v(0.5), syn_projEE_ampa[3306], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3307: cell 41, seg 0 (0.5) [0.5 on Epop[41]] -> cell 27, seg 0 (0.5) [0.5 on Epop[27]], weight: 4.1363508E-4, delay 1.5
        h("Epop[27] syn_projEE_ampa[3307] = new ampa(0.5)")
        h("Epop[41] netConn_projEE_ampa[3307] = new NetCon(&v(0.5), syn_projEE_ampa[3307], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3308: cell 41, seg 0 (0.5) [0.5 on Epop[41]] -> cell 28, seg 0 (0.5) [0.5 on Epop[28]], weight: 4.1363508E-4, delay 1.5
        h("Epop[28] syn_projEE_ampa[3308] = new ampa(0.5)")
        h("Epop[41] netConn_projEE_ampa[3308] = new NetCon(&v(0.5), syn_projEE_ampa[3308], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3309: cell 41, seg 0 (0.5) [0.5 on Epop[41]] -> cell 29, seg 0 (0.5) [0.5 on Epop[29]], weight: 4.1363508E-4, delay 1.5
        h("Epop[29] syn_projEE_ampa[3309] = new ampa(0.5)")
        h("Epop[41] netConn_projEE_ampa[3309] = new NetCon(&v(0.5), syn_projEE_ampa[3309], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3310: cell 41, seg 0 (0.5) [0.5 on Epop[41]] -> cell 30, seg 0 (0.5) [0.5 on Epop[30]], weight: 4.1363508E-4, delay 1.5
        h("Epop[30] syn_projEE_ampa[3310] = new ampa(0.5)")
        h("Epop[41] netConn_projEE_ampa[3310] = new NetCon(&v(0.5), syn_projEE_ampa[3310], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3311: cell 41, seg 0 (0.5) [0.5 on Epop[41]] -> cell 31, seg 0 (0.5) [0.5 on Epop[31]], weight: 4.1363508E-4, delay 1.5
        h("Epop[31] syn_projEE_ampa[3311] = new ampa(0.5)")
        h("Epop[41] netConn_projEE_ampa[3311] = new NetCon(&v(0.5), syn_projEE_ampa[3311], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3312: cell 41, seg 0 (0.5) [0.5 on Epop[41]] -> cell 32, seg 0 (0.5) [0.5 on Epop[32]], weight: 4.1363508E-4, delay 1.5
        h("Epop[32] syn_projEE_ampa[3312] = new ampa(0.5)")
        h("Epop[41] netConn_projEE_ampa[3312] = new NetCon(&v(0.5), syn_projEE_ampa[3312], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3313: cell 41, seg 0 (0.5) [0.5 on Epop[41]] -> cell 33, seg 0 (0.5) [0.5 on Epop[33]], weight: 4.1363508E-4, delay 1.5
        h("Epop[33] syn_projEE_ampa[3313] = new ampa(0.5)")
        h("Epop[41] netConn_projEE_ampa[3313] = new NetCon(&v(0.5), syn_projEE_ampa[3313], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3314: cell 41, seg 0 (0.5) [0.5 on Epop[41]] -> cell 34, seg 0 (0.5) [0.5 on Epop[34]], weight: 4.1363508E-4, delay 1.5
        h("Epop[34] syn_projEE_ampa[3314] = new ampa(0.5)")
        h("Epop[41] netConn_projEE_ampa[3314] = new NetCon(&v(0.5), syn_projEE_ampa[3314], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3315: cell 41, seg 0 (0.5) [0.5 on Epop[41]] -> cell 35, seg 0 (0.5) [0.5 on Epop[35]], weight: 4.1363508E-4, delay 1.5
        h("Epop[35] syn_projEE_ampa[3315] = new ampa(0.5)")
        h("Epop[41] netConn_projEE_ampa[3315] = new NetCon(&v(0.5), syn_projEE_ampa[3315], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3316: cell 41, seg 0 (0.5) [0.5 on Epop[41]] -> cell 36, seg 0 (0.5) [0.5 on Epop[36]], weight: 4.1363508E-4, delay 1.5
        h("Epop[36] syn_projEE_ampa[3316] = new ampa(0.5)")
        h("Epop[41] netConn_projEE_ampa[3316] = new NetCon(&v(0.5), syn_projEE_ampa[3316], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3317: cell 41, seg 0 (0.5) [0.5 on Epop[41]] -> cell 37, seg 0 (0.5) [0.5 on Epop[37]], weight: 4.1363508E-4, delay 1.5
        h("Epop[37] syn_projEE_ampa[3317] = new ampa(0.5)")
        h("Epop[41] netConn_projEE_ampa[3317] = new NetCon(&v(0.5), syn_projEE_ampa[3317], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3318: cell 41, seg 0 (0.5) [0.5 on Epop[41]] -> cell 38, seg 0 (0.5) [0.5 on Epop[38]], weight: 4.1363508E-4, delay 1.5
        h("Epop[38] syn_projEE_ampa[3318] = new ampa(0.5)")
        h("Epop[41] netConn_projEE_ampa[3318] = new NetCon(&v(0.5), syn_projEE_ampa[3318], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3319: cell 41, seg 0 (0.5) [0.5 on Epop[41]] -> cell 39, seg 0 (0.5) [0.5 on Epop[39]], weight: 4.1363508E-4, delay 1.5
        h("Epop[39] syn_projEE_ampa[3319] = new ampa(0.5)")
        h("Epop[41] netConn_projEE_ampa[3319] = new NetCon(&v(0.5), syn_projEE_ampa[3319], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3320: cell 41, seg 0 (0.5) [0.5 on Epop[41]] -> cell 40, seg 0 (0.5) [0.5 on Epop[40]], weight: 4.1363508E-4, delay 1.5
        h("Epop[40] syn_projEE_ampa[3320] = new ampa(0.5)")
        h("Epop[41] netConn_projEE_ampa[3320] = new NetCon(&v(0.5), syn_projEE_ampa[3320], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3321: cell 41, seg 0 (0.5) [0.5 on Epop[41]] -> cell 41, seg 0 (0.5) [0.5 on Epop[41]], weight: 4.1363508E-4, delay 1.5
        h("Epop[41] syn_projEE_ampa[3321] = new ampa(0.5)")
        h("Epop[41] netConn_projEE_ampa[3321] = new NetCon(&v(0.5), syn_projEE_ampa[3321], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3322: cell 41, seg 0 (0.5) [0.5 on Epop[41]] -> cell 42, seg 0 (0.5) [0.5 on Epop[42]], weight: 4.1363508E-4, delay 1.5
        h("Epop[42] syn_projEE_ampa[3322] = new ampa(0.5)")
        h("Epop[41] netConn_projEE_ampa[3322] = new NetCon(&v(0.5), syn_projEE_ampa[3322], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3323: cell 41, seg 0 (0.5) [0.5 on Epop[41]] -> cell 43, seg 0 (0.5) [0.5 on Epop[43]], weight: 4.1363508E-4, delay 1.5
        h("Epop[43] syn_projEE_ampa[3323] = new ampa(0.5)")
        h("Epop[41] netConn_projEE_ampa[3323] = new NetCon(&v(0.5), syn_projEE_ampa[3323], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3324: cell 41, seg 0 (0.5) [0.5 on Epop[41]] -> cell 44, seg 0 (0.5) [0.5 on Epop[44]], weight: 4.1363508E-4, delay 1.5
        h("Epop[44] syn_projEE_ampa[3324] = new ampa(0.5)")
        h("Epop[41] netConn_projEE_ampa[3324] = new NetCon(&v(0.5), syn_projEE_ampa[3324], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3325: cell 41, seg 0 (0.5) [0.5 on Epop[41]] -> cell 45, seg 0 (0.5) [0.5 on Epop[45]], weight: 4.1363508E-4, delay 1.5
        h("Epop[45] syn_projEE_ampa[3325] = new ampa(0.5)")
        h("Epop[41] netConn_projEE_ampa[3325] = new NetCon(&v(0.5), syn_projEE_ampa[3325], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3326: cell 41, seg 0 (0.5) [0.5 on Epop[41]] -> cell 46, seg 0 (0.5) [0.5 on Epop[46]], weight: 4.1363508E-4, delay 1.5
        h("Epop[46] syn_projEE_ampa[3326] = new ampa(0.5)")
        h("Epop[41] netConn_projEE_ampa[3326] = new NetCon(&v(0.5), syn_projEE_ampa[3326], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3327: cell 41, seg 0 (0.5) [0.5 on Epop[41]] -> cell 47, seg 0 (0.5) [0.5 on Epop[47]], weight: 4.1363508E-4, delay 1.5
        h("Epop[47] syn_projEE_ampa[3327] = new ampa(0.5)")
        h("Epop[41] netConn_projEE_ampa[3327] = new NetCon(&v(0.5), syn_projEE_ampa[3327], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3328: cell 41, seg 0 (0.5) [0.5 on Epop[41]] -> cell 48, seg 0 (0.5) [0.5 on Epop[48]], weight: 4.1363508E-4, delay 1.5
        h("Epop[48] syn_projEE_ampa[3328] = new ampa(0.5)")
        h("Epop[41] netConn_projEE_ampa[3328] = new NetCon(&v(0.5), syn_projEE_ampa[3328], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3329: cell 41, seg 0 (0.5) [0.5 on Epop[41]] -> cell 49, seg 0 (0.5) [0.5 on Epop[49]], weight: 4.1363508E-4, delay 1.5
        h("Epop[49] syn_projEE_ampa[3329] = new ampa(0.5)")
        h("Epop[41] netConn_projEE_ampa[3329] = new NetCon(&v(0.5), syn_projEE_ampa[3329], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3330: cell 41, seg 0 (0.5) [0.5 on Epop[41]] -> cell 50, seg 0 (0.5) [0.5 on Epop[50]], weight: 4.1363508E-4, delay 1.5
        h("Epop[50] syn_projEE_ampa[3330] = new ampa(0.5)")
        h("Epop[41] netConn_projEE_ampa[3330] = new NetCon(&v(0.5), syn_projEE_ampa[3330], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3331: cell 41, seg 0 (0.5) [0.5 on Epop[41]] -> cell 51, seg 0 (0.5) [0.5 on Epop[51]], weight: 4.1363508E-4, delay 1.5
        h("Epop[51] syn_projEE_ampa[3331] = new ampa(0.5)")
        h("Epop[41] netConn_projEE_ampa[3331] = new NetCon(&v(0.5), syn_projEE_ampa[3331], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3332: cell 41, seg 0 (0.5) [0.5 on Epop[41]] -> cell 52, seg 0 (0.5) [0.5 on Epop[52]], weight: 4.1363508E-4, delay 1.5
        h("Epop[52] syn_projEE_ampa[3332] = new ampa(0.5)")
        h("Epop[41] netConn_projEE_ampa[3332] = new NetCon(&v(0.5), syn_projEE_ampa[3332], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3333: cell 41, seg 0 (0.5) [0.5 on Epop[41]] -> cell 53, seg 0 (0.5) [0.5 on Epop[53]], weight: 4.1363508E-4, delay 1.5
        h("Epop[53] syn_projEE_ampa[3333] = new ampa(0.5)")
        h("Epop[41] netConn_projEE_ampa[3333] = new NetCon(&v(0.5), syn_projEE_ampa[3333], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3334: cell 41, seg 0 (0.5) [0.5 on Epop[41]] -> cell 54, seg 0 (0.5) [0.5 on Epop[54]], weight: 4.1363508E-4, delay 1.5
        h("Epop[54] syn_projEE_ampa[3334] = new ampa(0.5)")
        h("Epop[41] netConn_projEE_ampa[3334] = new NetCon(&v(0.5), syn_projEE_ampa[3334], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3335: cell 41, seg 0 (0.5) [0.5 on Epop[41]] -> cell 55, seg 0 (0.5) [0.5 on Epop[55]], weight: 4.1363508E-4, delay 1.5
        h("Epop[55] syn_projEE_ampa[3335] = new ampa(0.5)")
        h("Epop[41] netConn_projEE_ampa[3335] = new NetCon(&v(0.5), syn_projEE_ampa[3335], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3336: cell 41, seg 0 (0.5) [0.5 on Epop[41]] -> cell 56, seg 0 (0.5) [0.5 on Epop[56]], weight: 4.1363508E-4, delay 1.5
        h("Epop[56] syn_projEE_ampa[3336] = new ampa(0.5)")
        h("Epop[41] netConn_projEE_ampa[3336] = new NetCon(&v(0.5), syn_projEE_ampa[3336], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3337: cell 41, seg 0 (0.5) [0.5 on Epop[41]] -> cell 57, seg 0 (0.5) [0.5 on Epop[57]], weight: 4.1363508E-4, delay 1.5
        h("Epop[57] syn_projEE_ampa[3337] = new ampa(0.5)")
        h("Epop[41] netConn_projEE_ampa[3337] = new NetCon(&v(0.5), syn_projEE_ampa[3337], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3338: cell 41, seg 0 (0.5) [0.5 on Epop[41]] -> cell 58, seg 0 (0.5) [0.5 on Epop[58]], weight: 4.1363508E-4, delay 1.5
        h("Epop[58] syn_projEE_ampa[3338] = new ampa(0.5)")
        h("Epop[41] netConn_projEE_ampa[3338] = new NetCon(&v(0.5), syn_projEE_ampa[3338], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3339: cell 41, seg 0 (0.5) [0.5 on Epop[41]] -> cell 59, seg 0 (0.5) [0.5 on Epop[59]], weight: 4.1363508E-4, delay 1.5
        h("Epop[59] syn_projEE_ampa[3339] = new ampa(0.5)")
        h("Epop[41] netConn_projEE_ampa[3339] = new NetCon(&v(0.5), syn_projEE_ampa[3339], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3340: cell 41, seg 0 (0.5) [0.5 on Epop[41]] -> cell 60, seg 0 (0.5) [0.5 on Epop[60]], weight: 4.1363508E-4, delay 1.5
        h("Epop[60] syn_projEE_ampa[3340] = new ampa(0.5)")
        h("Epop[41] netConn_projEE_ampa[3340] = new NetCon(&v(0.5), syn_projEE_ampa[3340], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3341: cell 41, seg 0 (0.5) [0.5 on Epop[41]] -> cell 61, seg 0 (0.5) [0.5 on Epop[61]], weight: 4.1363508E-4, delay 1.5
        h("Epop[61] syn_projEE_ampa[3341] = new ampa(0.5)")
        h("Epop[41] netConn_projEE_ampa[3341] = new NetCon(&v(0.5), syn_projEE_ampa[3341], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3342: cell 41, seg 0 (0.5) [0.5 on Epop[41]] -> cell 62, seg 0 (0.5) [0.5 on Epop[62]], weight: 4.1363508E-4, delay 1.5
        h("Epop[62] syn_projEE_ampa[3342] = new ampa(0.5)")
        h("Epop[41] netConn_projEE_ampa[3342] = new NetCon(&v(0.5), syn_projEE_ampa[3342], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3343: cell 41, seg 0 (0.5) [0.5 on Epop[41]] -> cell 63, seg 0 (0.5) [0.5 on Epop[63]], weight: 4.1363508E-4, delay 1.5
        h("Epop[63] syn_projEE_ampa[3343] = new ampa(0.5)")
        h("Epop[41] netConn_projEE_ampa[3343] = new NetCon(&v(0.5), syn_projEE_ampa[3343], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3344: cell 41, seg 0 (0.5) [0.5 on Epop[41]] -> cell 64, seg 0 (0.5) [0.5 on Epop[64]], weight: 4.1363508E-4, delay 1.5
        h("Epop[64] syn_projEE_ampa[3344] = new ampa(0.5)")
        h("Epop[41] netConn_projEE_ampa[3344] = new NetCon(&v(0.5), syn_projEE_ampa[3344], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3345: cell 41, seg 0 (0.5) [0.5 on Epop[41]] -> cell 65, seg 0 (0.5) [0.5 on Epop[65]], weight: 4.1363508E-4, delay 1.5
        h("Epop[65] syn_projEE_ampa[3345] = new ampa(0.5)")
        h("Epop[41] netConn_projEE_ampa[3345] = new NetCon(&v(0.5), syn_projEE_ampa[3345], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3346: cell 41, seg 0 (0.5) [0.5 on Epop[41]] -> cell 66, seg 0 (0.5) [0.5 on Epop[66]], weight: 4.1363508E-4, delay 1.5
        h("Epop[66] syn_projEE_ampa[3346] = new ampa(0.5)")
        h("Epop[41] netConn_projEE_ampa[3346] = new NetCon(&v(0.5), syn_projEE_ampa[3346], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3347: cell 41, seg 0 (0.5) [0.5 on Epop[41]] -> cell 67, seg 0 (0.5) [0.5 on Epop[67]], weight: 4.1363508E-4, delay 1.5
        h("Epop[67] syn_projEE_ampa[3347] = new ampa(0.5)")
        h("Epop[41] netConn_projEE_ampa[3347] = new NetCon(&v(0.5), syn_projEE_ampa[3347], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3348: cell 41, seg 0 (0.5) [0.5 on Epop[41]] -> cell 68, seg 0 (0.5) [0.5 on Epop[68]], weight: 4.1363508E-4, delay 1.5
        h("Epop[68] syn_projEE_ampa[3348] = new ampa(0.5)")
        h("Epop[41] netConn_projEE_ampa[3348] = new NetCon(&v(0.5), syn_projEE_ampa[3348], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3349: cell 41, seg 0 (0.5) [0.5 on Epop[41]] -> cell 69, seg 0 (0.5) [0.5 on Epop[69]], weight: 4.1363508E-4, delay 1.5
        h("Epop[69] syn_projEE_ampa[3349] = new ampa(0.5)")
        h("Epop[41] netConn_projEE_ampa[3349] = new NetCon(&v(0.5), syn_projEE_ampa[3349], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3350: cell 41, seg 0 (0.5) [0.5 on Epop[41]] -> cell 70, seg 0 (0.5) [0.5 on Epop[70]], weight: 4.1363508E-4, delay 1.5
        h("Epop[70] syn_projEE_ampa[3350] = new ampa(0.5)")
        h("Epop[41] netConn_projEE_ampa[3350] = new NetCon(&v(0.5), syn_projEE_ampa[3350], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3351: cell 41, seg 0 (0.5) [0.5 on Epop[41]] -> cell 71, seg 0 (0.5) [0.5 on Epop[71]], weight: 4.1363508E-4, delay 1.5
        h("Epop[71] syn_projEE_ampa[3351] = new ampa(0.5)")
        h("Epop[41] netConn_projEE_ampa[3351] = new NetCon(&v(0.5), syn_projEE_ampa[3351], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3352: cell 41, seg 0 (0.5) [0.5 on Epop[41]] -> cell 72, seg 0 (0.5) [0.5 on Epop[72]], weight: 4.1363508E-4, delay 1.5
        h("Epop[72] syn_projEE_ampa[3352] = new ampa(0.5)")
        h("Epop[41] netConn_projEE_ampa[3352] = new NetCon(&v(0.5), syn_projEE_ampa[3352], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3353: cell 41, seg 0 (0.5) [0.5 on Epop[41]] -> cell 73, seg 0 (0.5) [0.5 on Epop[73]], weight: 4.1363508E-4, delay 1.5
        h("Epop[73] syn_projEE_ampa[3353] = new ampa(0.5)")
        h("Epop[41] netConn_projEE_ampa[3353] = new NetCon(&v(0.5), syn_projEE_ampa[3353], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3354: cell 41, seg 0 (0.5) [0.5 on Epop[41]] -> cell 74, seg 0 (0.5) [0.5 on Epop[74]], weight: 4.1363508E-4, delay 1.5
        h("Epop[74] syn_projEE_ampa[3354] = new ampa(0.5)")
        h("Epop[41] netConn_projEE_ampa[3354] = new NetCon(&v(0.5), syn_projEE_ampa[3354], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3355: cell 41, seg 0 (0.5) [0.5 on Epop[41]] -> cell 75, seg 0 (0.5) [0.5 on Epop[75]], weight: 4.1363508E-4, delay 1.5
        h("Epop[75] syn_projEE_ampa[3355] = new ampa(0.5)")
        h("Epop[41] netConn_projEE_ampa[3355] = new NetCon(&v(0.5), syn_projEE_ampa[3355], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3356: cell 41, seg 0 (0.5) [0.5 on Epop[41]] -> cell 76, seg 0 (0.5) [0.5 on Epop[76]], weight: 4.1363508E-4, delay 1.5
        h("Epop[76] syn_projEE_ampa[3356] = new ampa(0.5)")
        h("Epop[41] netConn_projEE_ampa[3356] = new NetCon(&v(0.5), syn_projEE_ampa[3356], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3357: cell 41, seg 0 (0.5) [0.5 on Epop[41]] -> cell 77, seg 0 (0.5) [0.5 on Epop[77]], weight: 4.1363508E-4, delay 1.5
        h("Epop[77] syn_projEE_ampa[3357] = new ampa(0.5)")
        h("Epop[41] netConn_projEE_ampa[3357] = new NetCon(&v(0.5), syn_projEE_ampa[3357], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3358: cell 41, seg 0 (0.5) [0.5 on Epop[41]] -> cell 78, seg 0 (0.5) [0.5 on Epop[78]], weight: 4.1363508E-4, delay 1.5
        h("Epop[78] syn_projEE_ampa[3358] = new ampa(0.5)")
        h("Epop[41] netConn_projEE_ampa[3358] = new NetCon(&v(0.5), syn_projEE_ampa[3358], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3359: cell 41, seg 0 (0.5) [0.5 on Epop[41]] -> cell 79, seg 0 (0.5) [0.5 on Epop[79]], weight: 4.1363508E-4, delay 1.5
        h("Epop[79] syn_projEE_ampa[3359] = new ampa(0.5)")
        h("Epop[41] netConn_projEE_ampa[3359] = new NetCon(&v(0.5), syn_projEE_ampa[3359], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3360: cell 42, seg 0 (0.5) [0.5 on Epop[42]] -> cell 0, seg 0 (0.5) [0.5 on Epop[0]], weight: 4.1363508E-4, delay 1.5
        h("Epop[0] syn_projEE_ampa[3360] = new ampa(0.5)")
        h("Epop[42] netConn_projEE_ampa[3360] = new NetCon(&v(0.5), syn_projEE_ampa[3360], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3361: cell 42, seg 0 (0.5) [0.5 on Epop[42]] -> cell 1, seg 0 (0.5) [0.5 on Epop[1]], weight: 4.1363508E-4, delay 1.5
        h("Epop[1] syn_projEE_ampa[3361] = new ampa(0.5)")
        h("Epop[42] netConn_projEE_ampa[3361] = new NetCon(&v(0.5), syn_projEE_ampa[3361], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3362: cell 42, seg 0 (0.5) [0.5 on Epop[42]] -> cell 2, seg 0 (0.5) [0.5 on Epop[2]], weight: 4.1363508E-4, delay 1.5
        h("Epop[2] syn_projEE_ampa[3362] = new ampa(0.5)")
        h("Epop[42] netConn_projEE_ampa[3362] = new NetCon(&v(0.5), syn_projEE_ampa[3362], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3363: cell 42, seg 0 (0.5) [0.5 on Epop[42]] -> cell 3, seg 0 (0.5) [0.5 on Epop[3]], weight: 4.1363508E-4, delay 1.5
        h("Epop[3] syn_projEE_ampa[3363] = new ampa(0.5)")
        h("Epop[42] netConn_projEE_ampa[3363] = new NetCon(&v(0.5), syn_projEE_ampa[3363], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3364: cell 42, seg 0 (0.5) [0.5 on Epop[42]] -> cell 4, seg 0 (0.5) [0.5 on Epop[4]], weight: 4.1363508E-4, delay 1.5
        h("Epop[4] syn_projEE_ampa[3364] = new ampa(0.5)")
        h("Epop[42] netConn_projEE_ampa[3364] = new NetCon(&v(0.5), syn_projEE_ampa[3364], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3365: cell 42, seg 0 (0.5) [0.5 on Epop[42]] -> cell 5, seg 0 (0.5) [0.5 on Epop[5]], weight: 4.1363508E-4, delay 1.5
        h("Epop[5] syn_projEE_ampa[3365] = new ampa(0.5)")
        h("Epop[42] netConn_projEE_ampa[3365] = new NetCon(&v(0.5), syn_projEE_ampa[3365], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3366: cell 42, seg 0 (0.5) [0.5 on Epop[42]] -> cell 6, seg 0 (0.5) [0.5 on Epop[6]], weight: 4.1363508E-4, delay 1.5
        h("Epop[6] syn_projEE_ampa[3366] = new ampa(0.5)")
        h("Epop[42] netConn_projEE_ampa[3366] = new NetCon(&v(0.5), syn_projEE_ampa[3366], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3367: cell 42, seg 0 (0.5) [0.5 on Epop[42]] -> cell 7, seg 0 (0.5) [0.5 on Epop[7]], weight: 4.1363508E-4, delay 1.5
        h("Epop[7] syn_projEE_ampa[3367] = new ampa(0.5)")
        h("Epop[42] netConn_projEE_ampa[3367] = new NetCon(&v(0.5), syn_projEE_ampa[3367], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3368: cell 42, seg 0 (0.5) [0.5 on Epop[42]] -> cell 8, seg 0 (0.5) [0.5 on Epop[8]], weight: 4.1363508E-4, delay 1.5
        h("Epop[8] syn_projEE_ampa[3368] = new ampa(0.5)")
        h("Epop[42] netConn_projEE_ampa[3368] = new NetCon(&v(0.5), syn_projEE_ampa[3368], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3369: cell 42, seg 0 (0.5) [0.5 on Epop[42]] -> cell 9, seg 0 (0.5) [0.5 on Epop[9]], weight: 4.1363508E-4, delay 1.5
        h("Epop[9] syn_projEE_ampa[3369] = new ampa(0.5)")
        h("Epop[42] netConn_projEE_ampa[3369] = new NetCon(&v(0.5), syn_projEE_ampa[3369], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3370: cell 42, seg 0 (0.5) [0.5 on Epop[42]] -> cell 10, seg 0 (0.5) [0.5 on Epop[10]], weight: 4.1363508E-4, delay 1.5
        h("Epop[10] syn_projEE_ampa[3370] = new ampa(0.5)")
        h("Epop[42] netConn_projEE_ampa[3370] = new NetCon(&v(0.5), syn_projEE_ampa[3370], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3371: cell 42, seg 0 (0.5) [0.5 on Epop[42]] -> cell 11, seg 0 (0.5) [0.5 on Epop[11]], weight: 4.1363508E-4, delay 1.5
        h("Epop[11] syn_projEE_ampa[3371] = new ampa(0.5)")
        h("Epop[42] netConn_projEE_ampa[3371] = new NetCon(&v(0.5), syn_projEE_ampa[3371], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3372: cell 42, seg 0 (0.5) [0.5 on Epop[42]] -> cell 12, seg 0 (0.5) [0.5 on Epop[12]], weight: 4.1363508E-4, delay 1.5
        h("Epop[12] syn_projEE_ampa[3372] = new ampa(0.5)")
        h("Epop[42] netConn_projEE_ampa[3372] = new NetCon(&v(0.5), syn_projEE_ampa[3372], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3373: cell 42, seg 0 (0.5) [0.5 on Epop[42]] -> cell 13, seg 0 (0.5) [0.5 on Epop[13]], weight: 4.1363508E-4, delay 1.5
        h("Epop[13] syn_projEE_ampa[3373] = new ampa(0.5)")
        h("Epop[42] netConn_projEE_ampa[3373] = new NetCon(&v(0.5), syn_projEE_ampa[3373], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3374: cell 42, seg 0 (0.5) [0.5 on Epop[42]] -> cell 14, seg 0 (0.5) [0.5 on Epop[14]], weight: 4.1363508E-4, delay 1.5
        h("Epop[14] syn_projEE_ampa[3374] = new ampa(0.5)")
        h("Epop[42] netConn_projEE_ampa[3374] = new NetCon(&v(0.5), syn_projEE_ampa[3374], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3375: cell 42, seg 0 (0.5) [0.5 on Epop[42]] -> cell 15, seg 0 (0.5) [0.5 on Epop[15]], weight: 4.1363508E-4, delay 1.5
        h("Epop[15] syn_projEE_ampa[3375] = new ampa(0.5)")
        h("Epop[42] netConn_projEE_ampa[3375] = new NetCon(&v(0.5), syn_projEE_ampa[3375], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3376: cell 42, seg 0 (0.5) [0.5 on Epop[42]] -> cell 16, seg 0 (0.5) [0.5 on Epop[16]], weight: 4.1363508E-4, delay 1.5
        h("Epop[16] syn_projEE_ampa[3376] = new ampa(0.5)")
        h("Epop[42] netConn_projEE_ampa[3376] = new NetCon(&v(0.5), syn_projEE_ampa[3376], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3377: cell 42, seg 0 (0.5) [0.5 on Epop[42]] -> cell 17, seg 0 (0.5) [0.5 on Epop[17]], weight: 4.1363508E-4, delay 1.5
        h("Epop[17] syn_projEE_ampa[3377] = new ampa(0.5)")
        h("Epop[42] netConn_projEE_ampa[3377] = new NetCon(&v(0.5), syn_projEE_ampa[3377], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3378: cell 42, seg 0 (0.5) [0.5 on Epop[42]] -> cell 18, seg 0 (0.5) [0.5 on Epop[18]], weight: 4.1363508E-4, delay 1.5
        h("Epop[18] syn_projEE_ampa[3378] = new ampa(0.5)")
        h("Epop[42] netConn_projEE_ampa[3378] = new NetCon(&v(0.5), syn_projEE_ampa[3378], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3379: cell 42, seg 0 (0.5) [0.5 on Epop[42]] -> cell 19, seg 0 (0.5) [0.5 on Epop[19]], weight: 4.1363508E-4, delay 1.5
        h("Epop[19] syn_projEE_ampa[3379] = new ampa(0.5)")
        h("Epop[42] netConn_projEE_ampa[3379] = new NetCon(&v(0.5), syn_projEE_ampa[3379], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3380: cell 42, seg 0 (0.5) [0.5 on Epop[42]] -> cell 20, seg 0 (0.5) [0.5 on Epop[20]], weight: 4.1363508E-4, delay 1.5
        h("Epop[20] syn_projEE_ampa[3380] = new ampa(0.5)")
        h("Epop[42] netConn_projEE_ampa[3380] = new NetCon(&v(0.5), syn_projEE_ampa[3380], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3381: cell 42, seg 0 (0.5) [0.5 on Epop[42]] -> cell 21, seg 0 (0.5) [0.5 on Epop[21]], weight: 4.1363508E-4, delay 1.5
        h("Epop[21] syn_projEE_ampa[3381] = new ampa(0.5)")
        h("Epop[42] netConn_projEE_ampa[3381] = new NetCon(&v(0.5), syn_projEE_ampa[3381], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3382: cell 42, seg 0 (0.5) [0.5 on Epop[42]] -> cell 22, seg 0 (0.5) [0.5 on Epop[22]], weight: 4.1363508E-4, delay 1.5
        h("Epop[22] syn_projEE_ampa[3382] = new ampa(0.5)")
        h("Epop[42] netConn_projEE_ampa[3382] = new NetCon(&v(0.5), syn_projEE_ampa[3382], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3383: cell 42, seg 0 (0.5) [0.5 on Epop[42]] -> cell 23, seg 0 (0.5) [0.5 on Epop[23]], weight: 4.1363508E-4, delay 1.5
        h("Epop[23] syn_projEE_ampa[3383] = new ampa(0.5)")
        h("Epop[42] netConn_projEE_ampa[3383] = new NetCon(&v(0.5), syn_projEE_ampa[3383], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3384: cell 42, seg 0 (0.5) [0.5 on Epop[42]] -> cell 24, seg 0 (0.5) [0.5 on Epop[24]], weight: 4.1363508E-4, delay 1.5
        h("Epop[24] syn_projEE_ampa[3384] = new ampa(0.5)")
        h("Epop[42] netConn_projEE_ampa[3384] = new NetCon(&v(0.5), syn_projEE_ampa[3384], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3385: cell 42, seg 0 (0.5) [0.5 on Epop[42]] -> cell 25, seg 0 (0.5) [0.5 on Epop[25]], weight: 4.1363508E-4, delay 1.5
        h("Epop[25] syn_projEE_ampa[3385] = new ampa(0.5)")
        h("Epop[42] netConn_projEE_ampa[3385] = new NetCon(&v(0.5), syn_projEE_ampa[3385], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3386: cell 42, seg 0 (0.5) [0.5 on Epop[42]] -> cell 26, seg 0 (0.5) [0.5 on Epop[26]], weight: 4.1363508E-4, delay 1.5
        h("Epop[26] syn_projEE_ampa[3386] = new ampa(0.5)")
        h("Epop[42] netConn_projEE_ampa[3386] = new NetCon(&v(0.5), syn_projEE_ampa[3386], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3387: cell 42, seg 0 (0.5) [0.5 on Epop[42]] -> cell 27, seg 0 (0.5) [0.5 on Epop[27]], weight: 4.1363508E-4, delay 1.5
        h("Epop[27] syn_projEE_ampa[3387] = new ampa(0.5)")
        h("Epop[42] netConn_projEE_ampa[3387] = new NetCon(&v(0.5), syn_projEE_ampa[3387], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3388: cell 42, seg 0 (0.5) [0.5 on Epop[42]] -> cell 28, seg 0 (0.5) [0.5 on Epop[28]], weight: 4.1363508E-4, delay 1.5
        h("Epop[28] syn_projEE_ampa[3388] = new ampa(0.5)")
        h("Epop[42] netConn_projEE_ampa[3388] = new NetCon(&v(0.5), syn_projEE_ampa[3388], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3389: cell 42, seg 0 (0.5) [0.5 on Epop[42]] -> cell 29, seg 0 (0.5) [0.5 on Epop[29]], weight: 4.1363508E-4, delay 1.5
        h("Epop[29] syn_projEE_ampa[3389] = new ampa(0.5)")
        h("Epop[42] netConn_projEE_ampa[3389] = new NetCon(&v(0.5), syn_projEE_ampa[3389], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3390: cell 42, seg 0 (0.5) [0.5 on Epop[42]] -> cell 30, seg 0 (0.5) [0.5 on Epop[30]], weight: 4.1363508E-4, delay 1.5
        h("Epop[30] syn_projEE_ampa[3390] = new ampa(0.5)")
        h("Epop[42] netConn_projEE_ampa[3390] = new NetCon(&v(0.5), syn_projEE_ampa[3390], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3391: cell 42, seg 0 (0.5) [0.5 on Epop[42]] -> cell 31, seg 0 (0.5) [0.5 on Epop[31]], weight: 4.1363508E-4, delay 1.5
        h("Epop[31] syn_projEE_ampa[3391] = new ampa(0.5)")
        h("Epop[42] netConn_projEE_ampa[3391] = new NetCon(&v(0.5), syn_projEE_ampa[3391], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3392: cell 42, seg 0 (0.5) [0.5 on Epop[42]] -> cell 32, seg 0 (0.5) [0.5 on Epop[32]], weight: 4.1363508E-4, delay 1.5
        h("Epop[32] syn_projEE_ampa[3392] = new ampa(0.5)")
        h("Epop[42] netConn_projEE_ampa[3392] = new NetCon(&v(0.5), syn_projEE_ampa[3392], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3393: cell 42, seg 0 (0.5) [0.5 on Epop[42]] -> cell 33, seg 0 (0.5) [0.5 on Epop[33]], weight: 4.1363508E-4, delay 1.5
        h("Epop[33] syn_projEE_ampa[3393] = new ampa(0.5)")
        h("Epop[42] netConn_projEE_ampa[3393] = new NetCon(&v(0.5), syn_projEE_ampa[3393], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3394: cell 42, seg 0 (0.5) [0.5 on Epop[42]] -> cell 34, seg 0 (0.5) [0.5 on Epop[34]], weight: 4.1363508E-4, delay 1.5
        h("Epop[34] syn_projEE_ampa[3394] = new ampa(0.5)")
        h("Epop[42] netConn_projEE_ampa[3394] = new NetCon(&v(0.5), syn_projEE_ampa[3394], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3395: cell 42, seg 0 (0.5) [0.5 on Epop[42]] -> cell 35, seg 0 (0.5) [0.5 on Epop[35]], weight: 4.1363508E-4, delay 1.5
        h("Epop[35] syn_projEE_ampa[3395] = new ampa(0.5)")
        h("Epop[42] netConn_projEE_ampa[3395] = new NetCon(&v(0.5), syn_projEE_ampa[3395], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3396: cell 42, seg 0 (0.5) [0.5 on Epop[42]] -> cell 36, seg 0 (0.5) [0.5 on Epop[36]], weight: 4.1363508E-4, delay 1.5
        h("Epop[36] syn_projEE_ampa[3396] = new ampa(0.5)")
        h("Epop[42] netConn_projEE_ampa[3396] = new NetCon(&v(0.5), syn_projEE_ampa[3396], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3397: cell 42, seg 0 (0.5) [0.5 on Epop[42]] -> cell 37, seg 0 (0.5) [0.5 on Epop[37]], weight: 4.1363508E-4, delay 1.5
        h("Epop[37] syn_projEE_ampa[3397] = new ampa(0.5)")
        h("Epop[42] netConn_projEE_ampa[3397] = new NetCon(&v(0.5), syn_projEE_ampa[3397], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3398: cell 42, seg 0 (0.5) [0.5 on Epop[42]] -> cell 38, seg 0 (0.5) [0.5 on Epop[38]], weight: 4.1363508E-4, delay 1.5
        h("Epop[38] syn_projEE_ampa[3398] = new ampa(0.5)")
        h("Epop[42] netConn_projEE_ampa[3398] = new NetCon(&v(0.5), syn_projEE_ampa[3398], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3399: cell 42, seg 0 (0.5) [0.5 on Epop[42]] -> cell 39, seg 0 (0.5) [0.5 on Epop[39]], weight: 4.1363508E-4, delay 1.5
        h("Epop[39] syn_projEE_ampa[3399] = new ampa(0.5)")
        h("Epop[42] netConn_projEE_ampa[3399] = new NetCon(&v(0.5), syn_projEE_ampa[3399], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3400: cell 42, seg 0 (0.5) [0.5 on Epop[42]] -> cell 40, seg 0 (0.5) [0.5 on Epop[40]], weight: 4.1363508E-4, delay 1.5
        h("Epop[40] syn_projEE_ampa[3400] = new ampa(0.5)")
        h("Epop[42] netConn_projEE_ampa[3400] = new NetCon(&v(0.5), syn_projEE_ampa[3400], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3401: cell 42, seg 0 (0.5) [0.5 on Epop[42]] -> cell 41, seg 0 (0.5) [0.5 on Epop[41]], weight: 4.1363508E-4, delay 1.5
        h("Epop[41] syn_projEE_ampa[3401] = new ampa(0.5)")
        h("Epop[42] netConn_projEE_ampa[3401] = new NetCon(&v(0.5), syn_projEE_ampa[3401], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3402: cell 42, seg 0 (0.5) [0.5 on Epop[42]] -> cell 42, seg 0 (0.5) [0.5 on Epop[42]], weight: 4.1363508E-4, delay 1.5
        h("Epop[42] syn_projEE_ampa[3402] = new ampa(0.5)")
        h("Epop[42] netConn_projEE_ampa[3402] = new NetCon(&v(0.5), syn_projEE_ampa[3402], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3403: cell 42, seg 0 (0.5) [0.5 on Epop[42]] -> cell 43, seg 0 (0.5) [0.5 on Epop[43]], weight: 4.1363508E-4, delay 1.5
        h("Epop[43] syn_projEE_ampa[3403] = new ampa(0.5)")
        h("Epop[42] netConn_projEE_ampa[3403] = new NetCon(&v(0.5), syn_projEE_ampa[3403], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3404: cell 42, seg 0 (0.5) [0.5 on Epop[42]] -> cell 44, seg 0 (0.5) [0.5 on Epop[44]], weight: 4.1363508E-4, delay 1.5
        h("Epop[44] syn_projEE_ampa[3404] = new ampa(0.5)")
        h("Epop[42] netConn_projEE_ampa[3404] = new NetCon(&v(0.5), syn_projEE_ampa[3404], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3405: cell 42, seg 0 (0.5) [0.5 on Epop[42]] -> cell 45, seg 0 (0.5) [0.5 on Epop[45]], weight: 4.1363508E-4, delay 1.5
        h("Epop[45] syn_projEE_ampa[3405] = new ampa(0.5)")
        h("Epop[42] netConn_projEE_ampa[3405] = new NetCon(&v(0.5), syn_projEE_ampa[3405], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3406: cell 42, seg 0 (0.5) [0.5 on Epop[42]] -> cell 46, seg 0 (0.5) [0.5 on Epop[46]], weight: 4.1363508E-4, delay 1.5
        h("Epop[46] syn_projEE_ampa[3406] = new ampa(0.5)")
        h("Epop[42] netConn_projEE_ampa[3406] = new NetCon(&v(0.5), syn_projEE_ampa[3406], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3407: cell 42, seg 0 (0.5) [0.5 on Epop[42]] -> cell 47, seg 0 (0.5) [0.5 on Epop[47]], weight: 4.1363508E-4, delay 1.5
        h("Epop[47] syn_projEE_ampa[3407] = new ampa(0.5)")
        h("Epop[42] netConn_projEE_ampa[3407] = new NetCon(&v(0.5), syn_projEE_ampa[3407], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3408: cell 42, seg 0 (0.5) [0.5 on Epop[42]] -> cell 48, seg 0 (0.5) [0.5 on Epop[48]], weight: 4.1363508E-4, delay 1.5
        h("Epop[48] syn_projEE_ampa[3408] = new ampa(0.5)")
        h("Epop[42] netConn_projEE_ampa[3408] = new NetCon(&v(0.5), syn_projEE_ampa[3408], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3409: cell 42, seg 0 (0.5) [0.5 on Epop[42]] -> cell 49, seg 0 (0.5) [0.5 on Epop[49]], weight: 4.1363508E-4, delay 1.5
        h("Epop[49] syn_projEE_ampa[3409] = new ampa(0.5)")
        h("Epop[42] netConn_projEE_ampa[3409] = new NetCon(&v(0.5), syn_projEE_ampa[3409], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3410: cell 42, seg 0 (0.5) [0.5 on Epop[42]] -> cell 50, seg 0 (0.5) [0.5 on Epop[50]], weight: 4.1363508E-4, delay 1.5
        h("Epop[50] syn_projEE_ampa[3410] = new ampa(0.5)")
        h("Epop[42] netConn_projEE_ampa[3410] = new NetCon(&v(0.5), syn_projEE_ampa[3410], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3411: cell 42, seg 0 (0.5) [0.5 on Epop[42]] -> cell 51, seg 0 (0.5) [0.5 on Epop[51]], weight: 4.1363508E-4, delay 1.5
        h("Epop[51] syn_projEE_ampa[3411] = new ampa(0.5)")
        h("Epop[42] netConn_projEE_ampa[3411] = new NetCon(&v(0.5), syn_projEE_ampa[3411], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3412: cell 42, seg 0 (0.5) [0.5 on Epop[42]] -> cell 52, seg 0 (0.5) [0.5 on Epop[52]], weight: 4.1363508E-4, delay 1.5
        h("Epop[52] syn_projEE_ampa[3412] = new ampa(0.5)")
        h("Epop[42] netConn_projEE_ampa[3412] = new NetCon(&v(0.5), syn_projEE_ampa[3412], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3413: cell 42, seg 0 (0.5) [0.5 on Epop[42]] -> cell 53, seg 0 (0.5) [0.5 on Epop[53]], weight: 4.1363508E-4, delay 1.5
        h("Epop[53] syn_projEE_ampa[3413] = new ampa(0.5)")
        h("Epop[42] netConn_projEE_ampa[3413] = new NetCon(&v(0.5), syn_projEE_ampa[3413], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3414: cell 42, seg 0 (0.5) [0.5 on Epop[42]] -> cell 54, seg 0 (0.5) [0.5 on Epop[54]], weight: 4.1363508E-4, delay 1.5
        h("Epop[54] syn_projEE_ampa[3414] = new ampa(0.5)")
        h("Epop[42] netConn_projEE_ampa[3414] = new NetCon(&v(0.5), syn_projEE_ampa[3414], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3415: cell 42, seg 0 (0.5) [0.5 on Epop[42]] -> cell 55, seg 0 (0.5) [0.5 on Epop[55]], weight: 4.1363508E-4, delay 1.5
        h("Epop[55] syn_projEE_ampa[3415] = new ampa(0.5)")
        h("Epop[42] netConn_projEE_ampa[3415] = new NetCon(&v(0.5), syn_projEE_ampa[3415], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3416: cell 42, seg 0 (0.5) [0.5 on Epop[42]] -> cell 56, seg 0 (0.5) [0.5 on Epop[56]], weight: 4.1363508E-4, delay 1.5
        h("Epop[56] syn_projEE_ampa[3416] = new ampa(0.5)")
        h("Epop[42] netConn_projEE_ampa[3416] = new NetCon(&v(0.5), syn_projEE_ampa[3416], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3417: cell 42, seg 0 (0.5) [0.5 on Epop[42]] -> cell 57, seg 0 (0.5) [0.5 on Epop[57]], weight: 4.1363508E-4, delay 1.5
        h("Epop[57] syn_projEE_ampa[3417] = new ampa(0.5)")
        h("Epop[42] netConn_projEE_ampa[3417] = new NetCon(&v(0.5), syn_projEE_ampa[3417], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3418: cell 42, seg 0 (0.5) [0.5 on Epop[42]] -> cell 58, seg 0 (0.5) [0.5 on Epop[58]], weight: 4.1363508E-4, delay 1.5
        h("Epop[58] syn_projEE_ampa[3418] = new ampa(0.5)")
        h("Epop[42] netConn_projEE_ampa[3418] = new NetCon(&v(0.5), syn_projEE_ampa[3418], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3419: cell 42, seg 0 (0.5) [0.5 on Epop[42]] -> cell 59, seg 0 (0.5) [0.5 on Epop[59]], weight: 4.1363508E-4, delay 1.5
        h("Epop[59] syn_projEE_ampa[3419] = new ampa(0.5)")
        h("Epop[42] netConn_projEE_ampa[3419] = new NetCon(&v(0.5), syn_projEE_ampa[3419], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3420: cell 42, seg 0 (0.5) [0.5 on Epop[42]] -> cell 60, seg 0 (0.5) [0.5 on Epop[60]], weight: 4.1363508E-4, delay 1.5
        h("Epop[60] syn_projEE_ampa[3420] = new ampa(0.5)")
        h("Epop[42] netConn_projEE_ampa[3420] = new NetCon(&v(0.5), syn_projEE_ampa[3420], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3421: cell 42, seg 0 (0.5) [0.5 on Epop[42]] -> cell 61, seg 0 (0.5) [0.5 on Epop[61]], weight: 4.1363508E-4, delay 1.5
        h("Epop[61] syn_projEE_ampa[3421] = new ampa(0.5)")
        h("Epop[42] netConn_projEE_ampa[3421] = new NetCon(&v(0.5), syn_projEE_ampa[3421], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3422: cell 42, seg 0 (0.5) [0.5 on Epop[42]] -> cell 62, seg 0 (0.5) [0.5 on Epop[62]], weight: 4.1363508E-4, delay 1.5
        h("Epop[62] syn_projEE_ampa[3422] = new ampa(0.5)")
        h("Epop[42] netConn_projEE_ampa[3422] = new NetCon(&v(0.5), syn_projEE_ampa[3422], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3423: cell 42, seg 0 (0.5) [0.5 on Epop[42]] -> cell 63, seg 0 (0.5) [0.5 on Epop[63]], weight: 4.1363508E-4, delay 1.5
        h("Epop[63] syn_projEE_ampa[3423] = new ampa(0.5)")
        h("Epop[42] netConn_projEE_ampa[3423] = new NetCon(&v(0.5), syn_projEE_ampa[3423], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3424: cell 42, seg 0 (0.5) [0.5 on Epop[42]] -> cell 64, seg 0 (0.5) [0.5 on Epop[64]], weight: 4.1363508E-4, delay 1.5
        h("Epop[64] syn_projEE_ampa[3424] = new ampa(0.5)")
        h("Epop[42] netConn_projEE_ampa[3424] = new NetCon(&v(0.5), syn_projEE_ampa[3424], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3425: cell 42, seg 0 (0.5) [0.5 on Epop[42]] -> cell 65, seg 0 (0.5) [0.5 on Epop[65]], weight: 4.1363508E-4, delay 1.5
        h("Epop[65] syn_projEE_ampa[3425] = new ampa(0.5)")
        h("Epop[42] netConn_projEE_ampa[3425] = new NetCon(&v(0.5), syn_projEE_ampa[3425], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3426: cell 42, seg 0 (0.5) [0.5 on Epop[42]] -> cell 66, seg 0 (0.5) [0.5 on Epop[66]], weight: 4.1363508E-4, delay 1.5
        h("Epop[66] syn_projEE_ampa[3426] = new ampa(0.5)")
        h("Epop[42] netConn_projEE_ampa[3426] = new NetCon(&v(0.5), syn_projEE_ampa[3426], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3427: cell 42, seg 0 (0.5) [0.5 on Epop[42]] -> cell 67, seg 0 (0.5) [0.5 on Epop[67]], weight: 4.1363508E-4, delay 1.5
        h("Epop[67] syn_projEE_ampa[3427] = new ampa(0.5)")
        h("Epop[42] netConn_projEE_ampa[3427] = new NetCon(&v(0.5), syn_projEE_ampa[3427], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3428: cell 42, seg 0 (0.5) [0.5 on Epop[42]] -> cell 68, seg 0 (0.5) [0.5 on Epop[68]], weight: 4.1363508E-4, delay 1.5
        h("Epop[68] syn_projEE_ampa[3428] = new ampa(0.5)")
        h("Epop[42] netConn_projEE_ampa[3428] = new NetCon(&v(0.5), syn_projEE_ampa[3428], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3429: cell 42, seg 0 (0.5) [0.5 on Epop[42]] -> cell 69, seg 0 (0.5) [0.5 on Epop[69]], weight: 4.1363508E-4, delay 1.5
        h("Epop[69] syn_projEE_ampa[3429] = new ampa(0.5)")
        h("Epop[42] netConn_projEE_ampa[3429] = new NetCon(&v(0.5), syn_projEE_ampa[3429], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3430: cell 42, seg 0 (0.5) [0.5 on Epop[42]] -> cell 70, seg 0 (0.5) [0.5 on Epop[70]], weight: 4.1363508E-4, delay 1.5
        h("Epop[70] syn_projEE_ampa[3430] = new ampa(0.5)")
        h("Epop[42] netConn_projEE_ampa[3430] = new NetCon(&v(0.5), syn_projEE_ampa[3430], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3431: cell 42, seg 0 (0.5) [0.5 on Epop[42]] -> cell 71, seg 0 (0.5) [0.5 on Epop[71]], weight: 4.1363508E-4, delay 1.5
        h("Epop[71] syn_projEE_ampa[3431] = new ampa(0.5)")
        h("Epop[42] netConn_projEE_ampa[3431] = new NetCon(&v(0.5), syn_projEE_ampa[3431], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3432: cell 42, seg 0 (0.5) [0.5 on Epop[42]] -> cell 72, seg 0 (0.5) [0.5 on Epop[72]], weight: 4.1363508E-4, delay 1.5
        h("Epop[72] syn_projEE_ampa[3432] = new ampa(0.5)")
        h("Epop[42] netConn_projEE_ampa[3432] = new NetCon(&v(0.5), syn_projEE_ampa[3432], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3433: cell 42, seg 0 (0.5) [0.5 on Epop[42]] -> cell 73, seg 0 (0.5) [0.5 on Epop[73]], weight: 4.1363508E-4, delay 1.5
        h("Epop[73] syn_projEE_ampa[3433] = new ampa(0.5)")
        h("Epop[42] netConn_projEE_ampa[3433] = new NetCon(&v(0.5), syn_projEE_ampa[3433], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3434: cell 42, seg 0 (0.5) [0.5 on Epop[42]] -> cell 74, seg 0 (0.5) [0.5 on Epop[74]], weight: 4.1363508E-4, delay 1.5
        h("Epop[74] syn_projEE_ampa[3434] = new ampa(0.5)")
        h("Epop[42] netConn_projEE_ampa[3434] = new NetCon(&v(0.5), syn_projEE_ampa[3434], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3435: cell 42, seg 0 (0.5) [0.5 on Epop[42]] -> cell 75, seg 0 (0.5) [0.5 on Epop[75]], weight: 4.1363508E-4, delay 1.5
        h("Epop[75] syn_projEE_ampa[3435] = new ampa(0.5)")
        h("Epop[42] netConn_projEE_ampa[3435] = new NetCon(&v(0.5), syn_projEE_ampa[3435], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3436: cell 42, seg 0 (0.5) [0.5 on Epop[42]] -> cell 76, seg 0 (0.5) [0.5 on Epop[76]], weight: 4.1363508E-4, delay 1.5
        h("Epop[76] syn_projEE_ampa[3436] = new ampa(0.5)")
        h("Epop[42] netConn_projEE_ampa[3436] = new NetCon(&v(0.5), syn_projEE_ampa[3436], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3437: cell 42, seg 0 (0.5) [0.5 on Epop[42]] -> cell 77, seg 0 (0.5) [0.5 on Epop[77]], weight: 4.1363508E-4, delay 1.5
        h("Epop[77] syn_projEE_ampa[3437] = new ampa(0.5)")
        h("Epop[42] netConn_projEE_ampa[3437] = new NetCon(&v(0.5), syn_projEE_ampa[3437], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3438: cell 42, seg 0 (0.5) [0.5 on Epop[42]] -> cell 78, seg 0 (0.5) [0.5 on Epop[78]], weight: 4.1363508E-4, delay 1.5
        h("Epop[78] syn_projEE_ampa[3438] = new ampa(0.5)")
        h("Epop[42] netConn_projEE_ampa[3438] = new NetCon(&v(0.5), syn_projEE_ampa[3438], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3439: cell 42, seg 0 (0.5) [0.5 on Epop[42]] -> cell 79, seg 0 (0.5) [0.5 on Epop[79]], weight: 4.1363508E-4, delay 1.5
        h("Epop[79] syn_projEE_ampa[3439] = new ampa(0.5)")
        h("Epop[42] netConn_projEE_ampa[3439] = new NetCon(&v(0.5), syn_projEE_ampa[3439], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3440: cell 43, seg 0 (0.5) [0.5 on Epop[43]] -> cell 0, seg 0 (0.5) [0.5 on Epop[0]], weight: 4.1363508E-4, delay 1.5
        h("Epop[0] syn_projEE_ampa[3440] = new ampa(0.5)")
        h("Epop[43] netConn_projEE_ampa[3440] = new NetCon(&v(0.5), syn_projEE_ampa[3440], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3441: cell 43, seg 0 (0.5) [0.5 on Epop[43]] -> cell 1, seg 0 (0.5) [0.5 on Epop[1]], weight: 4.1363508E-4, delay 1.5
        h("Epop[1] syn_projEE_ampa[3441] = new ampa(0.5)")
        h("Epop[43] netConn_projEE_ampa[3441] = new NetCon(&v(0.5), syn_projEE_ampa[3441], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3442: cell 43, seg 0 (0.5) [0.5 on Epop[43]] -> cell 2, seg 0 (0.5) [0.5 on Epop[2]], weight: 4.1363508E-4, delay 1.5
        h("Epop[2] syn_projEE_ampa[3442] = new ampa(0.5)")
        h("Epop[43] netConn_projEE_ampa[3442] = new NetCon(&v(0.5), syn_projEE_ampa[3442], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3443: cell 43, seg 0 (0.5) [0.5 on Epop[43]] -> cell 3, seg 0 (0.5) [0.5 on Epop[3]], weight: 4.1363508E-4, delay 1.5
        h("Epop[3] syn_projEE_ampa[3443] = new ampa(0.5)")
        h("Epop[43] netConn_projEE_ampa[3443] = new NetCon(&v(0.5), syn_projEE_ampa[3443], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3444: cell 43, seg 0 (0.5) [0.5 on Epop[43]] -> cell 4, seg 0 (0.5) [0.5 on Epop[4]], weight: 4.1363508E-4, delay 1.5
        h("Epop[4] syn_projEE_ampa[3444] = new ampa(0.5)")
        h("Epop[43] netConn_projEE_ampa[3444] = new NetCon(&v(0.5), syn_projEE_ampa[3444], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3445: cell 43, seg 0 (0.5) [0.5 on Epop[43]] -> cell 5, seg 0 (0.5) [0.5 on Epop[5]], weight: 4.1363508E-4, delay 1.5
        h("Epop[5] syn_projEE_ampa[3445] = new ampa(0.5)")
        h("Epop[43] netConn_projEE_ampa[3445] = new NetCon(&v(0.5), syn_projEE_ampa[3445], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3446: cell 43, seg 0 (0.5) [0.5 on Epop[43]] -> cell 6, seg 0 (0.5) [0.5 on Epop[6]], weight: 4.1363508E-4, delay 1.5
        h("Epop[6] syn_projEE_ampa[3446] = new ampa(0.5)")
        h("Epop[43] netConn_projEE_ampa[3446] = new NetCon(&v(0.5), syn_projEE_ampa[3446], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3447: cell 43, seg 0 (0.5) [0.5 on Epop[43]] -> cell 7, seg 0 (0.5) [0.5 on Epop[7]], weight: 4.1363508E-4, delay 1.5
        h("Epop[7] syn_projEE_ampa[3447] = new ampa(0.5)")
        h("Epop[43] netConn_projEE_ampa[3447] = new NetCon(&v(0.5), syn_projEE_ampa[3447], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3448: cell 43, seg 0 (0.5) [0.5 on Epop[43]] -> cell 8, seg 0 (0.5) [0.5 on Epop[8]], weight: 4.1363508E-4, delay 1.5
        h("Epop[8] syn_projEE_ampa[3448] = new ampa(0.5)")
        h("Epop[43] netConn_projEE_ampa[3448] = new NetCon(&v(0.5), syn_projEE_ampa[3448], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3449: cell 43, seg 0 (0.5) [0.5 on Epop[43]] -> cell 9, seg 0 (0.5) [0.5 on Epop[9]], weight: 4.1363508E-4, delay 1.5
        h("Epop[9] syn_projEE_ampa[3449] = new ampa(0.5)")
        h("Epop[43] netConn_projEE_ampa[3449] = new NetCon(&v(0.5), syn_projEE_ampa[3449], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3450: cell 43, seg 0 (0.5) [0.5 on Epop[43]] -> cell 10, seg 0 (0.5) [0.5 on Epop[10]], weight: 4.1363508E-4, delay 1.5
        h("Epop[10] syn_projEE_ampa[3450] = new ampa(0.5)")
        h("Epop[43] netConn_projEE_ampa[3450] = new NetCon(&v(0.5), syn_projEE_ampa[3450], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3451: cell 43, seg 0 (0.5) [0.5 on Epop[43]] -> cell 11, seg 0 (0.5) [0.5 on Epop[11]], weight: 4.1363508E-4, delay 1.5
        h("Epop[11] syn_projEE_ampa[3451] = new ampa(0.5)")
        h("Epop[43] netConn_projEE_ampa[3451] = new NetCon(&v(0.5), syn_projEE_ampa[3451], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3452: cell 43, seg 0 (0.5) [0.5 on Epop[43]] -> cell 12, seg 0 (0.5) [0.5 on Epop[12]], weight: 4.1363508E-4, delay 1.5
        h("Epop[12] syn_projEE_ampa[3452] = new ampa(0.5)")
        h("Epop[43] netConn_projEE_ampa[3452] = new NetCon(&v(0.5), syn_projEE_ampa[3452], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3453: cell 43, seg 0 (0.5) [0.5 on Epop[43]] -> cell 13, seg 0 (0.5) [0.5 on Epop[13]], weight: 4.1363508E-4, delay 1.5
        h("Epop[13] syn_projEE_ampa[3453] = new ampa(0.5)")
        h("Epop[43] netConn_projEE_ampa[3453] = new NetCon(&v(0.5), syn_projEE_ampa[3453], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3454: cell 43, seg 0 (0.5) [0.5 on Epop[43]] -> cell 14, seg 0 (0.5) [0.5 on Epop[14]], weight: 4.1363508E-4, delay 1.5
        h("Epop[14] syn_projEE_ampa[3454] = new ampa(0.5)")
        h("Epop[43] netConn_projEE_ampa[3454] = new NetCon(&v(0.5), syn_projEE_ampa[3454], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3455: cell 43, seg 0 (0.5) [0.5 on Epop[43]] -> cell 15, seg 0 (0.5) [0.5 on Epop[15]], weight: 4.1363508E-4, delay 1.5
        h("Epop[15] syn_projEE_ampa[3455] = new ampa(0.5)")
        h("Epop[43] netConn_projEE_ampa[3455] = new NetCon(&v(0.5), syn_projEE_ampa[3455], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3456: cell 43, seg 0 (0.5) [0.5 on Epop[43]] -> cell 16, seg 0 (0.5) [0.5 on Epop[16]], weight: 4.1363508E-4, delay 1.5
        h("Epop[16] syn_projEE_ampa[3456] = new ampa(0.5)")
        h("Epop[43] netConn_projEE_ampa[3456] = new NetCon(&v(0.5), syn_projEE_ampa[3456], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3457: cell 43, seg 0 (0.5) [0.5 on Epop[43]] -> cell 17, seg 0 (0.5) [0.5 on Epop[17]], weight: 4.1363508E-4, delay 1.5
        h("Epop[17] syn_projEE_ampa[3457] = new ampa(0.5)")
        h("Epop[43] netConn_projEE_ampa[3457] = new NetCon(&v(0.5), syn_projEE_ampa[3457], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3458: cell 43, seg 0 (0.5) [0.5 on Epop[43]] -> cell 18, seg 0 (0.5) [0.5 on Epop[18]], weight: 4.1363508E-4, delay 1.5
        h("Epop[18] syn_projEE_ampa[3458] = new ampa(0.5)")
        h("Epop[43] netConn_projEE_ampa[3458] = new NetCon(&v(0.5), syn_projEE_ampa[3458], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3459: cell 43, seg 0 (0.5) [0.5 on Epop[43]] -> cell 19, seg 0 (0.5) [0.5 on Epop[19]], weight: 4.1363508E-4, delay 1.5
        h("Epop[19] syn_projEE_ampa[3459] = new ampa(0.5)")
        h("Epop[43] netConn_projEE_ampa[3459] = new NetCon(&v(0.5), syn_projEE_ampa[3459], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3460: cell 43, seg 0 (0.5) [0.5 on Epop[43]] -> cell 20, seg 0 (0.5) [0.5 on Epop[20]], weight: 4.1363508E-4, delay 1.5
        h("Epop[20] syn_projEE_ampa[3460] = new ampa(0.5)")
        h("Epop[43] netConn_projEE_ampa[3460] = new NetCon(&v(0.5), syn_projEE_ampa[3460], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3461: cell 43, seg 0 (0.5) [0.5 on Epop[43]] -> cell 21, seg 0 (0.5) [0.5 on Epop[21]], weight: 4.1363508E-4, delay 1.5
        h("Epop[21] syn_projEE_ampa[3461] = new ampa(0.5)")
        h("Epop[43] netConn_projEE_ampa[3461] = new NetCon(&v(0.5), syn_projEE_ampa[3461], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3462: cell 43, seg 0 (0.5) [0.5 on Epop[43]] -> cell 22, seg 0 (0.5) [0.5 on Epop[22]], weight: 4.1363508E-4, delay 1.5
        h("Epop[22] syn_projEE_ampa[3462] = new ampa(0.5)")
        h("Epop[43] netConn_projEE_ampa[3462] = new NetCon(&v(0.5), syn_projEE_ampa[3462], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3463: cell 43, seg 0 (0.5) [0.5 on Epop[43]] -> cell 23, seg 0 (0.5) [0.5 on Epop[23]], weight: 4.1363508E-4, delay 1.5
        h("Epop[23] syn_projEE_ampa[3463] = new ampa(0.5)")
        h("Epop[43] netConn_projEE_ampa[3463] = new NetCon(&v(0.5), syn_projEE_ampa[3463], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3464: cell 43, seg 0 (0.5) [0.5 on Epop[43]] -> cell 24, seg 0 (0.5) [0.5 on Epop[24]], weight: 4.1363508E-4, delay 1.5
        h("Epop[24] syn_projEE_ampa[3464] = new ampa(0.5)")
        h("Epop[43] netConn_projEE_ampa[3464] = new NetCon(&v(0.5), syn_projEE_ampa[3464], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3465: cell 43, seg 0 (0.5) [0.5 on Epop[43]] -> cell 25, seg 0 (0.5) [0.5 on Epop[25]], weight: 4.1363508E-4, delay 1.5
        h("Epop[25] syn_projEE_ampa[3465] = new ampa(0.5)")
        h("Epop[43] netConn_projEE_ampa[3465] = new NetCon(&v(0.5), syn_projEE_ampa[3465], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3466: cell 43, seg 0 (0.5) [0.5 on Epop[43]] -> cell 26, seg 0 (0.5) [0.5 on Epop[26]], weight: 4.1363508E-4, delay 1.5
        h("Epop[26] syn_projEE_ampa[3466] = new ampa(0.5)")
        h("Epop[43] netConn_projEE_ampa[3466] = new NetCon(&v(0.5), syn_projEE_ampa[3466], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3467: cell 43, seg 0 (0.5) [0.5 on Epop[43]] -> cell 27, seg 0 (0.5) [0.5 on Epop[27]], weight: 4.1363508E-4, delay 1.5
        h("Epop[27] syn_projEE_ampa[3467] = new ampa(0.5)")
        h("Epop[43] netConn_projEE_ampa[3467] = new NetCon(&v(0.5), syn_projEE_ampa[3467], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3468: cell 43, seg 0 (0.5) [0.5 on Epop[43]] -> cell 28, seg 0 (0.5) [0.5 on Epop[28]], weight: 4.1363508E-4, delay 1.5
        h("Epop[28] syn_projEE_ampa[3468] = new ampa(0.5)")
        h("Epop[43] netConn_projEE_ampa[3468] = new NetCon(&v(0.5), syn_projEE_ampa[3468], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3469: cell 43, seg 0 (0.5) [0.5 on Epop[43]] -> cell 29, seg 0 (0.5) [0.5 on Epop[29]], weight: 4.1363508E-4, delay 1.5
        h("Epop[29] syn_projEE_ampa[3469] = new ampa(0.5)")
        h("Epop[43] netConn_projEE_ampa[3469] = new NetCon(&v(0.5), syn_projEE_ampa[3469], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3470: cell 43, seg 0 (0.5) [0.5 on Epop[43]] -> cell 30, seg 0 (0.5) [0.5 on Epop[30]], weight: 4.1363508E-4, delay 1.5
        h("Epop[30] syn_projEE_ampa[3470] = new ampa(0.5)")
        h("Epop[43] netConn_projEE_ampa[3470] = new NetCon(&v(0.5), syn_projEE_ampa[3470], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3471: cell 43, seg 0 (0.5) [0.5 on Epop[43]] -> cell 31, seg 0 (0.5) [0.5 on Epop[31]], weight: 4.1363508E-4, delay 1.5
        h("Epop[31] syn_projEE_ampa[3471] = new ampa(0.5)")
        h("Epop[43] netConn_projEE_ampa[3471] = new NetCon(&v(0.5), syn_projEE_ampa[3471], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3472: cell 43, seg 0 (0.5) [0.5 on Epop[43]] -> cell 32, seg 0 (0.5) [0.5 on Epop[32]], weight: 4.1363508E-4, delay 1.5
        h("Epop[32] syn_projEE_ampa[3472] = new ampa(0.5)")
        h("Epop[43] netConn_projEE_ampa[3472] = new NetCon(&v(0.5), syn_projEE_ampa[3472], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3473: cell 43, seg 0 (0.5) [0.5 on Epop[43]] -> cell 33, seg 0 (0.5) [0.5 on Epop[33]], weight: 4.1363508E-4, delay 1.5
        h("Epop[33] syn_projEE_ampa[3473] = new ampa(0.5)")
        h("Epop[43] netConn_projEE_ampa[3473] = new NetCon(&v(0.5), syn_projEE_ampa[3473], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3474: cell 43, seg 0 (0.5) [0.5 on Epop[43]] -> cell 34, seg 0 (0.5) [0.5 on Epop[34]], weight: 4.1363508E-4, delay 1.5
        h("Epop[34] syn_projEE_ampa[3474] = new ampa(0.5)")
        h("Epop[43] netConn_projEE_ampa[3474] = new NetCon(&v(0.5), syn_projEE_ampa[3474], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3475: cell 43, seg 0 (0.5) [0.5 on Epop[43]] -> cell 35, seg 0 (0.5) [0.5 on Epop[35]], weight: 4.1363508E-4, delay 1.5
        h("Epop[35] syn_projEE_ampa[3475] = new ampa(0.5)")
        h("Epop[43] netConn_projEE_ampa[3475] = new NetCon(&v(0.5), syn_projEE_ampa[3475], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3476: cell 43, seg 0 (0.5) [0.5 on Epop[43]] -> cell 36, seg 0 (0.5) [0.5 on Epop[36]], weight: 4.1363508E-4, delay 1.5
        h("Epop[36] syn_projEE_ampa[3476] = new ampa(0.5)")
        h("Epop[43] netConn_projEE_ampa[3476] = new NetCon(&v(0.5), syn_projEE_ampa[3476], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3477: cell 43, seg 0 (0.5) [0.5 on Epop[43]] -> cell 37, seg 0 (0.5) [0.5 on Epop[37]], weight: 4.1363508E-4, delay 1.5
        h("Epop[37] syn_projEE_ampa[3477] = new ampa(0.5)")
        h("Epop[43] netConn_projEE_ampa[3477] = new NetCon(&v(0.5), syn_projEE_ampa[3477], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3478: cell 43, seg 0 (0.5) [0.5 on Epop[43]] -> cell 38, seg 0 (0.5) [0.5 on Epop[38]], weight: 4.1363508E-4, delay 1.5
        h("Epop[38] syn_projEE_ampa[3478] = new ampa(0.5)")
        h("Epop[43] netConn_projEE_ampa[3478] = new NetCon(&v(0.5), syn_projEE_ampa[3478], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3479: cell 43, seg 0 (0.5) [0.5 on Epop[43]] -> cell 39, seg 0 (0.5) [0.5 on Epop[39]], weight: 4.1363508E-4, delay 1.5
        h("Epop[39] syn_projEE_ampa[3479] = new ampa(0.5)")
        h("Epop[43] netConn_projEE_ampa[3479] = new NetCon(&v(0.5), syn_projEE_ampa[3479], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3480: cell 43, seg 0 (0.5) [0.5 on Epop[43]] -> cell 40, seg 0 (0.5) [0.5 on Epop[40]], weight: 4.1363508E-4, delay 1.5
        h("Epop[40] syn_projEE_ampa[3480] = new ampa(0.5)")
        h("Epop[43] netConn_projEE_ampa[3480] = new NetCon(&v(0.5), syn_projEE_ampa[3480], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3481: cell 43, seg 0 (0.5) [0.5 on Epop[43]] -> cell 41, seg 0 (0.5) [0.5 on Epop[41]], weight: 4.1363508E-4, delay 1.5
        h("Epop[41] syn_projEE_ampa[3481] = new ampa(0.5)")
        h("Epop[43] netConn_projEE_ampa[3481] = new NetCon(&v(0.5), syn_projEE_ampa[3481], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3482: cell 43, seg 0 (0.5) [0.5 on Epop[43]] -> cell 42, seg 0 (0.5) [0.5 on Epop[42]], weight: 4.1363508E-4, delay 1.5
        h("Epop[42] syn_projEE_ampa[3482] = new ampa(0.5)")
        h("Epop[43] netConn_projEE_ampa[3482] = new NetCon(&v(0.5), syn_projEE_ampa[3482], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3483: cell 43, seg 0 (0.5) [0.5 on Epop[43]] -> cell 43, seg 0 (0.5) [0.5 on Epop[43]], weight: 4.1363508E-4, delay 1.5
        h("Epop[43] syn_projEE_ampa[3483] = new ampa(0.5)")
        h("Epop[43] netConn_projEE_ampa[3483] = new NetCon(&v(0.5), syn_projEE_ampa[3483], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3484: cell 43, seg 0 (0.5) [0.5 on Epop[43]] -> cell 44, seg 0 (0.5) [0.5 on Epop[44]], weight: 4.1363508E-4, delay 1.5
        h("Epop[44] syn_projEE_ampa[3484] = new ampa(0.5)")
        h("Epop[43] netConn_projEE_ampa[3484] = new NetCon(&v(0.5), syn_projEE_ampa[3484], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3485: cell 43, seg 0 (0.5) [0.5 on Epop[43]] -> cell 45, seg 0 (0.5) [0.5 on Epop[45]], weight: 4.1363508E-4, delay 1.5
        h("Epop[45] syn_projEE_ampa[3485] = new ampa(0.5)")
        h("Epop[43] netConn_projEE_ampa[3485] = new NetCon(&v(0.5), syn_projEE_ampa[3485], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3486: cell 43, seg 0 (0.5) [0.5 on Epop[43]] -> cell 46, seg 0 (0.5) [0.5 on Epop[46]], weight: 4.1363508E-4, delay 1.5
        h("Epop[46] syn_projEE_ampa[3486] = new ampa(0.5)")
        h("Epop[43] netConn_projEE_ampa[3486] = new NetCon(&v(0.5), syn_projEE_ampa[3486], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3487: cell 43, seg 0 (0.5) [0.5 on Epop[43]] -> cell 47, seg 0 (0.5) [0.5 on Epop[47]], weight: 4.1363508E-4, delay 1.5
        h("Epop[47] syn_projEE_ampa[3487] = new ampa(0.5)")
        h("Epop[43] netConn_projEE_ampa[3487] = new NetCon(&v(0.5), syn_projEE_ampa[3487], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3488: cell 43, seg 0 (0.5) [0.5 on Epop[43]] -> cell 48, seg 0 (0.5) [0.5 on Epop[48]], weight: 4.1363508E-4, delay 1.5
        h("Epop[48] syn_projEE_ampa[3488] = new ampa(0.5)")
        h("Epop[43] netConn_projEE_ampa[3488] = new NetCon(&v(0.5), syn_projEE_ampa[3488], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3489: cell 43, seg 0 (0.5) [0.5 on Epop[43]] -> cell 49, seg 0 (0.5) [0.5 on Epop[49]], weight: 4.1363508E-4, delay 1.5
        h("Epop[49] syn_projEE_ampa[3489] = new ampa(0.5)")
        h("Epop[43] netConn_projEE_ampa[3489] = new NetCon(&v(0.5), syn_projEE_ampa[3489], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3490: cell 43, seg 0 (0.5) [0.5 on Epop[43]] -> cell 50, seg 0 (0.5) [0.5 on Epop[50]], weight: 4.1363508E-4, delay 1.5
        h("Epop[50] syn_projEE_ampa[3490] = new ampa(0.5)")
        h("Epop[43] netConn_projEE_ampa[3490] = new NetCon(&v(0.5), syn_projEE_ampa[3490], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3491: cell 43, seg 0 (0.5) [0.5 on Epop[43]] -> cell 51, seg 0 (0.5) [0.5 on Epop[51]], weight: 4.1363508E-4, delay 1.5
        h("Epop[51] syn_projEE_ampa[3491] = new ampa(0.5)")
        h("Epop[43] netConn_projEE_ampa[3491] = new NetCon(&v(0.5), syn_projEE_ampa[3491], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3492: cell 43, seg 0 (0.5) [0.5 on Epop[43]] -> cell 52, seg 0 (0.5) [0.5 on Epop[52]], weight: 4.1363508E-4, delay 1.5
        h("Epop[52] syn_projEE_ampa[3492] = new ampa(0.5)")
        h("Epop[43] netConn_projEE_ampa[3492] = new NetCon(&v(0.5), syn_projEE_ampa[3492], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3493: cell 43, seg 0 (0.5) [0.5 on Epop[43]] -> cell 53, seg 0 (0.5) [0.5 on Epop[53]], weight: 4.1363508E-4, delay 1.5
        h("Epop[53] syn_projEE_ampa[3493] = new ampa(0.5)")
        h("Epop[43] netConn_projEE_ampa[3493] = new NetCon(&v(0.5), syn_projEE_ampa[3493], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3494: cell 43, seg 0 (0.5) [0.5 on Epop[43]] -> cell 54, seg 0 (0.5) [0.5 on Epop[54]], weight: 4.1363508E-4, delay 1.5
        h("Epop[54] syn_projEE_ampa[3494] = new ampa(0.5)")
        h("Epop[43] netConn_projEE_ampa[3494] = new NetCon(&v(0.5), syn_projEE_ampa[3494], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3495: cell 43, seg 0 (0.5) [0.5 on Epop[43]] -> cell 55, seg 0 (0.5) [0.5 on Epop[55]], weight: 4.1363508E-4, delay 1.5
        h("Epop[55] syn_projEE_ampa[3495] = new ampa(0.5)")
        h("Epop[43] netConn_projEE_ampa[3495] = new NetCon(&v(0.5), syn_projEE_ampa[3495], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3496: cell 43, seg 0 (0.5) [0.5 on Epop[43]] -> cell 56, seg 0 (0.5) [0.5 on Epop[56]], weight: 4.1363508E-4, delay 1.5
        h("Epop[56] syn_projEE_ampa[3496] = new ampa(0.5)")
        h("Epop[43] netConn_projEE_ampa[3496] = new NetCon(&v(0.5), syn_projEE_ampa[3496], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3497: cell 43, seg 0 (0.5) [0.5 on Epop[43]] -> cell 57, seg 0 (0.5) [0.5 on Epop[57]], weight: 4.1363508E-4, delay 1.5
        h("Epop[57] syn_projEE_ampa[3497] = new ampa(0.5)")
        h("Epop[43] netConn_projEE_ampa[3497] = new NetCon(&v(0.5), syn_projEE_ampa[3497], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3498: cell 43, seg 0 (0.5) [0.5 on Epop[43]] -> cell 58, seg 0 (0.5) [0.5 on Epop[58]], weight: 4.1363508E-4, delay 1.5
        h("Epop[58] syn_projEE_ampa[3498] = new ampa(0.5)")
        h("Epop[43] netConn_projEE_ampa[3498] = new NetCon(&v(0.5), syn_projEE_ampa[3498], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3499: cell 43, seg 0 (0.5) [0.5 on Epop[43]] -> cell 59, seg 0 (0.5) [0.5 on Epop[59]], weight: 4.1363508E-4, delay 1.5
        h("Epop[59] syn_projEE_ampa[3499] = new ampa(0.5)")
        h("Epop[43] netConn_projEE_ampa[3499] = new NetCon(&v(0.5), syn_projEE_ampa[3499], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3500: cell 43, seg 0 (0.5) [0.5 on Epop[43]] -> cell 60, seg 0 (0.5) [0.5 on Epop[60]], weight: 4.1363508E-4, delay 1.5
        h("Epop[60] syn_projEE_ampa[3500] = new ampa(0.5)")
        h("Epop[43] netConn_projEE_ampa[3500] = new NetCon(&v(0.5), syn_projEE_ampa[3500], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3501: cell 43, seg 0 (0.5) [0.5 on Epop[43]] -> cell 61, seg 0 (0.5) [0.5 on Epop[61]], weight: 4.1363508E-4, delay 1.5
        h("Epop[61] syn_projEE_ampa[3501] = new ampa(0.5)")
        h("Epop[43] netConn_projEE_ampa[3501] = new NetCon(&v(0.5), syn_projEE_ampa[3501], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3502: cell 43, seg 0 (0.5) [0.5 on Epop[43]] -> cell 62, seg 0 (0.5) [0.5 on Epop[62]], weight: 4.1363508E-4, delay 1.5
        h("Epop[62] syn_projEE_ampa[3502] = new ampa(0.5)")
        h("Epop[43] netConn_projEE_ampa[3502] = new NetCon(&v(0.5), syn_projEE_ampa[3502], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3503: cell 43, seg 0 (0.5) [0.5 on Epop[43]] -> cell 63, seg 0 (0.5) [0.5 on Epop[63]], weight: 4.1363508E-4, delay 1.5
        h("Epop[63] syn_projEE_ampa[3503] = new ampa(0.5)")
        h("Epop[43] netConn_projEE_ampa[3503] = new NetCon(&v(0.5), syn_projEE_ampa[3503], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3504: cell 43, seg 0 (0.5) [0.5 on Epop[43]] -> cell 64, seg 0 (0.5) [0.5 on Epop[64]], weight: 4.1363508E-4, delay 1.5
        h("Epop[64] syn_projEE_ampa[3504] = new ampa(0.5)")
        h("Epop[43] netConn_projEE_ampa[3504] = new NetCon(&v(0.5), syn_projEE_ampa[3504], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3505: cell 43, seg 0 (0.5) [0.5 on Epop[43]] -> cell 65, seg 0 (0.5) [0.5 on Epop[65]], weight: 4.1363508E-4, delay 1.5
        h("Epop[65] syn_projEE_ampa[3505] = new ampa(0.5)")
        h("Epop[43] netConn_projEE_ampa[3505] = new NetCon(&v(0.5), syn_projEE_ampa[3505], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3506: cell 43, seg 0 (0.5) [0.5 on Epop[43]] -> cell 66, seg 0 (0.5) [0.5 on Epop[66]], weight: 4.1363508E-4, delay 1.5
        h("Epop[66] syn_projEE_ampa[3506] = new ampa(0.5)")
        h("Epop[43] netConn_projEE_ampa[3506] = new NetCon(&v(0.5), syn_projEE_ampa[3506], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3507: cell 43, seg 0 (0.5) [0.5 on Epop[43]] -> cell 67, seg 0 (0.5) [0.5 on Epop[67]], weight: 4.1363508E-4, delay 1.5
        h("Epop[67] syn_projEE_ampa[3507] = new ampa(0.5)")
        h("Epop[43] netConn_projEE_ampa[3507] = new NetCon(&v(0.5), syn_projEE_ampa[3507], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3508: cell 43, seg 0 (0.5) [0.5 on Epop[43]] -> cell 68, seg 0 (0.5) [0.5 on Epop[68]], weight: 4.1363508E-4, delay 1.5
        h("Epop[68] syn_projEE_ampa[3508] = new ampa(0.5)")
        h("Epop[43] netConn_projEE_ampa[3508] = new NetCon(&v(0.5), syn_projEE_ampa[3508], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3509: cell 43, seg 0 (0.5) [0.5 on Epop[43]] -> cell 69, seg 0 (0.5) [0.5 on Epop[69]], weight: 4.1363508E-4, delay 1.5
        h("Epop[69] syn_projEE_ampa[3509] = new ampa(0.5)")
        h("Epop[43] netConn_projEE_ampa[3509] = new NetCon(&v(0.5), syn_projEE_ampa[3509], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3510: cell 43, seg 0 (0.5) [0.5 on Epop[43]] -> cell 70, seg 0 (0.5) [0.5 on Epop[70]], weight: 4.1363508E-4, delay 1.5
        h("Epop[70] syn_projEE_ampa[3510] = new ampa(0.5)")
        h("Epop[43] netConn_projEE_ampa[3510] = new NetCon(&v(0.5), syn_projEE_ampa[3510], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3511: cell 43, seg 0 (0.5) [0.5 on Epop[43]] -> cell 71, seg 0 (0.5) [0.5 on Epop[71]], weight: 4.1363508E-4, delay 1.5
        h("Epop[71] syn_projEE_ampa[3511] = new ampa(0.5)")
        h("Epop[43] netConn_projEE_ampa[3511] = new NetCon(&v(0.5), syn_projEE_ampa[3511], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3512: cell 43, seg 0 (0.5) [0.5 on Epop[43]] -> cell 72, seg 0 (0.5) [0.5 on Epop[72]], weight: 4.1363508E-4, delay 1.5
        h("Epop[72] syn_projEE_ampa[3512] = new ampa(0.5)")
        h("Epop[43] netConn_projEE_ampa[3512] = new NetCon(&v(0.5), syn_projEE_ampa[3512], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3513: cell 43, seg 0 (0.5) [0.5 on Epop[43]] -> cell 73, seg 0 (0.5) [0.5 on Epop[73]], weight: 4.1363508E-4, delay 1.5
        h("Epop[73] syn_projEE_ampa[3513] = new ampa(0.5)")
        h("Epop[43] netConn_projEE_ampa[3513] = new NetCon(&v(0.5), syn_projEE_ampa[3513], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3514: cell 43, seg 0 (0.5) [0.5 on Epop[43]] -> cell 74, seg 0 (0.5) [0.5 on Epop[74]], weight: 4.1363508E-4, delay 1.5
        h("Epop[74] syn_projEE_ampa[3514] = new ampa(0.5)")
        h("Epop[43] netConn_projEE_ampa[3514] = new NetCon(&v(0.5), syn_projEE_ampa[3514], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3515: cell 43, seg 0 (0.5) [0.5 on Epop[43]] -> cell 75, seg 0 (0.5) [0.5 on Epop[75]], weight: 4.1363508E-4, delay 1.5
        h("Epop[75] syn_projEE_ampa[3515] = new ampa(0.5)")
        h("Epop[43] netConn_projEE_ampa[3515] = new NetCon(&v(0.5), syn_projEE_ampa[3515], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3516: cell 43, seg 0 (0.5) [0.5 on Epop[43]] -> cell 76, seg 0 (0.5) [0.5 on Epop[76]], weight: 4.1363508E-4, delay 1.5
        h("Epop[76] syn_projEE_ampa[3516] = new ampa(0.5)")
        h("Epop[43] netConn_projEE_ampa[3516] = new NetCon(&v(0.5), syn_projEE_ampa[3516], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3517: cell 43, seg 0 (0.5) [0.5 on Epop[43]] -> cell 77, seg 0 (0.5) [0.5 on Epop[77]], weight: 4.1363508E-4, delay 1.5
        h("Epop[77] syn_projEE_ampa[3517] = new ampa(0.5)")
        h("Epop[43] netConn_projEE_ampa[3517] = new NetCon(&v(0.5), syn_projEE_ampa[3517], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3518: cell 43, seg 0 (0.5) [0.5 on Epop[43]] -> cell 78, seg 0 (0.5) [0.5 on Epop[78]], weight: 4.1363508E-4, delay 1.5
        h("Epop[78] syn_projEE_ampa[3518] = new ampa(0.5)")
        h("Epop[43] netConn_projEE_ampa[3518] = new NetCon(&v(0.5), syn_projEE_ampa[3518], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3519: cell 43, seg 0 (0.5) [0.5 on Epop[43]] -> cell 79, seg 0 (0.5) [0.5 on Epop[79]], weight: 4.1363508E-4, delay 1.5
        h("Epop[79] syn_projEE_ampa[3519] = new ampa(0.5)")
        h("Epop[43] netConn_projEE_ampa[3519] = new NetCon(&v(0.5), syn_projEE_ampa[3519], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3520: cell 44, seg 0 (0.5) [0.5 on Epop[44]] -> cell 0, seg 0 (0.5) [0.5 on Epop[0]], weight: 4.1363508E-4, delay 1.5
        h("Epop[0] syn_projEE_ampa[3520] = new ampa(0.5)")
        h("Epop[44] netConn_projEE_ampa[3520] = new NetCon(&v(0.5), syn_projEE_ampa[3520], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3521: cell 44, seg 0 (0.5) [0.5 on Epop[44]] -> cell 1, seg 0 (0.5) [0.5 on Epop[1]], weight: 4.1363508E-4, delay 1.5
        h("Epop[1] syn_projEE_ampa[3521] = new ampa(0.5)")
        h("Epop[44] netConn_projEE_ampa[3521] = new NetCon(&v(0.5), syn_projEE_ampa[3521], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3522: cell 44, seg 0 (0.5) [0.5 on Epop[44]] -> cell 2, seg 0 (0.5) [0.5 on Epop[2]], weight: 4.1363508E-4, delay 1.5
        h("Epop[2] syn_projEE_ampa[3522] = new ampa(0.5)")
        h("Epop[44] netConn_projEE_ampa[3522] = new NetCon(&v(0.5), syn_projEE_ampa[3522], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3523: cell 44, seg 0 (0.5) [0.5 on Epop[44]] -> cell 3, seg 0 (0.5) [0.5 on Epop[3]], weight: 4.1363508E-4, delay 1.5
        h("Epop[3] syn_projEE_ampa[3523] = new ampa(0.5)")
        h("Epop[44] netConn_projEE_ampa[3523] = new NetCon(&v(0.5), syn_projEE_ampa[3523], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3524: cell 44, seg 0 (0.5) [0.5 on Epop[44]] -> cell 4, seg 0 (0.5) [0.5 on Epop[4]], weight: 4.1363508E-4, delay 1.5
        h("Epop[4] syn_projEE_ampa[3524] = new ampa(0.5)")
        h("Epop[44] netConn_projEE_ampa[3524] = new NetCon(&v(0.5), syn_projEE_ampa[3524], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3525: cell 44, seg 0 (0.5) [0.5 on Epop[44]] -> cell 5, seg 0 (0.5) [0.5 on Epop[5]], weight: 4.1363508E-4, delay 1.5
        h("Epop[5] syn_projEE_ampa[3525] = new ampa(0.5)")
        h("Epop[44] netConn_projEE_ampa[3525] = new NetCon(&v(0.5), syn_projEE_ampa[3525], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3526: cell 44, seg 0 (0.5) [0.5 on Epop[44]] -> cell 6, seg 0 (0.5) [0.5 on Epop[6]], weight: 4.1363508E-4, delay 1.5
        h("Epop[6] syn_projEE_ampa[3526] = new ampa(0.5)")
        h("Epop[44] netConn_projEE_ampa[3526] = new NetCon(&v(0.5), syn_projEE_ampa[3526], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3527: cell 44, seg 0 (0.5) [0.5 on Epop[44]] -> cell 7, seg 0 (0.5) [0.5 on Epop[7]], weight: 4.1363508E-4, delay 1.5
        h("Epop[7] syn_projEE_ampa[3527] = new ampa(0.5)")
        h("Epop[44] netConn_projEE_ampa[3527] = new NetCon(&v(0.5), syn_projEE_ampa[3527], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3528: cell 44, seg 0 (0.5) [0.5 on Epop[44]] -> cell 8, seg 0 (0.5) [0.5 on Epop[8]], weight: 4.1363508E-4, delay 1.5
        h("Epop[8] syn_projEE_ampa[3528] = new ampa(0.5)")
        h("Epop[44] netConn_projEE_ampa[3528] = new NetCon(&v(0.5), syn_projEE_ampa[3528], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3529: cell 44, seg 0 (0.5) [0.5 on Epop[44]] -> cell 9, seg 0 (0.5) [0.5 on Epop[9]], weight: 4.1363508E-4, delay 1.5
        h("Epop[9] syn_projEE_ampa[3529] = new ampa(0.5)")
        h("Epop[44] netConn_projEE_ampa[3529] = new NetCon(&v(0.5), syn_projEE_ampa[3529], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3530: cell 44, seg 0 (0.5) [0.5 on Epop[44]] -> cell 10, seg 0 (0.5) [0.5 on Epop[10]], weight: 4.1363508E-4, delay 1.5
        h("Epop[10] syn_projEE_ampa[3530] = new ampa(0.5)")
        h("Epop[44] netConn_projEE_ampa[3530] = new NetCon(&v(0.5), syn_projEE_ampa[3530], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3531: cell 44, seg 0 (0.5) [0.5 on Epop[44]] -> cell 11, seg 0 (0.5) [0.5 on Epop[11]], weight: 4.1363508E-4, delay 1.5
        h("Epop[11] syn_projEE_ampa[3531] = new ampa(0.5)")
        h("Epop[44] netConn_projEE_ampa[3531] = new NetCon(&v(0.5), syn_projEE_ampa[3531], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3532: cell 44, seg 0 (0.5) [0.5 on Epop[44]] -> cell 12, seg 0 (0.5) [0.5 on Epop[12]], weight: 4.1363508E-4, delay 1.5
        h("Epop[12] syn_projEE_ampa[3532] = new ampa(0.5)")
        h("Epop[44] netConn_projEE_ampa[3532] = new NetCon(&v(0.5), syn_projEE_ampa[3532], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3533: cell 44, seg 0 (0.5) [0.5 on Epop[44]] -> cell 13, seg 0 (0.5) [0.5 on Epop[13]], weight: 4.1363508E-4, delay 1.5
        h("Epop[13] syn_projEE_ampa[3533] = new ampa(0.5)")
        h("Epop[44] netConn_projEE_ampa[3533] = new NetCon(&v(0.5), syn_projEE_ampa[3533], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3534: cell 44, seg 0 (0.5) [0.5 on Epop[44]] -> cell 14, seg 0 (0.5) [0.5 on Epop[14]], weight: 4.1363508E-4, delay 1.5
        h("Epop[14] syn_projEE_ampa[3534] = new ampa(0.5)")
        h("Epop[44] netConn_projEE_ampa[3534] = new NetCon(&v(0.5), syn_projEE_ampa[3534], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3535: cell 44, seg 0 (0.5) [0.5 on Epop[44]] -> cell 15, seg 0 (0.5) [0.5 on Epop[15]], weight: 4.1363508E-4, delay 1.5
        h("Epop[15] syn_projEE_ampa[3535] = new ampa(0.5)")
        h("Epop[44] netConn_projEE_ampa[3535] = new NetCon(&v(0.5), syn_projEE_ampa[3535], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3536: cell 44, seg 0 (0.5) [0.5 on Epop[44]] -> cell 16, seg 0 (0.5) [0.5 on Epop[16]], weight: 4.1363508E-4, delay 1.5
        h("Epop[16] syn_projEE_ampa[3536] = new ampa(0.5)")
        h("Epop[44] netConn_projEE_ampa[3536] = new NetCon(&v(0.5), syn_projEE_ampa[3536], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3537: cell 44, seg 0 (0.5) [0.5 on Epop[44]] -> cell 17, seg 0 (0.5) [0.5 on Epop[17]], weight: 4.1363508E-4, delay 1.5
        h("Epop[17] syn_projEE_ampa[3537] = new ampa(0.5)")
        h("Epop[44] netConn_projEE_ampa[3537] = new NetCon(&v(0.5), syn_projEE_ampa[3537], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3538: cell 44, seg 0 (0.5) [0.5 on Epop[44]] -> cell 18, seg 0 (0.5) [0.5 on Epop[18]], weight: 4.1363508E-4, delay 1.5
        h("Epop[18] syn_projEE_ampa[3538] = new ampa(0.5)")
        h("Epop[44] netConn_projEE_ampa[3538] = new NetCon(&v(0.5), syn_projEE_ampa[3538], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3539: cell 44, seg 0 (0.5) [0.5 on Epop[44]] -> cell 19, seg 0 (0.5) [0.5 on Epop[19]], weight: 4.1363508E-4, delay 1.5
        h("Epop[19] syn_projEE_ampa[3539] = new ampa(0.5)")
        h("Epop[44] netConn_projEE_ampa[3539] = new NetCon(&v(0.5), syn_projEE_ampa[3539], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3540: cell 44, seg 0 (0.5) [0.5 on Epop[44]] -> cell 20, seg 0 (0.5) [0.5 on Epop[20]], weight: 4.1363508E-4, delay 1.5
        h("Epop[20] syn_projEE_ampa[3540] = new ampa(0.5)")
        h("Epop[44] netConn_projEE_ampa[3540] = new NetCon(&v(0.5), syn_projEE_ampa[3540], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3541: cell 44, seg 0 (0.5) [0.5 on Epop[44]] -> cell 21, seg 0 (0.5) [0.5 on Epop[21]], weight: 4.1363508E-4, delay 1.5
        h("Epop[21] syn_projEE_ampa[3541] = new ampa(0.5)")
        h("Epop[44] netConn_projEE_ampa[3541] = new NetCon(&v(0.5), syn_projEE_ampa[3541], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3542: cell 44, seg 0 (0.5) [0.5 on Epop[44]] -> cell 22, seg 0 (0.5) [0.5 on Epop[22]], weight: 4.1363508E-4, delay 1.5
        h("Epop[22] syn_projEE_ampa[3542] = new ampa(0.5)")
        h("Epop[44] netConn_projEE_ampa[3542] = new NetCon(&v(0.5), syn_projEE_ampa[3542], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3543: cell 44, seg 0 (0.5) [0.5 on Epop[44]] -> cell 23, seg 0 (0.5) [0.5 on Epop[23]], weight: 4.1363508E-4, delay 1.5
        h("Epop[23] syn_projEE_ampa[3543] = new ampa(0.5)")
        h("Epop[44] netConn_projEE_ampa[3543] = new NetCon(&v(0.5), syn_projEE_ampa[3543], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3544: cell 44, seg 0 (0.5) [0.5 on Epop[44]] -> cell 24, seg 0 (0.5) [0.5 on Epop[24]], weight: 4.1363508E-4, delay 1.5
        h("Epop[24] syn_projEE_ampa[3544] = new ampa(0.5)")
        h("Epop[44] netConn_projEE_ampa[3544] = new NetCon(&v(0.5), syn_projEE_ampa[3544], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3545: cell 44, seg 0 (0.5) [0.5 on Epop[44]] -> cell 25, seg 0 (0.5) [0.5 on Epop[25]], weight: 4.1363508E-4, delay 1.5
        h("Epop[25] syn_projEE_ampa[3545] = new ampa(0.5)")
        h("Epop[44] netConn_projEE_ampa[3545] = new NetCon(&v(0.5), syn_projEE_ampa[3545], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3546: cell 44, seg 0 (0.5) [0.5 on Epop[44]] -> cell 26, seg 0 (0.5) [0.5 on Epop[26]], weight: 4.1363508E-4, delay 1.5
        h("Epop[26] syn_projEE_ampa[3546] = new ampa(0.5)")
        h("Epop[44] netConn_projEE_ampa[3546] = new NetCon(&v(0.5), syn_projEE_ampa[3546], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3547: cell 44, seg 0 (0.5) [0.5 on Epop[44]] -> cell 27, seg 0 (0.5) [0.5 on Epop[27]], weight: 4.1363508E-4, delay 1.5
        h("Epop[27] syn_projEE_ampa[3547] = new ampa(0.5)")
        h("Epop[44] netConn_projEE_ampa[3547] = new NetCon(&v(0.5), syn_projEE_ampa[3547], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3548: cell 44, seg 0 (0.5) [0.5 on Epop[44]] -> cell 28, seg 0 (0.5) [0.5 on Epop[28]], weight: 4.1363508E-4, delay 1.5
        h("Epop[28] syn_projEE_ampa[3548] = new ampa(0.5)")
        h("Epop[44] netConn_projEE_ampa[3548] = new NetCon(&v(0.5), syn_projEE_ampa[3548], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3549: cell 44, seg 0 (0.5) [0.5 on Epop[44]] -> cell 29, seg 0 (0.5) [0.5 on Epop[29]], weight: 4.1363508E-4, delay 1.5
        h("Epop[29] syn_projEE_ampa[3549] = new ampa(0.5)")
        h("Epop[44] netConn_projEE_ampa[3549] = new NetCon(&v(0.5), syn_projEE_ampa[3549], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3550: cell 44, seg 0 (0.5) [0.5 on Epop[44]] -> cell 30, seg 0 (0.5) [0.5 on Epop[30]], weight: 4.1363508E-4, delay 1.5
        h("Epop[30] syn_projEE_ampa[3550] = new ampa(0.5)")
        h("Epop[44] netConn_projEE_ampa[3550] = new NetCon(&v(0.5), syn_projEE_ampa[3550], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3551: cell 44, seg 0 (0.5) [0.5 on Epop[44]] -> cell 31, seg 0 (0.5) [0.5 on Epop[31]], weight: 4.1363508E-4, delay 1.5
        h("Epop[31] syn_projEE_ampa[3551] = new ampa(0.5)")
        h("Epop[44] netConn_projEE_ampa[3551] = new NetCon(&v(0.5), syn_projEE_ampa[3551], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3552: cell 44, seg 0 (0.5) [0.5 on Epop[44]] -> cell 32, seg 0 (0.5) [0.5 on Epop[32]], weight: 4.1363508E-4, delay 1.5
        h("Epop[32] syn_projEE_ampa[3552] = new ampa(0.5)")
        h("Epop[44] netConn_projEE_ampa[3552] = new NetCon(&v(0.5), syn_projEE_ampa[3552], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3553: cell 44, seg 0 (0.5) [0.5 on Epop[44]] -> cell 33, seg 0 (0.5) [0.5 on Epop[33]], weight: 4.1363508E-4, delay 1.5
        h("Epop[33] syn_projEE_ampa[3553] = new ampa(0.5)")
        h("Epop[44] netConn_projEE_ampa[3553] = new NetCon(&v(0.5), syn_projEE_ampa[3553], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3554: cell 44, seg 0 (0.5) [0.5 on Epop[44]] -> cell 34, seg 0 (0.5) [0.5 on Epop[34]], weight: 4.1363508E-4, delay 1.5
        h("Epop[34] syn_projEE_ampa[3554] = new ampa(0.5)")
        h("Epop[44] netConn_projEE_ampa[3554] = new NetCon(&v(0.5), syn_projEE_ampa[3554], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3555: cell 44, seg 0 (0.5) [0.5 on Epop[44]] -> cell 35, seg 0 (0.5) [0.5 on Epop[35]], weight: 4.1363508E-4, delay 1.5
        h("Epop[35] syn_projEE_ampa[3555] = new ampa(0.5)")
        h("Epop[44] netConn_projEE_ampa[3555] = new NetCon(&v(0.5), syn_projEE_ampa[3555], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3556: cell 44, seg 0 (0.5) [0.5 on Epop[44]] -> cell 36, seg 0 (0.5) [0.5 on Epop[36]], weight: 4.1363508E-4, delay 1.5
        h("Epop[36] syn_projEE_ampa[3556] = new ampa(0.5)")
        h("Epop[44] netConn_projEE_ampa[3556] = new NetCon(&v(0.5), syn_projEE_ampa[3556], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3557: cell 44, seg 0 (0.5) [0.5 on Epop[44]] -> cell 37, seg 0 (0.5) [0.5 on Epop[37]], weight: 4.1363508E-4, delay 1.5
        h("Epop[37] syn_projEE_ampa[3557] = new ampa(0.5)")
        h("Epop[44] netConn_projEE_ampa[3557] = new NetCon(&v(0.5), syn_projEE_ampa[3557], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3558: cell 44, seg 0 (0.5) [0.5 on Epop[44]] -> cell 38, seg 0 (0.5) [0.5 on Epop[38]], weight: 4.1363508E-4, delay 1.5
        h("Epop[38] syn_projEE_ampa[3558] = new ampa(0.5)")
        h("Epop[44] netConn_projEE_ampa[3558] = new NetCon(&v(0.5), syn_projEE_ampa[3558], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3559: cell 44, seg 0 (0.5) [0.5 on Epop[44]] -> cell 39, seg 0 (0.5) [0.5 on Epop[39]], weight: 4.1363508E-4, delay 1.5
        h("Epop[39] syn_projEE_ampa[3559] = new ampa(0.5)")
        h("Epop[44] netConn_projEE_ampa[3559] = new NetCon(&v(0.5), syn_projEE_ampa[3559], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3560: cell 44, seg 0 (0.5) [0.5 on Epop[44]] -> cell 40, seg 0 (0.5) [0.5 on Epop[40]], weight: 4.1363508E-4, delay 1.5
        h("Epop[40] syn_projEE_ampa[3560] = new ampa(0.5)")
        h("Epop[44] netConn_projEE_ampa[3560] = new NetCon(&v(0.5), syn_projEE_ampa[3560], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3561: cell 44, seg 0 (0.5) [0.5 on Epop[44]] -> cell 41, seg 0 (0.5) [0.5 on Epop[41]], weight: 4.1363508E-4, delay 1.5
        h("Epop[41] syn_projEE_ampa[3561] = new ampa(0.5)")
        h("Epop[44] netConn_projEE_ampa[3561] = new NetCon(&v(0.5), syn_projEE_ampa[3561], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3562: cell 44, seg 0 (0.5) [0.5 on Epop[44]] -> cell 42, seg 0 (0.5) [0.5 on Epop[42]], weight: 4.1363508E-4, delay 1.5
        h("Epop[42] syn_projEE_ampa[3562] = new ampa(0.5)")
        h("Epop[44] netConn_projEE_ampa[3562] = new NetCon(&v(0.5), syn_projEE_ampa[3562], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3563: cell 44, seg 0 (0.5) [0.5 on Epop[44]] -> cell 43, seg 0 (0.5) [0.5 on Epop[43]], weight: 4.1363508E-4, delay 1.5
        h("Epop[43] syn_projEE_ampa[3563] = new ampa(0.5)")
        h("Epop[44] netConn_projEE_ampa[3563] = new NetCon(&v(0.5), syn_projEE_ampa[3563], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3564: cell 44, seg 0 (0.5) [0.5 on Epop[44]] -> cell 44, seg 0 (0.5) [0.5 on Epop[44]], weight: 4.1363508E-4, delay 1.5
        h("Epop[44] syn_projEE_ampa[3564] = new ampa(0.5)")
        h("Epop[44] netConn_projEE_ampa[3564] = new NetCon(&v(0.5), syn_projEE_ampa[3564], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3565: cell 44, seg 0 (0.5) [0.5 on Epop[44]] -> cell 45, seg 0 (0.5) [0.5 on Epop[45]], weight: 4.1363508E-4, delay 1.5
        h("Epop[45] syn_projEE_ampa[3565] = new ampa(0.5)")
        h("Epop[44] netConn_projEE_ampa[3565] = new NetCon(&v(0.5), syn_projEE_ampa[3565], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3566: cell 44, seg 0 (0.5) [0.5 on Epop[44]] -> cell 46, seg 0 (0.5) [0.5 on Epop[46]], weight: 4.1363508E-4, delay 1.5
        h("Epop[46] syn_projEE_ampa[3566] = new ampa(0.5)")
        h("Epop[44] netConn_projEE_ampa[3566] = new NetCon(&v(0.5), syn_projEE_ampa[3566], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3567: cell 44, seg 0 (0.5) [0.5 on Epop[44]] -> cell 47, seg 0 (0.5) [0.5 on Epop[47]], weight: 4.1363508E-4, delay 1.5
        h("Epop[47] syn_projEE_ampa[3567] = new ampa(0.5)")
        h("Epop[44] netConn_projEE_ampa[3567] = new NetCon(&v(0.5), syn_projEE_ampa[3567], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3568: cell 44, seg 0 (0.5) [0.5 on Epop[44]] -> cell 48, seg 0 (0.5) [0.5 on Epop[48]], weight: 4.1363508E-4, delay 1.5
        h("Epop[48] syn_projEE_ampa[3568] = new ampa(0.5)")
        h("Epop[44] netConn_projEE_ampa[3568] = new NetCon(&v(0.5), syn_projEE_ampa[3568], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3569: cell 44, seg 0 (0.5) [0.5 on Epop[44]] -> cell 49, seg 0 (0.5) [0.5 on Epop[49]], weight: 4.1363508E-4, delay 1.5
        h("Epop[49] syn_projEE_ampa[3569] = new ampa(0.5)")
        h("Epop[44] netConn_projEE_ampa[3569] = new NetCon(&v(0.5), syn_projEE_ampa[3569], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3570: cell 44, seg 0 (0.5) [0.5 on Epop[44]] -> cell 50, seg 0 (0.5) [0.5 on Epop[50]], weight: 4.1363508E-4, delay 1.5
        h("Epop[50] syn_projEE_ampa[3570] = new ampa(0.5)")
        h("Epop[44] netConn_projEE_ampa[3570] = new NetCon(&v(0.5), syn_projEE_ampa[3570], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3571: cell 44, seg 0 (0.5) [0.5 on Epop[44]] -> cell 51, seg 0 (0.5) [0.5 on Epop[51]], weight: 4.1363508E-4, delay 1.5
        h("Epop[51] syn_projEE_ampa[3571] = new ampa(0.5)")
        h("Epop[44] netConn_projEE_ampa[3571] = new NetCon(&v(0.5), syn_projEE_ampa[3571], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3572: cell 44, seg 0 (0.5) [0.5 on Epop[44]] -> cell 52, seg 0 (0.5) [0.5 on Epop[52]], weight: 4.1363508E-4, delay 1.5
        h("Epop[52] syn_projEE_ampa[3572] = new ampa(0.5)")
        h("Epop[44] netConn_projEE_ampa[3572] = new NetCon(&v(0.5), syn_projEE_ampa[3572], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3573: cell 44, seg 0 (0.5) [0.5 on Epop[44]] -> cell 53, seg 0 (0.5) [0.5 on Epop[53]], weight: 4.1363508E-4, delay 1.5
        h("Epop[53] syn_projEE_ampa[3573] = new ampa(0.5)")
        h("Epop[44] netConn_projEE_ampa[3573] = new NetCon(&v(0.5), syn_projEE_ampa[3573], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3574: cell 44, seg 0 (0.5) [0.5 on Epop[44]] -> cell 54, seg 0 (0.5) [0.5 on Epop[54]], weight: 4.1363508E-4, delay 1.5
        h("Epop[54] syn_projEE_ampa[3574] = new ampa(0.5)")
        h("Epop[44] netConn_projEE_ampa[3574] = new NetCon(&v(0.5), syn_projEE_ampa[3574], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3575: cell 44, seg 0 (0.5) [0.5 on Epop[44]] -> cell 55, seg 0 (0.5) [0.5 on Epop[55]], weight: 4.1363508E-4, delay 1.5
        h("Epop[55] syn_projEE_ampa[3575] = new ampa(0.5)")
        h("Epop[44] netConn_projEE_ampa[3575] = new NetCon(&v(0.5), syn_projEE_ampa[3575], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3576: cell 44, seg 0 (0.5) [0.5 on Epop[44]] -> cell 56, seg 0 (0.5) [0.5 on Epop[56]], weight: 4.1363508E-4, delay 1.5
        h("Epop[56] syn_projEE_ampa[3576] = new ampa(0.5)")
        h("Epop[44] netConn_projEE_ampa[3576] = new NetCon(&v(0.5), syn_projEE_ampa[3576], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3577: cell 44, seg 0 (0.5) [0.5 on Epop[44]] -> cell 57, seg 0 (0.5) [0.5 on Epop[57]], weight: 4.1363508E-4, delay 1.5
        h("Epop[57] syn_projEE_ampa[3577] = new ampa(0.5)")
        h("Epop[44] netConn_projEE_ampa[3577] = new NetCon(&v(0.5), syn_projEE_ampa[3577], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3578: cell 44, seg 0 (0.5) [0.5 on Epop[44]] -> cell 58, seg 0 (0.5) [0.5 on Epop[58]], weight: 4.1363508E-4, delay 1.5
        h("Epop[58] syn_projEE_ampa[3578] = new ampa(0.5)")
        h("Epop[44] netConn_projEE_ampa[3578] = new NetCon(&v(0.5), syn_projEE_ampa[3578], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3579: cell 44, seg 0 (0.5) [0.5 on Epop[44]] -> cell 59, seg 0 (0.5) [0.5 on Epop[59]], weight: 4.1363508E-4, delay 1.5
        h("Epop[59] syn_projEE_ampa[3579] = new ampa(0.5)")
        h("Epop[44] netConn_projEE_ampa[3579] = new NetCon(&v(0.5), syn_projEE_ampa[3579], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3580: cell 44, seg 0 (0.5) [0.5 on Epop[44]] -> cell 60, seg 0 (0.5) [0.5 on Epop[60]], weight: 4.1363508E-4, delay 1.5
        h("Epop[60] syn_projEE_ampa[3580] = new ampa(0.5)")
        h("Epop[44] netConn_projEE_ampa[3580] = new NetCon(&v(0.5), syn_projEE_ampa[3580], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3581: cell 44, seg 0 (0.5) [0.5 on Epop[44]] -> cell 61, seg 0 (0.5) [0.5 on Epop[61]], weight: 4.1363508E-4, delay 1.5
        h("Epop[61] syn_projEE_ampa[3581] = new ampa(0.5)")
        h("Epop[44] netConn_projEE_ampa[3581] = new NetCon(&v(0.5), syn_projEE_ampa[3581], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3582: cell 44, seg 0 (0.5) [0.5 on Epop[44]] -> cell 62, seg 0 (0.5) [0.5 on Epop[62]], weight: 4.1363508E-4, delay 1.5
        h("Epop[62] syn_projEE_ampa[3582] = new ampa(0.5)")
        h("Epop[44] netConn_projEE_ampa[3582] = new NetCon(&v(0.5), syn_projEE_ampa[3582], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3583: cell 44, seg 0 (0.5) [0.5 on Epop[44]] -> cell 63, seg 0 (0.5) [0.5 on Epop[63]], weight: 4.1363508E-4, delay 1.5
        h("Epop[63] syn_projEE_ampa[3583] = new ampa(0.5)")
        h("Epop[44] netConn_projEE_ampa[3583] = new NetCon(&v(0.5), syn_projEE_ampa[3583], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3584: cell 44, seg 0 (0.5) [0.5 on Epop[44]] -> cell 64, seg 0 (0.5) [0.5 on Epop[64]], weight: 4.1363508E-4, delay 1.5
        h("Epop[64] syn_projEE_ampa[3584] = new ampa(0.5)")
        h("Epop[44] netConn_projEE_ampa[3584] = new NetCon(&v(0.5), syn_projEE_ampa[3584], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3585: cell 44, seg 0 (0.5) [0.5 on Epop[44]] -> cell 65, seg 0 (0.5) [0.5 on Epop[65]], weight: 4.1363508E-4, delay 1.5
        h("Epop[65] syn_projEE_ampa[3585] = new ampa(0.5)")
        h("Epop[44] netConn_projEE_ampa[3585] = new NetCon(&v(0.5), syn_projEE_ampa[3585], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3586: cell 44, seg 0 (0.5) [0.5 on Epop[44]] -> cell 66, seg 0 (0.5) [0.5 on Epop[66]], weight: 4.1363508E-4, delay 1.5
        h("Epop[66] syn_projEE_ampa[3586] = new ampa(0.5)")
        h("Epop[44] netConn_projEE_ampa[3586] = new NetCon(&v(0.5), syn_projEE_ampa[3586], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3587: cell 44, seg 0 (0.5) [0.5 on Epop[44]] -> cell 67, seg 0 (0.5) [0.5 on Epop[67]], weight: 4.1363508E-4, delay 1.5
        h("Epop[67] syn_projEE_ampa[3587] = new ampa(0.5)")
        h("Epop[44] netConn_projEE_ampa[3587] = new NetCon(&v(0.5), syn_projEE_ampa[3587], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3588: cell 44, seg 0 (0.5) [0.5 on Epop[44]] -> cell 68, seg 0 (0.5) [0.5 on Epop[68]], weight: 4.1363508E-4, delay 1.5
        h("Epop[68] syn_projEE_ampa[3588] = new ampa(0.5)")
        h("Epop[44] netConn_projEE_ampa[3588] = new NetCon(&v(0.5), syn_projEE_ampa[3588], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3589: cell 44, seg 0 (0.5) [0.5 on Epop[44]] -> cell 69, seg 0 (0.5) [0.5 on Epop[69]], weight: 4.1363508E-4, delay 1.5
        h("Epop[69] syn_projEE_ampa[3589] = new ampa(0.5)")
        h("Epop[44] netConn_projEE_ampa[3589] = new NetCon(&v(0.5), syn_projEE_ampa[3589], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3590: cell 44, seg 0 (0.5) [0.5 on Epop[44]] -> cell 70, seg 0 (0.5) [0.5 on Epop[70]], weight: 4.1363508E-4, delay 1.5
        h("Epop[70] syn_projEE_ampa[3590] = new ampa(0.5)")
        h("Epop[44] netConn_projEE_ampa[3590] = new NetCon(&v(0.5), syn_projEE_ampa[3590], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3591: cell 44, seg 0 (0.5) [0.5 on Epop[44]] -> cell 71, seg 0 (0.5) [0.5 on Epop[71]], weight: 4.1363508E-4, delay 1.5
        h("Epop[71] syn_projEE_ampa[3591] = new ampa(0.5)")
        h("Epop[44] netConn_projEE_ampa[3591] = new NetCon(&v(0.5), syn_projEE_ampa[3591], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3592: cell 44, seg 0 (0.5) [0.5 on Epop[44]] -> cell 72, seg 0 (0.5) [0.5 on Epop[72]], weight: 4.1363508E-4, delay 1.5
        h("Epop[72] syn_projEE_ampa[3592] = new ampa(0.5)")
        h("Epop[44] netConn_projEE_ampa[3592] = new NetCon(&v(0.5), syn_projEE_ampa[3592], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3593: cell 44, seg 0 (0.5) [0.5 on Epop[44]] -> cell 73, seg 0 (0.5) [0.5 on Epop[73]], weight: 4.1363508E-4, delay 1.5
        h("Epop[73] syn_projEE_ampa[3593] = new ampa(0.5)")
        h("Epop[44] netConn_projEE_ampa[3593] = new NetCon(&v(0.5), syn_projEE_ampa[3593], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3594: cell 44, seg 0 (0.5) [0.5 on Epop[44]] -> cell 74, seg 0 (0.5) [0.5 on Epop[74]], weight: 4.1363508E-4, delay 1.5
        h("Epop[74] syn_projEE_ampa[3594] = new ampa(0.5)")
        h("Epop[44] netConn_projEE_ampa[3594] = new NetCon(&v(0.5), syn_projEE_ampa[3594], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3595: cell 44, seg 0 (0.5) [0.5 on Epop[44]] -> cell 75, seg 0 (0.5) [0.5 on Epop[75]], weight: 4.1363508E-4, delay 1.5
        h("Epop[75] syn_projEE_ampa[3595] = new ampa(0.5)")
        h("Epop[44] netConn_projEE_ampa[3595] = new NetCon(&v(0.5), syn_projEE_ampa[3595], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3596: cell 44, seg 0 (0.5) [0.5 on Epop[44]] -> cell 76, seg 0 (0.5) [0.5 on Epop[76]], weight: 4.1363508E-4, delay 1.5
        h("Epop[76] syn_projEE_ampa[3596] = new ampa(0.5)")
        h("Epop[44] netConn_projEE_ampa[3596] = new NetCon(&v(0.5), syn_projEE_ampa[3596], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3597: cell 44, seg 0 (0.5) [0.5 on Epop[44]] -> cell 77, seg 0 (0.5) [0.5 on Epop[77]], weight: 4.1363508E-4, delay 1.5
        h("Epop[77] syn_projEE_ampa[3597] = new ampa(0.5)")
        h("Epop[44] netConn_projEE_ampa[3597] = new NetCon(&v(0.5), syn_projEE_ampa[3597], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3598: cell 44, seg 0 (0.5) [0.5 on Epop[44]] -> cell 78, seg 0 (0.5) [0.5 on Epop[78]], weight: 4.1363508E-4, delay 1.5
        h("Epop[78] syn_projEE_ampa[3598] = new ampa(0.5)")
        h("Epop[44] netConn_projEE_ampa[3598] = new NetCon(&v(0.5), syn_projEE_ampa[3598], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3599: cell 44, seg 0 (0.5) [0.5 on Epop[44]] -> cell 79, seg 0 (0.5) [0.5 on Epop[79]], weight: 4.1363508E-4, delay 1.5
        h("Epop[79] syn_projEE_ampa[3599] = new ampa(0.5)")
        h("Epop[44] netConn_projEE_ampa[3599] = new NetCon(&v(0.5), syn_projEE_ampa[3599], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3600: cell 45, seg 0 (0.5) [0.5 on Epop[45]] -> cell 0, seg 0 (0.5) [0.5 on Epop[0]], weight: 4.1363508E-4, delay 1.5
        h("Epop[0] syn_projEE_ampa[3600] = new ampa(0.5)")
        h("Epop[45] netConn_projEE_ampa[3600] = new NetCon(&v(0.5), syn_projEE_ampa[3600], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3601: cell 45, seg 0 (0.5) [0.5 on Epop[45]] -> cell 1, seg 0 (0.5) [0.5 on Epop[1]], weight: 4.1363508E-4, delay 1.5
        h("Epop[1] syn_projEE_ampa[3601] = new ampa(0.5)")
        h("Epop[45] netConn_projEE_ampa[3601] = new NetCon(&v(0.5), syn_projEE_ampa[3601], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3602: cell 45, seg 0 (0.5) [0.5 on Epop[45]] -> cell 2, seg 0 (0.5) [0.5 on Epop[2]], weight: 4.1363508E-4, delay 1.5
        h("Epop[2] syn_projEE_ampa[3602] = new ampa(0.5)")
        h("Epop[45] netConn_projEE_ampa[3602] = new NetCon(&v(0.5), syn_projEE_ampa[3602], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3603: cell 45, seg 0 (0.5) [0.5 on Epop[45]] -> cell 3, seg 0 (0.5) [0.5 on Epop[3]], weight: 4.1363508E-4, delay 1.5
        h("Epop[3] syn_projEE_ampa[3603] = new ampa(0.5)")
        h("Epop[45] netConn_projEE_ampa[3603] = new NetCon(&v(0.5), syn_projEE_ampa[3603], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3604: cell 45, seg 0 (0.5) [0.5 on Epop[45]] -> cell 4, seg 0 (0.5) [0.5 on Epop[4]], weight: 4.1363508E-4, delay 1.5
        h("Epop[4] syn_projEE_ampa[3604] = new ampa(0.5)")
        h("Epop[45] netConn_projEE_ampa[3604] = new NetCon(&v(0.5), syn_projEE_ampa[3604], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3605: cell 45, seg 0 (0.5) [0.5 on Epop[45]] -> cell 5, seg 0 (0.5) [0.5 on Epop[5]], weight: 4.1363508E-4, delay 1.5
        h("Epop[5] syn_projEE_ampa[3605] = new ampa(0.5)")
        h("Epop[45] netConn_projEE_ampa[3605] = new NetCon(&v(0.5), syn_projEE_ampa[3605], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3606: cell 45, seg 0 (0.5) [0.5 on Epop[45]] -> cell 6, seg 0 (0.5) [0.5 on Epop[6]], weight: 4.1363508E-4, delay 1.5
        h("Epop[6] syn_projEE_ampa[3606] = new ampa(0.5)")
        h("Epop[45] netConn_projEE_ampa[3606] = new NetCon(&v(0.5), syn_projEE_ampa[3606], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3607: cell 45, seg 0 (0.5) [0.5 on Epop[45]] -> cell 7, seg 0 (0.5) [0.5 on Epop[7]], weight: 4.1363508E-4, delay 1.5
        h("Epop[7] syn_projEE_ampa[3607] = new ampa(0.5)")
        h("Epop[45] netConn_projEE_ampa[3607] = new NetCon(&v(0.5), syn_projEE_ampa[3607], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3608: cell 45, seg 0 (0.5) [0.5 on Epop[45]] -> cell 8, seg 0 (0.5) [0.5 on Epop[8]], weight: 4.1363508E-4, delay 1.5
        h("Epop[8] syn_projEE_ampa[3608] = new ampa(0.5)")
        h("Epop[45] netConn_projEE_ampa[3608] = new NetCon(&v(0.5), syn_projEE_ampa[3608], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3609: cell 45, seg 0 (0.5) [0.5 on Epop[45]] -> cell 9, seg 0 (0.5) [0.5 on Epop[9]], weight: 4.1363508E-4, delay 1.5
        h("Epop[9] syn_projEE_ampa[3609] = new ampa(0.5)")
        h("Epop[45] netConn_projEE_ampa[3609] = new NetCon(&v(0.5), syn_projEE_ampa[3609], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3610: cell 45, seg 0 (0.5) [0.5 on Epop[45]] -> cell 10, seg 0 (0.5) [0.5 on Epop[10]], weight: 4.1363508E-4, delay 1.5
        h("Epop[10] syn_projEE_ampa[3610] = new ampa(0.5)")
        h("Epop[45] netConn_projEE_ampa[3610] = new NetCon(&v(0.5), syn_projEE_ampa[3610], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3611: cell 45, seg 0 (0.5) [0.5 on Epop[45]] -> cell 11, seg 0 (0.5) [0.5 on Epop[11]], weight: 4.1363508E-4, delay 1.5
        h("Epop[11] syn_projEE_ampa[3611] = new ampa(0.5)")
        h("Epop[45] netConn_projEE_ampa[3611] = new NetCon(&v(0.5), syn_projEE_ampa[3611], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3612: cell 45, seg 0 (0.5) [0.5 on Epop[45]] -> cell 12, seg 0 (0.5) [0.5 on Epop[12]], weight: 4.1363508E-4, delay 1.5
        h("Epop[12] syn_projEE_ampa[3612] = new ampa(0.5)")
        h("Epop[45] netConn_projEE_ampa[3612] = new NetCon(&v(0.5), syn_projEE_ampa[3612], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3613: cell 45, seg 0 (0.5) [0.5 on Epop[45]] -> cell 13, seg 0 (0.5) [0.5 on Epop[13]], weight: 4.1363508E-4, delay 1.5
        h("Epop[13] syn_projEE_ampa[3613] = new ampa(0.5)")
        h("Epop[45] netConn_projEE_ampa[3613] = new NetCon(&v(0.5), syn_projEE_ampa[3613], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3614: cell 45, seg 0 (0.5) [0.5 on Epop[45]] -> cell 14, seg 0 (0.5) [0.5 on Epop[14]], weight: 4.1363508E-4, delay 1.5
        h("Epop[14] syn_projEE_ampa[3614] = new ampa(0.5)")
        h("Epop[45] netConn_projEE_ampa[3614] = new NetCon(&v(0.5), syn_projEE_ampa[3614], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3615: cell 45, seg 0 (0.5) [0.5 on Epop[45]] -> cell 15, seg 0 (0.5) [0.5 on Epop[15]], weight: 4.1363508E-4, delay 1.5
        h("Epop[15] syn_projEE_ampa[3615] = new ampa(0.5)")
        h("Epop[45] netConn_projEE_ampa[3615] = new NetCon(&v(0.5), syn_projEE_ampa[3615], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3616: cell 45, seg 0 (0.5) [0.5 on Epop[45]] -> cell 16, seg 0 (0.5) [0.5 on Epop[16]], weight: 4.1363508E-4, delay 1.5
        h("Epop[16] syn_projEE_ampa[3616] = new ampa(0.5)")
        h("Epop[45] netConn_projEE_ampa[3616] = new NetCon(&v(0.5), syn_projEE_ampa[3616], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3617: cell 45, seg 0 (0.5) [0.5 on Epop[45]] -> cell 17, seg 0 (0.5) [0.5 on Epop[17]], weight: 4.1363508E-4, delay 1.5
        h("Epop[17] syn_projEE_ampa[3617] = new ampa(0.5)")
        h("Epop[45] netConn_projEE_ampa[3617] = new NetCon(&v(0.5), syn_projEE_ampa[3617], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3618: cell 45, seg 0 (0.5) [0.5 on Epop[45]] -> cell 18, seg 0 (0.5) [0.5 on Epop[18]], weight: 4.1363508E-4, delay 1.5
        h("Epop[18] syn_projEE_ampa[3618] = new ampa(0.5)")
        h("Epop[45] netConn_projEE_ampa[3618] = new NetCon(&v(0.5), syn_projEE_ampa[3618], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3619: cell 45, seg 0 (0.5) [0.5 on Epop[45]] -> cell 19, seg 0 (0.5) [0.5 on Epop[19]], weight: 4.1363508E-4, delay 1.5
        h("Epop[19] syn_projEE_ampa[3619] = new ampa(0.5)")
        h("Epop[45] netConn_projEE_ampa[3619] = new NetCon(&v(0.5), syn_projEE_ampa[3619], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3620: cell 45, seg 0 (0.5) [0.5 on Epop[45]] -> cell 20, seg 0 (0.5) [0.5 on Epop[20]], weight: 4.1363508E-4, delay 1.5
        h("Epop[20] syn_projEE_ampa[3620] = new ampa(0.5)")
        h("Epop[45] netConn_projEE_ampa[3620] = new NetCon(&v(0.5), syn_projEE_ampa[3620], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3621: cell 45, seg 0 (0.5) [0.5 on Epop[45]] -> cell 21, seg 0 (0.5) [0.5 on Epop[21]], weight: 4.1363508E-4, delay 1.5
        h("Epop[21] syn_projEE_ampa[3621] = new ampa(0.5)")
        h("Epop[45] netConn_projEE_ampa[3621] = new NetCon(&v(0.5), syn_projEE_ampa[3621], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3622: cell 45, seg 0 (0.5) [0.5 on Epop[45]] -> cell 22, seg 0 (0.5) [0.5 on Epop[22]], weight: 4.1363508E-4, delay 1.5
        h("Epop[22] syn_projEE_ampa[3622] = new ampa(0.5)")
        h("Epop[45] netConn_projEE_ampa[3622] = new NetCon(&v(0.5), syn_projEE_ampa[3622], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3623: cell 45, seg 0 (0.5) [0.5 on Epop[45]] -> cell 23, seg 0 (0.5) [0.5 on Epop[23]], weight: 4.1363508E-4, delay 1.5
        h("Epop[23] syn_projEE_ampa[3623] = new ampa(0.5)")
        h("Epop[45] netConn_projEE_ampa[3623] = new NetCon(&v(0.5), syn_projEE_ampa[3623], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3624: cell 45, seg 0 (0.5) [0.5 on Epop[45]] -> cell 24, seg 0 (0.5) [0.5 on Epop[24]], weight: 4.1363508E-4, delay 1.5
        h("Epop[24] syn_projEE_ampa[3624] = new ampa(0.5)")
        h("Epop[45] netConn_projEE_ampa[3624] = new NetCon(&v(0.5), syn_projEE_ampa[3624], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3625: cell 45, seg 0 (0.5) [0.5 on Epop[45]] -> cell 25, seg 0 (0.5) [0.5 on Epop[25]], weight: 4.1363508E-4, delay 1.5
        h("Epop[25] syn_projEE_ampa[3625] = new ampa(0.5)")
        h("Epop[45] netConn_projEE_ampa[3625] = new NetCon(&v(0.5), syn_projEE_ampa[3625], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3626: cell 45, seg 0 (0.5) [0.5 on Epop[45]] -> cell 26, seg 0 (0.5) [0.5 on Epop[26]], weight: 4.1363508E-4, delay 1.5
        h("Epop[26] syn_projEE_ampa[3626] = new ampa(0.5)")
        h("Epop[45] netConn_projEE_ampa[3626] = new NetCon(&v(0.5), syn_projEE_ampa[3626], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3627: cell 45, seg 0 (0.5) [0.5 on Epop[45]] -> cell 27, seg 0 (0.5) [0.5 on Epop[27]], weight: 4.1363508E-4, delay 1.5
        h("Epop[27] syn_projEE_ampa[3627] = new ampa(0.5)")
        h("Epop[45] netConn_projEE_ampa[3627] = new NetCon(&v(0.5), syn_projEE_ampa[3627], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3628: cell 45, seg 0 (0.5) [0.5 on Epop[45]] -> cell 28, seg 0 (0.5) [0.5 on Epop[28]], weight: 4.1363508E-4, delay 1.5
        h("Epop[28] syn_projEE_ampa[3628] = new ampa(0.5)")
        h("Epop[45] netConn_projEE_ampa[3628] = new NetCon(&v(0.5), syn_projEE_ampa[3628], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3629: cell 45, seg 0 (0.5) [0.5 on Epop[45]] -> cell 29, seg 0 (0.5) [0.5 on Epop[29]], weight: 4.1363508E-4, delay 1.5
        h("Epop[29] syn_projEE_ampa[3629] = new ampa(0.5)")
        h("Epop[45] netConn_projEE_ampa[3629] = new NetCon(&v(0.5), syn_projEE_ampa[3629], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3630: cell 45, seg 0 (0.5) [0.5 on Epop[45]] -> cell 30, seg 0 (0.5) [0.5 on Epop[30]], weight: 4.1363508E-4, delay 1.5
        h("Epop[30] syn_projEE_ampa[3630] = new ampa(0.5)")
        h("Epop[45] netConn_projEE_ampa[3630] = new NetCon(&v(0.5), syn_projEE_ampa[3630], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3631: cell 45, seg 0 (0.5) [0.5 on Epop[45]] -> cell 31, seg 0 (0.5) [0.5 on Epop[31]], weight: 4.1363508E-4, delay 1.5
        h("Epop[31] syn_projEE_ampa[3631] = new ampa(0.5)")
        h("Epop[45] netConn_projEE_ampa[3631] = new NetCon(&v(0.5), syn_projEE_ampa[3631], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3632: cell 45, seg 0 (0.5) [0.5 on Epop[45]] -> cell 32, seg 0 (0.5) [0.5 on Epop[32]], weight: 4.1363508E-4, delay 1.5
        h("Epop[32] syn_projEE_ampa[3632] = new ampa(0.5)")
        h("Epop[45] netConn_projEE_ampa[3632] = new NetCon(&v(0.5), syn_projEE_ampa[3632], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3633: cell 45, seg 0 (0.5) [0.5 on Epop[45]] -> cell 33, seg 0 (0.5) [0.5 on Epop[33]], weight: 4.1363508E-4, delay 1.5
        h("Epop[33] syn_projEE_ampa[3633] = new ampa(0.5)")
        h("Epop[45] netConn_projEE_ampa[3633] = new NetCon(&v(0.5), syn_projEE_ampa[3633], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3634: cell 45, seg 0 (0.5) [0.5 on Epop[45]] -> cell 34, seg 0 (0.5) [0.5 on Epop[34]], weight: 4.1363508E-4, delay 1.5
        h("Epop[34] syn_projEE_ampa[3634] = new ampa(0.5)")
        h("Epop[45] netConn_projEE_ampa[3634] = new NetCon(&v(0.5), syn_projEE_ampa[3634], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3635: cell 45, seg 0 (0.5) [0.5 on Epop[45]] -> cell 35, seg 0 (0.5) [0.5 on Epop[35]], weight: 4.1363508E-4, delay 1.5
        h("Epop[35] syn_projEE_ampa[3635] = new ampa(0.5)")
        h("Epop[45] netConn_projEE_ampa[3635] = new NetCon(&v(0.5), syn_projEE_ampa[3635], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3636: cell 45, seg 0 (0.5) [0.5 on Epop[45]] -> cell 36, seg 0 (0.5) [0.5 on Epop[36]], weight: 4.1363508E-4, delay 1.5
        h("Epop[36] syn_projEE_ampa[3636] = new ampa(0.5)")
        h("Epop[45] netConn_projEE_ampa[3636] = new NetCon(&v(0.5), syn_projEE_ampa[3636], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3637: cell 45, seg 0 (0.5) [0.5 on Epop[45]] -> cell 37, seg 0 (0.5) [0.5 on Epop[37]], weight: 4.1363508E-4, delay 1.5
        h("Epop[37] syn_projEE_ampa[3637] = new ampa(0.5)")
        h("Epop[45] netConn_projEE_ampa[3637] = new NetCon(&v(0.5), syn_projEE_ampa[3637], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3638: cell 45, seg 0 (0.5) [0.5 on Epop[45]] -> cell 38, seg 0 (0.5) [0.5 on Epop[38]], weight: 4.1363508E-4, delay 1.5
        h("Epop[38] syn_projEE_ampa[3638] = new ampa(0.5)")
        h("Epop[45] netConn_projEE_ampa[3638] = new NetCon(&v(0.5), syn_projEE_ampa[3638], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3639: cell 45, seg 0 (0.5) [0.5 on Epop[45]] -> cell 39, seg 0 (0.5) [0.5 on Epop[39]], weight: 4.1363508E-4, delay 1.5
        h("Epop[39] syn_projEE_ampa[3639] = new ampa(0.5)")
        h("Epop[45] netConn_projEE_ampa[3639] = new NetCon(&v(0.5), syn_projEE_ampa[3639], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3640: cell 45, seg 0 (0.5) [0.5 on Epop[45]] -> cell 40, seg 0 (0.5) [0.5 on Epop[40]], weight: 4.1363508E-4, delay 1.5
        h("Epop[40] syn_projEE_ampa[3640] = new ampa(0.5)")
        h("Epop[45] netConn_projEE_ampa[3640] = new NetCon(&v(0.5), syn_projEE_ampa[3640], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3641: cell 45, seg 0 (0.5) [0.5 on Epop[45]] -> cell 41, seg 0 (0.5) [0.5 on Epop[41]], weight: 4.1363508E-4, delay 1.5
        h("Epop[41] syn_projEE_ampa[3641] = new ampa(0.5)")
        h("Epop[45] netConn_projEE_ampa[3641] = new NetCon(&v(0.5), syn_projEE_ampa[3641], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3642: cell 45, seg 0 (0.5) [0.5 on Epop[45]] -> cell 42, seg 0 (0.5) [0.5 on Epop[42]], weight: 4.1363508E-4, delay 1.5
        h("Epop[42] syn_projEE_ampa[3642] = new ampa(0.5)")
        h("Epop[45] netConn_projEE_ampa[3642] = new NetCon(&v(0.5), syn_projEE_ampa[3642], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3643: cell 45, seg 0 (0.5) [0.5 on Epop[45]] -> cell 43, seg 0 (0.5) [0.5 on Epop[43]], weight: 4.1363508E-4, delay 1.5
        h("Epop[43] syn_projEE_ampa[3643] = new ampa(0.5)")
        h("Epop[45] netConn_projEE_ampa[3643] = new NetCon(&v(0.5), syn_projEE_ampa[3643], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3644: cell 45, seg 0 (0.5) [0.5 on Epop[45]] -> cell 44, seg 0 (0.5) [0.5 on Epop[44]], weight: 4.1363508E-4, delay 1.5
        h("Epop[44] syn_projEE_ampa[3644] = new ampa(0.5)")
        h("Epop[45] netConn_projEE_ampa[3644] = new NetCon(&v(0.5), syn_projEE_ampa[3644], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3645: cell 45, seg 0 (0.5) [0.5 on Epop[45]] -> cell 45, seg 0 (0.5) [0.5 on Epop[45]], weight: 4.1363508E-4, delay 1.5
        h("Epop[45] syn_projEE_ampa[3645] = new ampa(0.5)")
        h("Epop[45] netConn_projEE_ampa[3645] = new NetCon(&v(0.5), syn_projEE_ampa[3645], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3646: cell 45, seg 0 (0.5) [0.5 on Epop[45]] -> cell 46, seg 0 (0.5) [0.5 on Epop[46]], weight: 4.1363508E-4, delay 1.5
        h("Epop[46] syn_projEE_ampa[3646] = new ampa(0.5)")
        h("Epop[45] netConn_projEE_ampa[3646] = new NetCon(&v(0.5), syn_projEE_ampa[3646], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3647: cell 45, seg 0 (0.5) [0.5 on Epop[45]] -> cell 47, seg 0 (0.5) [0.5 on Epop[47]], weight: 4.1363508E-4, delay 1.5
        h("Epop[47] syn_projEE_ampa[3647] = new ampa(0.5)")
        h("Epop[45] netConn_projEE_ampa[3647] = new NetCon(&v(0.5), syn_projEE_ampa[3647], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3648: cell 45, seg 0 (0.5) [0.5 on Epop[45]] -> cell 48, seg 0 (0.5) [0.5 on Epop[48]], weight: 4.1363508E-4, delay 1.5
        h("Epop[48] syn_projEE_ampa[3648] = new ampa(0.5)")
        h("Epop[45] netConn_projEE_ampa[3648] = new NetCon(&v(0.5), syn_projEE_ampa[3648], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3649: cell 45, seg 0 (0.5) [0.5 on Epop[45]] -> cell 49, seg 0 (0.5) [0.5 on Epop[49]], weight: 4.1363508E-4, delay 1.5
        h("Epop[49] syn_projEE_ampa[3649] = new ampa(0.5)")
        h("Epop[45] netConn_projEE_ampa[3649] = new NetCon(&v(0.5), syn_projEE_ampa[3649], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3650: cell 45, seg 0 (0.5) [0.5 on Epop[45]] -> cell 50, seg 0 (0.5) [0.5 on Epop[50]], weight: 4.1363508E-4, delay 1.5
        h("Epop[50] syn_projEE_ampa[3650] = new ampa(0.5)")
        h("Epop[45] netConn_projEE_ampa[3650] = new NetCon(&v(0.5), syn_projEE_ampa[3650], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3651: cell 45, seg 0 (0.5) [0.5 on Epop[45]] -> cell 51, seg 0 (0.5) [0.5 on Epop[51]], weight: 4.1363508E-4, delay 1.5
        h("Epop[51] syn_projEE_ampa[3651] = new ampa(0.5)")
        h("Epop[45] netConn_projEE_ampa[3651] = new NetCon(&v(0.5), syn_projEE_ampa[3651], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3652: cell 45, seg 0 (0.5) [0.5 on Epop[45]] -> cell 52, seg 0 (0.5) [0.5 on Epop[52]], weight: 4.1363508E-4, delay 1.5
        h("Epop[52] syn_projEE_ampa[3652] = new ampa(0.5)")
        h("Epop[45] netConn_projEE_ampa[3652] = new NetCon(&v(0.5), syn_projEE_ampa[3652], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3653: cell 45, seg 0 (0.5) [0.5 on Epop[45]] -> cell 53, seg 0 (0.5) [0.5 on Epop[53]], weight: 4.1363508E-4, delay 1.5
        h("Epop[53] syn_projEE_ampa[3653] = new ampa(0.5)")
        h("Epop[45] netConn_projEE_ampa[3653] = new NetCon(&v(0.5), syn_projEE_ampa[3653], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3654: cell 45, seg 0 (0.5) [0.5 on Epop[45]] -> cell 54, seg 0 (0.5) [0.5 on Epop[54]], weight: 4.1363508E-4, delay 1.5
        h("Epop[54] syn_projEE_ampa[3654] = new ampa(0.5)")
        h("Epop[45] netConn_projEE_ampa[3654] = new NetCon(&v(0.5), syn_projEE_ampa[3654], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3655: cell 45, seg 0 (0.5) [0.5 on Epop[45]] -> cell 55, seg 0 (0.5) [0.5 on Epop[55]], weight: 4.1363508E-4, delay 1.5
        h("Epop[55] syn_projEE_ampa[3655] = new ampa(0.5)")
        h("Epop[45] netConn_projEE_ampa[3655] = new NetCon(&v(0.5), syn_projEE_ampa[3655], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3656: cell 45, seg 0 (0.5) [0.5 on Epop[45]] -> cell 56, seg 0 (0.5) [0.5 on Epop[56]], weight: 4.1363508E-4, delay 1.5
        h("Epop[56] syn_projEE_ampa[3656] = new ampa(0.5)")
        h("Epop[45] netConn_projEE_ampa[3656] = new NetCon(&v(0.5), syn_projEE_ampa[3656], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3657: cell 45, seg 0 (0.5) [0.5 on Epop[45]] -> cell 57, seg 0 (0.5) [0.5 on Epop[57]], weight: 4.1363508E-4, delay 1.5
        h("Epop[57] syn_projEE_ampa[3657] = new ampa(0.5)")
        h("Epop[45] netConn_projEE_ampa[3657] = new NetCon(&v(0.5), syn_projEE_ampa[3657], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3658: cell 45, seg 0 (0.5) [0.5 on Epop[45]] -> cell 58, seg 0 (0.5) [0.5 on Epop[58]], weight: 4.1363508E-4, delay 1.5
        h("Epop[58] syn_projEE_ampa[3658] = new ampa(0.5)")
        h("Epop[45] netConn_projEE_ampa[3658] = new NetCon(&v(0.5), syn_projEE_ampa[3658], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3659: cell 45, seg 0 (0.5) [0.5 on Epop[45]] -> cell 59, seg 0 (0.5) [0.5 on Epop[59]], weight: 4.1363508E-4, delay 1.5
        h("Epop[59] syn_projEE_ampa[3659] = new ampa(0.5)")
        h("Epop[45] netConn_projEE_ampa[3659] = new NetCon(&v(0.5), syn_projEE_ampa[3659], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3660: cell 45, seg 0 (0.5) [0.5 on Epop[45]] -> cell 60, seg 0 (0.5) [0.5 on Epop[60]], weight: 4.1363508E-4, delay 1.5
        h("Epop[60] syn_projEE_ampa[3660] = new ampa(0.5)")
        h("Epop[45] netConn_projEE_ampa[3660] = new NetCon(&v(0.5), syn_projEE_ampa[3660], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3661: cell 45, seg 0 (0.5) [0.5 on Epop[45]] -> cell 61, seg 0 (0.5) [0.5 on Epop[61]], weight: 4.1363508E-4, delay 1.5
        h("Epop[61] syn_projEE_ampa[3661] = new ampa(0.5)")
        h("Epop[45] netConn_projEE_ampa[3661] = new NetCon(&v(0.5), syn_projEE_ampa[3661], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3662: cell 45, seg 0 (0.5) [0.5 on Epop[45]] -> cell 62, seg 0 (0.5) [0.5 on Epop[62]], weight: 4.1363508E-4, delay 1.5
        h("Epop[62] syn_projEE_ampa[3662] = new ampa(0.5)")
        h("Epop[45] netConn_projEE_ampa[3662] = new NetCon(&v(0.5), syn_projEE_ampa[3662], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3663: cell 45, seg 0 (0.5) [0.5 on Epop[45]] -> cell 63, seg 0 (0.5) [0.5 on Epop[63]], weight: 4.1363508E-4, delay 1.5
        h("Epop[63] syn_projEE_ampa[3663] = new ampa(0.5)")
        h("Epop[45] netConn_projEE_ampa[3663] = new NetCon(&v(0.5), syn_projEE_ampa[3663], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3664: cell 45, seg 0 (0.5) [0.5 on Epop[45]] -> cell 64, seg 0 (0.5) [0.5 on Epop[64]], weight: 4.1363508E-4, delay 1.5
        h("Epop[64] syn_projEE_ampa[3664] = new ampa(0.5)")
        h("Epop[45] netConn_projEE_ampa[3664] = new NetCon(&v(0.5), syn_projEE_ampa[3664], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3665: cell 45, seg 0 (0.5) [0.5 on Epop[45]] -> cell 65, seg 0 (0.5) [0.5 on Epop[65]], weight: 4.1363508E-4, delay 1.5
        h("Epop[65] syn_projEE_ampa[3665] = new ampa(0.5)")
        h("Epop[45] netConn_projEE_ampa[3665] = new NetCon(&v(0.5), syn_projEE_ampa[3665], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3666: cell 45, seg 0 (0.5) [0.5 on Epop[45]] -> cell 66, seg 0 (0.5) [0.5 on Epop[66]], weight: 4.1363508E-4, delay 1.5
        h("Epop[66] syn_projEE_ampa[3666] = new ampa(0.5)")
        h("Epop[45] netConn_projEE_ampa[3666] = new NetCon(&v(0.5), syn_projEE_ampa[3666], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3667: cell 45, seg 0 (0.5) [0.5 on Epop[45]] -> cell 67, seg 0 (0.5) [0.5 on Epop[67]], weight: 4.1363508E-4, delay 1.5
        h("Epop[67] syn_projEE_ampa[3667] = new ampa(0.5)")
        h("Epop[45] netConn_projEE_ampa[3667] = new NetCon(&v(0.5), syn_projEE_ampa[3667], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3668: cell 45, seg 0 (0.5) [0.5 on Epop[45]] -> cell 68, seg 0 (0.5) [0.5 on Epop[68]], weight: 4.1363508E-4, delay 1.5
        h("Epop[68] syn_projEE_ampa[3668] = new ampa(0.5)")
        h("Epop[45] netConn_projEE_ampa[3668] = new NetCon(&v(0.5), syn_projEE_ampa[3668], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3669: cell 45, seg 0 (0.5) [0.5 on Epop[45]] -> cell 69, seg 0 (0.5) [0.5 on Epop[69]], weight: 4.1363508E-4, delay 1.5
        h("Epop[69] syn_projEE_ampa[3669] = new ampa(0.5)")
        h("Epop[45] netConn_projEE_ampa[3669] = new NetCon(&v(0.5), syn_projEE_ampa[3669], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3670: cell 45, seg 0 (0.5) [0.5 on Epop[45]] -> cell 70, seg 0 (0.5) [0.5 on Epop[70]], weight: 4.1363508E-4, delay 1.5
        h("Epop[70] syn_projEE_ampa[3670] = new ampa(0.5)")
        h("Epop[45] netConn_projEE_ampa[3670] = new NetCon(&v(0.5), syn_projEE_ampa[3670], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3671: cell 45, seg 0 (0.5) [0.5 on Epop[45]] -> cell 71, seg 0 (0.5) [0.5 on Epop[71]], weight: 4.1363508E-4, delay 1.5
        h("Epop[71] syn_projEE_ampa[3671] = new ampa(0.5)")
        h("Epop[45] netConn_projEE_ampa[3671] = new NetCon(&v(0.5), syn_projEE_ampa[3671], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3672: cell 45, seg 0 (0.5) [0.5 on Epop[45]] -> cell 72, seg 0 (0.5) [0.5 on Epop[72]], weight: 4.1363508E-4, delay 1.5
        h("Epop[72] syn_projEE_ampa[3672] = new ampa(0.5)")
        h("Epop[45] netConn_projEE_ampa[3672] = new NetCon(&v(0.5), syn_projEE_ampa[3672], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3673: cell 45, seg 0 (0.5) [0.5 on Epop[45]] -> cell 73, seg 0 (0.5) [0.5 on Epop[73]], weight: 4.1363508E-4, delay 1.5
        h("Epop[73] syn_projEE_ampa[3673] = new ampa(0.5)")
        h("Epop[45] netConn_projEE_ampa[3673] = new NetCon(&v(0.5), syn_projEE_ampa[3673], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3674: cell 45, seg 0 (0.5) [0.5 on Epop[45]] -> cell 74, seg 0 (0.5) [0.5 on Epop[74]], weight: 4.1363508E-4, delay 1.5
        h("Epop[74] syn_projEE_ampa[3674] = new ampa(0.5)")
        h("Epop[45] netConn_projEE_ampa[3674] = new NetCon(&v(0.5), syn_projEE_ampa[3674], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3675: cell 45, seg 0 (0.5) [0.5 on Epop[45]] -> cell 75, seg 0 (0.5) [0.5 on Epop[75]], weight: 4.1363508E-4, delay 1.5
        h("Epop[75] syn_projEE_ampa[3675] = new ampa(0.5)")
        h("Epop[45] netConn_projEE_ampa[3675] = new NetCon(&v(0.5), syn_projEE_ampa[3675], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3676: cell 45, seg 0 (0.5) [0.5 on Epop[45]] -> cell 76, seg 0 (0.5) [0.5 on Epop[76]], weight: 4.1363508E-4, delay 1.5
        h("Epop[76] syn_projEE_ampa[3676] = new ampa(0.5)")
        h("Epop[45] netConn_projEE_ampa[3676] = new NetCon(&v(0.5), syn_projEE_ampa[3676], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3677: cell 45, seg 0 (0.5) [0.5 on Epop[45]] -> cell 77, seg 0 (0.5) [0.5 on Epop[77]], weight: 4.1363508E-4, delay 1.5
        h("Epop[77] syn_projEE_ampa[3677] = new ampa(0.5)")
        h("Epop[45] netConn_projEE_ampa[3677] = new NetCon(&v(0.5), syn_projEE_ampa[3677], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3678: cell 45, seg 0 (0.5) [0.5 on Epop[45]] -> cell 78, seg 0 (0.5) [0.5 on Epop[78]], weight: 4.1363508E-4, delay 1.5
        h("Epop[78] syn_projEE_ampa[3678] = new ampa(0.5)")
        h("Epop[45] netConn_projEE_ampa[3678] = new NetCon(&v(0.5), syn_projEE_ampa[3678], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3679: cell 45, seg 0 (0.5) [0.5 on Epop[45]] -> cell 79, seg 0 (0.5) [0.5 on Epop[79]], weight: 4.1363508E-4, delay 1.5
        h("Epop[79] syn_projEE_ampa[3679] = new ampa(0.5)")
        h("Epop[45] netConn_projEE_ampa[3679] = new NetCon(&v(0.5), syn_projEE_ampa[3679], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3680: cell 46, seg 0 (0.5) [0.5 on Epop[46]] -> cell 0, seg 0 (0.5) [0.5 on Epop[0]], weight: 4.1363508E-4, delay 1.5
        h("Epop[0] syn_projEE_ampa[3680] = new ampa(0.5)")
        h("Epop[46] netConn_projEE_ampa[3680] = new NetCon(&v(0.5), syn_projEE_ampa[3680], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3681: cell 46, seg 0 (0.5) [0.5 on Epop[46]] -> cell 1, seg 0 (0.5) [0.5 on Epop[1]], weight: 4.1363508E-4, delay 1.5
        h("Epop[1] syn_projEE_ampa[3681] = new ampa(0.5)")
        h("Epop[46] netConn_projEE_ampa[3681] = new NetCon(&v(0.5), syn_projEE_ampa[3681], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3682: cell 46, seg 0 (0.5) [0.5 on Epop[46]] -> cell 2, seg 0 (0.5) [0.5 on Epop[2]], weight: 4.1363508E-4, delay 1.5
        h("Epop[2] syn_projEE_ampa[3682] = new ampa(0.5)")
        h("Epop[46] netConn_projEE_ampa[3682] = new NetCon(&v(0.5), syn_projEE_ampa[3682], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3683: cell 46, seg 0 (0.5) [0.5 on Epop[46]] -> cell 3, seg 0 (0.5) [0.5 on Epop[3]], weight: 4.1363508E-4, delay 1.5
        h("Epop[3] syn_projEE_ampa[3683] = new ampa(0.5)")
        h("Epop[46] netConn_projEE_ampa[3683] = new NetCon(&v(0.5), syn_projEE_ampa[3683], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3684: cell 46, seg 0 (0.5) [0.5 on Epop[46]] -> cell 4, seg 0 (0.5) [0.5 on Epop[4]], weight: 4.1363508E-4, delay 1.5
        h("Epop[4] syn_projEE_ampa[3684] = new ampa(0.5)")
        h("Epop[46] netConn_projEE_ampa[3684] = new NetCon(&v(0.5), syn_projEE_ampa[3684], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3685: cell 46, seg 0 (0.5) [0.5 on Epop[46]] -> cell 5, seg 0 (0.5) [0.5 on Epop[5]], weight: 4.1363508E-4, delay 1.5
        h("Epop[5] syn_projEE_ampa[3685] = new ampa(0.5)")
        h("Epop[46] netConn_projEE_ampa[3685] = new NetCon(&v(0.5), syn_projEE_ampa[3685], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3686: cell 46, seg 0 (0.5) [0.5 on Epop[46]] -> cell 6, seg 0 (0.5) [0.5 on Epop[6]], weight: 4.1363508E-4, delay 1.5
        h("Epop[6] syn_projEE_ampa[3686] = new ampa(0.5)")
        h("Epop[46] netConn_projEE_ampa[3686] = new NetCon(&v(0.5), syn_projEE_ampa[3686], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3687: cell 46, seg 0 (0.5) [0.5 on Epop[46]] -> cell 7, seg 0 (0.5) [0.5 on Epop[7]], weight: 4.1363508E-4, delay 1.5
        h("Epop[7] syn_projEE_ampa[3687] = new ampa(0.5)")
        h("Epop[46] netConn_projEE_ampa[3687] = new NetCon(&v(0.5), syn_projEE_ampa[3687], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3688: cell 46, seg 0 (0.5) [0.5 on Epop[46]] -> cell 8, seg 0 (0.5) [0.5 on Epop[8]], weight: 4.1363508E-4, delay 1.5
        h("Epop[8] syn_projEE_ampa[3688] = new ampa(0.5)")
        h("Epop[46] netConn_projEE_ampa[3688] = new NetCon(&v(0.5), syn_projEE_ampa[3688], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3689: cell 46, seg 0 (0.5) [0.5 on Epop[46]] -> cell 9, seg 0 (0.5) [0.5 on Epop[9]], weight: 4.1363508E-4, delay 1.5
        h("Epop[9] syn_projEE_ampa[3689] = new ampa(0.5)")
        h("Epop[46] netConn_projEE_ampa[3689] = new NetCon(&v(0.5), syn_projEE_ampa[3689], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3690: cell 46, seg 0 (0.5) [0.5 on Epop[46]] -> cell 10, seg 0 (0.5) [0.5 on Epop[10]], weight: 4.1363508E-4, delay 1.5
        h("Epop[10] syn_projEE_ampa[3690] = new ampa(0.5)")
        h("Epop[46] netConn_projEE_ampa[3690] = new NetCon(&v(0.5), syn_projEE_ampa[3690], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3691: cell 46, seg 0 (0.5) [0.5 on Epop[46]] -> cell 11, seg 0 (0.5) [0.5 on Epop[11]], weight: 4.1363508E-4, delay 1.5
        h("Epop[11] syn_projEE_ampa[3691] = new ampa(0.5)")
        h("Epop[46] netConn_projEE_ampa[3691] = new NetCon(&v(0.5), syn_projEE_ampa[3691], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3692: cell 46, seg 0 (0.5) [0.5 on Epop[46]] -> cell 12, seg 0 (0.5) [0.5 on Epop[12]], weight: 4.1363508E-4, delay 1.5
        h("Epop[12] syn_projEE_ampa[3692] = new ampa(0.5)")
        h("Epop[46] netConn_projEE_ampa[3692] = new NetCon(&v(0.5), syn_projEE_ampa[3692], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3693: cell 46, seg 0 (0.5) [0.5 on Epop[46]] -> cell 13, seg 0 (0.5) [0.5 on Epop[13]], weight: 4.1363508E-4, delay 1.5
        h("Epop[13] syn_projEE_ampa[3693] = new ampa(0.5)")
        h("Epop[46] netConn_projEE_ampa[3693] = new NetCon(&v(0.5), syn_projEE_ampa[3693], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3694: cell 46, seg 0 (0.5) [0.5 on Epop[46]] -> cell 14, seg 0 (0.5) [0.5 on Epop[14]], weight: 4.1363508E-4, delay 1.5
        h("Epop[14] syn_projEE_ampa[3694] = new ampa(0.5)")
        h("Epop[46] netConn_projEE_ampa[3694] = new NetCon(&v(0.5), syn_projEE_ampa[3694], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3695: cell 46, seg 0 (0.5) [0.5 on Epop[46]] -> cell 15, seg 0 (0.5) [0.5 on Epop[15]], weight: 4.1363508E-4, delay 1.5
        h("Epop[15] syn_projEE_ampa[3695] = new ampa(0.5)")
        h("Epop[46] netConn_projEE_ampa[3695] = new NetCon(&v(0.5), syn_projEE_ampa[3695], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3696: cell 46, seg 0 (0.5) [0.5 on Epop[46]] -> cell 16, seg 0 (0.5) [0.5 on Epop[16]], weight: 4.1363508E-4, delay 1.5
        h("Epop[16] syn_projEE_ampa[3696] = new ampa(0.5)")
        h("Epop[46] netConn_projEE_ampa[3696] = new NetCon(&v(0.5), syn_projEE_ampa[3696], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3697: cell 46, seg 0 (0.5) [0.5 on Epop[46]] -> cell 17, seg 0 (0.5) [0.5 on Epop[17]], weight: 4.1363508E-4, delay 1.5
        h("Epop[17] syn_projEE_ampa[3697] = new ampa(0.5)")
        h("Epop[46] netConn_projEE_ampa[3697] = new NetCon(&v(0.5), syn_projEE_ampa[3697], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3698: cell 46, seg 0 (0.5) [0.5 on Epop[46]] -> cell 18, seg 0 (0.5) [0.5 on Epop[18]], weight: 4.1363508E-4, delay 1.5
        h("Epop[18] syn_projEE_ampa[3698] = new ampa(0.5)")
        h("Epop[46] netConn_projEE_ampa[3698] = new NetCon(&v(0.5), syn_projEE_ampa[3698], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3699: cell 46, seg 0 (0.5) [0.5 on Epop[46]] -> cell 19, seg 0 (0.5) [0.5 on Epop[19]], weight: 4.1363508E-4, delay 1.5
        h("Epop[19] syn_projEE_ampa[3699] = new ampa(0.5)")
        h("Epop[46] netConn_projEE_ampa[3699] = new NetCon(&v(0.5), syn_projEE_ampa[3699], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3700: cell 46, seg 0 (0.5) [0.5 on Epop[46]] -> cell 20, seg 0 (0.5) [0.5 on Epop[20]], weight: 4.1363508E-4, delay 1.5
        h("Epop[20] syn_projEE_ampa[3700] = new ampa(0.5)")
        h("Epop[46] netConn_projEE_ampa[3700] = new NetCon(&v(0.5), syn_projEE_ampa[3700], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3701: cell 46, seg 0 (0.5) [0.5 on Epop[46]] -> cell 21, seg 0 (0.5) [0.5 on Epop[21]], weight: 4.1363508E-4, delay 1.5
        h("Epop[21] syn_projEE_ampa[3701] = new ampa(0.5)")
        h("Epop[46] netConn_projEE_ampa[3701] = new NetCon(&v(0.5), syn_projEE_ampa[3701], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3702: cell 46, seg 0 (0.5) [0.5 on Epop[46]] -> cell 22, seg 0 (0.5) [0.5 on Epop[22]], weight: 4.1363508E-4, delay 1.5
        h("Epop[22] syn_projEE_ampa[3702] = new ampa(0.5)")
        h("Epop[46] netConn_projEE_ampa[3702] = new NetCon(&v(0.5), syn_projEE_ampa[3702], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3703: cell 46, seg 0 (0.5) [0.5 on Epop[46]] -> cell 23, seg 0 (0.5) [0.5 on Epop[23]], weight: 4.1363508E-4, delay 1.5
        h("Epop[23] syn_projEE_ampa[3703] = new ampa(0.5)")
        h("Epop[46] netConn_projEE_ampa[3703] = new NetCon(&v(0.5), syn_projEE_ampa[3703], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3704: cell 46, seg 0 (0.5) [0.5 on Epop[46]] -> cell 24, seg 0 (0.5) [0.5 on Epop[24]], weight: 4.1363508E-4, delay 1.5
        h("Epop[24] syn_projEE_ampa[3704] = new ampa(0.5)")
        h("Epop[46] netConn_projEE_ampa[3704] = new NetCon(&v(0.5), syn_projEE_ampa[3704], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3705: cell 46, seg 0 (0.5) [0.5 on Epop[46]] -> cell 25, seg 0 (0.5) [0.5 on Epop[25]], weight: 4.1363508E-4, delay 1.5
        h("Epop[25] syn_projEE_ampa[3705] = new ampa(0.5)")
        h("Epop[46] netConn_projEE_ampa[3705] = new NetCon(&v(0.5), syn_projEE_ampa[3705], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3706: cell 46, seg 0 (0.5) [0.5 on Epop[46]] -> cell 26, seg 0 (0.5) [0.5 on Epop[26]], weight: 4.1363508E-4, delay 1.5
        h("Epop[26] syn_projEE_ampa[3706] = new ampa(0.5)")
        h("Epop[46] netConn_projEE_ampa[3706] = new NetCon(&v(0.5), syn_projEE_ampa[3706], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3707: cell 46, seg 0 (0.5) [0.5 on Epop[46]] -> cell 27, seg 0 (0.5) [0.5 on Epop[27]], weight: 4.1363508E-4, delay 1.5
        h("Epop[27] syn_projEE_ampa[3707] = new ampa(0.5)")
        h("Epop[46] netConn_projEE_ampa[3707] = new NetCon(&v(0.5), syn_projEE_ampa[3707], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3708: cell 46, seg 0 (0.5) [0.5 on Epop[46]] -> cell 28, seg 0 (0.5) [0.5 on Epop[28]], weight: 4.1363508E-4, delay 1.5
        h("Epop[28] syn_projEE_ampa[3708] = new ampa(0.5)")
        h("Epop[46] netConn_projEE_ampa[3708] = new NetCon(&v(0.5), syn_projEE_ampa[3708], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3709: cell 46, seg 0 (0.5) [0.5 on Epop[46]] -> cell 29, seg 0 (0.5) [0.5 on Epop[29]], weight: 4.1363508E-4, delay 1.5
        h("Epop[29] syn_projEE_ampa[3709] = new ampa(0.5)")
        h("Epop[46] netConn_projEE_ampa[3709] = new NetCon(&v(0.5), syn_projEE_ampa[3709], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3710: cell 46, seg 0 (0.5) [0.5 on Epop[46]] -> cell 30, seg 0 (0.5) [0.5 on Epop[30]], weight: 4.1363508E-4, delay 1.5
        h("Epop[30] syn_projEE_ampa[3710] = new ampa(0.5)")
        h("Epop[46] netConn_projEE_ampa[3710] = new NetCon(&v(0.5), syn_projEE_ampa[3710], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3711: cell 46, seg 0 (0.5) [0.5 on Epop[46]] -> cell 31, seg 0 (0.5) [0.5 on Epop[31]], weight: 4.1363508E-4, delay 1.5
        h("Epop[31] syn_projEE_ampa[3711] = new ampa(0.5)")
        h("Epop[46] netConn_projEE_ampa[3711] = new NetCon(&v(0.5), syn_projEE_ampa[3711], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3712: cell 46, seg 0 (0.5) [0.5 on Epop[46]] -> cell 32, seg 0 (0.5) [0.5 on Epop[32]], weight: 4.1363508E-4, delay 1.5
        h("Epop[32] syn_projEE_ampa[3712] = new ampa(0.5)")
        h("Epop[46] netConn_projEE_ampa[3712] = new NetCon(&v(0.5), syn_projEE_ampa[3712], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3713: cell 46, seg 0 (0.5) [0.5 on Epop[46]] -> cell 33, seg 0 (0.5) [0.5 on Epop[33]], weight: 4.1363508E-4, delay 1.5
        h("Epop[33] syn_projEE_ampa[3713] = new ampa(0.5)")
        h("Epop[46] netConn_projEE_ampa[3713] = new NetCon(&v(0.5), syn_projEE_ampa[3713], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3714: cell 46, seg 0 (0.5) [0.5 on Epop[46]] -> cell 34, seg 0 (0.5) [0.5 on Epop[34]], weight: 4.1363508E-4, delay 1.5
        h("Epop[34] syn_projEE_ampa[3714] = new ampa(0.5)")
        h("Epop[46] netConn_projEE_ampa[3714] = new NetCon(&v(0.5), syn_projEE_ampa[3714], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3715: cell 46, seg 0 (0.5) [0.5 on Epop[46]] -> cell 35, seg 0 (0.5) [0.5 on Epop[35]], weight: 4.1363508E-4, delay 1.5
        h("Epop[35] syn_projEE_ampa[3715] = new ampa(0.5)")
        h("Epop[46] netConn_projEE_ampa[3715] = new NetCon(&v(0.5), syn_projEE_ampa[3715], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3716: cell 46, seg 0 (0.5) [0.5 on Epop[46]] -> cell 36, seg 0 (0.5) [0.5 on Epop[36]], weight: 4.1363508E-4, delay 1.5
        h("Epop[36] syn_projEE_ampa[3716] = new ampa(0.5)")
        h("Epop[46] netConn_projEE_ampa[3716] = new NetCon(&v(0.5), syn_projEE_ampa[3716], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3717: cell 46, seg 0 (0.5) [0.5 on Epop[46]] -> cell 37, seg 0 (0.5) [0.5 on Epop[37]], weight: 4.1363508E-4, delay 1.5
        h("Epop[37] syn_projEE_ampa[3717] = new ampa(0.5)")
        h("Epop[46] netConn_projEE_ampa[3717] = new NetCon(&v(0.5), syn_projEE_ampa[3717], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3718: cell 46, seg 0 (0.5) [0.5 on Epop[46]] -> cell 38, seg 0 (0.5) [0.5 on Epop[38]], weight: 4.1363508E-4, delay 1.5
        h("Epop[38] syn_projEE_ampa[3718] = new ampa(0.5)")
        h("Epop[46] netConn_projEE_ampa[3718] = new NetCon(&v(0.5), syn_projEE_ampa[3718], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3719: cell 46, seg 0 (0.5) [0.5 on Epop[46]] -> cell 39, seg 0 (0.5) [0.5 on Epop[39]], weight: 4.1363508E-4, delay 1.5
        h("Epop[39] syn_projEE_ampa[3719] = new ampa(0.5)")
        h("Epop[46] netConn_projEE_ampa[3719] = new NetCon(&v(0.5), syn_projEE_ampa[3719], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3720: cell 46, seg 0 (0.5) [0.5 on Epop[46]] -> cell 40, seg 0 (0.5) [0.5 on Epop[40]], weight: 4.1363508E-4, delay 1.5
        h("Epop[40] syn_projEE_ampa[3720] = new ampa(0.5)")
        h("Epop[46] netConn_projEE_ampa[3720] = new NetCon(&v(0.5), syn_projEE_ampa[3720], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3721: cell 46, seg 0 (0.5) [0.5 on Epop[46]] -> cell 41, seg 0 (0.5) [0.5 on Epop[41]], weight: 4.1363508E-4, delay 1.5
        h("Epop[41] syn_projEE_ampa[3721] = new ampa(0.5)")
        h("Epop[46] netConn_projEE_ampa[3721] = new NetCon(&v(0.5), syn_projEE_ampa[3721], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3722: cell 46, seg 0 (0.5) [0.5 on Epop[46]] -> cell 42, seg 0 (0.5) [0.5 on Epop[42]], weight: 4.1363508E-4, delay 1.5
        h("Epop[42] syn_projEE_ampa[3722] = new ampa(0.5)")
        h("Epop[46] netConn_projEE_ampa[3722] = new NetCon(&v(0.5), syn_projEE_ampa[3722], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3723: cell 46, seg 0 (0.5) [0.5 on Epop[46]] -> cell 43, seg 0 (0.5) [0.5 on Epop[43]], weight: 4.1363508E-4, delay 1.5
        h("Epop[43] syn_projEE_ampa[3723] = new ampa(0.5)")
        h("Epop[46] netConn_projEE_ampa[3723] = new NetCon(&v(0.5), syn_projEE_ampa[3723], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3724: cell 46, seg 0 (0.5) [0.5 on Epop[46]] -> cell 44, seg 0 (0.5) [0.5 on Epop[44]], weight: 4.1363508E-4, delay 1.5
        h("Epop[44] syn_projEE_ampa[3724] = new ampa(0.5)")
        h("Epop[46] netConn_projEE_ampa[3724] = new NetCon(&v(0.5), syn_projEE_ampa[3724], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3725: cell 46, seg 0 (0.5) [0.5 on Epop[46]] -> cell 45, seg 0 (0.5) [0.5 on Epop[45]], weight: 4.1363508E-4, delay 1.5
        h("Epop[45] syn_projEE_ampa[3725] = new ampa(0.5)")
        h("Epop[46] netConn_projEE_ampa[3725] = new NetCon(&v(0.5), syn_projEE_ampa[3725], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3726: cell 46, seg 0 (0.5) [0.5 on Epop[46]] -> cell 46, seg 0 (0.5) [0.5 on Epop[46]], weight: 4.1363508E-4, delay 1.5
        h("Epop[46] syn_projEE_ampa[3726] = new ampa(0.5)")
        h("Epop[46] netConn_projEE_ampa[3726] = new NetCon(&v(0.5), syn_projEE_ampa[3726], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3727: cell 46, seg 0 (0.5) [0.5 on Epop[46]] -> cell 47, seg 0 (0.5) [0.5 on Epop[47]], weight: 4.1363508E-4, delay 1.5
        h("Epop[47] syn_projEE_ampa[3727] = new ampa(0.5)")
        h("Epop[46] netConn_projEE_ampa[3727] = new NetCon(&v(0.5), syn_projEE_ampa[3727], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3728: cell 46, seg 0 (0.5) [0.5 on Epop[46]] -> cell 48, seg 0 (0.5) [0.5 on Epop[48]], weight: 4.1363508E-4, delay 1.5
        h("Epop[48] syn_projEE_ampa[3728] = new ampa(0.5)")
        h("Epop[46] netConn_projEE_ampa[3728] = new NetCon(&v(0.5), syn_projEE_ampa[3728], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3729: cell 46, seg 0 (0.5) [0.5 on Epop[46]] -> cell 49, seg 0 (0.5) [0.5 on Epop[49]], weight: 4.1363508E-4, delay 1.5
        h("Epop[49] syn_projEE_ampa[3729] = new ampa(0.5)")
        h("Epop[46] netConn_projEE_ampa[3729] = new NetCon(&v(0.5), syn_projEE_ampa[3729], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3730: cell 46, seg 0 (0.5) [0.5 on Epop[46]] -> cell 50, seg 0 (0.5) [0.5 on Epop[50]], weight: 4.1363508E-4, delay 1.5
        h("Epop[50] syn_projEE_ampa[3730] = new ampa(0.5)")
        h("Epop[46] netConn_projEE_ampa[3730] = new NetCon(&v(0.5), syn_projEE_ampa[3730], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3731: cell 46, seg 0 (0.5) [0.5 on Epop[46]] -> cell 51, seg 0 (0.5) [0.5 on Epop[51]], weight: 4.1363508E-4, delay 1.5
        h("Epop[51] syn_projEE_ampa[3731] = new ampa(0.5)")
        h("Epop[46] netConn_projEE_ampa[3731] = new NetCon(&v(0.5), syn_projEE_ampa[3731], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3732: cell 46, seg 0 (0.5) [0.5 on Epop[46]] -> cell 52, seg 0 (0.5) [0.5 on Epop[52]], weight: 4.1363508E-4, delay 1.5
        h("Epop[52] syn_projEE_ampa[3732] = new ampa(0.5)")
        h("Epop[46] netConn_projEE_ampa[3732] = new NetCon(&v(0.5), syn_projEE_ampa[3732], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3733: cell 46, seg 0 (0.5) [0.5 on Epop[46]] -> cell 53, seg 0 (0.5) [0.5 on Epop[53]], weight: 4.1363508E-4, delay 1.5
        h("Epop[53] syn_projEE_ampa[3733] = new ampa(0.5)")
        h("Epop[46] netConn_projEE_ampa[3733] = new NetCon(&v(0.5), syn_projEE_ampa[3733], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3734: cell 46, seg 0 (0.5) [0.5 on Epop[46]] -> cell 54, seg 0 (0.5) [0.5 on Epop[54]], weight: 4.1363508E-4, delay 1.5
        h("Epop[54] syn_projEE_ampa[3734] = new ampa(0.5)")
        h("Epop[46] netConn_projEE_ampa[3734] = new NetCon(&v(0.5), syn_projEE_ampa[3734], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3735: cell 46, seg 0 (0.5) [0.5 on Epop[46]] -> cell 55, seg 0 (0.5) [0.5 on Epop[55]], weight: 4.1363508E-4, delay 1.5
        h("Epop[55] syn_projEE_ampa[3735] = new ampa(0.5)")
        h("Epop[46] netConn_projEE_ampa[3735] = new NetCon(&v(0.5), syn_projEE_ampa[3735], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3736: cell 46, seg 0 (0.5) [0.5 on Epop[46]] -> cell 56, seg 0 (0.5) [0.5 on Epop[56]], weight: 4.1363508E-4, delay 1.5
        h("Epop[56] syn_projEE_ampa[3736] = new ampa(0.5)")
        h("Epop[46] netConn_projEE_ampa[3736] = new NetCon(&v(0.5), syn_projEE_ampa[3736], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3737: cell 46, seg 0 (0.5) [0.5 on Epop[46]] -> cell 57, seg 0 (0.5) [0.5 on Epop[57]], weight: 4.1363508E-4, delay 1.5
        h("Epop[57] syn_projEE_ampa[3737] = new ampa(0.5)")
        h("Epop[46] netConn_projEE_ampa[3737] = new NetCon(&v(0.5), syn_projEE_ampa[3737], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3738: cell 46, seg 0 (0.5) [0.5 on Epop[46]] -> cell 58, seg 0 (0.5) [0.5 on Epop[58]], weight: 4.1363508E-4, delay 1.5
        h("Epop[58] syn_projEE_ampa[3738] = new ampa(0.5)")
        h("Epop[46] netConn_projEE_ampa[3738] = new NetCon(&v(0.5), syn_projEE_ampa[3738], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3739: cell 46, seg 0 (0.5) [0.5 on Epop[46]] -> cell 59, seg 0 (0.5) [0.5 on Epop[59]], weight: 4.1363508E-4, delay 1.5
        h("Epop[59] syn_projEE_ampa[3739] = new ampa(0.5)")
        h("Epop[46] netConn_projEE_ampa[3739] = new NetCon(&v(0.5), syn_projEE_ampa[3739], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3740: cell 46, seg 0 (0.5) [0.5 on Epop[46]] -> cell 60, seg 0 (0.5) [0.5 on Epop[60]], weight: 4.1363508E-4, delay 1.5
        h("Epop[60] syn_projEE_ampa[3740] = new ampa(0.5)")
        h("Epop[46] netConn_projEE_ampa[3740] = new NetCon(&v(0.5), syn_projEE_ampa[3740], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3741: cell 46, seg 0 (0.5) [0.5 on Epop[46]] -> cell 61, seg 0 (0.5) [0.5 on Epop[61]], weight: 4.1363508E-4, delay 1.5
        h("Epop[61] syn_projEE_ampa[3741] = new ampa(0.5)")
        h("Epop[46] netConn_projEE_ampa[3741] = new NetCon(&v(0.5), syn_projEE_ampa[3741], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3742: cell 46, seg 0 (0.5) [0.5 on Epop[46]] -> cell 62, seg 0 (0.5) [0.5 on Epop[62]], weight: 4.1363508E-4, delay 1.5
        h("Epop[62] syn_projEE_ampa[3742] = new ampa(0.5)")
        h("Epop[46] netConn_projEE_ampa[3742] = new NetCon(&v(0.5), syn_projEE_ampa[3742], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3743: cell 46, seg 0 (0.5) [0.5 on Epop[46]] -> cell 63, seg 0 (0.5) [0.5 on Epop[63]], weight: 4.1363508E-4, delay 1.5
        h("Epop[63] syn_projEE_ampa[3743] = new ampa(0.5)")
        h("Epop[46] netConn_projEE_ampa[3743] = new NetCon(&v(0.5), syn_projEE_ampa[3743], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3744: cell 46, seg 0 (0.5) [0.5 on Epop[46]] -> cell 64, seg 0 (0.5) [0.5 on Epop[64]], weight: 4.1363508E-4, delay 1.5
        h("Epop[64] syn_projEE_ampa[3744] = new ampa(0.5)")
        h("Epop[46] netConn_projEE_ampa[3744] = new NetCon(&v(0.5), syn_projEE_ampa[3744], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3745: cell 46, seg 0 (0.5) [0.5 on Epop[46]] -> cell 65, seg 0 (0.5) [0.5 on Epop[65]], weight: 4.1363508E-4, delay 1.5
        h("Epop[65] syn_projEE_ampa[3745] = new ampa(0.5)")
        h("Epop[46] netConn_projEE_ampa[3745] = new NetCon(&v(0.5), syn_projEE_ampa[3745], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3746: cell 46, seg 0 (0.5) [0.5 on Epop[46]] -> cell 66, seg 0 (0.5) [0.5 on Epop[66]], weight: 4.1363508E-4, delay 1.5
        h("Epop[66] syn_projEE_ampa[3746] = new ampa(0.5)")
        h("Epop[46] netConn_projEE_ampa[3746] = new NetCon(&v(0.5), syn_projEE_ampa[3746], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3747: cell 46, seg 0 (0.5) [0.5 on Epop[46]] -> cell 67, seg 0 (0.5) [0.5 on Epop[67]], weight: 4.1363508E-4, delay 1.5
        h("Epop[67] syn_projEE_ampa[3747] = new ampa(0.5)")
        h("Epop[46] netConn_projEE_ampa[3747] = new NetCon(&v(0.5), syn_projEE_ampa[3747], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3748: cell 46, seg 0 (0.5) [0.5 on Epop[46]] -> cell 68, seg 0 (0.5) [0.5 on Epop[68]], weight: 4.1363508E-4, delay 1.5
        h("Epop[68] syn_projEE_ampa[3748] = new ampa(0.5)")
        h("Epop[46] netConn_projEE_ampa[3748] = new NetCon(&v(0.5), syn_projEE_ampa[3748], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3749: cell 46, seg 0 (0.5) [0.5 on Epop[46]] -> cell 69, seg 0 (0.5) [0.5 on Epop[69]], weight: 4.1363508E-4, delay 1.5
        h("Epop[69] syn_projEE_ampa[3749] = new ampa(0.5)")
        h("Epop[46] netConn_projEE_ampa[3749] = new NetCon(&v(0.5), syn_projEE_ampa[3749], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3750: cell 46, seg 0 (0.5) [0.5 on Epop[46]] -> cell 70, seg 0 (0.5) [0.5 on Epop[70]], weight: 4.1363508E-4, delay 1.5
        h("Epop[70] syn_projEE_ampa[3750] = new ampa(0.5)")
        h("Epop[46] netConn_projEE_ampa[3750] = new NetCon(&v(0.5), syn_projEE_ampa[3750], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3751: cell 46, seg 0 (0.5) [0.5 on Epop[46]] -> cell 71, seg 0 (0.5) [0.5 on Epop[71]], weight: 4.1363508E-4, delay 1.5
        h("Epop[71] syn_projEE_ampa[3751] = new ampa(0.5)")
        h("Epop[46] netConn_projEE_ampa[3751] = new NetCon(&v(0.5), syn_projEE_ampa[3751], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3752: cell 46, seg 0 (0.5) [0.5 on Epop[46]] -> cell 72, seg 0 (0.5) [0.5 on Epop[72]], weight: 4.1363508E-4, delay 1.5
        h("Epop[72] syn_projEE_ampa[3752] = new ampa(0.5)")
        h("Epop[46] netConn_projEE_ampa[3752] = new NetCon(&v(0.5), syn_projEE_ampa[3752], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3753: cell 46, seg 0 (0.5) [0.5 on Epop[46]] -> cell 73, seg 0 (0.5) [0.5 on Epop[73]], weight: 4.1363508E-4, delay 1.5
        h("Epop[73] syn_projEE_ampa[3753] = new ampa(0.5)")
        h("Epop[46] netConn_projEE_ampa[3753] = new NetCon(&v(0.5), syn_projEE_ampa[3753], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3754: cell 46, seg 0 (0.5) [0.5 on Epop[46]] -> cell 74, seg 0 (0.5) [0.5 on Epop[74]], weight: 4.1363508E-4, delay 1.5
        h("Epop[74] syn_projEE_ampa[3754] = new ampa(0.5)")
        h("Epop[46] netConn_projEE_ampa[3754] = new NetCon(&v(0.5), syn_projEE_ampa[3754], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3755: cell 46, seg 0 (0.5) [0.5 on Epop[46]] -> cell 75, seg 0 (0.5) [0.5 on Epop[75]], weight: 4.1363508E-4, delay 1.5
        h("Epop[75] syn_projEE_ampa[3755] = new ampa(0.5)")
        h("Epop[46] netConn_projEE_ampa[3755] = new NetCon(&v(0.5), syn_projEE_ampa[3755], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3756: cell 46, seg 0 (0.5) [0.5 on Epop[46]] -> cell 76, seg 0 (0.5) [0.5 on Epop[76]], weight: 4.1363508E-4, delay 1.5
        h("Epop[76] syn_projEE_ampa[3756] = new ampa(0.5)")
        h("Epop[46] netConn_projEE_ampa[3756] = new NetCon(&v(0.5), syn_projEE_ampa[3756], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3757: cell 46, seg 0 (0.5) [0.5 on Epop[46]] -> cell 77, seg 0 (0.5) [0.5 on Epop[77]], weight: 4.1363508E-4, delay 1.5
        h("Epop[77] syn_projEE_ampa[3757] = new ampa(0.5)")
        h("Epop[46] netConn_projEE_ampa[3757] = new NetCon(&v(0.5), syn_projEE_ampa[3757], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3758: cell 46, seg 0 (0.5) [0.5 on Epop[46]] -> cell 78, seg 0 (0.5) [0.5 on Epop[78]], weight: 4.1363508E-4, delay 1.5
        h("Epop[78] syn_projEE_ampa[3758] = new ampa(0.5)")
        h("Epop[46] netConn_projEE_ampa[3758] = new NetCon(&v(0.5), syn_projEE_ampa[3758], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3759: cell 46, seg 0 (0.5) [0.5 on Epop[46]] -> cell 79, seg 0 (0.5) [0.5 on Epop[79]], weight: 4.1363508E-4, delay 1.5
        h("Epop[79] syn_projEE_ampa[3759] = new ampa(0.5)")
        h("Epop[46] netConn_projEE_ampa[3759] = new NetCon(&v(0.5), syn_projEE_ampa[3759], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3760: cell 47, seg 0 (0.5) [0.5 on Epop[47]] -> cell 0, seg 0 (0.5) [0.5 on Epop[0]], weight: 4.1363508E-4, delay 1.5
        h("Epop[0] syn_projEE_ampa[3760] = new ampa(0.5)")
        h("Epop[47] netConn_projEE_ampa[3760] = new NetCon(&v(0.5), syn_projEE_ampa[3760], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3761: cell 47, seg 0 (0.5) [0.5 on Epop[47]] -> cell 1, seg 0 (0.5) [0.5 on Epop[1]], weight: 4.1363508E-4, delay 1.5
        h("Epop[1] syn_projEE_ampa[3761] = new ampa(0.5)")
        h("Epop[47] netConn_projEE_ampa[3761] = new NetCon(&v(0.5), syn_projEE_ampa[3761], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3762: cell 47, seg 0 (0.5) [0.5 on Epop[47]] -> cell 2, seg 0 (0.5) [0.5 on Epop[2]], weight: 4.1363508E-4, delay 1.5
        h("Epop[2] syn_projEE_ampa[3762] = new ampa(0.5)")
        h("Epop[47] netConn_projEE_ampa[3762] = new NetCon(&v(0.5), syn_projEE_ampa[3762], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3763: cell 47, seg 0 (0.5) [0.5 on Epop[47]] -> cell 3, seg 0 (0.5) [0.5 on Epop[3]], weight: 4.1363508E-4, delay 1.5
        h("Epop[3] syn_projEE_ampa[3763] = new ampa(0.5)")
        h("Epop[47] netConn_projEE_ampa[3763] = new NetCon(&v(0.5), syn_projEE_ampa[3763], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3764: cell 47, seg 0 (0.5) [0.5 on Epop[47]] -> cell 4, seg 0 (0.5) [0.5 on Epop[4]], weight: 4.1363508E-4, delay 1.5
        h("Epop[4] syn_projEE_ampa[3764] = new ampa(0.5)")
        h("Epop[47] netConn_projEE_ampa[3764] = new NetCon(&v(0.5), syn_projEE_ampa[3764], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3765: cell 47, seg 0 (0.5) [0.5 on Epop[47]] -> cell 5, seg 0 (0.5) [0.5 on Epop[5]], weight: 4.1363508E-4, delay 1.5
        h("Epop[5] syn_projEE_ampa[3765] = new ampa(0.5)")
        h("Epop[47] netConn_projEE_ampa[3765] = new NetCon(&v(0.5), syn_projEE_ampa[3765], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3766: cell 47, seg 0 (0.5) [0.5 on Epop[47]] -> cell 6, seg 0 (0.5) [0.5 on Epop[6]], weight: 4.1363508E-4, delay 1.5
        h("Epop[6] syn_projEE_ampa[3766] = new ampa(0.5)")
        h("Epop[47] netConn_projEE_ampa[3766] = new NetCon(&v(0.5), syn_projEE_ampa[3766], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3767: cell 47, seg 0 (0.5) [0.5 on Epop[47]] -> cell 7, seg 0 (0.5) [0.5 on Epop[7]], weight: 4.1363508E-4, delay 1.5
        h("Epop[7] syn_projEE_ampa[3767] = new ampa(0.5)")
        h("Epop[47] netConn_projEE_ampa[3767] = new NetCon(&v(0.5), syn_projEE_ampa[3767], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3768: cell 47, seg 0 (0.5) [0.5 on Epop[47]] -> cell 8, seg 0 (0.5) [0.5 on Epop[8]], weight: 4.1363508E-4, delay 1.5
        h("Epop[8] syn_projEE_ampa[3768] = new ampa(0.5)")
        h("Epop[47] netConn_projEE_ampa[3768] = new NetCon(&v(0.5), syn_projEE_ampa[3768], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3769: cell 47, seg 0 (0.5) [0.5 on Epop[47]] -> cell 9, seg 0 (0.5) [0.5 on Epop[9]], weight: 4.1363508E-4, delay 1.5
        h("Epop[9] syn_projEE_ampa[3769] = new ampa(0.5)")
        h("Epop[47] netConn_projEE_ampa[3769] = new NetCon(&v(0.5), syn_projEE_ampa[3769], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3770: cell 47, seg 0 (0.5) [0.5 on Epop[47]] -> cell 10, seg 0 (0.5) [0.5 on Epop[10]], weight: 4.1363508E-4, delay 1.5
        h("Epop[10] syn_projEE_ampa[3770] = new ampa(0.5)")
        h("Epop[47] netConn_projEE_ampa[3770] = new NetCon(&v(0.5), syn_projEE_ampa[3770], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3771: cell 47, seg 0 (0.5) [0.5 on Epop[47]] -> cell 11, seg 0 (0.5) [0.5 on Epop[11]], weight: 4.1363508E-4, delay 1.5
        h("Epop[11] syn_projEE_ampa[3771] = new ampa(0.5)")
        h("Epop[47] netConn_projEE_ampa[3771] = new NetCon(&v(0.5), syn_projEE_ampa[3771], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3772: cell 47, seg 0 (0.5) [0.5 on Epop[47]] -> cell 12, seg 0 (0.5) [0.5 on Epop[12]], weight: 4.1363508E-4, delay 1.5
        h("Epop[12] syn_projEE_ampa[3772] = new ampa(0.5)")
        h("Epop[47] netConn_projEE_ampa[3772] = new NetCon(&v(0.5), syn_projEE_ampa[3772], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3773: cell 47, seg 0 (0.5) [0.5 on Epop[47]] -> cell 13, seg 0 (0.5) [0.5 on Epop[13]], weight: 4.1363508E-4, delay 1.5
        h("Epop[13] syn_projEE_ampa[3773] = new ampa(0.5)")
        h("Epop[47] netConn_projEE_ampa[3773] = new NetCon(&v(0.5), syn_projEE_ampa[3773], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3774: cell 47, seg 0 (0.5) [0.5 on Epop[47]] -> cell 14, seg 0 (0.5) [0.5 on Epop[14]], weight: 4.1363508E-4, delay 1.5
        h("Epop[14] syn_projEE_ampa[3774] = new ampa(0.5)")
        h("Epop[47] netConn_projEE_ampa[3774] = new NetCon(&v(0.5), syn_projEE_ampa[3774], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3775: cell 47, seg 0 (0.5) [0.5 on Epop[47]] -> cell 15, seg 0 (0.5) [0.5 on Epop[15]], weight: 4.1363508E-4, delay 1.5
        h("Epop[15] syn_projEE_ampa[3775] = new ampa(0.5)")
        h("Epop[47] netConn_projEE_ampa[3775] = new NetCon(&v(0.5), syn_projEE_ampa[3775], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3776: cell 47, seg 0 (0.5) [0.5 on Epop[47]] -> cell 16, seg 0 (0.5) [0.5 on Epop[16]], weight: 4.1363508E-4, delay 1.5
        h("Epop[16] syn_projEE_ampa[3776] = new ampa(0.5)")
        h("Epop[47] netConn_projEE_ampa[3776] = new NetCon(&v(0.5), syn_projEE_ampa[3776], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3777: cell 47, seg 0 (0.5) [0.5 on Epop[47]] -> cell 17, seg 0 (0.5) [0.5 on Epop[17]], weight: 4.1363508E-4, delay 1.5
        h("Epop[17] syn_projEE_ampa[3777] = new ampa(0.5)")
        h("Epop[47] netConn_projEE_ampa[3777] = new NetCon(&v(0.5), syn_projEE_ampa[3777], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3778: cell 47, seg 0 (0.5) [0.5 on Epop[47]] -> cell 18, seg 0 (0.5) [0.5 on Epop[18]], weight: 4.1363508E-4, delay 1.5
        h("Epop[18] syn_projEE_ampa[3778] = new ampa(0.5)")
        h("Epop[47] netConn_projEE_ampa[3778] = new NetCon(&v(0.5), syn_projEE_ampa[3778], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3779: cell 47, seg 0 (0.5) [0.5 on Epop[47]] -> cell 19, seg 0 (0.5) [0.5 on Epop[19]], weight: 4.1363508E-4, delay 1.5
        h("Epop[19] syn_projEE_ampa[3779] = new ampa(0.5)")
        h("Epop[47] netConn_projEE_ampa[3779] = new NetCon(&v(0.5), syn_projEE_ampa[3779], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3780: cell 47, seg 0 (0.5) [0.5 on Epop[47]] -> cell 20, seg 0 (0.5) [0.5 on Epop[20]], weight: 4.1363508E-4, delay 1.5
        h("Epop[20] syn_projEE_ampa[3780] = new ampa(0.5)")
        h("Epop[47] netConn_projEE_ampa[3780] = new NetCon(&v(0.5), syn_projEE_ampa[3780], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3781: cell 47, seg 0 (0.5) [0.5 on Epop[47]] -> cell 21, seg 0 (0.5) [0.5 on Epop[21]], weight: 4.1363508E-4, delay 1.5
        h("Epop[21] syn_projEE_ampa[3781] = new ampa(0.5)")
        h("Epop[47] netConn_projEE_ampa[3781] = new NetCon(&v(0.5), syn_projEE_ampa[3781], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3782: cell 47, seg 0 (0.5) [0.5 on Epop[47]] -> cell 22, seg 0 (0.5) [0.5 on Epop[22]], weight: 4.1363508E-4, delay 1.5
        h("Epop[22] syn_projEE_ampa[3782] = new ampa(0.5)")
        h("Epop[47] netConn_projEE_ampa[3782] = new NetCon(&v(0.5), syn_projEE_ampa[3782], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3783: cell 47, seg 0 (0.5) [0.5 on Epop[47]] -> cell 23, seg 0 (0.5) [0.5 on Epop[23]], weight: 4.1363508E-4, delay 1.5
        h("Epop[23] syn_projEE_ampa[3783] = new ampa(0.5)")
        h("Epop[47] netConn_projEE_ampa[3783] = new NetCon(&v(0.5), syn_projEE_ampa[3783], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3784: cell 47, seg 0 (0.5) [0.5 on Epop[47]] -> cell 24, seg 0 (0.5) [0.5 on Epop[24]], weight: 4.1363508E-4, delay 1.5
        h("Epop[24] syn_projEE_ampa[3784] = new ampa(0.5)")
        h("Epop[47] netConn_projEE_ampa[3784] = new NetCon(&v(0.5), syn_projEE_ampa[3784], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3785: cell 47, seg 0 (0.5) [0.5 on Epop[47]] -> cell 25, seg 0 (0.5) [0.5 on Epop[25]], weight: 4.1363508E-4, delay 1.5
        h("Epop[25] syn_projEE_ampa[3785] = new ampa(0.5)")
        h("Epop[47] netConn_projEE_ampa[3785] = new NetCon(&v(0.5), syn_projEE_ampa[3785], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3786: cell 47, seg 0 (0.5) [0.5 on Epop[47]] -> cell 26, seg 0 (0.5) [0.5 on Epop[26]], weight: 4.1363508E-4, delay 1.5
        h("Epop[26] syn_projEE_ampa[3786] = new ampa(0.5)")
        h("Epop[47] netConn_projEE_ampa[3786] = new NetCon(&v(0.5), syn_projEE_ampa[3786], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3787: cell 47, seg 0 (0.5) [0.5 on Epop[47]] -> cell 27, seg 0 (0.5) [0.5 on Epop[27]], weight: 4.1363508E-4, delay 1.5
        h("Epop[27] syn_projEE_ampa[3787] = new ampa(0.5)")
        h("Epop[47] netConn_projEE_ampa[3787] = new NetCon(&v(0.5), syn_projEE_ampa[3787], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3788: cell 47, seg 0 (0.5) [0.5 on Epop[47]] -> cell 28, seg 0 (0.5) [0.5 on Epop[28]], weight: 4.1363508E-4, delay 1.5
        h("Epop[28] syn_projEE_ampa[3788] = new ampa(0.5)")
        h("Epop[47] netConn_projEE_ampa[3788] = new NetCon(&v(0.5), syn_projEE_ampa[3788], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3789: cell 47, seg 0 (0.5) [0.5 on Epop[47]] -> cell 29, seg 0 (0.5) [0.5 on Epop[29]], weight: 4.1363508E-4, delay 1.5
        h("Epop[29] syn_projEE_ampa[3789] = new ampa(0.5)")
        h("Epop[47] netConn_projEE_ampa[3789] = new NetCon(&v(0.5), syn_projEE_ampa[3789], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3790: cell 47, seg 0 (0.5) [0.5 on Epop[47]] -> cell 30, seg 0 (0.5) [0.5 on Epop[30]], weight: 4.1363508E-4, delay 1.5
        h("Epop[30] syn_projEE_ampa[3790] = new ampa(0.5)")
        h("Epop[47] netConn_projEE_ampa[3790] = new NetCon(&v(0.5), syn_projEE_ampa[3790], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3791: cell 47, seg 0 (0.5) [0.5 on Epop[47]] -> cell 31, seg 0 (0.5) [0.5 on Epop[31]], weight: 4.1363508E-4, delay 1.5
        h("Epop[31] syn_projEE_ampa[3791] = new ampa(0.5)")
        h("Epop[47] netConn_projEE_ampa[3791] = new NetCon(&v(0.5), syn_projEE_ampa[3791], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3792: cell 47, seg 0 (0.5) [0.5 on Epop[47]] -> cell 32, seg 0 (0.5) [0.5 on Epop[32]], weight: 4.1363508E-4, delay 1.5
        h("Epop[32] syn_projEE_ampa[3792] = new ampa(0.5)")
        h("Epop[47] netConn_projEE_ampa[3792] = new NetCon(&v(0.5), syn_projEE_ampa[3792], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3793: cell 47, seg 0 (0.5) [0.5 on Epop[47]] -> cell 33, seg 0 (0.5) [0.5 on Epop[33]], weight: 4.1363508E-4, delay 1.5
        h("Epop[33] syn_projEE_ampa[3793] = new ampa(0.5)")
        h("Epop[47] netConn_projEE_ampa[3793] = new NetCon(&v(0.5), syn_projEE_ampa[3793], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3794: cell 47, seg 0 (0.5) [0.5 on Epop[47]] -> cell 34, seg 0 (0.5) [0.5 on Epop[34]], weight: 4.1363508E-4, delay 1.5
        h("Epop[34] syn_projEE_ampa[3794] = new ampa(0.5)")
        h("Epop[47] netConn_projEE_ampa[3794] = new NetCon(&v(0.5), syn_projEE_ampa[3794], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3795: cell 47, seg 0 (0.5) [0.5 on Epop[47]] -> cell 35, seg 0 (0.5) [0.5 on Epop[35]], weight: 4.1363508E-4, delay 1.5
        h("Epop[35] syn_projEE_ampa[3795] = new ampa(0.5)")
        h("Epop[47] netConn_projEE_ampa[3795] = new NetCon(&v(0.5), syn_projEE_ampa[3795], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3796: cell 47, seg 0 (0.5) [0.5 on Epop[47]] -> cell 36, seg 0 (0.5) [0.5 on Epop[36]], weight: 4.1363508E-4, delay 1.5
        h("Epop[36] syn_projEE_ampa[3796] = new ampa(0.5)")
        h("Epop[47] netConn_projEE_ampa[3796] = new NetCon(&v(0.5), syn_projEE_ampa[3796], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3797: cell 47, seg 0 (0.5) [0.5 on Epop[47]] -> cell 37, seg 0 (0.5) [0.5 on Epop[37]], weight: 4.1363508E-4, delay 1.5
        h("Epop[37] syn_projEE_ampa[3797] = new ampa(0.5)")
        h("Epop[47] netConn_projEE_ampa[3797] = new NetCon(&v(0.5), syn_projEE_ampa[3797], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3798: cell 47, seg 0 (0.5) [0.5 on Epop[47]] -> cell 38, seg 0 (0.5) [0.5 on Epop[38]], weight: 4.1363508E-4, delay 1.5
        h("Epop[38] syn_projEE_ampa[3798] = new ampa(0.5)")
        h("Epop[47] netConn_projEE_ampa[3798] = new NetCon(&v(0.5), syn_projEE_ampa[3798], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3799: cell 47, seg 0 (0.5) [0.5 on Epop[47]] -> cell 39, seg 0 (0.5) [0.5 on Epop[39]], weight: 4.1363508E-4, delay 1.5
        h("Epop[39] syn_projEE_ampa[3799] = new ampa(0.5)")
        h("Epop[47] netConn_projEE_ampa[3799] = new NetCon(&v(0.5), syn_projEE_ampa[3799], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3800: cell 47, seg 0 (0.5) [0.5 on Epop[47]] -> cell 40, seg 0 (0.5) [0.5 on Epop[40]], weight: 4.1363508E-4, delay 1.5
        h("Epop[40] syn_projEE_ampa[3800] = new ampa(0.5)")
        h("Epop[47] netConn_projEE_ampa[3800] = new NetCon(&v(0.5), syn_projEE_ampa[3800], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3801: cell 47, seg 0 (0.5) [0.5 on Epop[47]] -> cell 41, seg 0 (0.5) [0.5 on Epop[41]], weight: 4.1363508E-4, delay 1.5
        h("Epop[41] syn_projEE_ampa[3801] = new ampa(0.5)")
        h("Epop[47] netConn_projEE_ampa[3801] = new NetCon(&v(0.5), syn_projEE_ampa[3801], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3802: cell 47, seg 0 (0.5) [0.5 on Epop[47]] -> cell 42, seg 0 (0.5) [0.5 on Epop[42]], weight: 4.1363508E-4, delay 1.5
        h("Epop[42] syn_projEE_ampa[3802] = new ampa(0.5)")
        h("Epop[47] netConn_projEE_ampa[3802] = new NetCon(&v(0.5), syn_projEE_ampa[3802], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3803: cell 47, seg 0 (0.5) [0.5 on Epop[47]] -> cell 43, seg 0 (0.5) [0.5 on Epop[43]], weight: 4.1363508E-4, delay 1.5
        h("Epop[43] syn_projEE_ampa[3803] = new ampa(0.5)")
        h("Epop[47] netConn_projEE_ampa[3803] = new NetCon(&v(0.5), syn_projEE_ampa[3803], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3804: cell 47, seg 0 (0.5) [0.5 on Epop[47]] -> cell 44, seg 0 (0.5) [0.5 on Epop[44]], weight: 4.1363508E-4, delay 1.5
        h("Epop[44] syn_projEE_ampa[3804] = new ampa(0.5)")
        h("Epop[47] netConn_projEE_ampa[3804] = new NetCon(&v(0.5), syn_projEE_ampa[3804], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3805: cell 47, seg 0 (0.5) [0.5 on Epop[47]] -> cell 45, seg 0 (0.5) [0.5 on Epop[45]], weight: 4.1363508E-4, delay 1.5
        h("Epop[45] syn_projEE_ampa[3805] = new ampa(0.5)")
        h("Epop[47] netConn_projEE_ampa[3805] = new NetCon(&v(0.5), syn_projEE_ampa[3805], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3806: cell 47, seg 0 (0.5) [0.5 on Epop[47]] -> cell 46, seg 0 (0.5) [0.5 on Epop[46]], weight: 4.1363508E-4, delay 1.5
        h("Epop[46] syn_projEE_ampa[3806] = new ampa(0.5)")
        h("Epop[47] netConn_projEE_ampa[3806] = new NetCon(&v(0.5), syn_projEE_ampa[3806], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3807: cell 47, seg 0 (0.5) [0.5 on Epop[47]] -> cell 47, seg 0 (0.5) [0.5 on Epop[47]], weight: 4.1363508E-4, delay 1.5
        h("Epop[47] syn_projEE_ampa[3807] = new ampa(0.5)")
        h("Epop[47] netConn_projEE_ampa[3807] = new NetCon(&v(0.5), syn_projEE_ampa[3807], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3808: cell 47, seg 0 (0.5) [0.5 on Epop[47]] -> cell 48, seg 0 (0.5) [0.5 on Epop[48]], weight: 4.1363508E-4, delay 1.5
        h("Epop[48] syn_projEE_ampa[3808] = new ampa(0.5)")
        h("Epop[47] netConn_projEE_ampa[3808] = new NetCon(&v(0.5), syn_projEE_ampa[3808], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3809: cell 47, seg 0 (0.5) [0.5 on Epop[47]] -> cell 49, seg 0 (0.5) [0.5 on Epop[49]], weight: 4.1363508E-4, delay 1.5
        h("Epop[49] syn_projEE_ampa[3809] = new ampa(0.5)")
        h("Epop[47] netConn_projEE_ampa[3809] = new NetCon(&v(0.5), syn_projEE_ampa[3809], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3810: cell 47, seg 0 (0.5) [0.5 on Epop[47]] -> cell 50, seg 0 (0.5) [0.5 on Epop[50]], weight: 4.1363508E-4, delay 1.5
        h("Epop[50] syn_projEE_ampa[3810] = new ampa(0.5)")
        h("Epop[47] netConn_projEE_ampa[3810] = new NetCon(&v(0.5), syn_projEE_ampa[3810], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3811: cell 47, seg 0 (0.5) [0.5 on Epop[47]] -> cell 51, seg 0 (0.5) [0.5 on Epop[51]], weight: 4.1363508E-4, delay 1.5
        h("Epop[51] syn_projEE_ampa[3811] = new ampa(0.5)")
        h("Epop[47] netConn_projEE_ampa[3811] = new NetCon(&v(0.5), syn_projEE_ampa[3811], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3812: cell 47, seg 0 (0.5) [0.5 on Epop[47]] -> cell 52, seg 0 (0.5) [0.5 on Epop[52]], weight: 4.1363508E-4, delay 1.5
        h("Epop[52] syn_projEE_ampa[3812] = new ampa(0.5)")
        h("Epop[47] netConn_projEE_ampa[3812] = new NetCon(&v(0.5), syn_projEE_ampa[3812], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3813: cell 47, seg 0 (0.5) [0.5 on Epop[47]] -> cell 53, seg 0 (0.5) [0.5 on Epop[53]], weight: 4.1363508E-4, delay 1.5
        h("Epop[53] syn_projEE_ampa[3813] = new ampa(0.5)")
        h("Epop[47] netConn_projEE_ampa[3813] = new NetCon(&v(0.5), syn_projEE_ampa[3813], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3814: cell 47, seg 0 (0.5) [0.5 on Epop[47]] -> cell 54, seg 0 (0.5) [0.5 on Epop[54]], weight: 4.1363508E-4, delay 1.5
        h("Epop[54] syn_projEE_ampa[3814] = new ampa(0.5)")
        h("Epop[47] netConn_projEE_ampa[3814] = new NetCon(&v(0.5), syn_projEE_ampa[3814], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3815: cell 47, seg 0 (0.5) [0.5 on Epop[47]] -> cell 55, seg 0 (0.5) [0.5 on Epop[55]], weight: 4.1363508E-4, delay 1.5
        h("Epop[55] syn_projEE_ampa[3815] = new ampa(0.5)")
        h("Epop[47] netConn_projEE_ampa[3815] = new NetCon(&v(0.5), syn_projEE_ampa[3815], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3816: cell 47, seg 0 (0.5) [0.5 on Epop[47]] -> cell 56, seg 0 (0.5) [0.5 on Epop[56]], weight: 4.1363508E-4, delay 1.5
        h("Epop[56] syn_projEE_ampa[3816] = new ampa(0.5)")
        h("Epop[47] netConn_projEE_ampa[3816] = new NetCon(&v(0.5), syn_projEE_ampa[3816], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3817: cell 47, seg 0 (0.5) [0.5 on Epop[47]] -> cell 57, seg 0 (0.5) [0.5 on Epop[57]], weight: 4.1363508E-4, delay 1.5
        h("Epop[57] syn_projEE_ampa[3817] = new ampa(0.5)")
        h("Epop[47] netConn_projEE_ampa[3817] = new NetCon(&v(0.5), syn_projEE_ampa[3817], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3818: cell 47, seg 0 (0.5) [0.5 on Epop[47]] -> cell 58, seg 0 (0.5) [0.5 on Epop[58]], weight: 4.1363508E-4, delay 1.5
        h("Epop[58] syn_projEE_ampa[3818] = new ampa(0.5)")
        h("Epop[47] netConn_projEE_ampa[3818] = new NetCon(&v(0.5), syn_projEE_ampa[3818], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3819: cell 47, seg 0 (0.5) [0.5 on Epop[47]] -> cell 59, seg 0 (0.5) [0.5 on Epop[59]], weight: 4.1363508E-4, delay 1.5
        h("Epop[59] syn_projEE_ampa[3819] = new ampa(0.5)")
        h("Epop[47] netConn_projEE_ampa[3819] = new NetCon(&v(0.5), syn_projEE_ampa[3819], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3820: cell 47, seg 0 (0.5) [0.5 on Epop[47]] -> cell 60, seg 0 (0.5) [0.5 on Epop[60]], weight: 4.1363508E-4, delay 1.5
        h("Epop[60] syn_projEE_ampa[3820] = new ampa(0.5)")
        h("Epop[47] netConn_projEE_ampa[3820] = new NetCon(&v(0.5), syn_projEE_ampa[3820], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3821: cell 47, seg 0 (0.5) [0.5 on Epop[47]] -> cell 61, seg 0 (0.5) [0.5 on Epop[61]], weight: 4.1363508E-4, delay 1.5
        h("Epop[61] syn_projEE_ampa[3821] = new ampa(0.5)")
        h("Epop[47] netConn_projEE_ampa[3821] = new NetCon(&v(0.5), syn_projEE_ampa[3821], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3822: cell 47, seg 0 (0.5) [0.5 on Epop[47]] -> cell 62, seg 0 (0.5) [0.5 on Epop[62]], weight: 4.1363508E-4, delay 1.5
        h("Epop[62] syn_projEE_ampa[3822] = new ampa(0.5)")
        h("Epop[47] netConn_projEE_ampa[3822] = new NetCon(&v(0.5), syn_projEE_ampa[3822], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3823: cell 47, seg 0 (0.5) [0.5 on Epop[47]] -> cell 63, seg 0 (0.5) [0.5 on Epop[63]], weight: 4.1363508E-4, delay 1.5
        h("Epop[63] syn_projEE_ampa[3823] = new ampa(0.5)")
        h("Epop[47] netConn_projEE_ampa[3823] = new NetCon(&v(0.5), syn_projEE_ampa[3823], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3824: cell 47, seg 0 (0.5) [0.5 on Epop[47]] -> cell 64, seg 0 (0.5) [0.5 on Epop[64]], weight: 4.1363508E-4, delay 1.5
        h("Epop[64] syn_projEE_ampa[3824] = new ampa(0.5)")
        h("Epop[47] netConn_projEE_ampa[3824] = new NetCon(&v(0.5), syn_projEE_ampa[3824], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3825: cell 47, seg 0 (0.5) [0.5 on Epop[47]] -> cell 65, seg 0 (0.5) [0.5 on Epop[65]], weight: 4.1363508E-4, delay 1.5
        h("Epop[65] syn_projEE_ampa[3825] = new ampa(0.5)")
        h("Epop[47] netConn_projEE_ampa[3825] = new NetCon(&v(0.5), syn_projEE_ampa[3825], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3826: cell 47, seg 0 (0.5) [0.5 on Epop[47]] -> cell 66, seg 0 (0.5) [0.5 on Epop[66]], weight: 4.1363508E-4, delay 1.5
        h("Epop[66] syn_projEE_ampa[3826] = new ampa(0.5)")
        h("Epop[47] netConn_projEE_ampa[3826] = new NetCon(&v(0.5), syn_projEE_ampa[3826], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3827: cell 47, seg 0 (0.5) [0.5 on Epop[47]] -> cell 67, seg 0 (0.5) [0.5 on Epop[67]], weight: 4.1363508E-4, delay 1.5
        h("Epop[67] syn_projEE_ampa[3827] = new ampa(0.5)")
        h("Epop[47] netConn_projEE_ampa[3827] = new NetCon(&v(0.5), syn_projEE_ampa[3827], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3828: cell 47, seg 0 (0.5) [0.5 on Epop[47]] -> cell 68, seg 0 (0.5) [0.5 on Epop[68]], weight: 4.1363508E-4, delay 1.5
        h("Epop[68] syn_projEE_ampa[3828] = new ampa(0.5)")
        h("Epop[47] netConn_projEE_ampa[3828] = new NetCon(&v(0.5), syn_projEE_ampa[3828], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3829: cell 47, seg 0 (0.5) [0.5 on Epop[47]] -> cell 69, seg 0 (0.5) [0.5 on Epop[69]], weight: 4.1363508E-4, delay 1.5
        h("Epop[69] syn_projEE_ampa[3829] = new ampa(0.5)")
        h("Epop[47] netConn_projEE_ampa[3829] = new NetCon(&v(0.5), syn_projEE_ampa[3829], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3830: cell 47, seg 0 (0.5) [0.5 on Epop[47]] -> cell 70, seg 0 (0.5) [0.5 on Epop[70]], weight: 4.1363508E-4, delay 1.5
        h("Epop[70] syn_projEE_ampa[3830] = new ampa(0.5)")
        h("Epop[47] netConn_projEE_ampa[3830] = new NetCon(&v(0.5), syn_projEE_ampa[3830], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3831: cell 47, seg 0 (0.5) [0.5 on Epop[47]] -> cell 71, seg 0 (0.5) [0.5 on Epop[71]], weight: 4.1363508E-4, delay 1.5
        h("Epop[71] syn_projEE_ampa[3831] = new ampa(0.5)")
        h("Epop[47] netConn_projEE_ampa[3831] = new NetCon(&v(0.5), syn_projEE_ampa[3831], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3832: cell 47, seg 0 (0.5) [0.5 on Epop[47]] -> cell 72, seg 0 (0.5) [0.5 on Epop[72]], weight: 4.1363508E-4, delay 1.5
        h("Epop[72] syn_projEE_ampa[3832] = new ampa(0.5)")
        h("Epop[47] netConn_projEE_ampa[3832] = new NetCon(&v(0.5), syn_projEE_ampa[3832], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3833: cell 47, seg 0 (0.5) [0.5 on Epop[47]] -> cell 73, seg 0 (0.5) [0.5 on Epop[73]], weight: 4.1363508E-4, delay 1.5
        h("Epop[73] syn_projEE_ampa[3833] = new ampa(0.5)")
        h("Epop[47] netConn_projEE_ampa[3833] = new NetCon(&v(0.5), syn_projEE_ampa[3833], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3834: cell 47, seg 0 (0.5) [0.5 on Epop[47]] -> cell 74, seg 0 (0.5) [0.5 on Epop[74]], weight: 4.1363508E-4, delay 1.5
        h("Epop[74] syn_projEE_ampa[3834] = new ampa(0.5)")
        h("Epop[47] netConn_projEE_ampa[3834] = new NetCon(&v(0.5), syn_projEE_ampa[3834], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3835: cell 47, seg 0 (0.5) [0.5 on Epop[47]] -> cell 75, seg 0 (0.5) [0.5 on Epop[75]], weight: 4.1363508E-4, delay 1.5
        h("Epop[75] syn_projEE_ampa[3835] = new ampa(0.5)")
        h("Epop[47] netConn_projEE_ampa[3835] = new NetCon(&v(0.5), syn_projEE_ampa[3835], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3836: cell 47, seg 0 (0.5) [0.5 on Epop[47]] -> cell 76, seg 0 (0.5) [0.5 on Epop[76]], weight: 4.1363508E-4, delay 1.5
        h("Epop[76] syn_projEE_ampa[3836] = new ampa(0.5)")
        h("Epop[47] netConn_projEE_ampa[3836] = new NetCon(&v(0.5), syn_projEE_ampa[3836], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3837: cell 47, seg 0 (0.5) [0.5 on Epop[47]] -> cell 77, seg 0 (0.5) [0.5 on Epop[77]], weight: 4.1363508E-4, delay 1.5
        h("Epop[77] syn_projEE_ampa[3837] = new ampa(0.5)")
        h("Epop[47] netConn_projEE_ampa[3837] = new NetCon(&v(0.5), syn_projEE_ampa[3837], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3838: cell 47, seg 0 (0.5) [0.5 on Epop[47]] -> cell 78, seg 0 (0.5) [0.5 on Epop[78]], weight: 4.1363508E-4, delay 1.5
        h("Epop[78] syn_projEE_ampa[3838] = new ampa(0.5)")
        h("Epop[47] netConn_projEE_ampa[3838] = new NetCon(&v(0.5), syn_projEE_ampa[3838], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3839: cell 47, seg 0 (0.5) [0.5 on Epop[47]] -> cell 79, seg 0 (0.5) [0.5 on Epop[79]], weight: 4.1363508E-4, delay 1.5
        h("Epop[79] syn_projEE_ampa[3839] = new ampa(0.5)")
        h("Epop[47] netConn_projEE_ampa[3839] = new NetCon(&v(0.5), syn_projEE_ampa[3839], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3840: cell 48, seg 0 (0.5) [0.5 on Epop[48]] -> cell 0, seg 0 (0.5) [0.5 on Epop[0]], weight: 4.1363508E-4, delay 1.5
        h("Epop[0] syn_projEE_ampa[3840] = new ampa(0.5)")
        h("Epop[48] netConn_projEE_ampa[3840] = new NetCon(&v(0.5), syn_projEE_ampa[3840], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3841: cell 48, seg 0 (0.5) [0.5 on Epop[48]] -> cell 1, seg 0 (0.5) [0.5 on Epop[1]], weight: 4.1363508E-4, delay 1.5
        h("Epop[1] syn_projEE_ampa[3841] = new ampa(0.5)")
        h("Epop[48] netConn_projEE_ampa[3841] = new NetCon(&v(0.5), syn_projEE_ampa[3841], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3842: cell 48, seg 0 (0.5) [0.5 on Epop[48]] -> cell 2, seg 0 (0.5) [0.5 on Epop[2]], weight: 4.1363508E-4, delay 1.5
        h("Epop[2] syn_projEE_ampa[3842] = new ampa(0.5)")
        h("Epop[48] netConn_projEE_ampa[3842] = new NetCon(&v(0.5), syn_projEE_ampa[3842], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3843: cell 48, seg 0 (0.5) [0.5 on Epop[48]] -> cell 3, seg 0 (0.5) [0.5 on Epop[3]], weight: 4.1363508E-4, delay 1.5
        h("Epop[3] syn_projEE_ampa[3843] = new ampa(0.5)")
        h("Epop[48] netConn_projEE_ampa[3843] = new NetCon(&v(0.5), syn_projEE_ampa[3843], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3844: cell 48, seg 0 (0.5) [0.5 on Epop[48]] -> cell 4, seg 0 (0.5) [0.5 on Epop[4]], weight: 4.1363508E-4, delay 1.5
        h("Epop[4] syn_projEE_ampa[3844] = new ampa(0.5)")
        h("Epop[48] netConn_projEE_ampa[3844] = new NetCon(&v(0.5), syn_projEE_ampa[3844], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3845: cell 48, seg 0 (0.5) [0.5 on Epop[48]] -> cell 5, seg 0 (0.5) [0.5 on Epop[5]], weight: 4.1363508E-4, delay 1.5
        h("Epop[5] syn_projEE_ampa[3845] = new ampa(0.5)")
        h("Epop[48] netConn_projEE_ampa[3845] = new NetCon(&v(0.5), syn_projEE_ampa[3845], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3846: cell 48, seg 0 (0.5) [0.5 on Epop[48]] -> cell 6, seg 0 (0.5) [0.5 on Epop[6]], weight: 4.1363508E-4, delay 1.5
        h("Epop[6] syn_projEE_ampa[3846] = new ampa(0.5)")
        h("Epop[48] netConn_projEE_ampa[3846] = new NetCon(&v(0.5), syn_projEE_ampa[3846], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3847: cell 48, seg 0 (0.5) [0.5 on Epop[48]] -> cell 7, seg 0 (0.5) [0.5 on Epop[7]], weight: 4.1363508E-4, delay 1.5
        h("Epop[7] syn_projEE_ampa[3847] = new ampa(0.5)")
        h("Epop[48] netConn_projEE_ampa[3847] = new NetCon(&v(0.5), syn_projEE_ampa[3847], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3848: cell 48, seg 0 (0.5) [0.5 on Epop[48]] -> cell 8, seg 0 (0.5) [0.5 on Epop[8]], weight: 4.1363508E-4, delay 1.5
        h("Epop[8] syn_projEE_ampa[3848] = new ampa(0.5)")
        h("Epop[48] netConn_projEE_ampa[3848] = new NetCon(&v(0.5), syn_projEE_ampa[3848], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3849: cell 48, seg 0 (0.5) [0.5 on Epop[48]] -> cell 9, seg 0 (0.5) [0.5 on Epop[9]], weight: 4.1363508E-4, delay 1.5
        h("Epop[9] syn_projEE_ampa[3849] = new ampa(0.5)")
        h("Epop[48] netConn_projEE_ampa[3849] = new NetCon(&v(0.5), syn_projEE_ampa[3849], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3850: cell 48, seg 0 (0.5) [0.5 on Epop[48]] -> cell 10, seg 0 (0.5) [0.5 on Epop[10]], weight: 4.1363508E-4, delay 1.5
        h("Epop[10] syn_projEE_ampa[3850] = new ampa(0.5)")
        h("Epop[48] netConn_projEE_ampa[3850] = new NetCon(&v(0.5), syn_projEE_ampa[3850], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3851: cell 48, seg 0 (0.5) [0.5 on Epop[48]] -> cell 11, seg 0 (0.5) [0.5 on Epop[11]], weight: 4.1363508E-4, delay 1.5
        h("Epop[11] syn_projEE_ampa[3851] = new ampa(0.5)")
        h("Epop[48] netConn_projEE_ampa[3851] = new NetCon(&v(0.5), syn_projEE_ampa[3851], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3852: cell 48, seg 0 (0.5) [0.5 on Epop[48]] -> cell 12, seg 0 (0.5) [0.5 on Epop[12]], weight: 4.1363508E-4, delay 1.5
        h("Epop[12] syn_projEE_ampa[3852] = new ampa(0.5)")
        h("Epop[48] netConn_projEE_ampa[3852] = new NetCon(&v(0.5), syn_projEE_ampa[3852], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3853: cell 48, seg 0 (0.5) [0.5 on Epop[48]] -> cell 13, seg 0 (0.5) [0.5 on Epop[13]], weight: 4.1363508E-4, delay 1.5
        h("Epop[13] syn_projEE_ampa[3853] = new ampa(0.5)")
        h("Epop[48] netConn_projEE_ampa[3853] = new NetCon(&v(0.5), syn_projEE_ampa[3853], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3854: cell 48, seg 0 (0.5) [0.5 on Epop[48]] -> cell 14, seg 0 (0.5) [0.5 on Epop[14]], weight: 4.1363508E-4, delay 1.5
        h("Epop[14] syn_projEE_ampa[3854] = new ampa(0.5)")
        h("Epop[48] netConn_projEE_ampa[3854] = new NetCon(&v(0.5), syn_projEE_ampa[3854], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3855: cell 48, seg 0 (0.5) [0.5 on Epop[48]] -> cell 15, seg 0 (0.5) [0.5 on Epop[15]], weight: 4.1363508E-4, delay 1.5
        h("Epop[15] syn_projEE_ampa[3855] = new ampa(0.5)")
        h("Epop[48] netConn_projEE_ampa[3855] = new NetCon(&v(0.5), syn_projEE_ampa[3855], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3856: cell 48, seg 0 (0.5) [0.5 on Epop[48]] -> cell 16, seg 0 (0.5) [0.5 on Epop[16]], weight: 4.1363508E-4, delay 1.5
        h("Epop[16] syn_projEE_ampa[3856] = new ampa(0.5)")
        h("Epop[48] netConn_projEE_ampa[3856] = new NetCon(&v(0.5), syn_projEE_ampa[3856], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3857: cell 48, seg 0 (0.5) [0.5 on Epop[48]] -> cell 17, seg 0 (0.5) [0.5 on Epop[17]], weight: 4.1363508E-4, delay 1.5
        h("Epop[17] syn_projEE_ampa[3857] = new ampa(0.5)")
        h("Epop[48] netConn_projEE_ampa[3857] = new NetCon(&v(0.5), syn_projEE_ampa[3857], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3858: cell 48, seg 0 (0.5) [0.5 on Epop[48]] -> cell 18, seg 0 (0.5) [0.5 on Epop[18]], weight: 4.1363508E-4, delay 1.5
        h("Epop[18] syn_projEE_ampa[3858] = new ampa(0.5)")
        h("Epop[48] netConn_projEE_ampa[3858] = new NetCon(&v(0.5), syn_projEE_ampa[3858], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3859: cell 48, seg 0 (0.5) [0.5 on Epop[48]] -> cell 19, seg 0 (0.5) [0.5 on Epop[19]], weight: 4.1363508E-4, delay 1.5
        h("Epop[19] syn_projEE_ampa[3859] = new ampa(0.5)")
        h("Epop[48] netConn_projEE_ampa[3859] = new NetCon(&v(0.5), syn_projEE_ampa[3859], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3860: cell 48, seg 0 (0.5) [0.5 on Epop[48]] -> cell 20, seg 0 (0.5) [0.5 on Epop[20]], weight: 4.1363508E-4, delay 1.5
        h("Epop[20] syn_projEE_ampa[3860] = new ampa(0.5)")
        h("Epop[48] netConn_projEE_ampa[3860] = new NetCon(&v(0.5), syn_projEE_ampa[3860], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3861: cell 48, seg 0 (0.5) [0.5 on Epop[48]] -> cell 21, seg 0 (0.5) [0.5 on Epop[21]], weight: 4.1363508E-4, delay 1.5
        h("Epop[21] syn_projEE_ampa[3861] = new ampa(0.5)")
        h("Epop[48] netConn_projEE_ampa[3861] = new NetCon(&v(0.5), syn_projEE_ampa[3861], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3862: cell 48, seg 0 (0.5) [0.5 on Epop[48]] -> cell 22, seg 0 (0.5) [0.5 on Epop[22]], weight: 4.1363508E-4, delay 1.5
        h("Epop[22] syn_projEE_ampa[3862] = new ampa(0.5)")
        h("Epop[48] netConn_projEE_ampa[3862] = new NetCon(&v(0.5), syn_projEE_ampa[3862], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3863: cell 48, seg 0 (0.5) [0.5 on Epop[48]] -> cell 23, seg 0 (0.5) [0.5 on Epop[23]], weight: 4.1363508E-4, delay 1.5
        h("Epop[23] syn_projEE_ampa[3863] = new ampa(0.5)")
        h("Epop[48] netConn_projEE_ampa[3863] = new NetCon(&v(0.5), syn_projEE_ampa[3863], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3864: cell 48, seg 0 (0.5) [0.5 on Epop[48]] -> cell 24, seg 0 (0.5) [0.5 on Epop[24]], weight: 4.1363508E-4, delay 1.5
        h("Epop[24] syn_projEE_ampa[3864] = new ampa(0.5)")
        h("Epop[48] netConn_projEE_ampa[3864] = new NetCon(&v(0.5), syn_projEE_ampa[3864], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3865: cell 48, seg 0 (0.5) [0.5 on Epop[48]] -> cell 25, seg 0 (0.5) [0.5 on Epop[25]], weight: 4.1363508E-4, delay 1.5
        h("Epop[25] syn_projEE_ampa[3865] = new ampa(0.5)")
        h("Epop[48] netConn_projEE_ampa[3865] = new NetCon(&v(0.5), syn_projEE_ampa[3865], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3866: cell 48, seg 0 (0.5) [0.5 on Epop[48]] -> cell 26, seg 0 (0.5) [0.5 on Epop[26]], weight: 4.1363508E-4, delay 1.5
        h("Epop[26] syn_projEE_ampa[3866] = new ampa(0.5)")
        h("Epop[48] netConn_projEE_ampa[3866] = new NetCon(&v(0.5), syn_projEE_ampa[3866], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3867: cell 48, seg 0 (0.5) [0.5 on Epop[48]] -> cell 27, seg 0 (0.5) [0.5 on Epop[27]], weight: 4.1363508E-4, delay 1.5
        h("Epop[27] syn_projEE_ampa[3867] = new ampa(0.5)")
        h("Epop[48] netConn_projEE_ampa[3867] = new NetCon(&v(0.5), syn_projEE_ampa[3867], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3868: cell 48, seg 0 (0.5) [0.5 on Epop[48]] -> cell 28, seg 0 (0.5) [0.5 on Epop[28]], weight: 4.1363508E-4, delay 1.5
        h("Epop[28] syn_projEE_ampa[3868] = new ampa(0.5)")
        h("Epop[48] netConn_projEE_ampa[3868] = new NetCon(&v(0.5), syn_projEE_ampa[3868], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3869: cell 48, seg 0 (0.5) [0.5 on Epop[48]] -> cell 29, seg 0 (0.5) [0.5 on Epop[29]], weight: 4.1363508E-4, delay 1.5
        h("Epop[29] syn_projEE_ampa[3869] = new ampa(0.5)")
        h("Epop[48] netConn_projEE_ampa[3869] = new NetCon(&v(0.5), syn_projEE_ampa[3869], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3870: cell 48, seg 0 (0.5) [0.5 on Epop[48]] -> cell 30, seg 0 (0.5) [0.5 on Epop[30]], weight: 4.1363508E-4, delay 1.5
        h("Epop[30] syn_projEE_ampa[3870] = new ampa(0.5)")
        h("Epop[48] netConn_projEE_ampa[3870] = new NetCon(&v(0.5), syn_projEE_ampa[3870], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3871: cell 48, seg 0 (0.5) [0.5 on Epop[48]] -> cell 31, seg 0 (0.5) [0.5 on Epop[31]], weight: 4.1363508E-4, delay 1.5
        h("Epop[31] syn_projEE_ampa[3871] = new ampa(0.5)")
        h("Epop[48] netConn_projEE_ampa[3871] = new NetCon(&v(0.5), syn_projEE_ampa[3871], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3872: cell 48, seg 0 (0.5) [0.5 on Epop[48]] -> cell 32, seg 0 (0.5) [0.5 on Epop[32]], weight: 4.1363508E-4, delay 1.5
        h("Epop[32] syn_projEE_ampa[3872] = new ampa(0.5)")
        h("Epop[48] netConn_projEE_ampa[3872] = new NetCon(&v(0.5), syn_projEE_ampa[3872], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3873: cell 48, seg 0 (0.5) [0.5 on Epop[48]] -> cell 33, seg 0 (0.5) [0.5 on Epop[33]], weight: 4.1363508E-4, delay 1.5
        h("Epop[33] syn_projEE_ampa[3873] = new ampa(0.5)")
        h("Epop[48] netConn_projEE_ampa[3873] = new NetCon(&v(0.5), syn_projEE_ampa[3873], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3874: cell 48, seg 0 (0.5) [0.5 on Epop[48]] -> cell 34, seg 0 (0.5) [0.5 on Epop[34]], weight: 4.1363508E-4, delay 1.5
        h("Epop[34] syn_projEE_ampa[3874] = new ampa(0.5)")
        h("Epop[48] netConn_projEE_ampa[3874] = new NetCon(&v(0.5), syn_projEE_ampa[3874], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3875: cell 48, seg 0 (0.5) [0.5 on Epop[48]] -> cell 35, seg 0 (0.5) [0.5 on Epop[35]], weight: 4.1363508E-4, delay 1.5
        h("Epop[35] syn_projEE_ampa[3875] = new ampa(0.5)")
        h("Epop[48] netConn_projEE_ampa[3875] = new NetCon(&v(0.5), syn_projEE_ampa[3875], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3876: cell 48, seg 0 (0.5) [0.5 on Epop[48]] -> cell 36, seg 0 (0.5) [0.5 on Epop[36]], weight: 4.1363508E-4, delay 1.5
        h("Epop[36] syn_projEE_ampa[3876] = new ampa(0.5)")
        h("Epop[48] netConn_projEE_ampa[3876] = new NetCon(&v(0.5), syn_projEE_ampa[3876], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3877: cell 48, seg 0 (0.5) [0.5 on Epop[48]] -> cell 37, seg 0 (0.5) [0.5 on Epop[37]], weight: 4.1363508E-4, delay 1.5
        h("Epop[37] syn_projEE_ampa[3877] = new ampa(0.5)")
        h("Epop[48] netConn_projEE_ampa[3877] = new NetCon(&v(0.5), syn_projEE_ampa[3877], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3878: cell 48, seg 0 (0.5) [0.5 on Epop[48]] -> cell 38, seg 0 (0.5) [0.5 on Epop[38]], weight: 4.1363508E-4, delay 1.5
        h("Epop[38] syn_projEE_ampa[3878] = new ampa(0.5)")
        h("Epop[48] netConn_projEE_ampa[3878] = new NetCon(&v(0.5), syn_projEE_ampa[3878], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3879: cell 48, seg 0 (0.5) [0.5 on Epop[48]] -> cell 39, seg 0 (0.5) [0.5 on Epop[39]], weight: 4.1363508E-4, delay 1.5
        h("Epop[39] syn_projEE_ampa[3879] = new ampa(0.5)")
        h("Epop[48] netConn_projEE_ampa[3879] = new NetCon(&v(0.5), syn_projEE_ampa[3879], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3880: cell 48, seg 0 (0.5) [0.5 on Epop[48]] -> cell 40, seg 0 (0.5) [0.5 on Epop[40]], weight: 4.1363508E-4, delay 1.5
        h("Epop[40] syn_projEE_ampa[3880] = new ampa(0.5)")
        h("Epop[48] netConn_projEE_ampa[3880] = new NetCon(&v(0.5), syn_projEE_ampa[3880], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3881: cell 48, seg 0 (0.5) [0.5 on Epop[48]] -> cell 41, seg 0 (0.5) [0.5 on Epop[41]], weight: 4.1363508E-4, delay 1.5
        h("Epop[41] syn_projEE_ampa[3881] = new ampa(0.5)")
        h("Epop[48] netConn_projEE_ampa[3881] = new NetCon(&v(0.5), syn_projEE_ampa[3881], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3882: cell 48, seg 0 (0.5) [0.5 on Epop[48]] -> cell 42, seg 0 (0.5) [0.5 on Epop[42]], weight: 4.1363508E-4, delay 1.5
        h("Epop[42] syn_projEE_ampa[3882] = new ampa(0.5)")
        h("Epop[48] netConn_projEE_ampa[3882] = new NetCon(&v(0.5), syn_projEE_ampa[3882], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3883: cell 48, seg 0 (0.5) [0.5 on Epop[48]] -> cell 43, seg 0 (0.5) [0.5 on Epop[43]], weight: 4.1363508E-4, delay 1.5
        h("Epop[43] syn_projEE_ampa[3883] = new ampa(0.5)")
        h("Epop[48] netConn_projEE_ampa[3883] = new NetCon(&v(0.5), syn_projEE_ampa[3883], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3884: cell 48, seg 0 (0.5) [0.5 on Epop[48]] -> cell 44, seg 0 (0.5) [0.5 on Epop[44]], weight: 4.1363508E-4, delay 1.5
        h("Epop[44] syn_projEE_ampa[3884] = new ampa(0.5)")
        h("Epop[48] netConn_projEE_ampa[3884] = new NetCon(&v(0.5), syn_projEE_ampa[3884], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3885: cell 48, seg 0 (0.5) [0.5 on Epop[48]] -> cell 45, seg 0 (0.5) [0.5 on Epop[45]], weight: 4.1363508E-4, delay 1.5
        h("Epop[45] syn_projEE_ampa[3885] = new ampa(0.5)")
        h("Epop[48] netConn_projEE_ampa[3885] = new NetCon(&v(0.5), syn_projEE_ampa[3885], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3886: cell 48, seg 0 (0.5) [0.5 on Epop[48]] -> cell 46, seg 0 (0.5) [0.5 on Epop[46]], weight: 4.1363508E-4, delay 1.5
        h("Epop[46] syn_projEE_ampa[3886] = new ampa(0.5)")
        h("Epop[48] netConn_projEE_ampa[3886] = new NetCon(&v(0.5), syn_projEE_ampa[3886], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3887: cell 48, seg 0 (0.5) [0.5 on Epop[48]] -> cell 47, seg 0 (0.5) [0.5 on Epop[47]], weight: 4.1363508E-4, delay 1.5
        h("Epop[47] syn_projEE_ampa[3887] = new ampa(0.5)")
        h("Epop[48] netConn_projEE_ampa[3887] = new NetCon(&v(0.5), syn_projEE_ampa[3887], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3888: cell 48, seg 0 (0.5) [0.5 on Epop[48]] -> cell 48, seg 0 (0.5) [0.5 on Epop[48]], weight: 4.1363508E-4, delay 1.5
        h("Epop[48] syn_projEE_ampa[3888] = new ampa(0.5)")
        h("Epop[48] netConn_projEE_ampa[3888] = new NetCon(&v(0.5), syn_projEE_ampa[3888], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3889: cell 48, seg 0 (0.5) [0.5 on Epop[48]] -> cell 49, seg 0 (0.5) [0.5 on Epop[49]], weight: 4.1363508E-4, delay 1.5
        h("Epop[49] syn_projEE_ampa[3889] = new ampa(0.5)")
        h("Epop[48] netConn_projEE_ampa[3889] = new NetCon(&v(0.5), syn_projEE_ampa[3889], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3890: cell 48, seg 0 (0.5) [0.5 on Epop[48]] -> cell 50, seg 0 (0.5) [0.5 on Epop[50]], weight: 4.1363508E-4, delay 1.5
        h("Epop[50] syn_projEE_ampa[3890] = new ampa(0.5)")
        h("Epop[48] netConn_projEE_ampa[3890] = new NetCon(&v(0.5), syn_projEE_ampa[3890], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3891: cell 48, seg 0 (0.5) [0.5 on Epop[48]] -> cell 51, seg 0 (0.5) [0.5 on Epop[51]], weight: 4.1363508E-4, delay 1.5
        h("Epop[51] syn_projEE_ampa[3891] = new ampa(0.5)")
        h("Epop[48] netConn_projEE_ampa[3891] = new NetCon(&v(0.5), syn_projEE_ampa[3891], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3892: cell 48, seg 0 (0.5) [0.5 on Epop[48]] -> cell 52, seg 0 (0.5) [0.5 on Epop[52]], weight: 4.1363508E-4, delay 1.5
        h("Epop[52] syn_projEE_ampa[3892] = new ampa(0.5)")
        h("Epop[48] netConn_projEE_ampa[3892] = new NetCon(&v(0.5), syn_projEE_ampa[3892], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3893: cell 48, seg 0 (0.5) [0.5 on Epop[48]] -> cell 53, seg 0 (0.5) [0.5 on Epop[53]], weight: 4.1363508E-4, delay 1.5
        h("Epop[53] syn_projEE_ampa[3893] = new ampa(0.5)")
        h("Epop[48] netConn_projEE_ampa[3893] = new NetCon(&v(0.5), syn_projEE_ampa[3893], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3894: cell 48, seg 0 (0.5) [0.5 on Epop[48]] -> cell 54, seg 0 (0.5) [0.5 on Epop[54]], weight: 4.1363508E-4, delay 1.5
        h("Epop[54] syn_projEE_ampa[3894] = new ampa(0.5)")
        h("Epop[48] netConn_projEE_ampa[3894] = new NetCon(&v(0.5), syn_projEE_ampa[3894], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3895: cell 48, seg 0 (0.5) [0.5 on Epop[48]] -> cell 55, seg 0 (0.5) [0.5 on Epop[55]], weight: 4.1363508E-4, delay 1.5
        h("Epop[55] syn_projEE_ampa[3895] = new ampa(0.5)")
        h("Epop[48] netConn_projEE_ampa[3895] = new NetCon(&v(0.5), syn_projEE_ampa[3895], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3896: cell 48, seg 0 (0.5) [0.5 on Epop[48]] -> cell 56, seg 0 (0.5) [0.5 on Epop[56]], weight: 4.1363508E-4, delay 1.5
        h("Epop[56] syn_projEE_ampa[3896] = new ampa(0.5)")
        h("Epop[48] netConn_projEE_ampa[3896] = new NetCon(&v(0.5), syn_projEE_ampa[3896], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3897: cell 48, seg 0 (0.5) [0.5 on Epop[48]] -> cell 57, seg 0 (0.5) [0.5 on Epop[57]], weight: 4.1363508E-4, delay 1.5
        h("Epop[57] syn_projEE_ampa[3897] = new ampa(0.5)")
        h("Epop[48] netConn_projEE_ampa[3897] = new NetCon(&v(0.5), syn_projEE_ampa[3897], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3898: cell 48, seg 0 (0.5) [0.5 on Epop[48]] -> cell 58, seg 0 (0.5) [0.5 on Epop[58]], weight: 4.1363508E-4, delay 1.5
        h("Epop[58] syn_projEE_ampa[3898] = new ampa(0.5)")
        h("Epop[48] netConn_projEE_ampa[3898] = new NetCon(&v(0.5), syn_projEE_ampa[3898], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3899: cell 48, seg 0 (0.5) [0.5 on Epop[48]] -> cell 59, seg 0 (0.5) [0.5 on Epop[59]], weight: 4.1363508E-4, delay 1.5
        h("Epop[59] syn_projEE_ampa[3899] = new ampa(0.5)")
        h("Epop[48] netConn_projEE_ampa[3899] = new NetCon(&v(0.5), syn_projEE_ampa[3899], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3900: cell 48, seg 0 (0.5) [0.5 on Epop[48]] -> cell 60, seg 0 (0.5) [0.5 on Epop[60]], weight: 4.1363508E-4, delay 1.5
        h("Epop[60] syn_projEE_ampa[3900] = new ampa(0.5)")
        h("Epop[48] netConn_projEE_ampa[3900] = new NetCon(&v(0.5), syn_projEE_ampa[3900], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3901: cell 48, seg 0 (0.5) [0.5 on Epop[48]] -> cell 61, seg 0 (0.5) [0.5 on Epop[61]], weight: 4.1363508E-4, delay 1.5
        h("Epop[61] syn_projEE_ampa[3901] = new ampa(0.5)")
        h("Epop[48] netConn_projEE_ampa[3901] = new NetCon(&v(0.5), syn_projEE_ampa[3901], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3902: cell 48, seg 0 (0.5) [0.5 on Epop[48]] -> cell 62, seg 0 (0.5) [0.5 on Epop[62]], weight: 4.1363508E-4, delay 1.5
        h("Epop[62] syn_projEE_ampa[3902] = new ampa(0.5)")
        h("Epop[48] netConn_projEE_ampa[3902] = new NetCon(&v(0.5), syn_projEE_ampa[3902], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3903: cell 48, seg 0 (0.5) [0.5 on Epop[48]] -> cell 63, seg 0 (0.5) [0.5 on Epop[63]], weight: 4.1363508E-4, delay 1.5
        h("Epop[63] syn_projEE_ampa[3903] = new ampa(0.5)")
        h("Epop[48] netConn_projEE_ampa[3903] = new NetCon(&v(0.5), syn_projEE_ampa[3903], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3904: cell 48, seg 0 (0.5) [0.5 on Epop[48]] -> cell 64, seg 0 (0.5) [0.5 on Epop[64]], weight: 4.1363508E-4, delay 1.5
        h("Epop[64] syn_projEE_ampa[3904] = new ampa(0.5)")
        h("Epop[48] netConn_projEE_ampa[3904] = new NetCon(&v(0.5), syn_projEE_ampa[3904], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3905: cell 48, seg 0 (0.5) [0.5 on Epop[48]] -> cell 65, seg 0 (0.5) [0.5 on Epop[65]], weight: 4.1363508E-4, delay 1.5
        h("Epop[65] syn_projEE_ampa[3905] = new ampa(0.5)")
        h("Epop[48] netConn_projEE_ampa[3905] = new NetCon(&v(0.5), syn_projEE_ampa[3905], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3906: cell 48, seg 0 (0.5) [0.5 on Epop[48]] -> cell 66, seg 0 (0.5) [0.5 on Epop[66]], weight: 4.1363508E-4, delay 1.5
        h("Epop[66] syn_projEE_ampa[3906] = new ampa(0.5)")
        h("Epop[48] netConn_projEE_ampa[3906] = new NetCon(&v(0.5), syn_projEE_ampa[3906], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3907: cell 48, seg 0 (0.5) [0.5 on Epop[48]] -> cell 67, seg 0 (0.5) [0.5 on Epop[67]], weight: 4.1363508E-4, delay 1.5
        h("Epop[67] syn_projEE_ampa[3907] = new ampa(0.5)")
        h("Epop[48] netConn_projEE_ampa[3907] = new NetCon(&v(0.5), syn_projEE_ampa[3907], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3908: cell 48, seg 0 (0.5) [0.5 on Epop[48]] -> cell 68, seg 0 (0.5) [0.5 on Epop[68]], weight: 4.1363508E-4, delay 1.5
        h("Epop[68] syn_projEE_ampa[3908] = new ampa(0.5)")
        h("Epop[48] netConn_projEE_ampa[3908] = new NetCon(&v(0.5), syn_projEE_ampa[3908], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3909: cell 48, seg 0 (0.5) [0.5 on Epop[48]] -> cell 69, seg 0 (0.5) [0.5 on Epop[69]], weight: 4.1363508E-4, delay 1.5
        h("Epop[69] syn_projEE_ampa[3909] = new ampa(0.5)")
        h("Epop[48] netConn_projEE_ampa[3909] = new NetCon(&v(0.5), syn_projEE_ampa[3909], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3910: cell 48, seg 0 (0.5) [0.5 on Epop[48]] -> cell 70, seg 0 (0.5) [0.5 on Epop[70]], weight: 4.1363508E-4, delay 1.5
        h("Epop[70] syn_projEE_ampa[3910] = new ampa(0.5)")
        h("Epop[48] netConn_projEE_ampa[3910] = new NetCon(&v(0.5), syn_projEE_ampa[3910], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3911: cell 48, seg 0 (0.5) [0.5 on Epop[48]] -> cell 71, seg 0 (0.5) [0.5 on Epop[71]], weight: 4.1363508E-4, delay 1.5
        h("Epop[71] syn_projEE_ampa[3911] = new ampa(0.5)")
        h("Epop[48] netConn_projEE_ampa[3911] = new NetCon(&v(0.5), syn_projEE_ampa[3911], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3912: cell 48, seg 0 (0.5) [0.5 on Epop[48]] -> cell 72, seg 0 (0.5) [0.5 on Epop[72]], weight: 4.1363508E-4, delay 1.5
        h("Epop[72] syn_projEE_ampa[3912] = new ampa(0.5)")
        h("Epop[48] netConn_projEE_ampa[3912] = new NetCon(&v(0.5), syn_projEE_ampa[3912], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3913: cell 48, seg 0 (0.5) [0.5 on Epop[48]] -> cell 73, seg 0 (0.5) [0.5 on Epop[73]], weight: 4.1363508E-4, delay 1.5
        h("Epop[73] syn_projEE_ampa[3913] = new ampa(0.5)")
        h("Epop[48] netConn_projEE_ampa[3913] = new NetCon(&v(0.5), syn_projEE_ampa[3913], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3914: cell 48, seg 0 (0.5) [0.5 on Epop[48]] -> cell 74, seg 0 (0.5) [0.5 on Epop[74]], weight: 4.1363508E-4, delay 1.5
        h("Epop[74] syn_projEE_ampa[3914] = new ampa(0.5)")
        h("Epop[48] netConn_projEE_ampa[3914] = new NetCon(&v(0.5), syn_projEE_ampa[3914], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3915: cell 48, seg 0 (0.5) [0.5 on Epop[48]] -> cell 75, seg 0 (0.5) [0.5 on Epop[75]], weight: 4.1363508E-4, delay 1.5
        h("Epop[75] syn_projEE_ampa[3915] = new ampa(0.5)")
        h("Epop[48] netConn_projEE_ampa[3915] = new NetCon(&v(0.5), syn_projEE_ampa[3915], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3916: cell 48, seg 0 (0.5) [0.5 on Epop[48]] -> cell 76, seg 0 (0.5) [0.5 on Epop[76]], weight: 4.1363508E-4, delay 1.5
        h("Epop[76] syn_projEE_ampa[3916] = new ampa(0.5)")
        h("Epop[48] netConn_projEE_ampa[3916] = new NetCon(&v(0.5), syn_projEE_ampa[3916], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3917: cell 48, seg 0 (0.5) [0.5 on Epop[48]] -> cell 77, seg 0 (0.5) [0.5 on Epop[77]], weight: 4.1363508E-4, delay 1.5
        h("Epop[77] syn_projEE_ampa[3917] = new ampa(0.5)")
        h("Epop[48] netConn_projEE_ampa[3917] = new NetCon(&v(0.5), syn_projEE_ampa[3917], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3918: cell 48, seg 0 (0.5) [0.5 on Epop[48]] -> cell 78, seg 0 (0.5) [0.5 on Epop[78]], weight: 4.1363508E-4, delay 1.5
        h("Epop[78] syn_projEE_ampa[3918] = new ampa(0.5)")
        h("Epop[48] netConn_projEE_ampa[3918] = new NetCon(&v(0.5), syn_projEE_ampa[3918], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3919: cell 48, seg 0 (0.5) [0.5 on Epop[48]] -> cell 79, seg 0 (0.5) [0.5 on Epop[79]], weight: 4.1363508E-4, delay 1.5
        h("Epop[79] syn_projEE_ampa[3919] = new ampa(0.5)")
        h("Epop[48] netConn_projEE_ampa[3919] = new NetCon(&v(0.5), syn_projEE_ampa[3919], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3920: cell 49, seg 0 (0.5) [0.5 on Epop[49]] -> cell 0, seg 0 (0.5) [0.5 on Epop[0]], weight: 4.1363508E-4, delay 1.5
        h("Epop[0] syn_projEE_ampa[3920] = new ampa(0.5)")
        h("Epop[49] netConn_projEE_ampa[3920] = new NetCon(&v(0.5), syn_projEE_ampa[3920], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3921: cell 49, seg 0 (0.5) [0.5 on Epop[49]] -> cell 1, seg 0 (0.5) [0.5 on Epop[1]], weight: 4.1363508E-4, delay 1.5
        h("Epop[1] syn_projEE_ampa[3921] = new ampa(0.5)")
        h("Epop[49] netConn_projEE_ampa[3921] = new NetCon(&v(0.5), syn_projEE_ampa[3921], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3922: cell 49, seg 0 (0.5) [0.5 on Epop[49]] -> cell 2, seg 0 (0.5) [0.5 on Epop[2]], weight: 4.1363508E-4, delay 1.5
        h("Epop[2] syn_projEE_ampa[3922] = new ampa(0.5)")
        h("Epop[49] netConn_projEE_ampa[3922] = new NetCon(&v(0.5), syn_projEE_ampa[3922], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3923: cell 49, seg 0 (0.5) [0.5 on Epop[49]] -> cell 3, seg 0 (0.5) [0.5 on Epop[3]], weight: 4.1363508E-4, delay 1.5
        h("Epop[3] syn_projEE_ampa[3923] = new ampa(0.5)")
        h("Epop[49] netConn_projEE_ampa[3923] = new NetCon(&v(0.5), syn_projEE_ampa[3923], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3924: cell 49, seg 0 (0.5) [0.5 on Epop[49]] -> cell 4, seg 0 (0.5) [0.5 on Epop[4]], weight: 4.1363508E-4, delay 1.5
        h("Epop[4] syn_projEE_ampa[3924] = new ampa(0.5)")
        h("Epop[49] netConn_projEE_ampa[3924] = new NetCon(&v(0.5), syn_projEE_ampa[3924], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3925: cell 49, seg 0 (0.5) [0.5 on Epop[49]] -> cell 5, seg 0 (0.5) [0.5 on Epop[5]], weight: 4.1363508E-4, delay 1.5
        h("Epop[5] syn_projEE_ampa[3925] = new ampa(0.5)")
        h("Epop[49] netConn_projEE_ampa[3925] = new NetCon(&v(0.5), syn_projEE_ampa[3925], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3926: cell 49, seg 0 (0.5) [0.5 on Epop[49]] -> cell 6, seg 0 (0.5) [0.5 on Epop[6]], weight: 4.1363508E-4, delay 1.5
        h("Epop[6] syn_projEE_ampa[3926] = new ampa(0.5)")
        h("Epop[49] netConn_projEE_ampa[3926] = new NetCon(&v(0.5), syn_projEE_ampa[3926], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3927: cell 49, seg 0 (0.5) [0.5 on Epop[49]] -> cell 7, seg 0 (0.5) [0.5 on Epop[7]], weight: 4.1363508E-4, delay 1.5
        h("Epop[7] syn_projEE_ampa[3927] = new ampa(0.5)")
        h("Epop[49] netConn_projEE_ampa[3927] = new NetCon(&v(0.5), syn_projEE_ampa[3927], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3928: cell 49, seg 0 (0.5) [0.5 on Epop[49]] -> cell 8, seg 0 (0.5) [0.5 on Epop[8]], weight: 4.1363508E-4, delay 1.5
        h("Epop[8] syn_projEE_ampa[3928] = new ampa(0.5)")
        h("Epop[49] netConn_projEE_ampa[3928] = new NetCon(&v(0.5), syn_projEE_ampa[3928], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3929: cell 49, seg 0 (0.5) [0.5 on Epop[49]] -> cell 9, seg 0 (0.5) [0.5 on Epop[9]], weight: 4.1363508E-4, delay 1.5
        h("Epop[9] syn_projEE_ampa[3929] = new ampa(0.5)")
        h("Epop[49] netConn_projEE_ampa[3929] = new NetCon(&v(0.5), syn_projEE_ampa[3929], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3930: cell 49, seg 0 (0.5) [0.5 on Epop[49]] -> cell 10, seg 0 (0.5) [0.5 on Epop[10]], weight: 4.1363508E-4, delay 1.5
        h("Epop[10] syn_projEE_ampa[3930] = new ampa(0.5)")
        h("Epop[49] netConn_projEE_ampa[3930] = new NetCon(&v(0.5), syn_projEE_ampa[3930], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3931: cell 49, seg 0 (0.5) [0.5 on Epop[49]] -> cell 11, seg 0 (0.5) [0.5 on Epop[11]], weight: 4.1363508E-4, delay 1.5
        h("Epop[11] syn_projEE_ampa[3931] = new ampa(0.5)")
        h("Epop[49] netConn_projEE_ampa[3931] = new NetCon(&v(0.5), syn_projEE_ampa[3931], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3932: cell 49, seg 0 (0.5) [0.5 on Epop[49]] -> cell 12, seg 0 (0.5) [0.5 on Epop[12]], weight: 4.1363508E-4, delay 1.5
        h("Epop[12] syn_projEE_ampa[3932] = new ampa(0.5)")
        h("Epop[49] netConn_projEE_ampa[3932] = new NetCon(&v(0.5), syn_projEE_ampa[3932], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3933: cell 49, seg 0 (0.5) [0.5 on Epop[49]] -> cell 13, seg 0 (0.5) [0.5 on Epop[13]], weight: 4.1363508E-4, delay 1.5
        h("Epop[13] syn_projEE_ampa[3933] = new ampa(0.5)")
        h("Epop[49] netConn_projEE_ampa[3933] = new NetCon(&v(0.5), syn_projEE_ampa[3933], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3934: cell 49, seg 0 (0.5) [0.5 on Epop[49]] -> cell 14, seg 0 (0.5) [0.5 on Epop[14]], weight: 4.1363508E-4, delay 1.5
        h("Epop[14] syn_projEE_ampa[3934] = new ampa(0.5)")
        h("Epop[49] netConn_projEE_ampa[3934] = new NetCon(&v(0.5), syn_projEE_ampa[3934], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3935: cell 49, seg 0 (0.5) [0.5 on Epop[49]] -> cell 15, seg 0 (0.5) [0.5 on Epop[15]], weight: 4.1363508E-4, delay 1.5
        h("Epop[15] syn_projEE_ampa[3935] = new ampa(0.5)")
        h("Epop[49] netConn_projEE_ampa[3935] = new NetCon(&v(0.5), syn_projEE_ampa[3935], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3936: cell 49, seg 0 (0.5) [0.5 on Epop[49]] -> cell 16, seg 0 (0.5) [0.5 on Epop[16]], weight: 4.1363508E-4, delay 1.5
        h("Epop[16] syn_projEE_ampa[3936] = new ampa(0.5)")
        h("Epop[49] netConn_projEE_ampa[3936] = new NetCon(&v(0.5), syn_projEE_ampa[3936], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3937: cell 49, seg 0 (0.5) [0.5 on Epop[49]] -> cell 17, seg 0 (0.5) [0.5 on Epop[17]], weight: 4.1363508E-4, delay 1.5
        h("Epop[17] syn_projEE_ampa[3937] = new ampa(0.5)")
        h("Epop[49] netConn_projEE_ampa[3937] = new NetCon(&v(0.5), syn_projEE_ampa[3937], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3938: cell 49, seg 0 (0.5) [0.5 on Epop[49]] -> cell 18, seg 0 (0.5) [0.5 on Epop[18]], weight: 4.1363508E-4, delay 1.5
        h("Epop[18] syn_projEE_ampa[3938] = new ampa(0.5)")
        h("Epop[49] netConn_projEE_ampa[3938] = new NetCon(&v(0.5), syn_projEE_ampa[3938], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3939: cell 49, seg 0 (0.5) [0.5 on Epop[49]] -> cell 19, seg 0 (0.5) [0.5 on Epop[19]], weight: 4.1363508E-4, delay 1.5
        h("Epop[19] syn_projEE_ampa[3939] = new ampa(0.5)")
        h("Epop[49] netConn_projEE_ampa[3939] = new NetCon(&v(0.5), syn_projEE_ampa[3939], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3940: cell 49, seg 0 (0.5) [0.5 on Epop[49]] -> cell 20, seg 0 (0.5) [0.5 on Epop[20]], weight: 4.1363508E-4, delay 1.5
        h("Epop[20] syn_projEE_ampa[3940] = new ampa(0.5)")
        h("Epop[49] netConn_projEE_ampa[3940] = new NetCon(&v(0.5), syn_projEE_ampa[3940], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3941: cell 49, seg 0 (0.5) [0.5 on Epop[49]] -> cell 21, seg 0 (0.5) [0.5 on Epop[21]], weight: 4.1363508E-4, delay 1.5
        h("Epop[21] syn_projEE_ampa[3941] = new ampa(0.5)")
        h("Epop[49] netConn_projEE_ampa[3941] = new NetCon(&v(0.5), syn_projEE_ampa[3941], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3942: cell 49, seg 0 (0.5) [0.5 on Epop[49]] -> cell 22, seg 0 (0.5) [0.5 on Epop[22]], weight: 4.1363508E-4, delay 1.5
        h("Epop[22] syn_projEE_ampa[3942] = new ampa(0.5)")
        h("Epop[49] netConn_projEE_ampa[3942] = new NetCon(&v(0.5), syn_projEE_ampa[3942], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3943: cell 49, seg 0 (0.5) [0.5 on Epop[49]] -> cell 23, seg 0 (0.5) [0.5 on Epop[23]], weight: 4.1363508E-4, delay 1.5
        h("Epop[23] syn_projEE_ampa[3943] = new ampa(0.5)")
        h("Epop[49] netConn_projEE_ampa[3943] = new NetCon(&v(0.5), syn_projEE_ampa[3943], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3944: cell 49, seg 0 (0.5) [0.5 on Epop[49]] -> cell 24, seg 0 (0.5) [0.5 on Epop[24]], weight: 4.1363508E-4, delay 1.5
        h("Epop[24] syn_projEE_ampa[3944] = new ampa(0.5)")
        h("Epop[49] netConn_projEE_ampa[3944] = new NetCon(&v(0.5), syn_projEE_ampa[3944], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3945: cell 49, seg 0 (0.5) [0.5 on Epop[49]] -> cell 25, seg 0 (0.5) [0.5 on Epop[25]], weight: 4.1363508E-4, delay 1.5
        h("Epop[25] syn_projEE_ampa[3945] = new ampa(0.5)")
        h("Epop[49] netConn_projEE_ampa[3945] = new NetCon(&v(0.5), syn_projEE_ampa[3945], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3946: cell 49, seg 0 (0.5) [0.5 on Epop[49]] -> cell 26, seg 0 (0.5) [0.5 on Epop[26]], weight: 4.1363508E-4, delay 1.5
        h("Epop[26] syn_projEE_ampa[3946] = new ampa(0.5)")
        h("Epop[49] netConn_projEE_ampa[3946] = new NetCon(&v(0.5), syn_projEE_ampa[3946], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3947: cell 49, seg 0 (0.5) [0.5 on Epop[49]] -> cell 27, seg 0 (0.5) [0.5 on Epop[27]], weight: 4.1363508E-4, delay 1.5
        h("Epop[27] syn_projEE_ampa[3947] = new ampa(0.5)")
        h("Epop[49] netConn_projEE_ampa[3947] = new NetCon(&v(0.5), syn_projEE_ampa[3947], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3948: cell 49, seg 0 (0.5) [0.5 on Epop[49]] -> cell 28, seg 0 (0.5) [0.5 on Epop[28]], weight: 4.1363508E-4, delay 1.5
        h("Epop[28] syn_projEE_ampa[3948] = new ampa(0.5)")
        h("Epop[49] netConn_projEE_ampa[3948] = new NetCon(&v(0.5), syn_projEE_ampa[3948], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3949: cell 49, seg 0 (0.5) [0.5 on Epop[49]] -> cell 29, seg 0 (0.5) [0.5 on Epop[29]], weight: 4.1363508E-4, delay 1.5
        h("Epop[29] syn_projEE_ampa[3949] = new ampa(0.5)")
        h("Epop[49] netConn_projEE_ampa[3949] = new NetCon(&v(0.5), syn_projEE_ampa[3949], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3950: cell 49, seg 0 (0.5) [0.5 on Epop[49]] -> cell 30, seg 0 (0.5) [0.5 on Epop[30]], weight: 4.1363508E-4, delay 1.5
        h("Epop[30] syn_projEE_ampa[3950] = new ampa(0.5)")
        h("Epop[49] netConn_projEE_ampa[3950] = new NetCon(&v(0.5), syn_projEE_ampa[3950], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3951: cell 49, seg 0 (0.5) [0.5 on Epop[49]] -> cell 31, seg 0 (0.5) [0.5 on Epop[31]], weight: 4.1363508E-4, delay 1.5
        h("Epop[31] syn_projEE_ampa[3951] = new ampa(0.5)")
        h("Epop[49] netConn_projEE_ampa[3951] = new NetCon(&v(0.5), syn_projEE_ampa[3951], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3952: cell 49, seg 0 (0.5) [0.5 on Epop[49]] -> cell 32, seg 0 (0.5) [0.5 on Epop[32]], weight: 4.1363508E-4, delay 1.5
        h("Epop[32] syn_projEE_ampa[3952] = new ampa(0.5)")
        h("Epop[49] netConn_projEE_ampa[3952] = new NetCon(&v(0.5), syn_projEE_ampa[3952], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3953: cell 49, seg 0 (0.5) [0.5 on Epop[49]] -> cell 33, seg 0 (0.5) [0.5 on Epop[33]], weight: 4.1363508E-4, delay 1.5
        h("Epop[33] syn_projEE_ampa[3953] = new ampa(0.5)")
        h("Epop[49] netConn_projEE_ampa[3953] = new NetCon(&v(0.5), syn_projEE_ampa[3953], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3954: cell 49, seg 0 (0.5) [0.5 on Epop[49]] -> cell 34, seg 0 (0.5) [0.5 on Epop[34]], weight: 4.1363508E-4, delay 1.5
        h("Epop[34] syn_projEE_ampa[3954] = new ampa(0.5)")
        h("Epop[49] netConn_projEE_ampa[3954] = new NetCon(&v(0.5), syn_projEE_ampa[3954], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3955: cell 49, seg 0 (0.5) [0.5 on Epop[49]] -> cell 35, seg 0 (0.5) [0.5 on Epop[35]], weight: 4.1363508E-4, delay 1.5
        h("Epop[35] syn_projEE_ampa[3955] = new ampa(0.5)")
        h("Epop[49] netConn_projEE_ampa[3955] = new NetCon(&v(0.5), syn_projEE_ampa[3955], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3956: cell 49, seg 0 (0.5) [0.5 on Epop[49]] -> cell 36, seg 0 (0.5) [0.5 on Epop[36]], weight: 4.1363508E-4, delay 1.5
        h("Epop[36] syn_projEE_ampa[3956] = new ampa(0.5)")
        h("Epop[49] netConn_projEE_ampa[3956] = new NetCon(&v(0.5), syn_projEE_ampa[3956], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3957: cell 49, seg 0 (0.5) [0.5 on Epop[49]] -> cell 37, seg 0 (0.5) [0.5 on Epop[37]], weight: 4.1363508E-4, delay 1.5
        h("Epop[37] syn_projEE_ampa[3957] = new ampa(0.5)")
        h("Epop[49] netConn_projEE_ampa[3957] = new NetCon(&v(0.5), syn_projEE_ampa[3957], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3958: cell 49, seg 0 (0.5) [0.5 on Epop[49]] -> cell 38, seg 0 (0.5) [0.5 on Epop[38]], weight: 4.1363508E-4, delay 1.5
        h("Epop[38] syn_projEE_ampa[3958] = new ampa(0.5)")
        h("Epop[49] netConn_projEE_ampa[3958] = new NetCon(&v(0.5), syn_projEE_ampa[3958], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3959: cell 49, seg 0 (0.5) [0.5 on Epop[49]] -> cell 39, seg 0 (0.5) [0.5 on Epop[39]], weight: 4.1363508E-4, delay 1.5
        h("Epop[39] syn_projEE_ampa[3959] = new ampa(0.5)")
        h("Epop[49] netConn_projEE_ampa[3959] = new NetCon(&v(0.5), syn_projEE_ampa[3959], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3960: cell 49, seg 0 (0.5) [0.5 on Epop[49]] -> cell 40, seg 0 (0.5) [0.5 on Epop[40]], weight: 4.1363508E-4, delay 1.5
        h("Epop[40] syn_projEE_ampa[3960] = new ampa(0.5)")
        h("Epop[49] netConn_projEE_ampa[3960] = new NetCon(&v(0.5), syn_projEE_ampa[3960], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3961: cell 49, seg 0 (0.5) [0.5 on Epop[49]] -> cell 41, seg 0 (0.5) [0.5 on Epop[41]], weight: 4.1363508E-4, delay 1.5
        h("Epop[41] syn_projEE_ampa[3961] = new ampa(0.5)")
        h("Epop[49] netConn_projEE_ampa[3961] = new NetCon(&v(0.5), syn_projEE_ampa[3961], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3962: cell 49, seg 0 (0.5) [0.5 on Epop[49]] -> cell 42, seg 0 (0.5) [0.5 on Epop[42]], weight: 4.1363508E-4, delay 1.5
        h("Epop[42] syn_projEE_ampa[3962] = new ampa(0.5)")
        h("Epop[49] netConn_projEE_ampa[3962] = new NetCon(&v(0.5), syn_projEE_ampa[3962], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3963: cell 49, seg 0 (0.5) [0.5 on Epop[49]] -> cell 43, seg 0 (0.5) [0.5 on Epop[43]], weight: 4.1363508E-4, delay 1.5
        h("Epop[43] syn_projEE_ampa[3963] = new ampa(0.5)")
        h("Epop[49] netConn_projEE_ampa[3963] = new NetCon(&v(0.5), syn_projEE_ampa[3963], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3964: cell 49, seg 0 (0.5) [0.5 on Epop[49]] -> cell 44, seg 0 (0.5) [0.5 on Epop[44]], weight: 4.1363508E-4, delay 1.5
        h("Epop[44] syn_projEE_ampa[3964] = new ampa(0.5)")
        h("Epop[49] netConn_projEE_ampa[3964] = new NetCon(&v(0.5), syn_projEE_ampa[3964], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3965: cell 49, seg 0 (0.5) [0.5 on Epop[49]] -> cell 45, seg 0 (0.5) [0.5 on Epop[45]], weight: 4.1363508E-4, delay 1.5
        h("Epop[45] syn_projEE_ampa[3965] = new ampa(0.5)")
        h("Epop[49] netConn_projEE_ampa[3965] = new NetCon(&v(0.5), syn_projEE_ampa[3965], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3966: cell 49, seg 0 (0.5) [0.5 on Epop[49]] -> cell 46, seg 0 (0.5) [0.5 on Epop[46]], weight: 4.1363508E-4, delay 1.5
        h("Epop[46] syn_projEE_ampa[3966] = new ampa(0.5)")
        h("Epop[49] netConn_projEE_ampa[3966] = new NetCon(&v(0.5), syn_projEE_ampa[3966], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3967: cell 49, seg 0 (0.5) [0.5 on Epop[49]] -> cell 47, seg 0 (0.5) [0.5 on Epop[47]], weight: 4.1363508E-4, delay 1.5
        h("Epop[47] syn_projEE_ampa[3967] = new ampa(0.5)")
        h("Epop[49] netConn_projEE_ampa[3967] = new NetCon(&v(0.5), syn_projEE_ampa[3967], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3968: cell 49, seg 0 (0.5) [0.5 on Epop[49]] -> cell 48, seg 0 (0.5) [0.5 on Epop[48]], weight: 4.1363508E-4, delay 1.5
        h("Epop[48] syn_projEE_ampa[3968] = new ampa(0.5)")
        h("Epop[49] netConn_projEE_ampa[3968] = new NetCon(&v(0.5), syn_projEE_ampa[3968], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3969: cell 49, seg 0 (0.5) [0.5 on Epop[49]] -> cell 49, seg 0 (0.5) [0.5 on Epop[49]], weight: 4.1363508E-4, delay 1.5
        h("Epop[49] syn_projEE_ampa[3969] = new ampa(0.5)")
        h("Epop[49] netConn_projEE_ampa[3969] = new NetCon(&v(0.5), syn_projEE_ampa[3969], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3970: cell 49, seg 0 (0.5) [0.5 on Epop[49]] -> cell 50, seg 0 (0.5) [0.5 on Epop[50]], weight: 4.1363508E-4, delay 1.5
        h("Epop[50] syn_projEE_ampa[3970] = new ampa(0.5)")
        h("Epop[49] netConn_projEE_ampa[3970] = new NetCon(&v(0.5), syn_projEE_ampa[3970], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3971: cell 49, seg 0 (0.5) [0.5 on Epop[49]] -> cell 51, seg 0 (0.5) [0.5 on Epop[51]], weight: 4.1363508E-4, delay 1.5
        h("Epop[51] syn_projEE_ampa[3971] = new ampa(0.5)")
        h("Epop[49] netConn_projEE_ampa[3971] = new NetCon(&v(0.5), syn_projEE_ampa[3971], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3972: cell 49, seg 0 (0.5) [0.5 on Epop[49]] -> cell 52, seg 0 (0.5) [0.5 on Epop[52]], weight: 4.1363508E-4, delay 1.5
        h("Epop[52] syn_projEE_ampa[3972] = new ampa(0.5)")
        h("Epop[49] netConn_projEE_ampa[3972] = new NetCon(&v(0.5), syn_projEE_ampa[3972], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3973: cell 49, seg 0 (0.5) [0.5 on Epop[49]] -> cell 53, seg 0 (0.5) [0.5 on Epop[53]], weight: 4.1363508E-4, delay 1.5
        h("Epop[53] syn_projEE_ampa[3973] = new ampa(0.5)")
        h("Epop[49] netConn_projEE_ampa[3973] = new NetCon(&v(0.5), syn_projEE_ampa[3973], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3974: cell 49, seg 0 (0.5) [0.5 on Epop[49]] -> cell 54, seg 0 (0.5) [0.5 on Epop[54]], weight: 4.1363508E-4, delay 1.5
        h("Epop[54] syn_projEE_ampa[3974] = new ampa(0.5)")
        h("Epop[49] netConn_projEE_ampa[3974] = new NetCon(&v(0.5), syn_projEE_ampa[3974], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3975: cell 49, seg 0 (0.5) [0.5 on Epop[49]] -> cell 55, seg 0 (0.5) [0.5 on Epop[55]], weight: 4.1363508E-4, delay 1.5
        h("Epop[55] syn_projEE_ampa[3975] = new ampa(0.5)")
        h("Epop[49] netConn_projEE_ampa[3975] = new NetCon(&v(0.5), syn_projEE_ampa[3975], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3976: cell 49, seg 0 (0.5) [0.5 on Epop[49]] -> cell 56, seg 0 (0.5) [0.5 on Epop[56]], weight: 4.1363508E-4, delay 1.5
        h("Epop[56] syn_projEE_ampa[3976] = new ampa(0.5)")
        h("Epop[49] netConn_projEE_ampa[3976] = new NetCon(&v(0.5), syn_projEE_ampa[3976], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3977: cell 49, seg 0 (0.5) [0.5 on Epop[49]] -> cell 57, seg 0 (0.5) [0.5 on Epop[57]], weight: 4.1363508E-4, delay 1.5
        h("Epop[57] syn_projEE_ampa[3977] = new ampa(0.5)")
        h("Epop[49] netConn_projEE_ampa[3977] = new NetCon(&v(0.5), syn_projEE_ampa[3977], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3978: cell 49, seg 0 (0.5) [0.5 on Epop[49]] -> cell 58, seg 0 (0.5) [0.5 on Epop[58]], weight: 4.1363508E-4, delay 1.5
        h("Epop[58] syn_projEE_ampa[3978] = new ampa(0.5)")
        h("Epop[49] netConn_projEE_ampa[3978] = new NetCon(&v(0.5), syn_projEE_ampa[3978], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3979: cell 49, seg 0 (0.5) [0.5 on Epop[49]] -> cell 59, seg 0 (0.5) [0.5 on Epop[59]], weight: 4.1363508E-4, delay 1.5
        h("Epop[59] syn_projEE_ampa[3979] = new ampa(0.5)")
        h("Epop[49] netConn_projEE_ampa[3979] = new NetCon(&v(0.5), syn_projEE_ampa[3979], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3980: cell 49, seg 0 (0.5) [0.5 on Epop[49]] -> cell 60, seg 0 (0.5) [0.5 on Epop[60]], weight: 4.1363508E-4, delay 1.5
        h("Epop[60] syn_projEE_ampa[3980] = new ampa(0.5)")
        h("Epop[49] netConn_projEE_ampa[3980] = new NetCon(&v(0.5), syn_projEE_ampa[3980], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3981: cell 49, seg 0 (0.5) [0.5 on Epop[49]] -> cell 61, seg 0 (0.5) [0.5 on Epop[61]], weight: 4.1363508E-4, delay 1.5
        h("Epop[61] syn_projEE_ampa[3981] = new ampa(0.5)")
        h("Epop[49] netConn_projEE_ampa[3981] = new NetCon(&v(0.5), syn_projEE_ampa[3981], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3982: cell 49, seg 0 (0.5) [0.5 on Epop[49]] -> cell 62, seg 0 (0.5) [0.5 on Epop[62]], weight: 4.1363508E-4, delay 1.5
        h("Epop[62] syn_projEE_ampa[3982] = new ampa(0.5)")
        h("Epop[49] netConn_projEE_ampa[3982] = new NetCon(&v(0.5), syn_projEE_ampa[3982], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3983: cell 49, seg 0 (0.5) [0.5 on Epop[49]] -> cell 63, seg 0 (0.5) [0.5 on Epop[63]], weight: 4.1363508E-4, delay 1.5
        h("Epop[63] syn_projEE_ampa[3983] = new ampa(0.5)")
        h("Epop[49] netConn_projEE_ampa[3983] = new NetCon(&v(0.5), syn_projEE_ampa[3983], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3984: cell 49, seg 0 (0.5) [0.5 on Epop[49]] -> cell 64, seg 0 (0.5) [0.5 on Epop[64]], weight: 4.1363508E-4, delay 1.5
        h("Epop[64] syn_projEE_ampa[3984] = new ampa(0.5)")
        h("Epop[49] netConn_projEE_ampa[3984] = new NetCon(&v(0.5), syn_projEE_ampa[3984], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3985: cell 49, seg 0 (0.5) [0.5 on Epop[49]] -> cell 65, seg 0 (0.5) [0.5 on Epop[65]], weight: 4.1363508E-4, delay 1.5
        h("Epop[65] syn_projEE_ampa[3985] = new ampa(0.5)")
        h("Epop[49] netConn_projEE_ampa[3985] = new NetCon(&v(0.5), syn_projEE_ampa[3985], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3986: cell 49, seg 0 (0.5) [0.5 on Epop[49]] -> cell 66, seg 0 (0.5) [0.5 on Epop[66]], weight: 4.1363508E-4, delay 1.5
        h("Epop[66] syn_projEE_ampa[3986] = new ampa(0.5)")
        h("Epop[49] netConn_projEE_ampa[3986] = new NetCon(&v(0.5), syn_projEE_ampa[3986], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3987: cell 49, seg 0 (0.5) [0.5 on Epop[49]] -> cell 67, seg 0 (0.5) [0.5 on Epop[67]], weight: 4.1363508E-4, delay 1.5
        h("Epop[67] syn_projEE_ampa[3987] = new ampa(0.5)")
        h("Epop[49] netConn_projEE_ampa[3987] = new NetCon(&v(0.5), syn_projEE_ampa[3987], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3988: cell 49, seg 0 (0.5) [0.5 on Epop[49]] -> cell 68, seg 0 (0.5) [0.5 on Epop[68]], weight: 4.1363508E-4, delay 1.5
        h("Epop[68] syn_projEE_ampa[3988] = new ampa(0.5)")
        h("Epop[49] netConn_projEE_ampa[3988] = new NetCon(&v(0.5), syn_projEE_ampa[3988], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3989: cell 49, seg 0 (0.5) [0.5 on Epop[49]] -> cell 69, seg 0 (0.5) [0.5 on Epop[69]], weight: 4.1363508E-4, delay 1.5
        h("Epop[69] syn_projEE_ampa[3989] = new ampa(0.5)")
        h("Epop[49] netConn_projEE_ampa[3989] = new NetCon(&v(0.5), syn_projEE_ampa[3989], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3990: cell 49, seg 0 (0.5) [0.5 on Epop[49]] -> cell 70, seg 0 (0.5) [0.5 on Epop[70]], weight: 4.1363508E-4, delay 1.5
        h("Epop[70] syn_projEE_ampa[3990] = new ampa(0.5)")
        h("Epop[49] netConn_projEE_ampa[3990] = new NetCon(&v(0.5), syn_projEE_ampa[3990], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3991: cell 49, seg 0 (0.5) [0.5 on Epop[49]] -> cell 71, seg 0 (0.5) [0.5 on Epop[71]], weight: 4.1363508E-4, delay 1.5
        h("Epop[71] syn_projEE_ampa[3991] = new ampa(0.5)")
        h("Epop[49] netConn_projEE_ampa[3991] = new NetCon(&v(0.5), syn_projEE_ampa[3991], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3992: cell 49, seg 0 (0.5) [0.5 on Epop[49]] -> cell 72, seg 0 (0.5) [0.5 on Epop[72]], weight: 4.1363508E-4, delay 1.5
        h("Epop[72] syn_projEE_ampa[3992] = new ampa(0.5)")
        h("Epop[49] netConn_projEE_ampa[3992] = new NetCon(&v(0.5), syn_projEE_ampa[3992], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3993: cell 49, seg 0 (0.5) [0.5 on Epop[49]] -> cell 73, seg 0 (0.5) [0.5 on Epop[73]], weight: 4.1363508E-4, delay 1.5
        h("Epop[73] syn_projEE_ampa[3993] = new ampa(0.5)")
        h("Epop[49] netConn_projEE_ampa[3993] = new NetCon(&v(0.5), syn_projEE_ampa[3993], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3994: cell 49, seg 0 (0.5) [0.5 on Epop[49]] -> cell 74, seg 0 (0.5) [0.5 on Epop[74]], weight: 4.1363508E-4, delay 1.5
        h("Epop[74] syn_projEE_ampa[3994] = new ampa(0.5)")
        h("Epop[49] netConn_projEE_ampa[3994] = new NetCon(&v(0.5), syn_projEE_ampa[3994], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3995: cell 49, seg 0 (0.5) [0.5 on Epop[49]] -> cell 75, seg 0 (0.5) [0.5 on Epop[75]], weight: 4.1363508E-4, delay 1.5
        h("Epop[75] syn_projEE_ampa[3995] = new ampa(0.5)")
        h("Epop[49] netConn_projEE_ampa[3995] = new NetCon(&v(0.5), syn_projEE_ampa[3995], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3996: cell 49, seg 0 (0.5) [0.5 on Epop[49]] -> cell 76, seg 0 (0.5) [0.5 on Epop[76]], weight: 4.1363508E-4, delay 1.5
        h("Epop[76] syn_projEE_ampa[3996] = new ampa(0.5)")
        h("Epop[49] netConn_projEE_ampa[3996] = new NetCon(&v(0.5), syn_projEE_ampa[3996], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3997: cell 49, seg 0 (0.5) [0.5 on Epop[49]] -> cell 77, seg 0 (0.5) [0.5 on Epop[77]], weight: 4.1363508E-4, delay 1.5
        h("Epop[77] syn_projEE_ampa[3997] = new ampa(0.5)")
        h("Epop[49] netConn_projEE_ampa[3997] = new NetCon(&v(0.5), syn_projEE_ampa[3997], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3998: cell 49, seg 0 (0.5) [0.5 on Epop[49]] -> cell 78, seg 0 (0.5) [0.5 on Epop[78]], weight: 4.1363508E-4, delay 1.5
        h("Epop[78] syn_projEE_ampa[3998] = new ampa(0.5)")
        h("Epop[49] netConn_projEE_ampa[3998] = new NetCon(&v(0.5), syn_projEE_ampa[3998], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3999: cell 49, seg 0 (0.5) [0.5 on Epop[49]] -> cell 79, seg 0 (0.5) [0.5 on Epop[79]], weight: 4.1363508E-4, delay 1.5
        h("Epop[79] syn_projEE_ampa[3999] = new ampa(0.5)")
        h("Epop[49] netConn_projEE_ampa[3999] = new NetCon(&v(0.5), syn_projEE_ampa[3999], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4000: cell 50, seg 0 (0.5) [0.5 on Epop[50]] -> cell 0, seg 0 (0.5) [0.5 on Epop[0]], weight: 4.1363508E-4, delay 1.5
        h("Epop[0] syn_projEE_ampa[4000] = new ampa(0.5)")
        h("Epop[50] netConn_projEE_ampa[4000] = new NetCon(&v(0.5), syn_projEE_ampa[4000], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4001: cell 50, seg 0 (0.5) [0.5 on Epop[50]] -> cell 1, seg 0 (0.5) [0.5 on Epop[1]], weight: 4.1363508E-4, delay 1.5
        h("Epop[1] syn_projEE_ampa[4001] = new ampa(0.5)")
        h("Epop[50] netConn_projEE_ampa[4001] = new NetCon(&v(0.5), syn_projEE_ampa[4001], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4002: cell 50, seg 0 (0.5) [0.5 on Epop[50]] -> cell 2, seg 0 (0.5) [0.5 on Epop[2]], weight: 4.1363508E-4, delay 1.5
        h("Epop[2] syn_projEE_ampa[4002] = new ampa(0.5)")
        h("Epop[50] netConn_projEE_ampa[4002] = new NetCon(&v(0.5), syn_projEE_ampa[4002], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4003: cell 50, seg 0 (0.5) [0.5 on Epop[50]] -> cell 3, seg 0 (0.5) [0.5 on Epop[3]], weight: 4.1363508E-4, delay 1.5
        h("Epop[3] syn_projEE_ampa[4003] = new ampa(0.5)")
        h("Epop[50] netConn_projEE_ampa[4003] = new NetCon(&v(0.5), syn_projEE_ampa[4003], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4004: cell 50, seg 0 (0.5) [0.5 on Epop[50]] -> cell 4, seg 0 (0.5) [0.5 on Epop[4]], weight: 4.1363508E-4, delay 1.5
        h("Epop[4] syn_projEE_ampa[4004] = new ampa(0.5)")
        h("Epop[50] netConn_projEE_ampa[4004] = new NetCon(&v(0.5), syn_projEE_ampa[4004], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4005: cell 50, seg 0 (0.5) [0.5 on Epop[50]] -> cell 5, seg 0 (0.5) [0.5 on Epop[5]], weight: 4.1363508E-4, delay 1.5
        h("Epop[5] syn_projEE_ampa[4005] = new ampa(0.5)")
        h("Epop[50] netConn_projEE_ampa[4005] = new NetCon(&v(0.5), syn_projEE_ampa[4005], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4006: cell 50, seg 0 (0.5) [0.5 on Epop[50]] -> cell 6, seg 0 (0.5) [0.5 on Epop[6]], weight: 4.1363508E-4, delay 1.5
        h("Epop[6] syn_projEE_ampa[4006] = new ampa(0.5)")
        h("Epop[50] netConn_projEE_ampa[4006] = new NetCon(&v(0.5), syn_projEE_ampa[4006], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4007: cell 50, seg 0 (0.5) [0.5 on Epop[50]] -> cell 7, seg 0 (0.5) [0.5 on Epop[7]], weight: 4.1363508E-4, delay 1.5
        h("Epop[7] syn_projEE_ampa[4007] = new ampa(0.5)")
        h("Epop[50] netConn_projEE_ampa[4007] = new NetCon(&v(0.5), syn_projEE_ampa[4007], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4008: cell 50, seg 0 (0.5) [0.5 on Epop[50]] -> cell 8, seg 0 (0.5) [0.5 on Epop[8]], weight: 4.1363508E-4, delay 1.5
        h("Epop[8] syn_projEE_ampa[4008] = new ampa(0.5)")
        h("Epop[50] netConn_projEE_ampa[4008] = new NetCon(&v(0.5), syn_projEE_ampa[4008], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4009: cell 50, seg 0 (0.5) [0.5 on Epop[50]] -> cell 9, seg 0 (0.5) [0.5 on Epop[9]], weight: 4.1363508E-4, delay 1.5
        h("Epop[9] syn_projEE_ampa[4009] = new ampa(0.5)")
        h("Epop[50] netConn_projEE_ampa[4009] = new NetCon(&v(0.5), syn_projEE_ampa[4009], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4010: cell 50, seg 0 (0.5) [0.5 on Epop[50]] -> cell 10, seg 0 (0.5) [0.5 on Epop[10]], weight: 4.1363508E-4, delay 1.5
        h("Epop[10] syn_projEE_ampa[4010] = new ampa(0.5)")
        h("Epop[50] netConn_projEE_ampa[4010] = new NetCon(&v(0.5), syn_projEE_ampa[4010], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4011: cell 50, seg 0 (0.5) [0.5 on Epop[50]] -> cell 11, seg 0 (0.5) [0.5 on Epop[11]], weight: 4.1363508E-4, delay 1.5
        h("Epop[11] syn_projEE_ampa[4011] = new ampa(0.5)")
        h("Epop[50] netConn_projEE_ampa[4011] = new NetCon(&v(0.5), syn_projEE_ampa[4011], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4012: cell 50, seg 0 (0.5) [0.5 on Epop[50]] -> cell 12, seg 0 (0.5) [0.5 on Epop[12]], weight: 4.1363508E-4, delay 1.5
        h("Epop[12] syn_projEE_ampa[4012] = new ampa(0.5)")
        h("Epop[50] netConn_projEE_ampa[4012] = new NetCon(&v(0.5), syn_projEE_ampa[4012], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4013: cell 50, seg 0 (0.5) [0.5 on Epop[50]] -> cell 13, seg 0 (0.5) [0.5 on Epop[13]], weight: 4.1363508E-4, delay 1.5
        h("Epop[13] syn_projEE_ampa[4013] = new ampa(0.5)")
        h("Epop[50] netConn_projEE_ampa[4013] = new NetCon(&v(0.5), syn_projEE_ampa[4013], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4014: cell 50, seg 0 (0.5) [0.5 on Epop[50]] -> cell 14, seg 0 (0.5) [0.5 on Epop[14]], weight: 4.1363508E-4, delay 1.5
        h("Epop[14] syn_projEE_ampa[4014] = new ampa(0.5)")
        h("Epop[50] netConn_projEE_ampa[4014] = new NetCon(&v(0.5), syn_projEE_ampa[4014], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4015: cell 50, seg 0 (0.5) [0.5 on Epop[50]] -> cell 15, seg 0 (0.5) [0.5 on Epop[15]], weight: 4.1363508E-4, delay 1.5
        h("Epop[15] syn_projEE_ampa[4015] = new ampa(0.5)")
        h("Epop[50] netConn_projEE_ampa[4015] = new NetCon(&v(0.5), syn_projEE_ampa[4015], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4016: cell 50, seg 0 (0.5) [0.5 on Epop[50]] -> cell 16, seg 0 (0.5) [0.5 on Epop[16]], weight: 4.1363508E-4, delay 1.5
        h("Epop[16] syn_projEE_ampa[4016] = new ampa(0.5)")
        h("Epop[50] netConn_projEE_ampa[4016] = new NetCon(&v(0.5), syn_projEE_ampa[4016], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4017: cell 50, seg 0 (0.5) [0.5 on Epop[50]] -> cell 17, seg 0 (0.5) [0.5 on Epop[17]], weight: 4.1363508E-4, delay 1.5
        h("Epop[17] syn_projEE_ampa[4017] = new ampa(0.5)")
        h("Epop[50] netConn_projEE_ampa[4017] = new NetCon(&v(0.5), syn_projEE_ampa[4017], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4018: cell 50, seg 0 (0.5) [0.5 on Epop[50]] -> cell 18, seg 0 (0.5) [0.5 on Epop[18]], weight: 4.1363508E-4, delay 1.5
        h("Epop[18] syn_projEE_ampa[4018] = new ampa(0.5)")
        h("Epop[50] netConn_projEE_ampa[4018] = new NetCon(&v(0.5), syn_projEE_ampa[4018], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4019: cell 50, seg 0 (0.5) [0.5 on Epop[50]] -> cell 19, seg 0 (0.5) [0.5 on Epop[19]], weight: 4.1363508E-4, delay 1.5
        h("Epop[19] syn_projEE_ampa[4019] = new ampa(0.5)")
        h("Epop[50] netConn_projEE_ampa[4019] = new NetCon(&v(0.5), syn_projEE_ampa[4019], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4020: cell 50, seg 0 (0.5) [0.5 on Epop[50]] -> cell 20, seg 0 (0.5) [0.5 on Epop[20]], weight: 4.1363508E-4, delay 1.5
        h("Epop[20] syn_projEE_ampa[4020] = new ampa(0.5)")
        h("Epop[50] netConn_projEE_ampa[4020] = new NetCon(&v(0.5), syn_projEE_ampa[4020], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4021: cell 50, seg 0 (0.5) [0.5 on Epop[50]] -> cell 21, seg 0 (0.5) [0.5 on Epop[21]], weight: 4.1363508E-4, delay 1.5
        h("Epop[21] syn_projEE_ampa[4021] = new ampa(0.5)")
        h("Epop[50] netConn_projEE_ampa[4021] = new NetCon(&v(0.5), syn_projEE_ampa[4021], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4022: cell 50, seg 0 (0.5) [0.5 on Epop[50]] -> cell 22, seg 0 (0.5) [0.5 on Epop[22]], weight: 4.1363508E-4, delay 1.5
        h("Epop[22] syn_projEE_ampa[4022] = new ampa(0.5)")
        h("Epop[50] netConn_projEE_ampa[4022] = new NetCon(&v(0.5), syn_projEE_ampa[4022], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4023: cell 50, seg 0 (0.5) [0.5 on Epop[50]] -> cell 23, seg 0 (0.5) [0.5 on Epop[23]], weight: 4.1363508E-4, delay 1.5
        h("Epop[23] syn_projEE_ampa[4023] = new ampa(0.5)")
        h("Epop[50] netConn_projEE_ampa[4023] = new NetCon(&v(0.5), syn_projEE_ampa[4023], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4024: cell 50, seg 0 (0.5) [0.5 on Epop[50]] -> cell 24, seg 0 (0.5) [0.5 on Epop[24]], weight: 4.1363508E-4, delay 1.5
        h("Epop[24] syn_projEE_ampa[4024] = new ampa(0.5)")
        h("Epop[50] netConn_projEE_ampa[4024] = new NetCon(&v(0.5), syn_projEE_ampa[4024], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4025: cell 50, seg 0 (0.5) [0.5 on Epop[50]] -> cell 25, seg 0 (0.5) [0.5 on Epop[25]], weight: 4.1363508E-4, delay 1.5
        h("Epop[25] syn_projEE_ampa[4025] = new ampa(0.5)")
        h("Epop[50] netConn_projEE_ampa[4025] = new NetCon(&v(0.5), syn_projEE_ampa[4025], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4026: cell 50, seg 0 (0.5) [0.5 on Epop[50]] -> cell 26, seg 0 (0.5) [0.5 on Epop[26]], weight: 4.1363508E-4, delay 1.5
        h("Epop[26] syn_projEE_ampa[4026] = new ampa(0.5)")
        h("Epop[50] netConn_projEE_ampa[4026] = new NetCon(&v(0.5), syn_projEE_ampa[4026], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4027: cell 50, seg 0 (0.5) [0.5 on Epop[50]] -> cell 27, seg 0 (0.5) [0.5 on Epop[27]], weight: 4.1363508E-4, delay 1.5
        h("Epop[27] syn_projEE_ampa[4027] = new ampa(0.5)")
        h("Epop[50] netConn_projEE_ampa[4027] = new NetCon(&v(0.5), syn_projEE_ampa[4027], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4028: cell 50, seg 0 (0.5) [0.5 on Epop[50]] -> cell 28, seg 0 (0.5) [0.5 on Epop[28]], weight: 4.1363508E-4, delay 1.5
        h("Epop[28] syn_projEE_ampa[4028] = new ampa(0.5)")
        h("Epop[50] netConn_projEE_ampa[4028] = new NetCon(&v(0.5), syn_projEE_ampa[4028], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4029: cell 50, seg 0 (0.5) [0.5 on Epop[50]] -> cell 29, seg 0 (0.5) [0.5 on Epop[29]], weight: 4.1363508E-4, delay 1.5
        h("Epop[29] syn_projEE_ampa[4029] = new ampa(0.5)")
        h("Epop[50] netConn_projEE_ampa[4029] = new NetCon(&v(0.5), syn_projEE_ampa[4029], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4030: cell 50, seg 0 (0.5) [0.5 on Epop[50]] -> cell 30, seg 0 (0.5) [0.5 on Epop[30]], weight: 4.1363508E-4, delay 1.5
        h("Epop[30] syn_projEE_ampa[4030] = new ampa(0.5)")
        h("Epop[50] netConn_projEE_ampa[4030] = new NetCon(&v(0.5), syn_projEE_ampa[4030], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4031: cell 50, seg 0 (0.5) [0.5 on Epop[50]] -> cell 31, seg 0 (0.5) [0.5 on Epop[31]], weight: 4.1363508E-4, delay 1.5
        h("Epop[31] syn_projEE_ampa[4031] = new ampa(0.5)")
        h("Epop[50] netConn_projEE_ampa[4031] = new NetCon(&v(0.5), syn_projEE_ampa[4031], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4032: cell 50, seg 0 (0.5) [0.5 on Epop[50]] -> cell 32, seg 0 (0.5) [0.5 on Epop[32]], weight: 4.1363508E-4, delay 1.5
        h("Epop[32] syn_projEE_ampa[4032] = new ampa(0.5)")
        h("Epop[50] netConn_projEE_ampa[4032] = new NetCon(&v(0.5), syn_projEE_ampa[4032], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4033: cell 50, seg 0 (0.5) [0.5 on Epop[50]] -> cell 33, seg 0 (0.5) [0.5 on Epop[33]], weight: 4.1363508E-4, delay 1.5
        h("Epop[33] syn_projEE_ampa[4033] = new ampa(0.5)")
        h("Epop[50] netConn_projEE_ampa[4033] = new NetCon(&v(0.5), syn_projEE_ampa[4033], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4034: cell 50, seg 0 (0.5) [0.5 on Epop[50]] -> cell 34, seg 0 (0.5) [0.5 on Epop[34]], weight: 4.1363508E-4, delay 1.5
        h("Epop[34] syn_projEE_ampa[4034] = new ampa(0.5)")
        h("Epop[50] netConn_projEE_ampa[4034] = new NetCon(&v(0.5), syn_projEE_ampa[4034], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4035: cell 50, seg 0 (0.5) [0.5 on Epop[50]] -> cell 35, seg 0 (0.5) [0.5 on Epop[35]], weight: 4.1363508E-4, delay 1.5
        h("Epop[35] syn_projEE_ampa[4035] = new ampa(0.5)")
        h("Epop[50] netConn_projEE_ampa[4035] = new NetCon(&v(0.5), syn_projEE_ampa[4035], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4036: cell 50, seg 0 (0.5) [0.5 on Epop[50]] -> cell 36, seg 0 (0.5) [0.5 on Epop[36]], weight: 4.1363508E-4, delay 1.5
        h("Epop[36] syn_projEE_ampa[4036] = new ampa(0.5)")
        h("Epop[50] netConn_projEE_ampa[4036] = new NetCon(&v(0.5), syn_projEE_ampa[4036], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4037: cell 50, seg 0 (0.5) [0.5 on Epop[50]] -> cell 37, seg 0 (0.5) [0.5 on Epop[37]], weight: 4.1363508E-4, delay 1.5
        h("Epop[37] syn_projEE_ampa[4037] = new ampa(0.5)")
        h("Epop[50] netConn_projEE_ampa[4037] = new NetCon(&v(0.5), syn_projEE_ampa[4037], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4038: cell 50, seg 0 (0.5) [0.5 on Epop[50]] -> cell 38, seg 0 (0.5) [0.5 on Epop[38]], weight: 4.1363508E-4, delay 1.5
        h("Epop[38] syn_projEE_ampa[4038] = new ampa(0.5)")
        h("Epop[50] netConn_projEE_ampa[4038] = new NetCon(&v(0.5), syn_projEE_ampa[4038], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4039: cell 50, seg 0 (0.5) [0.5 on Epop[50]] -> cell 39, seg 0 (0.5) [0.5 on Epop[39]], weight: 4.1363508E-4, delay 1.5
        h("Epop[39] syn_projEE_ampa[4039] = new ampa(0.5)")
        h("Epop[50] netConn_projEE_ampa[4039] = new NetCon(&v(0.5), syn_projEE_ampa[4039], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4040: cell 50, seg 0 (0.5) [0.5 on Epop[50]] -> cell 40, seg 0 (0.5) [0.5 on Epop[40]], weight: 4.1363508E-4, delay 1.5
        h("Epop[40] syn_projEE_ampa[4040] = new ampa(0.5)")
        h("Epop[50] netConn_projEE_ampa[4040] = new NetCon(&v(0.5), syn_projEE_ampa[4040], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4041: cell 50, seg 0 (0.5) [0.5 on Epop[50]] -> cell 41, seg 0 (0.5) [0.5 on Epop[41]], weight: 4.1363508E-4, delay 1.5
        h("Epop[41] syn_projEE_ampa[4041] = new ampa(0.5)")
        h("Epop[50] netConn_projEE_ampa[4041] = new NetCon(&v(0.5), syn_projEE_ampa[4041], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4042: cell 50, seg 0 (0.5) [0.5 on Epop[50]] -> cell 42, seg 0 (0.5) [0.5 on Epop[42]], weight: 4.1363508E-4, delay 1.5
        h("Epop[42] syn_projEE_ampa[4042] = new ampa(0.5)")
        h("Epop[50] netConn_projEE_ampa[4042] = new NetCon(&v(0.5), syn_projEE_ampa[4042], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4043: cell 50, seg 0 (0.5) [0.5 on Epop[50]] -> cell 43, seg 0 (0.5) [0.5 on Epop[43]], weight: 4.1363508E-4, delay 1.5
        h("Epop[43] syn_projEE_ampa[4043] = new ampa(0.5)")
        h("Epop[50] netConn_projEE_ampa[4043] = new NetCon(&v(0.5), syn_projEE_ampa[4043], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4044: cell 50, seg 0 (0.5) [0.5 on Epop[50]] -> cell 44, seg 0 (0.5) [0.5 on Epop[44]], weight: 4.1363508E-4, delay 1.5
        h("Epop[44] syn_projEE_ampa[4044] = new ampa(0.5)")
        h("Epop[50] netConn_projEE_ampa[4044] = new NetCon(&v(0.5), syn_projEE_ampa[4044], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4045: cell 50, seg 0 (0.5) [0.5 on Epop[50]] -> cell 45, seg 0 (0.5) [0.5 on Epop[45]], weight: 4.1363508E-4, delay 1.5
        h("Epop[45] syn_projEE_ampa[4045] = new ampa(0.5)")
        h("Epop[50] netConn_projEE_ampa[4045] = new NetCon(&v(0.5), syn_projEE_ampa[4045], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4046: cell 50, seg 0 (0.5) [0.5 on Epop[50]] -> cell 46, seg 0 (0.5) [0.5 on Epop[46]], weight: 4.1363508E-4, delay 1.5
        h("Epop[46] syn_projEE_ampa[4046] = new ampa(0.5)")
        h("Epop[50] netConn_projEE_ampa[4046] = new NetCon(&v(0.5), syn_projEE_ampa[4046], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4047: cell 50, seg 0 (0.5) [0.5 on Epop[50]] -> cell 47, seg 0 (0.5) [0.5 on Epop[47]], weight: 4.1363508E-4, delay 1.5
        h("Epop[47] syn_projEE_ampa[4047] = new ampa(0.5)")
        h("Epop[50] netConn_projEE_ampa[4047] = new NetCon(&v(0.5), syn_projEE_ampa[4047], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4048: cell 50, seg 0 (0.5) [0.5 on Epop[50]] -> cell 48, seg 0 (0.5) [0.5 on Epop[48]], weight: 4.1363508E-4, delay 1.5
        h("Epop[48] syn_projEE_ampa[4048] = new ampa(0.5)")
        h("Epop[50] netConn_projEE_ampa[4048] = new NetCon(&v(0.5), syn_projEE_ampa[4048], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4049: cell 50, seg 0 (0.5) [0.5 on Epop[50]] -> cell 49, seg 0 (0.5) [0.5 on Epop[49]], weight: 4.1363508E-4, delay 1.5
        h("Epop[49] syn_projEE_ampa[4049] = new ampa(0.5)")
        h("Epop[50] netConn_projEE_ampa[4049] = new NetCon(&v(0.5), syn_projEE_ampa[4049], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4050: cell 50, seg 0 (0.5) [0.5 on Epop[50]] -> cell 50, seg 0 (0.5) [0.5 on Epop[50]], weight: 4.1363508E-4, delay 1.5
        h("Epop[50] syn_projEE_ampa[4050] = new ampa(0.5)")
        h("Epop[50] netConn_projEE_ampa[4050] = new NetCon(&v(0.5), syn_projEE_ampa[4050], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4051: cell 50, seg 0 (0.5) [0.5 on Epop[50]] -> cell 51, seg 0 (0.5) [0.5 on Epop[51]], weight: 4.1363508E-4, delay 1.5
        h("Epop[51] syn_projEE_ampa[4051] = new ampa(0.5)")
        h("Epop[50] netConn_projEE_ampa[4051] = new NetCon(&v(0.5), syn_projEE_ampa[4051], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4052: cell 50, seg 0 (0.5) [0.5 on Epop[50]] -> cell 52, seg 0 (0.5) [0.5 on Epop[52]], weight: 4.1363508E-4, delay 1.5
        h("Epop[52] syn_projEE_ampa[4052] = new ampa(0.5)")
        h("Epop[50] netConn_projEE_ampa[4052] = new NetCon(&v(0.5), syn_projEE_ampa[4052], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4053: cell 50, seg 0 (0.5) [0.5 on Epop[50]] -> cell 53, seg 0 (0.5) [0.5 on Epop[53]], weight: 4.1363508E-4, delay 1.5
        h("Epop[53] syn_projEE_ampa[4053] = new ampa(0.5)")
        h("Epop[50] netConn_projEE_ampa[4053] = new NetCon(&v(0.5), syn_projEE_ampa[4053], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4054: cell 50, seg 0 (0.5) [0.5 on Epop[50]] -> cell 54, seg 0 (0.5) [0.5 on Epop[54]], weight: 4.1363508E-4, delay 1.5
        h("Epop[54] syn_projEE_ampa[4054] = new ampa(0.5)")
        h("Epop[50] netConn_projEE_ampa[4054] = new NetCon(&v(0.5), syn_projEE_ampa[4054], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4055: cell 50, seg 0 (0.5) [0.5 on Epop[50]] -> cell 55, seg 0 (0.5) [0.5 on Epop[55]], weight: 4.1363508E-4, delay 1.5
        h("Epop[55] syn_projEE_ampa[4055] = new ampa(0.5)")
        h("Epop[50] netConn_projEE_ampa[4055] = new NetCon(&v(0.5), syn_projEE_ampa[4055], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4056: cell 50, seg 0 (0.5) [0.5 on Epop[50]] -> cell 56, seg 0 (0.5) [0.5 on Epop[56]], weight: 4.1363508E-4, delay 1.5
        h("Epop[56] syn_projEE_ampa[4056] = new ampa(0.5)")
        h("Epop[50] netConn_projEE_ampa[4056] = new NetCon(&v(0.5), syn_projEE_ampa[4056], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4057: cell 50, seg 0 (0.5) [0.5 on Epop[50]] -> cell 57, seg 0 (0.5) [0.5 on Epop[57]], weight: 4.1363508E-4, delay 1.5
        h("Epop[57] syn_projEE_ampa[4057] = new ampa(0.5)")
        h("Epop[50] netConn_projEE_ampa[4057] = new NetCon(&v(0.5), syn_projEE_ampa[4057], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4058: cell 50, seg 0 (0.5) [0.5 on Epop[50]] -> cell 58, seg 0 (0.5) [0.5 on Epop[58]], weight: 4.1363508E-4, delay 1.5
        h("Epop[58] syn_projEE_ampa[4058] = new ampa(0.5)")
        h("Epop[50] netConn_projEE_ampa[4058] = new NetCon(&v(0.5), syn_projEE_ampa[4058], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4059: cell 50, seg 0 (0.5) [0.5 on Epop[50]] -> cell 59, seg 0 (0.5) [0.5 on Epop[59]], weight: 4.1363508E-4, delay 1.5
        h("Epop[59] syn_projEE_ampa[4059] = new ampa(0.5)")
        h("Epop[50] netConn_projEE_ampa[4059] = new NetCon(&v(0.5), syn_projEE_ampa[4059], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4060: cell 50, seg 0 (0.5) [0.5 on Epop[50]] -> cell 60, seg 0 (0.5) [0.5 on Epop[60]], weight: 4.1363508E-4, delay 1.5
        h("Epop[60] syn_projEE_ampa[4060] = new ampa(0.5)")
        h("Epop[50] netConn_projEE_ampa[4060] = new NetCon(&v(0.5), syn_projEE_ampa[4060], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4061: cell 50, seg 0 (0.5) [0.5 on Epop[50]] -> cell 61, seg 0 (0.5) [0.5 on Epop[61]], weight: 4.1363508E-4, delay 1.5
        h("Epop[61] syn_projEE_ampa[4061] = new ampa(0.5)")
        h("Epop[50] netConn_projEE_ampa[4061] = new NetCon(&v(0.5), syn_projEE_ampa[4061], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4062: cell 50, seg 0 (0.5) [0.5 on Epop[50]] -> cell 62, seg 0 (0.5) [0.5 on Epop[62]], weight: 4.1363508E-4, delay 1.5
        h("Epop[62] syn_projEE_ampa[4062] = new ampa(0.5)")
        h("Epop[50] netConn_projEE_ampa[4062] = new NetCon(&v(0.5), syn_projEE_ampa[4062], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4063: cell 50, seg 0 (0.5) [0.5 on Epop[50]] -> cell 63, seg 0 (0.5) [0.5 on Epop[63]], weight: 4.1363508E-4, delay 1.5
        h("Epop[63] syn_projEE_ampa[4063] = new ampa(0.5)")
        h("Epop[50] netConn_projEE_ampa[4063] = new NetCon(&v(0.5), syn_projEE_ampa[4063], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4064: cell 50, seg 0 (0.5) [0.5 on Epop[50]] -> cell 64, seg 0 (0.5) [0.5 on Epop[64]], weight: 4.1363508E-4, delay 1.5
        h("Epop[64] syn_projEE_ampa[4064] = new ampa(0.5)")
        h("Epop[50] netConn_projEE_ampa[4064] = new NetCon(&v(0.5), syn_projEE_ampa[4064], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4065: cell 50, seg 0 (0.5) [0.5 on Epop[50]] -> cell 65, seg 0 (0.5) [0.5 on Epop[65]], weight: 4.1363508E-4, delay 1.5
        h("Epop[65] syn_projEE_ampa[4065] = new ampa(0.5)")
        h("Epop[50] netConn_projEE_ampa[4065] = new NetCon(&v(0.5), syn_projEE_ampa[4065], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4066: cell 50, seg 0 (0.5) [0.5 on Epop[50]] -> cell 66, seg 0 (0.5) [0.5 on Epop[66]], weight: 4.1363508E-4, delay 1.5
        h("Epop[66] syn_projEE_ampa[4066] = new ampa(0.5)")
        h("Epop[50] netConn_projEE_ampa[4066] = new NetCon(&v(0.5), syn_projEE_ampa[4066], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4067: cell 50, seg 0 (0.5) [0.5 on Epop[50]] -> cell 67, seg 0 (0.5) [0.5 on Epop[67]], weight: 4.1363508E-4, delay 1.5
        h("Epop[67] syn_projEE_ampa[4067] = new ampa(0.5)")
        h("Epop[50] netConn_projEE_ampa[4067] = new NetCon(&v(0.5), syn_projEE_ampa[4067], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4068: cell 50, seg 0 (0.5) [0.5 on Epop[50]] -> cell 68, seg 0 (0.5) [0.5 on Epop[68]], weight: 4.1363508E-4, delay 1.5
        h("Epop[68] syn_projEE_ampa[4068] = new ampa(0.5)")
        h("Epop[50] netConn_projEE_ampa[4068] = new NetCon(&v(0.5), syn_projEE_ampa[4068], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4069: cell 50, seg 0 (0.5) [0.5 on Epop[50]] -> cell 69, seg 0 (0.5) [0.5 on Epop[69]], weight: 4.1363508E-4, delay 1.5
        h("Epop[69] syn_projEE_ampa[4069] = new ampa(0.5)")
        h("Epop[50] netConn_projEE_ampa[4069] = new NetCon(&v(0.5), syn_projEE_ampa[4069], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4070: cell 50, seg 0 (0.5) [0.5 on Epop[50]] -> cell 70, seg 0 (0.5) [0.5 on Epop[70]], weight: 4.1363508E-4, delay 1.5
        h("Epop[70] syn_projEE_ampa[4070] = new ampa(0.5)")
        h("Epop[50] netConn_projEE_ampa[4070] = new NetCon(&v(0.5), syn_projEE_ampa[4070], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4071: cell 50, seg 0 (0.5) [0.5 on Epop[50]] -> cell 71, seg 0 (0.5) [0.5 on Epop[71]], weight: 4.1363508E-4, delay 1.5
        h("Epop[71] syn_projEE_ampa[4071] = new ampa(0.5)")
        h("Epop[50] netConn_projEE_ampa[4071] = new NetCon(&v(0.5), syn_projEE_ampa[4071], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4072: cell 50, seg 0 (0.5) [0.5 on Epop[50]] -> cell 72, seg 0 (0.5) [0.5 on Epop[72]], weight: 4.1363508E-4, delay 1.5
        h("Epop[72] syn_projEE_ampa[4072] = new ampa(0.5)")
        h("Epop[50] netConn_projEE_ampa[4072] = new NetCon(&v(0.5), syn_projEE_ampa[4072], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4073: cell 50, seg 0 (0.5) [0.5 on Epop[50]] -> cell 73, seg 0 (0.5) [0.5 on Epop[73]], weight: 4.1363508E-4, delay 1.5
        h("Epop[73] syn_projEE_ampa[4073] = new ampa(0.5)")
        h("Epop[50] netConn_projEE_ampa[4073] = new NetCon(&v(0.5), syn_projEE_ampa[4073], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4074: cell 50, seg 0 (0.5) [0.5 on Epop[50]] -> cell 74, seg 0 (0.5) [0.5 on Epop[74]], weight: 4.1363508E-4, delay 1.5
        h("Epop[74] syn_projEE_ampa[4074] = new ampa(0.5)")
        h("Epop[50] netConn_projEE_ampa[4074] = new NetCon(&v(0.5), syn_projEE_ampa[4074], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4075: cell 50, seg 0 (0.5) [0.5 on Epop[50]] -> cell 75, seg 0 (0.5) [0.5 on Epop[75]], weight: 4.1363508E-4, delay 1.5
        h("Epop[75] syn_projEE_ampa[4075] = new ampa(0.5)")
        h("Epop[50] netConn_projEE_ampa[4075] = new NetCon(&v(0.5), syn_projEE_ampa[4075], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4076: cell 50, seg 0 (0.5) [0.5 on Epop[50]] -> cell 76, seg 0 (0.5) [0.5 on Epop[76]], weight: 4.1363508E-4, delay 1.5
        h("Epop[76] syn_projEE_ampa[4076] = new ampa(0.5)")
        h("Epop[50] netConn_projEE_ampa[4076] = new NetCon(&v(0.5), syn_projEE_ampa[4076], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4077: cell 50, seg 0 (0.5) [0.5 on Epop[50]] -> cell 77, seg 0 (0.5) [0.5 on Epop[77]], weight: 4.1363508E-4, delay 1.5
        h("Epop[77] syn_projEE_ampa[4077] = new ampa(0.5)")
        h("Epop[50] netConn_projEE_ampa[4077] = new NetCon(&v(0.5), syn_projEE_ampa[4077], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4078: cell 50, seg 0 (0.5) [0.5 on Epop[50]] -> cell 78, seg 0 (0.5) [0.5 on Epop[78]], weight: 4.1363508E-4, delay 1.5
        h("Epop[78] syn_projEE_ampa[4078] = new ampa(0.5)")
        h("Epop[50] netConn_projEE_ampa[4078] = new NetCon(&v(0.5), syn_projEE_ampa[4078], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4079: cell 50, seg 0 (0.5) [0.5 on Epop[50]] -> cell 79, seg 0 (0.5) [0.5 on Epop[79]], weight: 4.1363508E-4, delay 1.5
        h("Epop[79] syn_projEE_ampa[4079] = new ampa(0.5)")
        h("Epop[50] netConn_projEE_ampa[4079] = new NetCon(&v(0.5), syn_projEE_ampa[4079], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4080: cell 51, seg 0 (0.5) [0.5 on Epop[51]] -> cell 0, seg 0 (0.5) [0.5 on Epop[0]], weight: 4.1363508E-4, delay 1.5
        h("Epop[0] syn_projEE_ampa[4080] = new ampa(0.5)")
        h("Epop[51] netConn_projEE_ampa[4080] = new NetCon(&v(0.5), syn_projEE_ampa[4080], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4081: cell 51, seg 0 (0.5) [0.5 on Epop[51]] -> cell 1, seg 0 (0.5) [0.5 on Epop[1]], weight: 4.1363508E-4, delay 1.5
        h("Epop[1] syn_projEE_ampa[4081] = new ampa(0.5)")
        h("Epop[51] netConn_projEE_ampa[4081] = new NetCon(&v(0.5), syn_projEE_ampa[4081], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4082: cell 51, seg 0 (0.5) [0.5 on Epop[51]] -> cell 2, seg 0 (0.5) [0.5 on Epop[2]], weight: 4.1363508E-4, delay 1.5
        h("Epop[2] syn_projEE_ampa[4082] = new ampa(0.5)")
        h("Epop[51] netConn_projEE_ampa[4082] = new NetCon(&v(0.5), syn_projEE_ampa[4082], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4083: cell 51, seg 0 (0.5) [0.5 on Epop[51]] -> cell 3, seg 0 (0.5) [0.5 on Epop[3]], weight: 4.1363508E-4, delay 1.5
        h("Epop[3] syn_projEE_ampa[4083] = new ampa(0.5)")
        h("Epop[51] netConn_projEE_ampa[4083] = new NetCon(&v(0.5), syn_projEE_ampa[4083], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4084: cell 51, seg 0 (0.5) [0.5 on Epop[51]] -> cell 4, seg 0 (0.5) [0.5 on Epop[4]], weight: 4.1363508E-4, delay 1.5
        h("Epop[4] syn_projEE_ampa[4084] = new ampa(0.5)")
        h("Epop[51] netConn_projEE_ampa[4084] = new NetCon(&v(0.5), syn_projEE_ampa[4084], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4085: cell 51, seg 0 (0.5) [0.5 on Epop[51]] -> cell 5, seg 0 (0.5) [0.5 on Epop[5]], weight: 4.1363508E-4, delay 1.5
        h("Epop[5] syn_projEE_ampa[4085] = new ampa(0.5)")
        h("Epop[51] netConn_projEE_ampa[4085] = new NetCon(&v(0.5), syn_projEE_ampa[4085], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4086: cell 51, seg 0 (0.5) [0.5 on Epop[51]] -> cell 6, seg 0 (0.5) [0.5 on Epop[6]], weight: 4.1363508E-4, delay 1.5
        h("Epop[6] syn_projEE_ampa[4086] = new ampa(0.5)")
        h("Epop[51] netConn_projEE_ampa[4086] = new NetCon(&v(0.5), syn_projEE_ampa[4086], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4087: cell 51, seg 0 (0.5) [0.5 on Epop[51]] -> cell 7, seg 0 (0.5) [0.5 on Epop[7]], weight: 4.1363508E-4, delay 1.5
        h("Epop[7] syn_projEE_ampa[4087] = new ampa(0.5)")
        h("Epop[51] netConn_projEE_ampa[4087] = new NetCon(&v(0.5), syn_projEE_ampa[4087], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4088: cell 51, seg 0 (0.5) [0.5 on Epop[51]] -> cell 8, seg 0 (0.5) [0.5 on Epop[8]], weight: 4.1363508E-4, delay 1.5
        h("Epop[8] syn_projEE_ampa[4088] = new ampa(0.5)")
        h("Epop[51] netConn_projEE_ampa[4088] = new NetCon(&v(0.5), syn_projEE_ampa[4088], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4089: cell 51, seg 0 (0.5) [0.5 on Epop[51]] -> cell 9, seg 0 (0.5) [0.5 on Epop[9]], weight: 4.1363508E-4, delay 1.5
        h("Epop[9] syn_projEE_ampa[4089] = new ampa(0.5)")
        h("Epop[51] netConn_projEE_ampa[4089] = new NetCon(&v(0.5), syn_projEE_ampa[4089], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4090: cell 51, seg 0 (0.5) [0.5 on Epop[51]] -> cell 10, seg 0 (0.5) [0.5 on Epop[10]], weight: 4.1363508E-4, delay 1.5
        h("Epop[10] syn_projEE_ampa[4090] = new ampa(0.5)")
        h("Epop[51] netConn_projEE_ampa[4090] = new NetCon(&v(0.5), syn_projEE_ampa[4090], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4091: cell 51, seg 0 (0.5) [0.5 on Epop[51]] -> cell 11, seg 0 (0.5) [0.5 on Epop[11]], weight: 4.1363508E-4, delay 1.5
        h("Epop[11] syn_projEE_ampa[4091] = new ampa(0.5)")
        h("Epop[51] netConn_projEE_ampa[4091] = new NetCon(&v(0.5), syn_projEE_ampa[4091], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4092: cell 51, seg 0 (0.5) [0.5 on Epop[51]] -> cell 12, seg 0 (0.5) [0.5 on Epop[12]], weight: 4.1363508E-4, delay 1.5
        h("Epop[12] syn_projEE_ampa[4092] = new ampa(0.5)")
        h("Epop[51] netConn_projEE_ampa[4092] = new NetCon(&v(0.5), syn_projEE_ampa[4092], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4093: cell 51, seg 0 (0.5) [0.5 on Epop[51]] -> cell 13, seg 0 (0.5) [0.5 on Epop[13]], weight: 4.1363508E-4, delay 1.5
        h("Epop[13] syn_projEE_ampa[4093] = new ampa(0.5)")
        h("Epop[51] netConn_projEE_ampa[4093] = new NetCon(&v(0.5), syn_projEE_ampa[4093], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4094: cell 51, seg 0 (0.5) [0.5 on Epop[51]] -> cell 14, seg 0 (0.5) [0.5 on Epop[14]], weight: 4.1363508E-4, delay 1.5
        h("Epop[14] syn_projEE_ampa[4094] = new ampa(0.5)")
        h("Epop[51] netConn_projEE_ampa[4094] = new NetCon(&v(0.5), syn_projEE_ampa[4094], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4095: cell 51, seg 0 (0.5) [0.5 on Epop[51]] -> cell 15, seg 0 (0.5) [0.5 on Epop[15]], weight: 4.1363508E-4, delay 1.5
        h("Epop[15] syn_projEE_ampa[4095] = new ampa(0.5)")
        h("Epop[51] netConn_projEE_ampa[4095] = new NetCon(&v(0.5), syn_projEE_ampa[4095], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4096: cell 51, seg 0 (0.5) [0.5 on Epop[51]] -> cell 16, seg 0 (0.5) [0.5 on Epop[16]], weight: 4.1363508E-4, delay 1.5
        h("Epop[16] syn_projEE_ampa[4096] = new ampa(0.5)")
        h("Epop[51] netConn_projEE_ampa[4096] = new NetCon(&v(0.5), syn_projEE_ampa[4096], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4097: cell 51, seg 0 (0.5) [0.5 on Epop[51]] -> cell 17, seg 0 (0.5) [0.5 on Epop[17]], weight: 4.1363508E-4, delay 1.5
        h("Epop[17] syn_projEE_ampa[4097] = new ampa(0.5)")
        h("Epop[51] netConn_projEE_ampa[4097] = new NetCon(&v(0.5), syn_projEE_ampa[4097], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4098: cell 51, seg 0 (0.5) [0.5 on Epop[51]] -> cell 18, seg 0 (0.5) [0.5 on Epop[18]], weight: 4.1363508E-4, delay 1.5
        h("Epop[18] syn_projEE_ampa[4098] = new ampa(0.5)")
        h("Epop[51] netConn_projEE_ampa[4098] = new NetCon(&v(0.5), syn_projEE_ampa[4098], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4099: cell 51, seg 0 (0.5) [0.5 on Epop[51]] -> cell 19, seg 0 (0.5) [0.5 on Epop[19]], weight: 4.1363508E-4, delay 1.5
        h("Epop[19] syn_projEE_ampa[4099] = new ampa(0.5)")
        h("Epop[51] netConn_projEE_ampa[4099] = new NetCon(&v(0.5), syn_projEE_ampa[4099], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4100: cell 51, seg 0 (0.5) [0.5 on Epop[51]] -> cell 20, seg 0 (0.5) [0.5 on Epop[20]], weight: 4.1363508E-4, delay 1.5
        h("Epop[20] syn_projEE_ampa[4100] = new ampa(0.5)")
        h("Epop[51] netConn_projEE_ampa[4100] = new NetCon(&v(0.5), syn_projEE_ampa[4100], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4101: cell 51, seg 0 (0.5) [0.5 on Epop[51]] -> cell 21, seg 0 (0.5) [0.5 on Epop[21]], weight: 4.1363508E-4, delay 1.5
        h("Epop[21] syn_projEE_ampa[4101] = new ampa(0.5)")
        h("Epop[51] netConn_projEE_ampa[4101] = new NetCon(&v(0.5), syn_projEE_ampa[4101], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4102: cell 51, seg 0 (0.5) [0.5 on Epop[51]] -> cell 22, seg 0 (0.5) [0.5 on Epop[22]], weight: 4.1363508E-4, delay 1.5
        h("Epop[22] syn_projEE_ampa[4102] = new ampa(0.5)")
        h("Epop[51] netConn_projEE_ampa[4102] = new NetCon(&v(0.5), syn_projEE_ampa[4102], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4103: cell 51, seg 0 (0.5) [0.5 on Epop[51]] -> cell 23, seg 0 (0.5) [0.5 on Epop[23]], weight: 4.1363508E-4, delay 1.5
        h("Epop[23] syn_projEE_ampa[4103] = new ampa(0.5)")
        h("Epop[51] netConn_projEE_ampa[4103] = new NetCon(&v(0.5), syn_projEE_ampa[4103], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4104: cell 51, seg 0 (0.5) [0.5 on Epop[51]] -> cell 24, seg 0 (0.5) [0.5 on Epop[24]], weight: 4.1363508E-4, delay 1.5
        h("Epop[24] syn_projEE_ampa[4104] = new ampa(0.5)")
        h("Epop[51] netConn_projEE_ampa[4104] = new NetCon(&v(0.5), syn_projEE_ampa[4104], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4105: cell 51, seg 0 (0.5) [0.5 on Epop[51]] -> cell 25, seg 0 (0.5) [0.5 on Epop[25]], weight: 4.1363508E-4, delay 1.5
        h("Epop[25] syn_projEE_ampa[4105] = new ampa(0.5)")
        h("Epop[51] netConn_projEE_ampa[4105] = new NetCon(&v(0.5), syn_projEE_ampa[4105], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4106: cell 51, seg 0 (0.5) [0.5 on Epop[51]] -> cell 26, seg 0 (0.5) [0.5 on Epop[26]], weight: 4.1363508E-4, delay 1.5
        h("Epop[26] syn_projEE_ampa[4106] = new ampa(0.5)")
        h("Epop[51] netConn_projEE_ampa[4106] = new NetCon(&v(0.5), syn_projEE_ampa[4106], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4107: cell 51, seg 0 (0.5) [0.5 on Epop[51]] -> cell 27, seg 0 (0.5) [0.5 on Epop[27]], weight: 4.1363508E-4, delay 1.5
        h("Epop[27] syn_projEE_ampa[4107] = new ampa(0.5)")
        h("Epop[51] netConn_projEE_ampa[4107] = new NetCon(&v(0.5), syn_projEE_ampa[4107], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4108: cell 51, seg 0 (0.5) [0.5 on Epop[51]] -> cell 28, seg 0 (0.5) [0.5 on Epop[28]], weight: 4.1363508E-4, delay 1.5
        h("Epop[28] syn_projEE_ampa[4108] = new ampa(0.5)")
        h("Epop[51] netConn_projEE_ampa[4108] = new NetCon(&v(0.5), syn_projEE_ampa[4108], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4109: cell 51, seg 0 (0.5) [0.5 on Epop[51]] -> cell 29, seg 0 (0.5) [0.5 on Epop[29]], weight: 4.1363508E-4, delay 1.5
        h("Epop[29] syn_projEE_ampa[4109] = new ampa(0.5)")
        h("Epop[51] netConn_projEE_ampa[4109] = new NetCon(&v(0.5), syn_projEE_ampa[4109], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4110: cell 51, seg 0 (0.5) [0.5 on Epop[51]] -> cell 30, seg 0 (0.5) [0.5 on Epop[30]], weight: 4.1363508E-4, delay 1.5
        h("Epop[30] syn_projEE_ampa[4110] = new ampa(0.5)")
        h("Epop[51] netConn_projEE_ampa[4110] = new NetCon(&v(0.5), syn_projEE_ampa[4110], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4111: cell 51, seg 0 (0.5) [0.5 on Epop[51]] -> cell 31, seg 0 (0.5) [0.5 on Epop[31]], weight: 4.1363508E-4, delay 1.5
        h("Epop[31] syn_projEE_ampa[4111] = new ampa(0.5)")
        h("Epop[51] netConn_projEE_ampa[4111] = new NetCon(&v(0.5), syn_projEE_ampa[4111], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4112: cell 51, seg 0 (0.5) [0.5 on Epop[51]] -> cell 32, seg 0 (0.5) [0.5 on Epop[32]], weight: 4.1363508E-4, delay 1.5
        h("Epop[32] syn_projEE_ampa[4112] = new ampa(0.5)")
        h("Epop[51] netConn_projEE_ampa[4112] = new NetCon(&v(0.5), syn_projEE_ampa[4112], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4113: cell 51, seg 0 (0.5) [0.5 on Epop[51]] -> cell 33, seg 0 (0.5) [0.5 on Epop[33]], weight: 4.1363508E-4, delay 1.5
        h("Epop[33] syn_projEE_ampa[4113] = new ampa(0.5)")
        h("Epop[51] netConn_projEE_ampa[4113] = new NetCon(&v(0.5), syn_projEE_ampa[4113], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4114: cell 51, seg 0 (0.5) [0.5 on Epop[51]] -> cell 34, seg 0 (0.5) [0.5 on Epop[34]], weight: 4.1363508E-4, delay 1.5
        h("Epop[34] syn_projEE_ampa[4114] = new ampa(0.5)")
        h("Epop[51] netConn_projEE_ampa[4114] = new NetCon(&v(0.5), syn_projEE_ampa[4114], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4115: cell 51, seg 0 (0.5) [0.5 on Epop[51]] -> cell 35, seg 0 (0.5) [0.5 on Epop[35]], weight: 4.1363508E-4, delay 1.5
        h("Epop[35] syn_projEE_ampa[4115] = new ampa(0.5)")
        h("Epop[51] netConn_projEE_ampa[4115] = new NetCon(&v(0.5), syn_projEE_ampa[4115], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4116: cell 51, seg 0 (0.5) [0.5 on Epop[51]] -> cell 36, seg 0 (0.5) [0.5 on Epop[36]], weight: 4.1363508E-4, delay 1.5
        h("Epop[36] syn_projEE_ampa[4116] = new ampa(0.5)")
        h("Epop[51] netConn_projEE_ampa[4116] = new NetCon(&v(0.5), syn_projEE_ampa[4116], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4117: cell 51, seg 0 (0.5) [0.5 on Epop[51]] -> cell 37, seg 0 (0.5) [0.5 on Epop[37]], weight: 4.1363508E-4, delay 1.5
        h("Epop[37] syn_projEE_ampa[4117] = new ampa(0.5)")
        h("Epop[51] netConn_projEE_ampa[4117] = new NetCon(&v(0.5), syn_projEE_ampa[4117], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4118: cell 51, seg 0 (0.5) [0.5 on Epop[51]] -> cell 38, seg 0 (0.5) [0.5 on Epop[38]], weight: 4.1363508E-4, delay 1.5
        h("Epop[38] syn_projEE_ampa[4118] = new ampa(0.5)")
        h("Epop[51] netConn_projEE_ampa[4118] = new NetCon(&v(0.5), syn_projEE_ampa[4118], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4119: cell 51, seg 0 (0.5) [0.5 on Epop[51]] -> cell 39, seg 0 (0.5) [0.5 on Epop[39]], weight: 4.1363508E-4, delay 1.5
        h("Epop[39] syn_projEE_ampa[4119] = new ampa(0.5)")
        h("Epop[51] netConn_projEE_ampa[4119] = new NetCon(&v(0.5), syn_projEE_ampa[4119], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4120: cell 51, seg 0 (0.5) [0.5 on Epop[51]] -> cell 40, seg 0 (0.5) [0.5 on Epop[40]], weight: 4.1363508E-4, delay 1.5
        h("Epop[40] syn_projEE_ampa[4120] = new ampa(0.5)")
        h("Epop[51] netConn_projEE_ampa[4120] = new NetCon(&v(0.5), syn_projEE_ampa[4120], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4121: cell 51, seg 0 (0.5) [0.5 on Epop[51]] -> cell 41, seg 0 (0.5) [0.5 on Epop[41]], weight: 4.1363508E-4, delay 1.5
        h("Epop[41] syn_projEE_ampa[4121] = new ampa(0.5)")
        h("Epop[51] netConn_projEE_ampa[4121] = new NetCon(&v(0.5), syn_projEE_ampa[4121], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4122: cell 51, seg 0 (0.5) [0.5 on Epop[51]] -> cell 42, seg 0 (0.5) [0.5 on Epop[42]], weight: 4.1363508E-4, delay 1.5
        h("Epop[42] syn_projEE_ampa[4122] = new ampa(0.5)")
        h("Epop[51] netConn_projEE_ampa[4122] = new NetCon(&v(0.5), syn_projEE_ampa[4122], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4123: cell 51, seg 0 (0.5) [0.5 on Epop[51]] -> cell 43, seg 0 (0.5) [0.5 on Epop[43]], weight: 4.1363508E-4, delay 1.5
        h("Epop[43] syn_projEE_ampa[4123] = new ampa(0.5)")
        h("Epop[51] netConn_projEE_ampa[4123] = new NetCon(&v(0.5), syn_projEE_ampa[4123], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4124: cell 51, seg 0 (0.5) [0.5 on Epop[51]] -> cell 44, seg 0 (0.5) [0.5 on Epop[44]], weight: 4.1363508E-4, delay 1.5
        h("Epop[44] syn_projEE_ampa[4124] = new ampa(0.5)")
        h("Epop[51] netConn_projEE_ampa[4124] = new NetCon(&v(0.5), syn_projEE_ampa[4124], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4125: cell 51, seg 0 (0.5) [0.5 on Epop[51]] -> cell 45, seg 0 (0.5) [0.5 on Epop[45]], weight: 4.1363508E-4, delay 1.5
        h("Epop[45] syn_projEE_ampa[4125] = new ampa(0.5)")
        h("Epop[51] netConn_projEE_ampa[4125] = new NetCon(&v(0.5), syn_projEE_ampa[4125], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4126: cell 51, seg 0 (0.5) [0.5 on Epop[51]] -> cell 46, seg 0 (0.5) [0.5 on Epop[46]], weight: 4.1363508E-4, delay 1.5
        h("Epop[46] syn_projEE_ampa[4126] = new ampa(0.5)")
        h("Epop[51] netConn_projEE_ampa[4126] = new NetCon(&v(0.5), syn_projEE_ampa[4126], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4127: cell 51, seg 0 (0.5) [0.5 on Epop[51]] -> cell 47, seg 0 (0.5) [0.5 on Epop[47]], weight: 4.1363508E-4, delay 1.5
        h("Epop[47] syn_projEE_ampa[4127] = new ampa(0.5)")
        h("Epop[51] netConn_projEE_ampa[4127] = new NetCon(&v(0.5), syn_projEE_ampa[4127], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4128: cell 51, seg 0 (0.5) [0.5 on Epop[51]] -> cell 48, seg 0 (0.5) [0.5 on Epop[48]], weight: 4.1363508E-4, delay 1.5
        h("Epop[48] syn_projEE_ampa[4128] = new ampa(0.5)")
        h("Epop[51] netConn_projEE_ampa[4128] = new NetCon(&v(0.5), syn_projEE_ampa[4128], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4129: cell 51, seg 0 (0.5) [0.5 on Epop[51]] -> cell 49, seg 0 (0.5) [0.5 on Epop[49]], weight: 4.1363508E-4, delay 1.5
        h("Epop[49] syn_projEE_ampa[4129] = new ampa(0.5)")
        h("Epop[51] netConn_projEE_ampa[4129] = new NetCon(&v(0.5), syn_projEE_ampa[4129], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4130: cell 51, seg 0 (0.5) [0.5 on Epop[51]] -> cell 50, seg 0 (0.5) [0.5 on Epop[50]], weight: 4.1363508E-4, delay 1.5
        h("Epop[50] syn_projEE_ampa[4130] = new ampa(0.5)")
        h("Epop[51] netConn_projEE_ampa[4130] = new NetCon(&v(0.5), syn_projEE_ampa[4130], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4131: cell 51, seg 0 (0.5) [0.5 on Epop[51]] -> cell 51, seg 0 (0.5) [0.5 on Epop[51]], weight: 4.1363508E-4, delay 1.5
        h("Epop[51] syn_projEE_ampa[4131] = new ampa(0.5)")
        h("Epop[51] netConn_projEE_ampa[4131] = new NetCon(&v(0.5), syn_projEE_ampa[4131], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4132: cell 51, seg 0 (0.5) [0.5 on Epop[51]] -> cell 52, seg 0 (0.5) [0.5 on Epop[52]], weight: 4.1363508E-4, delay 1.5
        h("Epop[52] syn_projEE_ampa[4132] = new ampa(0.5)")
        h("Epop[51] netConn_projEE_ampa[4132] = new NetCon(&v(0.5), syn_projEE_ampa[4132], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4133: cell 51, seg 0 (0.5) [0.5 on Epop[51]] -> cell 53, seg 0 (0.5) [0.5 on Epop[53]], weight: 4.1363508E-4, delay 1.5
        h("Epop[53] syn_projEE_ampa[4133] = new ampa(0.5)")
        h("Epop[51] netConn_projEE_ampa[4133] = new NetCon(&v(0.5), syn_projEE_ampa[4133], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4134: cell 51, seg 0 (0.5) [0.5 on Epop[51]] -> cell 54, seg 0 (0.5) [0.5 on Epop[54]], weight: 4.1363508E-4, delay 1.5
        h("Epop[54] syn_projEE_ampa[4134] = new ampa(0.5)")
        h("Epop[51] netConn_projEE_ampa[4134] = new NetCon(&v(0.5), syn_projEE_ampa[4134], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4135: cell 51, seg 0 (0.5) [0.5 on Epop[51]] -> cell 55, seg 0 (0.5) [0.5 on Epop[55]], weight: 4.1363508E-4, delay 1.5
        h("Epop[55] syn_projEE_ampa[4135] = new ampa(0.5)")
        h("Epop[51] netConn_projEE_ampa[4135] = new NetCon(&v(0.5), syn_projEE_ampa[4135], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4136: cell 51, seg 0 (0.5) [0.5 on Epop[51]] -> cell 56, seg 0 (0.5) [0.5 on Epop[56]], weight: 4.1363508E-4, delay 1.5
        h("Epop[56] syn_projEE_ampa[4136] = new ampa(0.5)")
        h("Epop[51] netConn_projEE_ampa[4136] = new NetCon(&v(0.5), syn_projEE_ampa[4136], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4137: cell 51, seg 0 (0.5) [0.5 on Epop[51]] -> cell 57, seg 0 (0.5) [0.5 on Epop[57]], weight: 4.1363508E-4, delay 1.5
        h("Epop[57] syn_projEE_ampa[4137] = new ampa(0.5)")
        h("Epop[51] netConn_projEE_ampa[4137] = new NetCon(&v(0.5), syn_projEE_ampa[4137], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4138: cell 51, seg 0 (0.5) [0.5 on Epop[51]] -> cell 58, seg 0 (0.5) [0.5 on Epop[58]], weight: 4.1363508E-4, delay 1.5
        h("Epop[58] syn_projEE_ampa[4138] = new ampa(0.5)")
        h("Epop[51] netConn_projEE_ampa[4138] = new NetCon(&v(0.5), syn_projEE_ampa[4138], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4139: cell 51, seg 0 (0.5) [0.5 on Epop[51]] -> cell 59, seg 0 (0.5) [0.5 on Epop[59]], weight: 4.1363508E-4, delay 1.5
        h("Epop[59] syn_projEE_ampa[4139] = new ampa(0.5)")
        h("Epop[51] netConn_projEE_ampa[4139] = new NetCon(&v(0.5), syn_projEE_ampa[4139], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4140: cell 51, seg 0 (0.5) [0.5 on Epop[51]] -> cell 60, seg 0 (0.5) [0.5 on Epop[60]], weight: 4.1363508E-4, delay 1.5
        h("Epop[60] syn_projEE_ampa[4140] = new ampa(0.5)")
        h("Epop[51] netConn_projEE_ampa[4140] = new NetCon(&v(0.5), syn_projEE_ampa[4140], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4141: cell 51, seg 0 (0.5) [0.5 on Epop[51]] -> cell 61, seg 0 (0.5) [0.5 on Epop[61]], weight: 4.1363508E-4, delay 1.5
        h("Epop[61] syn_projEE_ampa[4141] = new ampa(0.5)")
        h("Epop[51] netConn_projEE_ampa[4141] = new NetCon(&v(0.5), syn_projEE_ampa[4141], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4142: cell 51, seg 0 (0.5) [0.5 on Epop[51]] -> cell 62, seg 0 (0.5) [0.5 on Epop[62]], weight: 4.1363508E-4, delay 1.5
        h("Epop[62] syn_projEE_ampa[4142] = new ampa(0.5)")
        h("Epop[51] netConn_projEE_ampa[4142] = new NetCon(&v(0.5), syn_projEE_ampa[4142], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4143: cell 51, seg 0 (0.5) [0.5 on Epop[51]] -> cell 63, seg 0 (0.5) [0.5 on Epop[63]], weight: 4.1363508E-4, delay 1.5
        h("Epop[63] syn_projEE_ampa[4143] = new ampa(0.5)")
        h("Epop[51] netConn_projEE_ampa[4143] = new NetCon(&v(0.5), syn_projEE_ampa[4143], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4144: cell 51, seg 0 (0.5) [0.5 on Epop[51]] -> cell 64, seg 0 (0.5) [0.5 on Epop[64]], weight: 4.1363508E-4, delay 1.5
        h("Epop[64] syn_projEE_ampa[4144] = new ampa(0.5)")
        h("Epop[51] netConn_projEE_ampa[4144] = new NetCon(&v(0.5), syn_projEE_ampa[4144], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4145: cell 51, seg 0 (0.5) [0.5 on Epop[51]] -> cell 65, seg 0 (0.5) [0.5 on Epop[65]], weight: 4.1363508E-4, delay 1.5
        h("Epop[65] syn_projEE_ampa[4145] = new ampa(0.5)")
        h("Epop[51] netConn_projEE_ampa[4145] = new NetCon(&v(0.5), syn_projEE_ampa[4145], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4146: cell 51, seg 0 (0.5) [0.5 on Epop[51]] -> cell 66, seg 0 (0.5) [0.5 on Epop[66]], weight: 4.1363508E-4, delay 1.5
        h("Epop[66] syn_projEE_ampa[4146] = new ampa(0.5)")
        h("Epop[51] netConn_projEE_ampa[4146] = new NetCon(&v(0.5), syn_projEE_ampa[4146], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4147: cell 51, seg 0 (0.5) [0.5 on Epop[51]] -> cell 67, seg 0 (0.5) [0.5 on Epop[67]], weight: 4.1363508E-4, delay 1.5
        h("Epop[67] syn_projEE_ampa[4147] = new ampa(0.5)")
        h("Epop[51] netConn_projEE_ampa[4147] = new NetCon(&v(0.5), syn_projEE_ampa[4147], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4148: cell 51, seg 0 (0.5) [0.5 on Epop[51]] -> cell 68, seg 0 (0.5) [0.5 on Epop[68]], weight: 4.1363508E-4, delay 1.5
        h("Epop[68] syn_projEE_ampa[4148] = new ampa(0.5)")
        h("Epop[51] netConn_projEE_ampa[4148] = new NetCon(&v(0.5), syn_projEE_ampa[4148], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4149: cell 51, seg 0 (0.5) [0.5 on Epop[51]] -> cell 69, seg 0 (0.5) [0.5 on Epop[69]], weight: 4.1363508E-4, delay 1.5
        h("Epop[69] syn_projEE_ampa[4149] = new ampa(0.5)")
        h("Epop[51] netConn_projEE_ampa[4149] = new NetCon(&v(0.5), syn_projEE_ampa[4149], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4150: cell 51, seg 0 (0.5) [0.5 on Epop[51]] -> cell 70, seg 0 (0.5) [0.5 on Epop[70]], weight: 4.1363508E-4, delay 1.5
        h("Epop[70] syn_projEE_ampa[4150] = new ampa(0.5)")
        h("Epop[51] netConn_projEE_ampa[4150] = new NetCon(&v(0.5), syn_projEE_ampa[4150], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4151: cell 51, seg 0 (0.5) [0.5 on Epop[51]] -> cell 71, seg 0 (0.5) [0.5 on Epop[71]], weight: 4.1363508E-4, delay 1.5
        h("Epop[71] syn_projEE_ampa[4151] = new ampa(0.5)")
        h("Epop[51] netConn_projEE_ampa[4151] = new NetCon(&v(0.5), syn_projEE_ampa[4151], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4152: cell 51, seg 0 (0.5) [0.5 on Epop[51]] -> cell 72, seg 0 (0.5) [0.5 on Epop[72]], weight: 4.1363508E-4, delay 1.5
        h("Epop[72] syn_projEE_ampa[4152] = new ampa(0.5)")
        h("Epop[51] netConn_projEE_ampa[4152] = new NetCon(&v(0.5), syn_projEE_ampa[4152], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4153: cell 51, seg 0 (0.5) [0.5 on Epop[51]] -> cell 73, seg 0 (0.5) [0.5 on Epop[73]], weight: 4.1363508E-4, delay 1.5
        h("Epop[73] syn_projEE_ampa[4153] = new ampa(0.5)")
        h("Epop[51] netConn_projEE_ampa[4153] = new NetCon(&v(0.5), syn_projEE_ampa[4153], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4154: cell 51, seg 0 (0.5) [0.5 on Epop[51]] -> cell 74, seg 0 (0.5) [0.5 on Epop[74]], weight: 4.1363508E-4, delay 1.5
        h("Epop[74] syn_projEE_ampa[4154] = new ampa(0.5)")
        h("Epop[51] netConn_projEE_ampa[4154] = new NetCon(&v(0.5), syn_projEE_ampa[4154], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4155: cell 51, seg 0 (0.5) [0.5 on Epop[51]] -> cell 75, seg 0 (0.5) [0.5 on Epop[75]], weight: 4.1363508E-4, delay 1.5
        h("Epop[75] syn_projEE_ampa[4155] = new ampa(0.5)")
        h("Epop[51] netConn_projEE_ampa[4155] = new NetCon(&v(0.5), syn_projEE_ampa[4155], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4156: cell 51, seg 0 (0.5) [0.5 on Epop[51]] -> cell 76, seg 0 (0.5) [0.5 on Epop[76]], weight: 4.1363508E-4, delay 1.5
        h("Epop[76] syn_projEE_ampa[4156] = new ampa(0.5)")
        h("Epop[51] netConn_projEE_ampa[4156] = new NetCon(&v(0.5), syn_projEE_ampa[4156], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4157: cell 51, seg 0 (0.5) [0.5 on Epop[51]] -> cell 77, seg 0 (0.5) [0.5 on Epop[77]], weight: 4.1363508E-4, delay 1.5
        h("Epop[77] syn_projEE_ampa[4157] = new ampa(0.5)")
        h("Epop[51] netConn_projEE_ampa[4157] = new NetCon(&v(0.5), syn_projEE_ampa[4157], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4158: cell 51, seg 0 (0.5) [0.5 on Epop[51]] -> cell 78, seg 0 (0.5) [0.5 on Epop[78]], weight: 4.1363508E-4, delay 1.5
        h("Epop[78] syn_projEE_ampa[4158] = new ampa(0.5)")
        h("Epop[51] netConn_projEE_ampa[4158] = new NetCon(&v(0.5), syn_projEE_ampa[4158], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4159: cell 51, seg 0 (0.5) [0.5 on Epop[51]] -> cell 79, seg 0 (0.5) [0.5 on Epop[79]], weight: 4.1363508E-4, delay 1.5
        h("Epop[79] syn_projEE_ampa[4159] = new ampa(0.5)")
        h("Epop[51] netConn_projEE_ampa[4159] = new NetCon(&v(0.5), syn_projEE_ampa[4159], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4160: cell 52, seg 0 (0.5) [0.5 on Epop[52]] -> cell 0, seg 0 (0.5) [0.5 on Epop[0]], weight: 4.1363508E-4, delay 1.5
        h("Epop[0] syn_projEE_ampa[4160] = new ampa(0.5)")
        h("Epop[52] netConn_projEE_ampa[4160] = new NetCon(&v(0.5), syn_projEE_ampa[4160], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4161: cell 52, seg 0 (0.5) [0.5 on Epop[52]] -> cell 1, seg 0 (0.5) [0.5 on Epop[1]], weight: 4.1363508E-4, delay 1.5
        h("Epop[1] syn_projEE_ampa[4161] = new ampa(0.5)")
        h("Epop[52] netConn_projEE_ampa[4161] = new NetCon(&v(0.5), syn_projEE_ampa[4161], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4162: cell 52, seg 0 (0.5) [0.5 on Epop[52]] -> cell 2, seg 0 (0.5) [0.5 on Epop[2]], weight: 4.1363508E-4, delay 1.5
        h("Epop[2] syn_projEE_ampa[4162] = new ampa(0.5)")
        h("Epop[52] netConn_projEE_ampa[4162] = new NetCon(&v(0.5), syn_projEE_ampa[4162], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4163: cell 52, seg 0 (0.5) [0.5 on Epop[52]] -> cell 3, seg 0 (0.5) [0.5 on Epop[3]], weight: 4.1363508E-4, delay 1.5
        h("Epop[3] syn_projEE_ampa[4163] = new ampa(0.5)")
        h("Epop[52] netConn_projEE_ampa[4163] = new NetCon(&v(0.5), syn_projEE_ampa[4163], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4164: cell 52, seg 0 (0.5) [0.5 on Epop[52]] -> cell 4, seg 0 (0.5) [0.5 on Epop[4]], weight: 4.1363508E-4, delay 1.5
        h("Epop[4] syn_projEE_ampa[4164] = new ampa(0.5)")
        h("Epop[52] netConn_projEE_ampa[4164] = new NetCon(&v(0.5), syn_projEE_ampa[4164], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4165: cell 52, seg 0 (0.5) [0.5 on Epop[52]] -> cell 5, seg 0 (0.5) [0.5 on Epop[5]], weight: 4.1363508E-4, delay 1.5
        h("Epop[5] syn_projEE_ampa[4165] = new ampa(0.5)")
        h("Epop[52] netConn_projEE_ampa[4165] = new NetCon(&v(0.5), syn_projEE_ampa[4165], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4166: cell 52, seg 0 (0.5) [0.5 on Epop[52]] -> cell 6, seg 0 (0.5) [0.5 on Epop[6]], weight: 4.1363508E-4, delay 1.5
        h("Epop[6] syn_projEE_ampa[4166] = new ampa(0.5)")
        h("Epop[52] netConn_projEE_ampa[4166] = new NetCon(&v(0.5), syn_projEE_ampa[4166], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4167: cell 52, seg 0 (0.5) [0.5 on Epop[52]] -> cell 7, seg 0 (0.5) [0.5 on Epop[7]], weight: 4.1363508E-4, delay 1.5
        h("Epop[7] syn_projEE_ampa[4167] = new ampa(0.5)")
        h("Epop[52] netConn_projEE_ampa[4167] = new NetCon(&v(0.5), syn_projEE_ampa[4167], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4168: cell 52, seg 0 (0.5) [0.5 on Epop[52]] -> cell 8, seg 0 (0.5) [0.5 on Epop[8]], weight: 4.1363508E-4, delay 1.5
        h("Epop[8] syn_projEE_ampa[4168] = new ampa(0.5)")
        h("Epop[52] netConn_projEE_ampa[4168] = new NetCon(&v(0.5), syn_projEE_ampa[4168], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4169: cell 52, seg 0 (0.5) [0.5 on Epop[52]] -> cell 9, seg 0 (0.5) [0.5 on Epop[9]], weight: 4.1363508E-4, delay 1.5
        h("Epop[9] syn_projEE_ampa[4169] = new ampa(0.5)")
        h("Epop[52] netConn_projEE_ampa[4169] = new NetCon(&v(0.5), syn_projEE_ampa[4169], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4170: cell 52, seg 0 (0.5) [0.5 on Epop[52]] -> cell 10, seg 0 (0.5) [0.5 on Epop[10]], weight: 4.1363508E-4, delay 1.5
        h("Epop[10] syn_projEE_ampa[4170] = new ampa(0.5)")
        h("Epop[52] netConn_projEE_ampa[4170] = new NetCon(&v(0.5), syn_projEE_ampa[4170], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4171: cell 52, seg 0 (0.5) [0.5 on Epop[52]] -> cell 11, seg 0 (0.5) [0.5 on Epop[11]], weight: 4.1363508E-4, delay 1.5
        h("Epop[11] syn_projEE_ampa[4171] = new ampa(0.5)")
        h("Epop[52] netConn_projEE_ampa[4171] = new NetCon(&v(0.5), syn_projEE_ampa[4171], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4172: cell 52, seg 0 (0.5) [0.5 on Epop[52]] -> cell 12, seg 0 (0.5) [0.5 on Epop[12]], weight: 4.1363508E-4, delay 1.5
        h("Epop[12] syn_projEE_ampa[4172] = new ampa(0.5)")
        h("Epop[52] netConn_projEE_ampa[4172] = new NetCon(&v(0.5), syn_projEE_ampa[4172], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4173: cell 52, seg 0 (0.5) [0.5 on Epop[52]] -> cell 13, seg 0 (0.5) [0.5 on Epop[13]], weight: 4.1363508E-4, delay 1.5
        h("Epop[13] syn_projEE_ampa[4173] = new ampa(0.5)")
        h("Epop[52] netConn_projEE_ampa[4173] = new NetCon(&v(0.5), syn_projEE_ampa[4173], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4174: cell 52, seg 0 (0.5) [0.5 on Epop[52]] -> cell 14, seg 0 (0.5) [0.5 on Epop[14]], weight: 4.1363508E-4, delay 1.5
        h("Epop[14] syn_projEE_ampa[4174] = new ampa(0.5)")
        h("Epop[52] netConn_projEE_ampa[4174] = new NetCon(&v(0.5), syn_projEE_ampa[4174], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4175: cell 52, seg 0 (0.5) [0.5 on Epop[52]] -> cell 15, seg 0 (0.5) [0.5 on Epop[15]], weight: 4.1363508E-4, delay 1.5
        h("Epop[15] syn_projEE_ampa[4175] = new ampa(0.5)")
        h("Epop[52] netConn_projEE_ampa[4175] = new NetCon(&v(0.5), syn_projEE_ampa[4175], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4176: cell 52, seg 0 (0.5) [0.5 on Epop[52]] -> cell 16, seg 0 (0.5) [0.5 on Epop[16]], weight: 4.1363508E-4, delay 1.5
        h("Epop[16] syn_projEE_ampa[4176] = new ampa(0.5)")
        h("Epop[52] netConn_projEE_ampa[4176] = new NetCon(&v(0.5), syn_projEE_ampa[4176], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4177: cell 52, seg 0 (0.5) [0.5 on Epop[52]] -> cell 17, seg 0 (0.5) [0.5 on Epop[17]], weight: 4.1363508E-4, delay 1.5
        h("Epop[17] syn_projEE_ampa[4177] = new ampa(0.5)")
        h("Epop[52] netConn_projEE_ampa[4177] = new NetCon(&v(0.5), syn_projEE_ampa[4177], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4178: cell 52, seg 0 (0.5) [0.5 on Epop[52]] -> cell 18, seg 0 (0.5) [0.5 on Epop[18]], weight: 4.1363508E-4, delay 1.5
        h("Epop[18] syn_projEE_ampa[4178] = new ampa(0.5)")
        h("Epop[52] netConn_projEE_ampa[4178] = new NetCon(&v(0.5), syn_projEE_ampa[4178], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4179: cell 52, seg 0 (0.5) [0.5 on Epop[52]] -> cell 19, seg 0 (0.5) [0.5 on Epop[19]], weight: 4.1363508E-4, delay 1.5
        h("Epop[19] syn_projEE_ampa[4179] = new ampa(0.5)")
        h("Epop[52] netConn_projEE_ampa[4179] = new NetCon(&v(0.5), syn_projEE_ampa[4179], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4180: cell 52, seg 0 (0.5) [0.5 on Epop[52]] -> cell 20, seg 0 (0.5) [0.5 on Epop[20]], weight: 4.1363508E-4, delay 1.5
        h("Epop[20] syn_projEE_ampa[4180] = new ampa(0.5)")
        h("Epop[52] netConn_projEE_ampa[4180] = new NetCon(&v(0.5), syn_projEE_ampa[4180], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4181: cell 52, seg 0 (0.5) [0.5 on Epop[52]] -> cell 21, seg 0 (0.5) [0.5 on Epop[21]], weight: 4.1363508E-4, delay 1.5
        h("Epop[21] syn_projEE_ampa[4181] = new ampa(0.5)")
        h("Epop[52] netConn_projEE_ampa[4181] = new NetCon(&v(0.5), syn_projEE_ampa[4181], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4182: cell 52, seg 0 (0.5) [0.5 on Epop[52]] -> cell 22, seg 0 (0.5) [0.5 on Epop[22]], weight: 4.1363508E-4, delay 1.5
        h("Epop[22] syn_projEE_ampa[4182] = new ampa(0.5)")
        h("Epop[52] netConn_projEE_ampa[4182] = new NetCon(&v(0.5), syn_projEE_ampa[4182], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4183: cell 52, seg 0 (0.5) [0.5 on Epop[52]] -> cell 23, seg 0 (0.5) [0.5 on Epop[23]], weight: 4.1363508E-4, delay 1.5
        h("Epop[23] syn_projEE_ampa[4183] = new ampa(0.5)")
        h("Epop[52] netConn_projEE_ampa[4183] = new NetCon(&v(0.5), syn_projEE_ampa[4183], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4184: cell 52, seg 0 (0.5) [0.5 on Epop[52]] -> cell 24, seg 0 (0.5) [0.5 on Epop[24]], weight: 4.1363508E-4, delay 1.5
        h("Epop[24] syn_projEE_ampa[4184] = new ampa(0.5)")
        h("Epop[52] netConn_projEE_ampa[4184] = new NetCon(&v(0.5), syn_projEE_ampa[4184], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4185: cell 52, seg 0 (0.5) [0.5 on Epop[52]] -> cell 25, seg 0 (0.5) [0.5 on Epop[25]], weight: 4.1363508E-4, delay 1.5
        h("Epop[25] syn_projEE_ampa[4185] = new ampa(0.5)")
        h("Epop[52] netConn_projEE_ampa[4185] = new NetCon(&v(0.5), syn_projEE_ampa[4185], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4186: cell 52, seg 0 (0.5) [0.5 on Epop[52]] -> cell 26, seg 0 (0.5) [0.5 on Epop[26]], weight: 4.1363508E-4, delay 1.5
        h("Epop[26] syn_projEE_ampa[4186] = new ampa(0.5)")
        h("Epop[52] netConn_projEE_ampa[4186] = new NetCon(&v(0.5), syn_projEE_ampa[4186], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4187: cell 52, seg 0 (0.5) [0.5 on Epop[52]] -> cell 27, seg 0 (0.5) [0.5 on Epop[27]], weight: 4.1363508E-4, delay 1.5
        h("Epop[27] syn_projEE_ampa[4187] = new ampa(0.5)")
        h("Epop[52] netConn_projEE_ampa[4187] = new NetCon(&v(0.5), syn_projEE_ampa[4187], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4188: cell 52, seg 0 (0.5) [0.5 on Epop[52]] -> cell 28, seg 0 (0.5) [0.5 on Epop[28]], weight: 4.1363508E-4, delay 1.5
        h("Epop[28] syn_projEE_ampa[4188] = new ampa(0.5)")
        h("Epop[52] netConn_projEE_ampa[4188] = new NetCon(&v(0.5), syn_projEE_ampa[4188], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4189: cell 52, seg 0 (0.5) [0.5 on Epop[52]] -> cell 29, seg 0 (0.5) [0.5 on Epop[29]], weight: 4.1363508E-4, delay 1.5
        h("Epop[29] syn_projEE_ampa[4189] = new ampa(0.5)")
        h("Epop[52] netConn_projEE_ampa[4189] = new NetCon(&v(0.5), syn_projEE_ampa[4189], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4190: cell 52, seg 0 (0.5) [0.5 on Epop[52]] -> cell 30, seg 0 (0.5) [0.5 on Epop[30]], weight: 4.1363508E-4, delay 1.5
        h("Epop[30] syn_projEE_ampa[4190] = new ampa(0.5)")
        h("Epop[52] netConn_projEE_ampa[4190] = new NetCon(&v(0.5), syn_projEE_ampa[4190], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4191: cell 52, seg 0 (0.5) [0.5 on Epop[52]] -> cell 31, seg 0 (0.5) [0.5 on Epop[31]], weight: 4.1363508E-4, delay 1.5
        h("Epop[31] syn_projEE_ampa[4191] = new ampa(0.5)")
        h("Epop[52] netConn_projEE_ampa[4191] = new NetCon(&v(0.5), syn_projEE_ampa[4191], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4192: cell 52, seg 0 (0.5) [0.5 on Epop[52]] -> cell 32, seg 0 (0.5) [0.5 on Epop[32]], weight: 4.1363508E-4, delay 1.5
        h("Epop[32] syn_projEE_ampa[4192] = new ampa(0.5)")
        h("Epop[52] netConn_projEE_ampa[4192] = new NetCon(&v(0.5), syn_projEE_ampa[4192], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4193: cell 52, seg 0 (0.5) [0.5 on Epop[52]] -> cell 33, seg 0 (0.5) [0.5 on Epop[33]], weight: 4.1363508E-4, delay 1.5
        h("Epop[33] syn_projEE_ampa[4193] = new ampa(0.5)")
        h("Epop[52] netConn_projEE_ampa[4193] = new NetCon(&v(0.5), syn_projEE_ampa[4193], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4194: cell 52, seg 0 (0.5) [0.5 on Epop[52]] -> cell 34, seg 0 (0.5) [0.5 on Epop[34]], weight: 4.1363508E-4, delay 1.5
        h("Epop[34] syn_projEE_ampa[4194] = new ampa(0.5)")
        h("Epop[52] netConn_projEE_ampa[4194] = new NetCon(&v(0.5), syn_projEE_ampa[4194], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4195: cell 52, seg 0 (0.5) [0.5 on Epop[52]] -> cell 35, seg 0 (0.5) [0.5 on Epop[35]], weight: 4.1363508E-4, delay 1.5
        h("Epop[35] syn_projEE_ampa[4195] = new ampa(0.5)")
        h("Epop[52] netConn_projEE_ampa[4195] = new NetCon(&v(0.5), syn_projEE_ampa[4195], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4196: cell 52, seg 0 (0.5) [0.5 on Epop[52]] -> cell 36, seg 0 (0.5) [0.5 on Epop[36]], weight: 4.1363508E-4, delay 1.5
        h("Epop[36] syn_projEE_ampa[4196] = new ampa(0.5)")
        h("Epop[52] netConn_projEE_ampa[4196] = new NetCon(&v(0.5), syn_projEE_ampa[4196], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4197: cell 52, seg 0 (0.5) [0.5 on Epop[52]] -> cell 37, seg 0 (0.5) [0.5 on Epop[37]], weight: 4.1363508E-4, delay 1.5
        h("Epop[37] syn_projEE_ampa[4197] = new ampa(0.5)")
        h("Epop[52] netConn_projEE_ampa[4197] = new NetCon(&v(0.5), syn_projEE_ampa[4197], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4198: cell 52, seg 0 (0.5) [0.5 on Epop[52]] -> cell 38, seg 0 (0.5) [0.5 on Epop[38]], weight: 4.1363508E-4, delay 1.5
        h("Epop[38] syn_projEE_ampa[4198] = new ampa(0.5)")
        h("Epop[52] netConn_projEE_ampa[4198] = new NetCon(&v(0.5), syn_projEE_ampa[4198], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4199: cell 52, seg 0 (0.5) [0.5 on Epop[52]] -> cell 39, seg 0 (0.5) [0.5 on Epop[39]], weight: 4.1363508E-4, delay 1.5
        h("Epop[39] syn_projEE_ampa[4199] = new ampa(0.5)")
        h("Epop[52] netConn_projEE_ampa[4199] = new NetCon(&v(0.5), syn_projEE_ampa[4199], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4200: cell 52, seg 0 (0.5) [0.5 on Epop[52]] -> cell 40, seg 0 (0.5) [0.5 on Epop[40]], weight: 4.1363508E-4, delay 1.5
        h("Epop[40] syn_projEE_ampa[4200] = new ampa(0.5)")
        h("Epop[52] netConn_projEE_ampa[4200] = new NetCon(&v(0.5), syn_projEE_ampa[4200], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4201: cell 52, seg 0 (0.5) [0.5 on Epop[52]] -> cell 41, seg 0 (0.5) [0.5 on Epop[41]], weight: 4.1363508E-4, delay 1.5
        h("Epop[41] syn_projEE_ampa[4201] = new ampa(0.5)")
        h("Epop[52] netConn_projEE_ampa[4201] = new NetCon(&v(0.5), syn_projEE_ampa[4201], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4202: cell 52, seg 0 (0.5) [0.5 on Epop[52]] -> cell 42, seg 0 (0.5) [0.5 on Epop[42]], weight: 4.1363508E-4, delay 1.5
        h("Epop[42] syn_projEE_ampa[4202] = new ampa(0.5)")
        h("Epop[52] netConn_projEE_ampa[4202] = new NetCon(&v(0.5), syn_projEE_ampa[4202], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4203: cell 52, seg 0 (0.5) [0.5 on Epop[52]] -> cell 43, seg 0 (0.5) [0.5 on Epop[43]], weight: 4.1363508E-4, delay 1.5
        h("Epop[43] syn_projEE_ampa[4203] = new ampa(0.5)")
        h("Epop[52] netConn_projEE_ampa[4203] = new NetCon(&v(0.5), syn_projEE_ampa[4203], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4204: cell 52, seg 0 (0.5) [0.5 on Epop[52]] -> cell 44, seg 0 (0.5) [0.5 on Epop[44]], weight: 4.1363508E-4, delay 1.5
        h("Epop[44] syn_projEE_ampa[4204] = new ampa(0.5)")
        h("Epop[52] netConn_projEE_ampa[4204] = new NetCon(&v(0.5), syn_projEE_ampa[4204], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4205: cell 52, seg 0 (0.5) [0.5 on Epop[52]] -> cell 45, seg 0 (0.5) [0.5 on Epop[45]], weight: 4.1363508E-4, delay 1.5
        h("Epop[45] syn_projEE_ampa[4205] = new ampa(0.5)")
        h("Epop[52] netConn_projEE_ampa[4205] = new NetCon(&v(0.5), syn_projEE_ampa[4205], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4206: cell 52, seg 0 (0.5) [0.5 on Epop[52]] -> cell 46, seg 0 (0.5) [0.5 on Epop[46]], weight: 4.1363508E-4, delay 1.5
        h("Epop[46] syn_projEE_ampa[4206] = new ampa(0.5)")
        h("Epop[52] netConn_projEE_ampa[4206] = new NetCon(&v(0.5), syn_projEE_ampa[4206], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4207: cell 52, seg 0 (0.5) [0.5 on Epop[52]] -> cell 47, seg 0 (0.5) [0.5 on Epop[47]], weight: 4.1363508E-4, delay 1.5
        h("Epop[47] syn_projEE_ampa[4207] = new ampa(0.5)")
        h("Epop[52] netConn_projEE_ampa[4207] = new NetCon(&v(0.5), syn_projEE_ampa[4207], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4208: cell 52, seg 0 (0.5) [0.5 on Epop[52]] -> cell 48, seg 0 (0.5) [0.5 on Epop[48]], weight: 4.1363508E-4, delay 1.5
        h("Epop[48] syn_projEE_ampa[4208] = new ampa(0.5)")
        h("Epop[52] netConn_projEE_ampa[4208] = new NetCon(&v(0.5), syn_projEE_ampa[4208], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4209: cell 52, seg 0 (0.5) [0.5 on Epop[52]] -> cell 49, seg 0 (0.5) [0.5 on Epop[49]], weight: 4.1363508E-4, delay 1.5
        h("Epop[49] syn_projEE_ampa[4209] = new ampa(0.5)")
        h("Epop[52] netConn_projEE_ampa[4209] = new NetCon(&v(0.5), syn_projEE_ampa[4209], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4210: cell 52, seg 0 (0.5) [0.5 on Epop[52]] -> cell 50, seg 0 (0.5) [0.5 on Epop[50]], weight: 4.1363508E-4, delay 1.5
        h("Epop[50] syn_projEE_ampa[4210] = new ampa(0.5)")
        h("Epop[52] netConn_projEE_ampa[4210] = new NetCon(&v(0.5), syn_projEE_ampa[4210], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4211: cell 52, seg 0 (0.5) [0.5 on Epop[52]] -> cell 51, seg 0 (0.5) [0.5 on Epop[51]], weight: 4.1363508E-4, delay 1.5
        h("Epop[51] syn_projEE_ampa[4211] = new ampa(0.5)")
        h("Epop[52] netConn_projEE_ampa[4211] = new NetCon(&v(0.5), syn_projEE_ampa[4211], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4212: cell 52, seg 0 (0.5) [0.5 on Epop[52]] -> cell 52, seg 0 (0.5) [0.5 on Epop[52]], weight: 4.1363508E-4, delay 1.5
        h("Epop[52] syn_projEE_ampa[4212] = new ampa(0.5)")
        h("Epop[52] netConn_projEE_ampa[4212] = new NetCon(&v(0.5), syn_projEE_ampa[4212], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4213: cell 52, seg 0 (0.5) [0.5 on Epop[52]] -> cell 53, seg 0 (0.5) [0.5 on Epop[53]], weight: 4.1363508E-4, delay 1.5
        h("Epop[53] syn_projEE_ampa[4213] = new ampa(0.5)")
        h("Epop[52] netConn_projEE_ampa[4213] = new NetCon(&v(0.5), syn_projEE_ampa[4213], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4214: cell 52, seg 0 (0.5) [0.5 on Epop[52]] -> cell 54, seg 0 (0.5) [0.5 on Epop[54]], weight: 4.1363508E-4, delay 1.5
        h("Epop[54] syn_projEE_ampa[4214] = new ampa(0.5)")
        h("Epop[52] netConn_projEE_ampa[4214] = new NetCon(&v(0.5), syn_projEE_ampa[4214], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4215: cell 52, seg 0 (0.5) [0.5 on Epop[52]] -> cell 55, seg 0 (0.5) [0.5 on Epop[55]], weight: 4.1363508E-4, delay 1.5
        h("Epop[55] syn_projEE_ampa[4215] = new ampa(0.5)")
        h("Epop[52] netConn_projEE_ampa[4215] = new NetCon(&v(0.5), syn_projEE_ampa[4215], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4216: cell 52, seg 0 (0.5) [0.5 on Epop[52]] -> cell 56, seg 0 (0.5) [0.5 on Epop[56]], weight: 4.1363508E-4, delay 1.5
        h("Epop[56] syn_projEE_ampa[4216] = new ampa(0.5)")
        h("Epop[52] netConn_projEE_ampa[4216] = new NetCon(&v(0.5), syn_projEE_ampa[4216], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4217: cell 52, seg 0 (0.5) [0.5 on Epop[52]] -> cell 57, seg 0 (0.5) [0.5 on Epop[57]], weight: 4.1363508E-4, delay 1.5
        h("Epop[57] syn_projEE_ampa[4217] = new ampa(0.5)")
        h("Epop[52] netConn_projEE_ampa[4217] = new NetCon(&v(0.5), syn_projEE_ampa[4217], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4218: cell 52, seg 0 (0.5) [0.5 on Epop[52]] -> cell 58, seg 0 (0.5) [0.5 on Epop[58]], weight: 4.1363508E-4, delay 1.5
        h("Epop[58] syn_projEE_ampa[4218] = new ampa(0.5)")
        h("Epop[52] netConn_projEE_ampa[4218] = new NetCon(&v(0.5), syn_projEE_ampa[4218], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4219: cell 52, seg 0 (0.5) [0.5 on Epop[52]] -> cell 59, seg 0 (0.5) [0.5 on Epop[59]], weight: 4.1363508E-4, delay 1.5
        h("Epop[59] syn_projEE_ampa[4219] = new ampa(0.5)")
        h("Epop[52] netConn_projEE_ampa[4219] = new NetCon(&v(0.5), syn_projEE_ampa[4219], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4220: cell 52, seg 0 (0.5) [0.5 on Epop[52]] -> cell 60, seg 0 (0.5) [0.5 on Epop[60]], weight: 4.1363508E-4, delay 1.5
        h("Epop[60] syn_projEE_ampa[4220] = new ampa(0.5)")
        h("Epop[52] netConn_projEE_ampa[4220] = new NetCon(&v(0.5), syn_projEE_ampa[4220], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4221: cell 52, seg 0 (0.5) [0.5 on Epop[52]] -> cell 61, seg 0 (0.5) [0.5 on Epop[61]], weight: 4.1363508E-4, delay 1.5
        h("Epop[61] syn_projEE_ampa[4221] = new ampa(0.5)")
        h("Epop[52] netConn_projEE_ampa[4221] = new NetCon(&v(0.5), syn_projEE_ampa[4221], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4222: cell 52, seg 0 (0.5) [0.5 on Epop[52]] -> cell 62, seg 0 (0.5) [0.5 on Epop[62]], weight: 4.1363508E-4, delay 1.5
        h("Epop[62] syn_projEE_ampa[4222] = new ampa(0.5)")
        h("Epop[52] netConn_projEE_ampa[4222] = new NetCon(&v(0.5), syn_projEE_ampa[4222], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4223: cell 52, seg 0 (0.5) [0.5 on Epop[52]] -> cell 63, seg 0 (0.5) [0.5 on Epop[63]], weight: 4.1363508E-4, delay 1.5
        h("Epop[63] syn_projEE_ampa[4223] = new ampa(0.5)")
        h("Epop[52] netConn_projEE_ampa[4223] = new NetCon(&v(0.5), syn_projEE_ampa[4223], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4224: cell 52, seg 0 (0.5) [0.5 on Epop[52]] -> cell 64, seg 0 (0.5) [0.5 on Epop[64]], weight: 4.1363508E-4, delay 1.5
        h("Epop[64] syn_projEE_ampa[4224] = new ampa(0.5)")
        h("Epop[52] netConn_projEE_ampa[4224] = new NetCon(&v(0.5), syn_projEE_ampa[4224], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4225: cell 52, seg 0 (0.5) [0.5 on Epop[52]] -> cell 65, seg 0 (0.5) [0.5 on Epop[65]], weight: 4.1363508E-4, delay 1.5
        h("Epop[65] syn_projEE_ampa[4225] = new ampa(0.5)")
        h("Epop[52] netConn_projEE_ampa[4225] = new NetCon(&v(0.5), syn_projEE_ampa[4225], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4226: cell 52, seg 0 (0.5) [0.5 on Epop[52]] -> cell 66, seg 0 (0.5) [0.5 on Epop[66]], weight: 4.1363508E-4, delay 1.5
        h("Epop[66] syn_projEE_ampa[4226] = new ampa(0.5)")
        h("Epop[52] netConn_projEE_ampa[4226] = new NetCon(&v(0.5), syn_projEE_ampa[4226], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4227: cell 52, seg 0 (0.5) [0.5 on Epop[52]] -> cell 67, seg 0 (0.5) [0.5 on Epop[67]], weight: 4.1363508E-4, delay 1.5
        h("Epop[67] syn_projEE_ampa[4227] = new ampa(0.5)")
        h("Epop[52] netConn_projEE_ampa[4227] = new NetCon(&v(0.5), syn_projEE_ampa[4227], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4228: cell 52, seg 0 (0.5) [0.5 on Epop[52]] -> cell 68, seg 0 (0.5) [0.5 on Epop[68]], weight: 4.1363508E-4, delay 1.5
        h("Epop[68] syn_projEE_ampa[4228] = new ampa(0.5)")
        h("Epop[52] netConn_projEE_ampa[4228] = new NetCon(&v(0.5), syn_projEE_ampa[4228], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4229: cell 52, seg 0 (0.5) [0.5 on Epop[52]] -> cell 69, seg 0 (0.5) [0.5 on Epop[69]], weight: 4.1363508E-4, delay 1.5
        h("Epop[69] syn_projEE_ampa[4229] = new ampa(0.5)")
        h("Epop[52] netConn_projEE_ampa[4229] = new NetCon(&v(0.5), syn_projEE_ampa[4229], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4230: cell 52, seg 0 (0.5) [0.5 on Epop[52]] -> cell 70, seg 0 (0.5) [0.5 on Epop[70]], weight: 4.1363508E-4, delay 1.5
        h("Epop[70] syn_projEE_ampa[4230] = new ampa(0.5)")
        h("Epop[52] netConn_projEE_ampa[4230] = new NetCon(&v(0.5), syn_projEE_ampa[4230], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4231: cell 52, seg 0 (0.5) [0.5 on Epop[52]] -> cell 71, seg 0 (0.5) [0.5 on Epop[71]], weight: 4.1363508E-4, delay 1.5
        h("Epop[71] syn_projEE_ampa[4231] = new ampa(0.5)")
        h("Epop[52] netConn_projEE_ampa[4231] = new NetCon(&v(0.5), syn_projEE_ampa[4231], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4232: cell 52, seg 0 (0.5) [0.5 on Epop[52]] -> cell 72, seg 0 (0.5) [0.5 on Epop[72]], weight: 4.1363508E-4, delay 1.5
        h("Epop[72] syn_projEE_ampa[4232] = new ampa(0.5)")
        h("Epop[52] netConn_projEE_ampa[4232] = new NetCon(&v(0.5), syn_projEE_ampa[4232], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4233: cell 52, seg 0 (0.5) [0.5 on Epop[52]] -> cell 73, seg 0 (0.5) [0.5 on Epop[73]], weight: 4.1363508E-4, delay 1.5
        h("Epop[73] syn_projEE_ampa[4233] = new ampa(0.5)")
        h("Epop[52] netConn_projEE_ampa[4233] = new NetCon(&v(0.5), syn_projEE_ampa[4233], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4234: cell 52, seg 0 (0.5) [0.5 on Epop[52]] -> cell 74, seg 0 (0.5) [0.5 on Epop[74]], weight: 4.1363508E-4, delay 1.5
        h("Epop[74] syn_projEE_ampa[4234] = new ampa(0.5)")
        h("Epop[52] netConn_projEE_ampa[4234] = new NetCon(&v(0.5), syn_projEE_ampa[4234], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4235: cell 52, seg 0 (0.5) [0.5 on Epop[52]] -> cell 75, seg 0 (0.5) [0.5 on Epop[75]], weight: 4.1363508E-4, delay 1.5
        h("Epop[75] syn_projEE_ampa[4235] = new ampa(0.5)")
        h("Epop[52] netConn_projEE_ampa[4235] = new NetCon(&v(0.5), syn_projEE_ampa[4235], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4236: cell 52, seg 0 (0.5) [0.5 on Epop[52]] -> cell 76, seg 0 (0.5) [0.5 on Epop[76]], weight: 4.1363508E-4, delay 1.5
        h("Epop[76] syn_projEE_ampa[4236] = new ampa(0.5)")
        h("Epop[52] netConn_projEE_ampa[4236] = new NetCon(&v(0.5), syn_projEE_ampa[4236], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4237: cell 52, seg 0 (0.5) [0.5 on Epop[52]] -> cell 77, seg 0 (0.5) [0.5 on Epop[77]], weight: 4.1363508E-4, delay 1.5
        h("Epop[77] syn_projEE_ampa[4237] = new ampa(0.5)")
        h("Epop[52] netConn_projEE_ampa[4237] = new NetCon(&v(0.5), syn_projEE_ampa[4237], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4238: cell 52, seg 0 (0.5) [0.5 on Epop[52]] -> cell 78, seg 0 (0.5) [0.5 on Epop[78]], weight: 4.1363508E-4, delay 1.5
        h("Epop[78] syn_projEE_ampa[4238] = new ampa(0.5)")
        h("Epop[52] netConn_projEE_ampa[4238] = new NetCon(&v(0.5), syn_projEE_ampa[4238], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4239: cell 52, seg 0 (0.5) [0.5 on Epop[52]] -> cell 79, seg 0 (0.5) [0.5 on Epop[79]], weight: 4.1363508E-4, delay 1.5
        h("Epop[79] syn_projEE_ampa[4239] = new ampa(0.5)")
        h("Epop[52] netConn_projEE_ampa[4239] = new NetCon(&v(0.5), syn_projEE_ampa[4239], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4240: cell 53, seg 0 (0.5) [0.5 on Epop[53]] -> cell 0, seg 0 (0.5) [0.5 on Epop[0]], weight: 4.1363508E-4, delay 1.5
        h("Epop[0] syn_projEE_ampa[4240] = new ampa(0.5)")
        h("Epop[53] netConn_projEE_ampa[4240] = new NetCon(&v(0.5), syn_projEE_ampa[4240], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4241: cell 53, seg 0 (0.5) [0.5 on Epop[53]] -> cell 1, seg 0 (0.5) [0.5 on Epop[1]], weight: 4.1363508E-4, delay 1.5
        h("Epop[1] syn_projEE_ampa[4241] = new ampa(0.5)")
        h("Epop[53] netConn_projEE_ampa[4241] = new NetCon(&v(0.5), syn_projEE_ampa[4241], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4242: cell 53, seg 0 (0.5) [0.5 on Epop[53]] -> cell 2, seg 0 (0.5) [0.5 on Epop[2]], weight: 4.1363508E-4, delay 1.5
        h("Epop[2] syn_projEE_ampa[4242] = new ampa(0.5)")
        h("Epop[53] netConn_projEE_ampa[4242] = new NetCon(&v(0.5), syn_projEE_ampa[4242], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4243: cell 53, seg 0 (0.5) [0.5 on Epop[53]] -> cell 3, seg 0 (0.5) [0.5 on Epop[3]], weight: 4.1363508E-4, delay 1.5
        h("Epop[3] syn_projEE_ampa[4243] = new ampa(0.5)")
        h("Epop[53] netConn_projEE_ampa[4243] = new NetCon(&v(0.5), syn_projEE_ampa[4243], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4244: cell 53, seg 0 (0.5) [0.5 on Epop[53]] -> cell 4, seg 0 (0.5) [0.5 on Epop[4]], weight: 4.1363508E-4, delay 1.5
        h("Epop[4] syn_projEE_ampa[4244] = new ampa(0.5)")
        h("Epop[53] netConn_projEE_ampa[4244] = new NetCon(&v(0.5), syn_projEE_ampa[4244], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4245: cell 53, seg 0 (0.5) [0.5 on Epop[53]] -> cell 5, seg 0 (0.5) [0.5 on Epop[5]], weight: 4.1363508E-4, delay 1.5
        h("Epop[5] syn_projEE_ampa[4245] = new ampa(0.5)")
        h("Epop[53] netConn_projEE_ampa[4245] = new NetCon(&v(0.5), syn_projEE_ampa[4245], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4246: cell 53, seg 0 (0.5) [0.5 on Epop[53]] -> cell 6, seg 0 (0.5) [0.5 on Epop[6]], weight: 4.1363508E-4, delay 1.5
        h("Epop[6] syn_projEE_ampa[4246] = new ampa(0.5)")
        h("Epop[53] netConn_projEE_ampa[4246] = new NetCon(&v(0.5), syn_projEE_ampa[4246], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4247: cell 53, seg 0 (0.5) [0.5 on Epop[53]] -> cell 7, seg 0 (0.5) [0.5 on Epop[7]], weight: 4.1363508E-4, delay 1.5
        h("Epop[7] syn_projEE_ampa[4247] = new ampa(0.5)")
        h("Epop[53] netConn_projEE_ampa[4247] = new NetCon(&v(0.5), syn_projEE_ampa[4247], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4248: cell 53, seg 0 (0.5) [0.5 on Epop[53]] -> cell 8, seg 0 (0.5) [0.5 on Epop[8]], weight: 4.1363508E-4, delay 1.5
        h("Epop[8] syn_projEE_ampa[4248] = new ampa(0.5)")
        h("Epop[53] netConn_projEE_ampa[4248] = new NetCon(&v(0.5), syn_projEE_ampa[4248], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4249: cell 53, seg 0 (0.5) [0.5 on Epop[53]] -> cell 9, seg 0 (0.5) [0.5 on Epop[9]], weight: 4.1363508E-4, delay 1.5
        h("Epop[9] syn_projEE_ampa[4249] = new ampa(0.5)")
        h("Epop[53] netConn_projEE_ampa[4249] = new NetCon(&v(0.5), syn_projEE_ampa[4249], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4250: cell 53, seg 0 (0.5) [0.5 on Epop[53]] -> cell 10, seg 0 (0.5) [0.5 on Epop[10]], weight: 4.1363508E-4, delay 1.5
        h("Epop[10] syn_projEE_ampa[4250] = new ampa(0.5)")
        h("Epop[53] netConn_projEE_ampa[4250] = new NetCon(&v(0.5), syn_projEE_ampa[4250], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4251: cell 53, seg 0 (0.5) [0.5 on Epop[53]] -> cell 11, seg 0 (0.5) [0.5 on Epop[11]], weight: 4.1363508E-4, delay 1.5
        h("Epop[11] syn_projEE_ampa[4251] = new ampa(0.5)")
        h("Epop[53] netConn_projEE_ampa[4251] = new NetCon(&v(0.5), syn_projEE_ampa[4251], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4252: cell 53, seg 0 (0.5) [0.5 on Epop[53]] -> cell 12, seg 0 (0.5) [0.5 on Epop[12]], weight: 4.1363508E-4, delay 1.5
        h("Epop[12] syn_projEE_ampa[4252] = new ampa(0.5)")
        h("Epop[53] netConn_projEE_ampa[4252] = new NetCon(&v(0.5), syn_projEE_ampa[4252], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4253: cell 53, seg 0 (0.5) [0.5 on Epop[53]] -> cell 13, seg 0 (0.5) [0.5 on Epop[13]], weight: 4.1363508E-4, delay 1.5
        h("Epop[13] syn_projEE_ampa[4253] = new ampa(0.5)")
        h("Epop[53] netConn_projEE_ampa[4253] = new NetCon(&v(0.5), syn_projEE_ampa[4253], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4254: cell 53, seg 0 (0.5) [0.5 on Epop[53]] -> cell 14, seg 0 (0.5) [0.5 on Epop[14]], weight: 4.1363508E-4, delay 1.5
        h("Epop[14] syn_projEE_ampa[4254] = new ampa(0.5)")
        h("Epop[53] netConn_projEE_ampa[4254] = new NetCon(&v(0.5), syn_projEE_ampa[4254], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4255: cell 53, seg 0 (0.5) [0.5 on Epop[53]] -> cell 15, seg 0 (0.5) [0.5 on Epop[15]], weight: 4.1363508E-4, delay 1.5
        h("Epop[15] syn_projEE_ampa[4255] = new ampa(0.5)")
        h("Epop[53] netConn_projEE_ampa[4255] = new NetCon(&v(0.5), syn_projEE_ampa[4255], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4256: cell 53, seg 0 (0.5) [0.5 on Epop[53]] -> cell 16, seg 0 (0.5) [0.5 on Epop[16]], weight: 4.1363508E-4, delay 1.5
        h("Epop[16] syn_projEE_ampa[4256] = new ampa(0.5)")
        h("Epop[53] netConn_projEE_ampa[4256] = new NetCon(&v(0.5), syn_projEE_ampa[4256], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4257: cell 53, seg 0 (0.5) [0.5 on Epop[53]] -> cell 17, seg 0 (0.5) [0.5 on Epop[17]], weight: 4.1363508E-4, delay 1.5
        h("Epop[17] syn_projEE_ampa[4257] = new ampa(0.5)")
        h("Epop[53] netConn_projEE_ampa[4257] = new NetCon(&v(0.5), syn_projEE_ampa[4257], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4258: cell 53, seg 0 (0.5) [0.5 on Epop[53]] -> cell 18, seg 0 (0.5) [0.5 on Epop[18]], weight: 4.1363508E-4, delay 1.5
        h("Epop[18] syn_projEE_ampa[4258] = new ampa(0.5)")
        h("Epop[53] netConn_projEE_ampa[4258] = new NetCon(&v(0.5), syn_projEE_ampa[4258], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4259: cell 53, seg 0 (0.5) [0.5 on Epop[53]] -> cell 19, seg 0 (0.5) [0.5 on Epop[19]], weight: 4.1363508E-4, delay 1.5
        h("Epop[19] syn_projEE_ampa[4259] = new ampa(0.5)")
        h("Epop[53] netConn_projEE_ampa[4259] = new NetCon(&v(0.5), syn_projEE_ampa[4259], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4260: cell 53, seg 0 (0.5) [0.5 on Epop[53]] -> cell 20, seg 0 (0.5) [0.5 on Epop[20]], weight: 4.1363508E-4, delay 1.5
        h("Epop[20] syn_projEE_ampa[4260] = new ampa(0.5)")
        h("Epop[53] netConn_projEE_ampa[4260] = new NetCon(&v(0.5), syn_projEE_ampa[4260], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4261: cell 53, seg 0 (0.5) [0.5 on Epop[53]] -> cell 21, seg 0 (0.5) [0.5 on Epop[21]], weight: 4.1363508E-4, delay 1.5
        h("Epop[21] syn_projEE_ampa[4261] = new ampa(0.5)")
        h("Epop[53] netConn_projEE_ampa[4261] = new NetCon(&v(0.5), syn_projEE_ampa[4261], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4262: cell 53, seg 0 (0.5) [0.5 on Epop[53]] -> cell 22, seg 0 (0.5) [0.5 on Epop[22]], weight: 4.1363508E-4, delay 1.5
        h("Epop[22] syn_projEE_ampa[4262] = new ampa(0.5)")
        h("Epop[53] netConn_projEE_ampa[4262] = new NetCon(&v(0.5), syn_projEE_ampa[4262], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4263: cell 53, seg 0 (0.5) [0.5 on Epop[53]] -> cell 23, seg 0 (0.5) [0.5 on Epop[23]], weight: 4.1363508E-4, delay 1.5
        h("Epop[23] syn_projEE_ampa[4263] = new ampa(0.5)")
        h("Epop[53] netConn_projEE_ampa[4263] = new NetCon(&v(0.5), syn_projEE_ampa[4263], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4264: cell 53, seg 0 (0.5) [0.5 on Epop[53]] -> cell 24, seg 0 (0.5) [0.5 on Epop[24]], weight: 4.1363508E-4, delay 1.5
        h("Epop[24] syn_projEE_ampa[4264] = new ampa(0.5)")
        h("Epop[53] netConn_projEE_ampa[4264] = new NetCon(&v(0.5), syn_projEE_ampa[4264], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4265: cell 53, seg 0 (0.5) [0.5 on Epop[53]] -> cell 25, seg 0 (0.5) [0.5 on Epop[25]], weight: 4.1363508E-4, delay 1.5
        h("Epop[25] syn_projEE_ampa[4265] = new ampa(0.5)")
        h("Epop[53] netConn_projEE_ampa[4265] = new NetCon(&v(0.5), syn_projEE_ampa[4265], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4266: cell 53, seg 0 (0.5) [0.5 on Epop[53]] -> cell 26, seg 0 (0.5) [0.5 on Epop[26]], weight: 4.1363508E-4, delay 1.5
        h("Epop[26] syn_projEE_ampa[4266] = new ampa(0.5)")
        h("Epop[53] netConn_projEE_ampa[4266] = new NetCon(&v(0.5), syn_projEE_ampa[4266], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4267: cell 53, seg 0 (0.5) [0.5 on Epop[53]] -> cell 27, seg 0 (0.5) [0.5 on Epop[27]], weight: 4.1363508E-4, delay 1.5
        h("Epop[27] syn_projEE_ampa[4267] = new ampa(0.5)")
        h("Epop[53] netConn_projEE_ampa[4267] = new NetCon(&v(0.5), syn_projEE_ampa[4267], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4268: cell 53, seg 0 (0.5) [0.5 on Epop[53]] -> cell 28, seg 0 (0.5) [0.5 on Epop[28]], weight: 4.1363508E-4, delay 1.5
        h("Epop[28] syn_projEE_ampa[4268] = new ampa(0.5)")
        h("Epop[53] netConn_projEE_ampa[4268] = new NetCon(&v(0.5), syn_projEE_ampa[4268], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4269: cell 53, seg 0 (0.5) [0.5 on Epop[53]] -> cell 29, seg 0 (0.5) [0.5 on Epop[29]], weight: 4.1363508E-4, delay 1.5
        h("Epop[29] syn_projEE_ampa[4269] = new ampa(0.5)")
        h("Epop[53] netConn_projEE_ampa[4269] = new NetCon(&v(0.5), syn_projEE_ampa[4269], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4270: cell 53, seg 0 (0.5) [0.5 on Epop[53]] -> cell 30, seg 0 (0.5) [0.5 on Epop[30]], weight: 4.1363508E-4, delay 1.5
        h("Epop[30] syn_projEE_ampa[4270] = new ampa(0.5)")
        h("Epop[53] netConn_projEE_ampa[4270] = new NetCon(&v(0.5), syn_projEE_ampa[4270], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4271: cell 53, seg 0 (0.5) [0.5 on Epop[53]] -> cell 31, seg 0 (0.5) [0.5 on Epop[31]], weight: 4.1363508E-4, delay 1.5
        h("Epop[31] syn_projEE_ampa[4271] = new ampa(0.5)")
        h("Epop[53] netConn_projEE_ampa[4271] = new NetCon(&v(0.5), syn_projEE_ampa[4271], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4272: cell 53, seg 0 (0.5) [0.5 on Epop[53]] -> cell 32, seg 0 (0.5) [0.5 on Epop[32]], weight: 4.1363508E-4, delay 1.5
        h("Epop[32] syn_projEE_ampa[4272] = new ampa(0.5)")
        h("Epop[53] netConn_projEE_ampa[4272] = new NetCon(&v(0.5), syn_projEE_ampa[4272], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4273: cell 53, seg 0 (0.5) [0.5 on Epop[53]] -> cell 33, seg 0 (0.5) [0.5 on Epop[33]], weight: 4.1363508E-4, delay 1.5
        h("Epop[33] syn_projEE_ampa[4273] = new ampa(0.5)")
        h("Epop[53] netConn_projEE_ampa[4273] = new NetCon(&v(0.5), syn_projEE_ampa[4273], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4274: cell 53, seg 0 (0.5) [0.5 on Epop[53]] -> cell 34, seg 0 (0.5) [0.5 on Epop[34]], weight: 4.1363508E-4, delay 1.5
        h("Epop[34] syn_projEE_ampa[4274] = new ampa(0.5)")
        h("Epop[53] netConn_projEE_ampa[4274] = new NetCon(&v(0.5), syn_projEE_ampa[4274], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4275: cell 53, seg 0 (0.5) [0.5 on Epop[53]] -> cell 35, seg 0 (0.5) [0.5 on Epop[35]], weight: 4.1363508E-4, delay 1.5
        h("Epop[35] syn_projEE_ampa[4275] = new ampa(0.5)")
        h("Epop[53] netConn_projEE_ampa[4275] = new NetCon(&v(0.5), syn_projEE_ampa[4275], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4276: cell 53, seg 0 (0.5) [0.5 on Epop[53]] -> cell 36, seg 0 (0.5) [0.5 on Epop[36]], weight: 4.1363508E-4, delay 1.5
        h("Epop[36] syn_projEE_ampa[4276] = new ampa(0.5)")
        h("Epop[53] netConn_projEE_ampa[4276] = new NetCon(&v(0.5), syn_projEE_ampa[4276], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4277: cell 53, seg 0 (0.5) [0.5 on Epop[53]] -> cell 37, seg 0 (0.5) [0.5 on Epop[37]], weight: 4.1363508E-4, delay 1.5
        h("Epop[37] syn_projEE_ampa[4277] = new ampa(0.5)")
        h("Epop[53] netConn_projEE_ampa[4277] = new NetCon(&v(0.5), syn_projEE_ampa[4277], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4278: cell 53, seg 0 (0.5) [0.5 on Epop[53]] -> cell 38, seg 0 (0.5) [0.5 on Epop[38]], weight: 4.1363508E-4, delay 1.5
        h("Epop[38] syn_projEE_ampa[4278] = new ampa(0.5)")
        h("Epop[53] netConn_projEE_ampa[4278] = new NetCon(&v(0.5), syn_projEE_ampa[4278], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4279: cell 53, seg 0 (0.5) [0.5 on Epop[53]] -> cell 39, seg 0 (0.5) [0.5 on Epop[39]], weight: 4.1363508E-4, delay 1.5
        h("Epop[39] syn_projEE_ampa[4279] = new ampa(0.5)")
        h("Epop[53] netConn_projEE_ampa[4279] = new NetCon(&v(0.5), syn_projEE_ampa[4279], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4280: cell 53, seg 0 (0.5) [0.5 on Epop[53]] -> cell 40, seg 0 (0.5) [0.5 on Epop[40]], weight: 4.1363508E-4, delay 1.5
        h("Epop[40] syn_projEE_ampa[4280] = new ampa(0.5)")
        h("Epop[53] netConn_projEE_ampa[4280] = new NetCon(&v(0.5), syn_projEE_ampa[4280], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4281: cell 53, seg 0 (0.5) [0.5 on Epop[53]] -> cell 41, seg 0 (0.5) [0.5 on Epop[41]], weight: 4.1363508E-4, delay 1.5
        h("Epop[41] syn_projEE_ampa[4281] = new ampa(0.5)")
        h("Epop[53] netConn_projEE_ampa[4281] = new NetCon(&v(0.5), syn_projEE_ampa[4281], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4282: cell 53, seg 0 (0.5) [0.5 on Epop[53]] -> cell 42, seg 0 (0.5) [0.5 on Epop[42]], weight: 4.1363508E-4, delay 1.5
        h("Epop[42] syn_projEE_ampa[4282] = new ampa(0.5)")
        h("Epop[53] netConn_projEE_ampa[4282] = new NetCon(&v(0.5), syn_projEE_ampa[4282], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4283: cell 53, seg 0 (0.5) [0.5 on Epop[53]] -> cell 43, seg 0 (0.5) [0.5 on Epop[43]], weight: 4.1363508E-4, delay 1.5
        h("Epop[43] syn_projEE_ampa[4283] = new ampa(0.5)")
        h("Epop[53] netConn_projEE_ampa[4283] = new NetCon(&v(0.5), syn_projEE_ampa[4283], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4284: cell 53, seg 0 (0.5) [0.5 on Epop[53]] -> cell 44, seg 0 (0.5) [0.5 on Epop[44]], weight: 4.1363508E-4, delay 1.5
        h("Epop[44] syn_projEE_ampa[4284] = new ampa(0.5)")
        h("Epop[53] netConn_projEE_ampa[4284] = new NetCon(&v(0.5), syn_projEE_ampa[4284], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4285: cell 53, seg 0 (0.5) [0.5 on Epop[53]] -> cell 45, seg 0 (0.5) [0.5 on Epop[45]], weight: 4.1363508E-4, delay 1.5
        h("Epop[45] syn_projEE_ampa[4285] = new ampa(0.5)")
        h("Epop[53] netConn_projEE_ampa[4285] = new NetCon(&v(0.5), syn_projEE_ampa[4285], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4286: cell 53, seg 0 (0.5) [0.5 on Epop[53]] -> cell 46, seg 0 (0.5) [0.5 on Epop[46]], weight: 4.1363508E-4, delay 1.5
        h("Epop[46] syn_projEE_ampa[4286] = new ampa(0.5)")
        h("Epop[53] netConn_projEE_ampa[4286] = new NetCon(&v(0.5), syn_projEE_ampa[4286], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4287: cell 53, seg 0 (0.5) [0.5 on Epop[53]] -> cell 47, seg 0 (0.5) [0.5 on Epop[47]], weight: 4.1363508E-4, delay 1.5
        h("Epop[47] syn_projEE_ampa[4287] = new ampa(0.5)")
        h("Epop[53] netConn_projEE_ampa[4287] = new NetCon(&v(0.5), syn_projEE_ampa[4287], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4288: cell 53, seg 0 (0.5) [0.5 on Epop[53]] -> cell 48, seg 0 (0.5) [0.5 on Epop[48]], weight: 4.1363508E-4, delay 1.5
        h("Epop[48] syn_projEE_ampa[4288] = new ampa(0.5)")
        h("Epop[53] netConn_projEE_ampa[4288] = new NetCon(&v(0.5), syn_projEE_ampa[4288], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4289: cell 53, seg 0 (0.5) [0.5 on Epop[53]] -> cell 49, seg 0 (0.5) [0.5 on Epop[49]], weight: 4.1363508E-4, delay 1.5
        h("Epop[49] syn_projEE_ampa[4289] = new ampa(0.5)")
        h("Epop[53] netConn_projEE_ampa[4289] = new NetCon(&v(0.5), syn_projEE_ampa[4289], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4290: cell 53, seg 0 (0.5) [0.5 on Epop[53]] -> cell 50, seg 0 (0.5) [0.5 on Epop[50]], weight: 4.1363508E-4, delay 1.5
        h("Epop[50] syn_projEE_ampa[4290] = new ampa(0.5)")
        h("Epop[53] netConn_projEE_ampa[4290] = new NetCon(&v(0.5), syn_projEE_ampa[4290], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4291: cell 53, seg 0 (0.5) [0.5 on Epop[53]] -> cell 51, seg 0 (0.5) [0.5 on Epop[51]], weight: 4.1363508E-4, delay 1.5
        h("Epop[51] syn_projEE_ampa[4291] = new ampa(0.5)")
        h("Epop[53] netConn_projEE_ampa[4291] = new NetCon(&v(0.5), syn_projEE_ampa[4291], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4292: cell 53, seg 0 (0.5) [0.5 on Epop[53]] -> cell 52, seg 0 (0.5) [0.5 on Epop[52]], weight: 4.1363508E-4, delay 1.5
        h("Epop[52] syn_projEE_ampa[4292] = new ampa(0.5)")
        h("Epop[53] netConn_projEE_ampa[4292] = new NetCon(&v(0.5), syn_projEE_ampa[4292], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4293: cell 53, seg 0 (0.5) [0.5 on Epop[53]] -> cell 53, seg 0 (0.5) [0.5 on Epop[53]], weight: 4.1363508E-4, delay 1.5
        h("Epop[53] syn_projEE_ampa[4293] = new ampa(0.5)")
        h("Epop[53] netConn_projEE_ampa[4293] = new NetCon(&v(0.5), syn_projEE_ampa[4293], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4294: cell 53, seg 0 (0.5) [0.5 on Epop[53]] -> cell 54, seg 0 (0.5) [0.5 on Epop[54]], weight: 4.1363508E-4, delay 1.5
        h("Epop[54] syn_projEE_ampa[4294] = new ampa(0.5)")
        h("Epop[53] netConn_projEE_ampa[4294] = new NetCon(&v(0.5), syn_projEE_ampa[4294], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4295: cell 53, seg 0 (0.5) [0.5 on Epop[53]] -> cell 55, seg 0 (0.5) [0.5 on Epop[55]], weight: 4.1363508E-4, delay 1.5
        h("Epop[55] syn_projEE_ampa[4295] = new ampa(0.5)")
        h("Epop[53] netConn_projEE_ampa[4295] = new NetCon(&v(0.5), syn_projEE_ampa[4295], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4296: cell 53, seg 0 (0.5) [0.5 on Epop[53]] -> cell 56, seg 0 (0.5) [0.5 on Epop[56]], weight: 4.1363508E-4, delay 1.5
        h("Epop[56] syn_projEE_ampa[4296] = new ampa(0.5)")
        h("Epop[53] netConn_projEE_ampa[4296] = new NetCon(&v(0.5), syn_projEE_ampa[4296], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4297: cell 53, seg 0 (0.5) [0.5 on Epop[53]] -> cell 57, seg 0 (0.5) [0.5 on Epop[57]], weight: 4.1363508E-4, delay 1.5
        h("Epop[57] syn_projEE_ampa[4297] = new ampa(0.5)")
        h("Epop[53] netConn_projEE_ampa[4297] = new NetCon(&v(0.5), syn_projEE_ampa[4297], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4298: cell 53, seg 0 (0.5) [0.5 on Epop[53]] -> cell 58, seg 0 (0.5) [0.5 on Epop[58]], weight: 4.1363508E-4, delay 1.5
        h("Epop[58] syn_projEE_ampa[4298] = new ampa(0.5)")
        h("Epop[53] netConn_projEE_ampa[4298] = new NetCon(&v(0.5), syn_projEE_ampa[4298], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4299: cell 53, seg 0 (0.5) [0.5 on Epop[53]] -> cell 59, seg 0 (0.5) [0.5 on Epop[59]], weight: 4.1363508E-4, delay 1.5
        h("Epop[59] syn_projEE_ampa[4299] = new ampa(0.5)")
        h("Epop[53] netConn_projEE_ampa[4299] = new NetCon(&v(0.5), syn_projEE_ampa[4299], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4300: cell 53, seg 0 (0.5) [0.5 on Epop[53]] -> cell 60, seg 0 (0.5) [0.5 on Epop[60]], weight: 4.1363508E-4, delay 1.5
        h("Epop[60] syn_projEE_ampa[4300] = new ampa(0.5)")
        h("Epop[53] netConn_projEE_ampa[4300] = new NetCon(&v(0.5), syn_projEE_ampa[4300], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4301: cell 53, seg 0 (0.5) [0.5 on Epop[53]] -> cell 61, seg 0 (0.5) [0.5 on Epop[61]], weight: 4.1363508E-4, delay 1.5
        h("Epop[61] syn_projEE_ampa[4301] = new ampa(0.5)")
        h("Epop[53] netConn_projEE_ampa[4301] = new NetCon(&v(0.5), syn_projEE_ampa[4301], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4302: cell 53, seg 0 (0.5) [0.5 on Epop[53]] -> cell 62, seg 0 (0.5) [0.5 on Epop[62]], weight: 4.1363508E-4, delay 1.5
        h("Epop[62] syn_projEE_ampa[4302] = new ampa(0.5)")
        h("Epop[53] netConn_projEE_ampa[4302] = new NetCon(&v(0.5), syn_projEE_ampa[4302], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4303: cell 53, seg 0 (0.5) [0.5 on Epop[53]] -> cell 63, seg 0 (0.5) [0.5 on Epop[63]], weight: 4.1363508E-4, delay 1.5
        h("Epop[63] syn_projEE_ampa[4303] = new ampa(0.5)")
        h("Epop[53] netConn_projEE_ampa[4303] = new NetCon(&v(0.5), syn_projEE_ampa[4303], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4304: cell 53, seg 0 (0.5) [0.5 on Epop[53]] -> cell 64, seg 0 (0.5) [0.5 on Epop[64]], weight: 4.1363508E-4, delay 1.5
        h("Epop[64] syn_projEE_ampa[4304] = new ampa(0.5)")
        h("Epop[53] netConn_projEE_ampa[4304] = new NetCon(&v(0.5), syn_projEE_ampa[4304], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4305: cell 53, seg 0 (0.5) [0.5 on Epop[53]] -> cell 65, seg 0 (0.5) [0.5 on Epop[65]], weight: 4.1363508E-4, delay 1.5
        h("Epop[65] syn_projEE_ampa[4305] = new ampa(0.5)")
        h("Epop[53] netConn_projEE_ampa[4305] = new NetCon(&v(0.5), syn_projEE_ampa[4305], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4306: cell 53, seg 0 (0.5) [0.5 on Epop[53]] -> cell 66, seg 0 (0.5) [0.5 on Epop[66]], weight: 4.1363508E-4, delay 1.5
        h("Epop[66] syn_projEE_ampa[4306] = new ampa(0.5)")
        h("Epop[53] netConn_projEE_ampa[4306] = new NetCon(&v(0.5), syn_projEE_ampa[4306], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4307: cell 53, seg 0 (0.5) [0.5 on Epop[53]] -> cell 67, seg 0 (0.5) [0.5 on Epop[67]], weight: 4.1363508E-4, delay 1.5
        h("Epop[67] syn_projEE_ampa[4307] = new ampa(0.5)")
        h("Epop[53] netConn_projEE_ampa[4307] = new NetCon(&v(0.5), syn_projEE_ampa[4307], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4308: cell 53, seg 0 (0.5) [0.5 on Epop[53]] -> cell 68, seg 0 (0.5) [0.5 on Epop[68]], weight: 4.1363508E-4, delay 1.5
        h("Epop[68] syn_projEE_ampa[4308] = new ampa(0.5)")
        h("Epop[53] netConn_projEE_ampa[4308] = new NetCon(&v(0.5), syn_projEE_ampa[4308], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4309: cell 53, seg 0 (0.5) [0.5 on Epop[53]] -> cell 69, seg 0 (0.5) [0.5 on Epop[69]], weight: 4.1363508E-4, delay 1.5
        h("Epop[69] syn_projEE_ampa[4309] = new ampa(0.5)")
        h("Epop[53] netConn_projEE_ampa[4309] = new NetCon(&v(0.5), syn_projEE_ampa[4309], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4310: cell 53, seg 0 (0.5) [0.5 on Epop[53]] -> cell 70, seg 0 (0.5) [0.5 on Epop[70]], weight: 4.1363508E-4, delay 1.5
        h("Epop[70] syn_projEE_ampa[4310] = new ampa(0.5)")
        h("Epop[53] netConn_projEE_ampa[4310] = new NetCon(&v(0.5), syn_projEE_ampa[4310], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4311: cell 53, seg 0 (0.5) [0.5 on Epop[53]] -> cell 71, seg 0 (0.5) [0.5 on Epop[71]], weight: 4.1363508E-4, delay 1.5
        h("Epop[71] syn_projEE_ampa[4311] = new ampa(0.5)")
        h("Epop[53] netConn_projEE_ampa[4311] = new NetCon(&v(0.5), syn_projEE_ampa[4311], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4312: cell 53, seg 0 (0.5) [0.5 on Epop[53]] -> cell 72, seg 0 (0.5) [0.5 on Epop[72]], weight: 4.1363508E-4, delay 1.5
        h("Epop[72] syn_projEE_ampa[4312] = new ampa(0.5)")
        h("Epop[53] netConn_projEE_ampa[4312] = new NetCon(&v(0.5), syn_projEE_ampa[4312], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4313: cell 53, seg 0 (0.5) [0.5 on Epop[53]] -> cell 73, seg 0 (0.5) [0.5 on Epop[73]], weight: 4.1363508E-4, delay 1.5
        h("Epop[73] syn_projEE_ampa[4313] = new ampa(0.5)")
        h("Epop[53] netConn_projEE_ampa[4313] = new NetCon(&v(0.5), syn_projEE_ampa[4313], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4314: cell 53, seg 0 (0.5) [0.5 on Epop[53]] -> cell 74, seg 0 (0.5) [0.5 on Epop[74]], weight: 4.1363508E-4, delay 1.5
        h("Epop[74] syn_projEE_ampa[4314] = new ampa(0.5)")
        h("Epop[53] netConn_projEE_ampa[4314] = new NetCon(&v(0.5), syn_projEE_ampa[4314], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4315: cell 53, seg 0 (0.5) [0.5 on Epop[53]] -> cell 75, seg 0 (0.5) [0.5 on Epop[75]], weight: 4.1363508E-4, delay 1.5
        h("Epop[75] syn_projEE_ampa[4315] = new ampa(0.5)")
        h("Epop[53] netConn_projEE_ampa[4315] = new NetCon(&v(0.5), syn_projEE_ampa[4315], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4316: cell 53, seg 0 (0.5) [0.5 on Epop[53]] -> cell 76, seg 0 (0.5) [0.5 on Epop[76]], weight: 4.1363508E-4, delay 1.5
        h("Epop[76] syn_projEE_ampa[4316] = new ampa(0.5)")
        h("Epop[53] netConn_projEE_ampa[4316] = new NetCon(&v(0.5), syn_projEE_ampa[4316], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4317: cell 53, seg 0 (0.5) [0.5 on Epop[53]] -> cell 77, seg 0 (0.5) [0.5 on Epop[77]], weight: 4.1363508E-4, delay 1.5
        h("Epop[77] syn_projEE_ampa[4317] = new ampa(0.5)")
        h("Epop[53] netConn_projEE_ampa[4317] = new NetCon(&v(0.5), syn_projEE_ampa[4317], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4318: cell 53, seg 0 (0.5) [0.5 on Epop[53]] -> cell 78, seg 0 (0.5) [0.5 on Epop[78]], weight: 4.1363508E-4, delay 1.5
        h("Epop[78] syn_projEE_ampa[4318] = new ampa(0.5)")
        h("Epop[53] netConn_projEE_ampa[4318] = new NetCon(&v(0.5), syn_projEE_ampa[4318], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4319: cell 53, seg 0 (0.5) [0.5 on Epop[53]] -> cell 79, seg 0 (0.5) [0.5 on Epop[79]], weight: 4.1363508E-4, delay 1.5
        h("Epop[79] syn_projEE_ampa[4319] = new ampa(0.5)")
        h("Epop[53] netConn_projEE_ampa[4319] = new NetCon(&v(0.5), syn_projEE_ampa[4319], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4320: cell 54, seg 0 (0.5) [0.5 on Epop[54]] -> cell 0, seg 0 (0.5) [0.5 on Epop[0]], weight: 4.1363508E-4, delay 1.5
        h("Epop[0] syn_projEE_ampa[4320] = new ampa(0.5)")
        h("Epop[54] netConn_projEE_ampa[4320] = new NetCon(&v(0.5), syn_projEE_ampa[4320], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4321: cell 54, seg 0 (0.5) [0.5 on Epop[54]] -> cell 1, seg 0 (0.5) [0.5 on Epop[1]], weight: 4.1363508E-4, delay 1.5
        h("Epop[1] syn_projEE_ampa[4321] = new ampa(0.5)")
        h("Epop[54] netConn_projEE_ampa[4321] = new NetCon(&v(0.5), syn_projEE_ampa[4321], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4322: cell 54, seg 0 (0.5) [0.5 on Epop[54]] -> cell 2, seg 0 (0.5) [0.5 on Epop[2]], weight: 4.1363508E-4, delay 1.5
        h("Epop[2] syn_projEE_ampa[4322] = new ampa(0.5)")
        h("Epop[54] netConn_projEE_ampa[4322] = new NetCon(&v(0.5), syn_projEE_ampa[4322], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4323: cell 54, seg 0 (0.5) [0.5 on Epop[54]] -> cell 3, seg 0 (0.5) [0.5 on Epop[3]], weight: 4.1363508E-4, delay 1.5
        h("Epop[3] syn_projEE_ampa[4323] = new ampa(0.5)")
        h("Epop[54] netConn_projEE_ampa[4323] = new NetCon(&v(0.5), syn_projEE_ampa[4323], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4324: cell 54, seg 0 (0.5) [0.5 on Epop[54]] -> cell 4, seg 0 (0.5) [0.5 on Epop[4]], weight: 4.1363508E-4, delay 1.5
        h("Epop[4] syn_projEE_ampa[4324] = new ampa(0.5)")
        h("Epop[54] netConn_projEE_ampa[4324] = new NetCon(&v(0.5), syn_projEE_ampa[4324], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4325: cell 54, seg 0 (0.5) [0.5 on Epop[54]] -> cell 5, seg 0 (0.5) [0.5 on Epop[5]], weight: 4.1363508E-4, delay 1.5
        h("Epop[5] syn_projEE_ampa[4325] = new ampa(0.5)")
        h("Epop[54] netConn_projEE_ampa[4325] = new NetCon(&v(0.5), syn_projEE_ampa[4325], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4326: cell 54, seg 0 (0.5) [0.5 on Epop[54]] -> cell 6, seg 0 (0.5) [0.5 on Epop[6]], weight: 4.1363508E-4, delay 1.5
        h("Epop[6] syn_projEE_ampa[4326] = new ampa(0.5)")
        h("Epop[54] netConn_projEE_ampa[4326] = new NetCon(&v(0.5), syn_projEE_ampa[4326], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4327: cell 54, seg 0 (0.5) [0.5 on Epop[54]] -> cell 7, seg 0 (0.5) [0.5 on Epop[7]], weight: 4.1363508E-4, delay 1.5
        h("Epop[7] syn_projEE_ampa[4327] = new ampa(0.5)")
        h("Epop[54] netConn_projEE_ampa[4327] = new NetCon(&v(0.5), syn_projEE_ampa[4327], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4328: cell 54, seg 0 (0.5) [0.5 on Epop[54]] -> cell 8, seg 0 (0.5) [0.5 on Epop[8]], weight: 4.1363508E-4, delay 1.5
        h("Epop[8] syn_projEE_ampa[4328] = new ampa(0.5)")
        h("Epop[54] netConn_projEE_ampa[4328] = new NetCon(&v(0.5), syn_projEE_ampa[4328], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4329: cell 54, seg 0 (0.5) [0.5 on Epop[54]] -> cell 9, seg 0 (0.5) [0.5 on Epop[9]], weight: 4.1363508E-4, delay 1.5
        h("Epop[9] syn_projEE_ampa[4329] = new ampa(0.5)")
        h("Epop[54] netConn_projEE_ampa[4329] = new NetCon(&v(0.5), syn_projEE_ampa[4329], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4330: cell 54, seg 0 (0.5) [0.5 on Epop[54]] -> cell 10, seg 0 (0.5) [0.5 on Epop[10]], weight: 4.1363508E-4, delay 1.5
        h("Epop[10] syn_projEE_ampa[4330] = new ampa(0.5)")
        h("Epop[54] netConn_projEE_ampa[4330] = new NetCon(&v(0.5), syn_projEE_ampa[4330], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4331: cell 54, seg 0 (0.5) [0.5 on Epop[54]] -> cell 11, seg 0 (0.5) [0.5 on Epop[11]], weight: 4.1363508E-4, delay 1.5
        h("Epop[11] syn_projEE_ampa[4331] = new ampa(0.5)")
        h("Epop[54] netConn_projEE_ampa[4331] = new NetCon(&v(0.5), syn_projEE_ampa[4331], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4332: cell 54, seg 0 (0.5) [0.5 on Epop[54]] -> cell 12, seg 0 (0.5) [0.5 on Epop[12]], weight: 4.1363508E-4, delay 1.5
        h("Epop[12] syn_projEE_ampa[4332] = new ampa(0.5)")
        h("Epop[54] netConn_projEE_ampa[4332] = new NetCon(&v(0.5), syn_projEE_ampa[4332], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4333: cell 54, seg 0 (0.5) [0.5 on Epop[54]] -> cell 13, seg 0 (0.5) [0.5 on Epop[13]], weight: 4.1363508E-4, delay 1.5
        h("Epop[13] syn_projEE_ampa[4333] = new ampa(0.5)")
        h("Epop[54] netConn_projEE_ampa[4333] = new NetCon(&v(0.5), syn_projEE_ampa[4333], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4334: cell 54, seg 0 (0.5) [0.5 on Epop[54]] -> cell 14, seg 0 (0.5) [0.5 on Epop[14]], weight: 4.1363508E-4, delay 1.5
        h("Epop[14] syn_projEE_ampa[4334] = new ampa(0.5)")
        h("Epop[54] netConn_projEE_ampa[4334] = new NetCon(&v(0.5), syn_projEE_ampa[4334], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4335: cell 54, seg 0 (0.5) [0.5 on Epop[54]] -> cell 15, seg 0 (0.5) [0.5 on Epop[15]], weight: 4.1363508E-4, delay 1.5
        h("Epop[15] syn_projEE_ampa[4335] = new ampa(0.5)")
        h("Epop[54] netConn_projEE_ampa[4335] = new NetCon(&v(0.5), syn_projEE_ampa[4335], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4336: cell 54, seg 0 (0.5) [0.5 on Epop[54]] -> cell 16, seg 0 (0.5) [0.5 on Epop[16]], weight: 4.1363508E-4, delay 1.5
        h("Epop[16] syn_projEE_ampa[4336] = new ampa(0.5)")
        h("Epop[54] netConn_projEE_ampa[4336] = new NetCon(&v(0.5), syn_projEE_ampa[4336], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4337: cell 54, seg 0 (0.5) [0.5 on Epop[54]] -> cell 17, seg 0 (0.5) [0.5 on Epop[17]], weight: 4.1363508E-4, delay 1.5
        h("Epop[17] syn_projEE_ampa[4337] = new ampa(0.5)")
        h("Epop[54] netConn_projEE_ampa[4337] = new NetCon(&v(0.5), syn_projEE_ampa[4337], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4338: cell 54, seg 0 (0.5) [0.5 on Epop[54]] -> cell 18, seg 0 (0.5) [0.5 on Epop[18]], weight: 4.1363508E-4, delay 1.5
        h("Epop[18] syn_projEE_ampa[4338] = new ampa(0.5)")
        h("Epop[54] netConn_projEE_ampa[4338] = new NetCon(&v(0.5), syn_projEE_ampa[4338], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4339: cell 54, seg 0 (0.5) [0.5 on Epop[54]] -> cell 19, seg 0 (0.5) [0.5 on Epop[19]], weight: 4.1363508E-4, delay 1.5
        h("Epop[19] syn_projEE_ampa[4339] = new ampa(0.5)")
        h("Epop[54] netConn_projEE_ampa[4339] = new NetCon(&v(0.5), syn_projEE_ampa[4339], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4340: cell 54, seg 0 (0.5) [0.5 on Epop[54]] -> cell 20, seg 0 (0.5) [0.5 on Epop[20]], weight: 4.1363508E-4, delay 1.5
        h("Epop[20] syn_projEE_ampa[4340] = new ampa(0.5)")
        h("Epop[54] netConn_projEE_ampa[4340] = new NetCon(&v(0.5), syn_projEE_ampa[4340], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4341: cell 54, seg 0 (0.5) [0.5 on Epop[54]] -> cell 21, seg 0 (0.5) [0.5 on Epop[21]], weight: 4.1363508E-4, delay 1.5
        h("Epop[21] syn_projEE_ampa[4341] = new ampa(0.5)")
        h("Epop[54] netConn_projEE_ampa[4341] = new NetCon(&v(0.5), syn_projEE_ampa[4341], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4342: cell 54, seg 0 (0.5) [0.5 on Epop[54]] -> cell 22, seg 0 (0.5) [0.5 on Epop[22]], weight: 4.1363508E-4, delay 1.5
        h("Epop[22] syn_projEE_ampa[4342] = new ampa(0.5)")
        h("Epop[54] netConn_projEE_ampa[4342] = new NetCon(&v(0.5), syn_projEE_ampa[4342], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4343: cell 54, seg 0 (0.5) [0.5 on Epop[54]] -> cell 23, seg 0 (0.5) [0.5 on Epop[23]], weight: 4.1363508E-4, delay 1.5
        h("Epop[23] syn_projEE_ampa[4343] = new ampa(0.5)")
        h("Epop[54] netConn_projEE_ampa[4343] = new NetCon(&v(0.5), syn_projEE_ampa[4343], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4344: cell 54, seg 0 (0.5) [0.5 on Epop[54]] -> cell 24, seg 0 (0.5) [0.5 on Epop[24]], weight: 4.1363508E-4, delay 1.5
        h("Epop[24] syn_projEE_ampa[4344] = new ampa(0.5)")
        h("Epop[54] netConn_projEE_ampa[4344] = new NetCon(&v(0.5), syn_projEE_ampa[4344], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4345: cell 54, seg 0 (0.5) [0.5 on Epop[54]] -> cell 25, seg 0 (0.5) [0.5 on Epop[25]], weight: 4.1363508E-4, delay 1.5
        h("Epop[25] syn_projEE_ampa[4345] = new ampa(0.5)")
        h("Epop[54] netConn_projEE_ampa[4345] = new NetCon(&v(0.5), syn_projEE_ampa[4345], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4346: cell 54, seg 0 (0.5) [0.5 on Epop[54]] -> cell 26, seg 0 (0.5) [0.5 on Epop[26]], weight: 4.1363508E-4, delay 1.5
        h("Epop[26] syn_projEE_ampa[4346] = new ampa(0.5)")
        h("Epop[54] netConn_projEE_ampa[4346] = new NetCon(&v(0.5), syn_projEE_ampa[4346], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4347: cell 54, seg 0 (0.5) [0.5 on Epop[54]] -> cell 27, seg 0 (0.5) [0.5 on Epop[27]], weight: 4.1363508E-4, delay 1.5
        h("Epop[27] syn_projEE_ampa[4347] = new ampa(0.5)")
        h("Epop[54] netConn_projEE_ampa[4347] = new NetCon(&v(0.5), syn_projEE_ampa[4347], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4348: cell 54, seg 0 (0.5) [0.5 on Epop[54]] -> cell 28, seg 0 (0.5) [0.5 on Epop[28]], weight: 4.1363508E-4, delay 1.5
        h("Epop[28] syn_projEE_ampa[4348] = new ampa(0.5)")
        h("Epop[54] netConn_projEE_ampa[4348] = new NetCon(&v(0.5), syn_projEE_ampa[4348], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4349: cell 54, seg 0 (0.5) [0.5 on Epop[54]] -> cell 29, seg 0 (0.5) [0.5 on Epop[29]], weight: 4.1363508E-4, delay 1.5
        h("Epop[29] syn_projEE_ampa[4349] = new ampa(0.5)")
        h("Epop[54] netConn_projEE_ampa[4349] = new NetCon(&v(0.5), syn_projEE_ampa[4349], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4350: cell 54, seg 0 (0.5) [0.5 on Epop[54]] -> cell 30, seg 0 (0.5) [0.5 on Epop[30]], weight: 4.1363508E-4, delay 1.5
        h("Epop[30] syn_projEE_ampa[4350] = new ampa(0.5)")
        h("Epop[54] netConn_projEE_ampa[4350] = new NetCon(&v(0.5), syn_projEE_ampa[4350], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4351: cell 54, seg 0 (0.5) [0.5 on Epop[54]] -> cell 31, seg 0 (0.5) [0.5 on Epop[31]], weight: 4.1363508E-4, delay 1.5
        h("Epop[31] syn_projEE_ampa[4351] = new ampa(0.5)")
        h("Epop[54] netConn_projEE_ampa[4351] = new NetCon(&v(0.5), syn_projEE_ampa[4351], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4352: cell 54, seg 0 (0.5) [0.5 on Epop[54]] -> cell 32, seg 0 (0.5) [0.5 on Epop[32]], weight: 4.1363508E-4, delay 1.5
        h("Epop[32] syn_projEE_ampa[4352] = new ampa(0.5)")
        h("Epop[54] netConn_projEE_ampa[4352] = new NetCon(&v(0.5), syn_projEE_ampa[4352], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4353: cell 54, seg 0 (0.5) [0.5 on Epop[54]] -> cell 33, seg 0 (0.5) [0.5 on Epop[33]], weight: 4.1363508E-4, delay 1.5
        h("Epop[33] syn_projEE_ampa[4353] = new ampa(0.5)")
        h("Epop[54] netConn_projEE_ampa[4353] = new NetCon(&v(0.5), syn_projEE_ampa[4353], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4354: cell 54, seg 0 (0.5) [0.5 on Epop[54]] -> cell 34, seg 0 (0.5) [0.5 on Epop[34]], weight: 4.1363508E-4, delay 1.5
        h("Epop[34] syn_projEE_ampa[4354] = new ampa(0.5)")
        h("Epop[54] netConn_projEE_ampa[4354] = new NetCon(&v(0.5), syn_projEE_ampa[4354], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4355: cell 54, seg 0 (0.5) [0.5 on Epop[54]] -> cell 35, seg 0 (0.5) [0.5 on Epop[35]], weight: 4.1363508E-4, delay 1.5
        h("Epop[35] syn_projEE_ampa[4355] = new ampa(0.5)")
        h("Epop[54] netConn_projEE_ampa[4355] = new NetCon(&v(0.5), syn_projEE_ampa[4355], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4356: cell 54, seg 0 (0.5) [0.5 on Epop[54]] -> cell 36, seg 0 (0.5) [0.5 on Epop[36]], weight: 4.1363508E-4, delay 1.5
        h("Epop[36] syn_projEE_ampa[4356] = new ampa(0.5)")
        h("Epop[54] netConn_projEE_ampa[4356] = new NetCon(&v(0.5), syn_projEE_ampa[4356], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4357: cell 54, seg 0 (0.5) [0.5 on Epop[54]] -> cell 37, seg 0 (0.5) [0.5 on Epop[37]], weight: 4.1363508E-4, delay 1.5
        h("Epop[37] syn_projEE_ampa[4357] = new ampa(0.5)")
        h("Epop[54] netConn_projEE_ampa[4357] = new NetCon(&v(0.5), syn_projEE_ampa[4357], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4358: cell 54, seg 0 (0.5) [0.5 on Epop[54]] -> cell 38, seg 0 (0.5) [0.5 on Epop[38]], weight: 4.1363508E-4, delay 1.5
        h("Epop[38] syn_projEE_ampa[4358] = new ampa(0.5)")
        h("Epop[54] netConn_projEE_ampa[4358] = new NetCon(&v(0.5), syn_projEE_ampa[4358], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4359: cell 54, seg 0 (0.5) [0.5 on Epop[54]] -> cell 39, seg 0 (0.5) [0.5 on Epop[39]], weight: 4.1363508E-4, delay 1.5
        h("Epop[39] syn_projEE_ampa[4359] = new ampa(0.5)")
        h("Epop[54] netConn_projEE_ampa[4359] = new NetCon(&v(0.5), syn_projEE_ampa[4359], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4360: cell 54, seg 0 (0.5) [0.5 on Epop[54]] -> cell 40, seg 0 (0.5) [0.5 on Epop[40]], weight: 4.1363508E-4, delay 1.5
        h("Epop[40] syn_projEE_ampa[4360] = new ampa(0.5)")
        h("Epop[54] netConn_projEE_ampa[4360] = new NetCon(&v(0.5), syn_projEE_ampa[4360], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4361: cell 54, seg 0 (0.5) [0.5 on Epop[54]] -> cell 41, seg 0 (0.5) [0.5 on Epop[41]], weight: 4.1363508E-4, delay 1.5
        h("Epop[41] syn_projEE_ampa[4361] = new ampa(0.5)")
        h("Epop[54] netConn_projEE_ampa[4361] = new NetCon(&v(0.5), syn_projEE_ampa[4361], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4362: cell 54, seg 0 (0.5) [0.5 on Epop[54]] -> cell 42, seg 0 (0.5) [0.5 on Epop[42]], weight: 4.1363508E-4, delay 1.5
        h("Epop[42] syn_projEE_ampa[4362] = new ampa(0.5)")
        h("Epop[54] netConn_projEE_ampa[4362] = new NetCon(&v(0.5), syn_projEE_ampa[4362], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4363: cell 54, seg 0 (0.5) [0.5 on Epop[54]] -> cell 43, seg 0 (0.5) [0.5 on Epop[43]], weight: 4.1363508E-4, delay 1.5
        h("Epop[43] syn_projEE_ampa[4363] = new ampa(0.5)")
        h("Epop[54] netConn_projEE_ampa[4363] = new NetCon(&v(0.5), syn_projEE_ampa[4363], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4364: cell 54, seg 0 (0.5) [0.5 on Epop[54]] -> cell 44, seg 0 (0.5) [0.5 on Epop[44]], weight: 4.1363508E-4, delay 1.5
        h("Epop[44] syn_projEE_ampa[4364] = new ampa(0.5)")
        h("Epop[54] netConn_projEE_ampa[4364] = new NetCon(&v(0.5), syn_projEE_ampa[4364], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4365: cell 54, seg 0 (0.5) [0.5 on Epop[54]] -> cell 45, seg 0 (0.5) [0.5 on Epop[45]], weight: 4.1363508E-4, delay 1.5
        h("Epop[45] syn_projEE_ampa[4365] = new ampa(0.5)")
        h("Epop[54] netConn_projEE_ampa[4365] = new NetCon(&v(0.5), syn_projEE_ampa[4365], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4366: cell 54, seg 0 (0.5) [0.5 on Epop[54]] -> cell 46, seg 0 (0.5) [0.5 on Epop[46]], weight: 4.1363508E-4, delay 1.5
        h("Epop[46] syn_projEE_ampa[4366] = new ampa(0.5)")
        h("Epop[54] netConn_projEE_ampa[4366] = new NetCon(&v(0.5), syn_projEE_ampa[4366], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4367: cell 54, seg 0 (0.5) [0.5 on Epop[54]] -> cell 47, seg 0 (0.5) [0.5 on Epop[47]], weight: 4.1363508E-4, delay 1.5
        h("Epop[47] syn_projEE_ampa[4367] = new ampa(0.5)")
        h("Epop[54] netConn_projEE_ampa[4367] = new NetCon(&v(0.5), syn_projEE_ampa[4367], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4368: cell 54, seg 0 (0.5) [0.5 on Epop[54]] -> cell 48, seg 0 (0.5) [0.5 on Epop[48]], weight: 4.1363508E-4, delay 1.5
        h("Epop[48] syn_projEE_ampa[4368] = new ampa(0.5)")
        h("Epop[54] netConn_projEE_ampa[4368] = new NetCon(&v(0.5), syn_projEE_ampa[4368], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4369: cell 54, seg 0 (0.5) [0.5 on Epop[54]] -> cell 49, seg 0 (0.5) [0.5 on Epop[49]], weight: 4.1363508E-4, delay 1.5
        h("Epop[49] syn_projEE_ampa[4369] = new ampa(0.5)")
        h("Epop[54] netConn_projEE_ampa[4369] = new NetCon(&v(0.5), syn_projEE_ampa[4369], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4370: cell 54, seg 0 (0.5) [0.5 on Epop[54]] -> cell 50, seg 0 (0.5) [0.5 on Epop[50]], weight: 4.1363508E-4, delay 1.5
        h("Epop[50] syn_projEE_ampa[4370] = new ampa(0.5)")
        h("Epop[54] netConn_projEE_ampa[4370] = new NetCon(&v(0.5), syn_projEE_ampa[4370], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4371: cell 54, seg 0 (0.5) [0.5 on Epop[54]] -> cell 51, seg 0 (0.5) [0.5 on Epop[51]], weight: 4.1363508E-4, delay 1.5
        h("Epop[51] syn_projEE_ampa[4371] = new ampa(0.5)")
        h("Epop[54] netConn_projEE_ampa[4371] = new NetCon(&v(0.5), syn_projEE_ampa[4371], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4372: cell 54, seg 0 (0.5) [0.5 on Epop[54]] -> cell 52, seg 0 (0.5) [0.5 on Epop[52]], weight: 4.1363508E-4, delay 1.5
        h("Epop[52] syn_projEE_ampa[4372] = new ampa(0.5)")
        h("Epop[54] netConn_projEE_ampa[4372] = new NetCon(&v(0.5), syn_projEE_ampa[4372], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4373: cell 54, seg 0 (0.5) [0.5 on Epop[54]] -> cell 53, seg 0 (0.5) [0.5 on Epop[53]], weight: 4.1363508E-4, delay 1.5
        h("Epop[53] syn_projEE_ampa[4373] = new ampa(0.5)")
        h("Epop[54] netConn_projEE_ampa[4373] = new NetCon(&v(0.5), syn_projEE_ampa[4373], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4374: cell 54, seg 0 (0.5) [0.5 on Epop[54]] -> cell 54, seg 0 (0.5) [0.5 on Epop[54]], weight: 4.1363508E-4, delay 1.5
        h("Epop[54] syn_projEE_ampa[4374] = new ampa(0.5)")
        h("Epop[54] netConn_projEE_ampa[4374] = new NetCon(&v(0.5), syn_projEE_ampa[4374], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4375: cell 54, seg 0 (0.5) [0.5 on Epop[54]] -> cell 55, seg 0 (0.5) [0.5 on Epop[55]], weight: 4.1363508E-4, delay 1.5
        h("Epop[55] syn_projEE_ampa[4375] = new ampa(0.5)")
        h("Epop[54] netConn_projEE_ampa[4375] = new NetCon(&v(0.5), syn_projEE_ampa[4375], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4376: cell 54, seg 0 (0.5) [0.5 on Epop[54]] -> cell 56, seg 0 (0.5) [0.5 on Epop[56]], weight: 4.1363508E-4, delay 1.5
        h("Epop[56] syn_projEE_ampa[4376] = new ampa(0.5)")
        h("Epop[54] netConn_projEE_ampa[4376] = new NetCon(&v(0.5), syn_projEE_ampa[4376], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4377: cell 54, seg 0 (0.5) [0.5 on Epop[54]] -> cell 57, seg 0 (0.5) [0.5 on Epop[57]], weight: 4.1363508E-4, delay 1.5
        h("Epop[57] syn_projEE_ampa[4377] = new ampa(0.5)")
        h("Epop[54] netConn_projEE_ampa[4377] = new NetCon(&v(0.5), syn_projEE_ampa[4377], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4378: cell 54, seg 0 (0.5) [0.5 on Epop[54]] -> cell 58, seg 0 (0.5) [0.5 on Epop[58]], weight: 4.1363508E-4, delay 1.5
        h("Epop[58] syn_projEE_ampa[4378] = new ampa(0.5)")
        h("Epop[54] netConn_projEE_ampa[4378] = new NetCon(&v(0.5), syn_projEE_ampa[4378], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4379: cell 54, seg 0 (0.5) [0.5 on Epop[54]] -> cell 59, seg 0 (0.5) [0.5 on Epop[59]], weight: 4.1363508E-4, delay 1.5
        h("Epop[59] syn_projEE_ampa[4379] = new ampa(0.5)")
        h("Epop[54] netConn_projEE_ampa[4379] = new NetCon(&v(0.5), syn_projEE_ampa[4379], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4380: cell 54, seg 0 (0.5) [0.5 on Epop[54]] -> cell 60, seg 0 (0.5) [0.5 on Epop[60]], weight: 4.1363508E-4, delay 1.5
        h("Epop[60] syn_projEE_ampa[4380] = new ampa(0.5)")
        h("Epop[54] netConn_projEE_ampa[4380] = new NetCon(&v(0.5), syn_projEE_ampa[4380], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4381: cell 54, seg 0 (0.5) [0.5 on Epop[54]] -> cell 61, seg 0 (0.5) [0.5 on Epop[61]], weight: 4.1363508E-4, delay 1.5
        h("Epop[61] syn_projEE_ampa[4381] = new ampa(0.5)")
        h("Epop[54] netConn_projEE_ampa[4381] = new NetCon(&v(0.5), syn_projEE_ampa[4381], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4382: cell 54, seg 0 (0.5) [0.5 on Epop[54]] -> cell 62, seg 0 (0.5) [0.5 on Epop[62]], weight: 4.1363508E-4, delay 1.5
        h("Epop[62] syn_projEE_ampa[4382] = new ampa(0.5)")
        h("Epop[54] netConn_projEE_ampa[4382] = new NetCon(&v(0.5), syn_projEE_ampa[4382], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4383: cell 54, seg 0 (0.5) [0.5 on Epop[54]] -> cell 63, seg 0 (0.5) [0.5 on Epop[63]], weight: 4.1363508E-4, delay 1.5
        h("Epop[63] syn_projEE_ampa[4383] = new ampa(0.5)")
        h("Epop[54] netConn_projEE_ampa[4383] = new NetCon(&v(0.5), syn_projEE_ampa[4383], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4384: cell 54, seg 0 (0.5) [0.5 on Epop[54]] -> cell 64, seg 0 (0.5) [0.5 on Epop[64]], weight: 4.1363508E-4, delay 1.5
        h("Epop[64] syn_projEE_ampa[4384] = new ampa(0.5)")
        h("Epop[54] netConn_projEE_ampa[4384] = new NetCon(&v(0.5), syn_projEE_ampa[4384], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4385: cell 54, seg 0 (0.5) [0.5 on Epop[54]] -> cell 65, seg 0 (0.5) [0.5 on Epop[65]], weight: 4.1363508E-4, delay 1.5
        h("Epop[65] syn_projEE_ampa[4385] = new ampa(0.5)")
        h("Epop[54] netConn_projEE_ampa[4385] = new NetCon(&v(0.5), syn_projEE_ampa[4385], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4386: cell 54, seg 0 (0.5) [0.5 on Epop[54]] -> cell 66, seg 0 (0.5) [0.5 on Epop[66]], weight: 4.1363508E-4, delay 1.5
        h("Epop[66] syn_projEE_ampa[4386] = new ampa(0.5)")
        h("Epop[54] netConn_projEE_ampa[4386] = new NetCon(&v(0.5), syn_projEE_ampa[4386], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4387: cell 54, seg 0 (0.5) [0.5 on Epop[54]] -> cell 67, seg 0 (0.5) [0.5 on Epop[67]], weight: 4.1363508E-4, delay 1.5
        h("Epop[67] syn_projEE_ampa[4387] = new ampa(0.5)")
        h("Epop[54] netConn_projEE_ampa[4387] = new NetCon(&v(0.5), syn_projEE_ampa[4387], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4388: cell 54, seg 0 (0.5) [0.5 on Epop[54]] -> cell 68, seg 0 (0.5) [0.5 on Epop[68]], weight: 4.1363508E-4, delay 1.5
        h("Epop[68] syn_projEE_ampa[4388] = new ampa(0.5)")
        h("Epop[54] netConn_projEE_ampa[4388] = new NetCon(&v(0.5), syn_projEE_ampa[4388], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4389: cell 54, seg 0 (0.5) [0.5 on Epop[54]] -> cell 69, seg 0 (0.5) [0.5 on Epop[69]], weight: 4.1363508E-4, delay 1.5
        h("Epop[69] syn_projEE_ampa[4389] = new ampa(0.5)")
        h("Epop[54] netConn_projEE_ampa[4389] = new NetCon(&v(0.5), syn_projEE_ampa[4389], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4390: cell 54, seg 0 (0.5) [0.5 on Epop[54]] -> cell 70, seg 0 (0.5) [0.5 on Epop[70]], weight: 4.1363508E-4, delay 1.5
        h("Epop[70] syn_projEE_ampa[4390] = new ampa(0.5)")
        h("Epop[54] netConn_projEE_ampa[4390] = new NetCon(&v(0.5), syn_projEE_ampa[4390], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4391: cell 54, seg 0 (0.5) [0.5 on Epop[54]] -> cell 71, seg 0 (0.5) [0.5 on Epop[71]], weight: 4.1363508E-4, delay 1.5
        h("Epop[71] syn_projEE_ampa[4391] = new ampa(0.5)")
        h("Epop[54] netConn_projEE_ampa[4391] = new NetCon(&v(0.5), syn_projEE_ampa[4391], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4392: cell 54, seg 0 (0.5) [0.5 on Epop[54]] -> cell 72, seg 0 (0.5) [0.5 on Epop[72]], weight: 4.1363508E-4, delay 1.5
        h("Epop[72] syn_projEE_ampa[4392] = new ampa(0.5)")
        h("Epop[54] netConn_projEE_ampa[4392] = new NetCon(&v(0.5), syn_projEE_ampa[4392], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4393: cell 54, seg 0 (0.5) [0.5 on Epop[54]] -> cell 73, seg 0 (0.5) [0.5 on Epop[73]], weight: 4.1363508E-4, delay 1.5
        h("Epop[73] syn_projEE_ampa[4393] = new ampa(0.5)")
        h("Epop[54] netConn_projEE_ampa[4393] = new NetCon(&v(0.5), syn_projEE_ampa[4393], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4394: cell 54, seg 0 (0.5) [0.5 on Epop[54]] -> cell 74, seg 0 (0.5) [0.5 on Epop[74]], weight: 4.1363508E-4, delay 1.5
        h("Epop[74] syn_projEE_ampa[4394] = new ampa(0.5)")
        h("Epop[54] netConn_projEE_ampa[4394] = new NetCon(&v(0.5), syn_projEE_ampa[4394], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4395: cell 54, seg 0 (0.5) [0.5 on Epop[54]] -> cell 75, seg 0 (0.5) [0.5 on Epop[75]], weight: 4.1363508E-4, delay 1.5
        h("Epop[75] syn_projEE_ampa[4395] = new ampa(0.5)")
        h("Epop[54] netConn_projEE_ampa[4395] = new NetCon(&v(0.5), syn_projEE_ampa[4395], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4396: cell 54, seg 0 (0.5) [0.5 on Epop[54]] -> cell 76, seg 0 (0.5) [0.5 on Epop[76]], weight: 4.1363508E-4, delay 1.5
        h("Epop[76] syn_projEE_ampa[4396] = new ampa(0.5)")
        h("Epop[54] netConn_projEE_ampa[4396] = new NetCon(&v(0.5), syn_projEE_ampa[4396], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4397: cell 54, seg 0 (0.5) [0.5 on Epop[54]] -> cell 77, seg 0 (0.5) [0.5 on Epop[77]], weight: 4.1363508E-4, delay 1.5
        h("Epop[77] syn_projEE_ampa[4397] = new ampa(0.5)")
        h("Epop[54] netConn_projEE_ampa[4397] = new NetCon(&v(0.5), syn_projEE_ampa[4397], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4398: cell 54, seg 0 (0.5) [0.5 on Epop[54]] -> cell 78, seg 0 (0.5) [0.5 on Epop[78]], weight: 4.1363508E-4, delay 1.5
        h("Epop[78] syn_projEE_ampa[4398] = new ampa(0.5)")
        h("Epop[54] netConn_projEE_ampa[4398] = new NetCon(&v(0.5), syn_projEE_ampa[4398], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4399: cell 54, seg 0 (0.5) [0.5 on Epop[54]] -> cell 79, seg 0 (0.5) [0.5 on Epop[79]], weight: 4.1363508E-4, delay 1.5
        h("Epop[79] syn_projEE_ampa[4399] = new ampa(0.5)")
        h("Epop[54] netConn_projEE_ampa[4399] = new NetCon(&v(0.5), syn_projEE_ampa[4399], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4400: cell 55, seg 0 (0.5) [0.5 on Epop[55]] -> cell 0, seg 0 (0.5) [0.5 on Epop[0]], weight: 4.1363508E-4, delay 1.5
        h("Epop[0] syn_projEE_ampa[4400] = new ampa(0.5)")
        h("Epop[55] netConn_projEE_ampa[4400] = new NetCon(&v(0.5), syn_projEE_ampa[4400], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4401: cell 55, seg 0 (0.5) [0.5 on Epop[55]] -> cell 1, seg 0 (0.5) [0.5 on Epop[1]], weight: 4.1363508E-4, delay 1.5
        h("Epop[1] syn_projEE_ampa[4401] = new ampa(0.5)")
        h("Epop[55] netConn_projEE_ampa[4401] = new NetCon(&v(0.5), syn_projEE_ampa[4401], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4402: cell 55, seg 0 (0.5) [0.5 on Epop[55]] -> cell 2, seg 0 (0.5) [0.5 on Epop[2]], weight: 4.1363508E-4, delay 1.5
        h("Epop[2] syn_projEE_ampa[4402] = new ampa(0.5)")
        h("Epop[55] netConn_projEE_ampa[4402] = new NetCon(&v(0.5), syn_projEE_ampa[4402], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4403: cell 55, seg 0 (0.5) [0.5 on Epop[55]] -> cell 3, seg 0 (0.5) [0.5 on Epop[3]], weight: 4.1363508E-4, delay 1.5
        h("Epop[3] syn_projEE_ampa[4403] = new ampa(0.5)")
        h("Epop[55] netConn_projEE_ampa[4403] = new NetCon(&v(0.5), syn_projEE_ampa[4403], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4404: cell 55, seg 0 (0.5) [0.5 on Epop[55]] -> cell 4, seg 0 (0.5) [0.5 on Epop[4]], weight: 4.1363508E-4, delay 1.5
        h("Epop[4] syn_projEE_ampa[4404] = new ampa(0.5)")
        h("Epop[55] netConn_projEE_ampa[4404] = new NetCon(&v(0.5), syn_projEE_ampa[4404], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4405: cell 55, seg 0 (0.5) [0.5 on Epop[55]] -> cell 5, seg 0 (0.5) [0.5 on Epop[5]], weight: 4.1363508E-4, delay 1.5
        h("Epop[5] syn_projEE_ampa[4405] = new ampa(0.5)")
        h("Epop[55] netConn_projEE_ampa[4405] = new NetCon(&v(0.5), syn_projEE_ampa[4405], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4406: cell 55, seg 0 (0.5) [0.5 on Epop[55]] -> cell 6, seg 0 (0.5) [0.5 on Epop[6]], weight: 4.1363508E-4, delay 1.5
        h("Epop[6] syn_projEE_ampa[4406] = new ampa(0.5)")
        h("Epop[55] netConn_projEE_ampa[4406] = new NetCon(&v(0.5), syn_projEE_ampa[4406], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4407: cell 55, seg 0 (0.5) [0.5 on Epop[55]] -> cell 7, seg 0 (0.5) [0.5 on Epop[7]], weight: 4.1363508E-4, delay 1.5
        h("Epop[7] syn_projEE_ampa[4407] = new ampa(0.5)")
        h("Epop[55] netConn_projEE_ampa[4407] = new NetCon(&v(0.5), syn_projEE_ampa[4407], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4408: cell 55, seg 0 (0.5) [0.5 on Epop[55]] -> cell 8, seg 0 (0.5) [0.5 on Epop[8]], weight: 4.1363508E-4, delay 1.5
        h("Epop[8] syn_projEE_ampa[4408] = new ampa(0.5)")
        h("Epop[55] netConn_projEE_ampa[4408] = new NetCon(&v(0.5), syn_projEE_ampa[4408], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4409: cell 55, seg 0 (0.5) [0.5 on Epop[55]] -> cell 9, seg 0 (0.5) [0.5 on Epop[9]], weight: 4.1363508E-4, delay 1.5
        h("Epop[9] syn_projEE_ampa[4409] = new ampa(0.5)")
        h("Epop[55] netConn_projEE_ampa[4409] = new NetCon(&v(0.5), syn_projEE_ampa[4409], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4410: cell 55, seg 0 (0.5) [0.5 on Epop[55]] -> cell 10, seg 0 (0.5) [0.5 on Epop[10]], weight: 4.1363508E-4, delay 1.5
        h("Epop[10] syn_projEE_ampa[4410] = new ampa(0.5)")
        h("Epop[55] netConn_projEE_ampa[4410] = new NetCon(&v(0.5), syn_projEE_ampa[4410], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4411: cell 55, seg 0 (0.5) [0.5 on Epop[55]] -> cell 11, seg 0 (0.5) [0.5 on Epop[11]], weight: 4.1363508E-4, delay 1.5
        h("Epop[11] syn_projEE_ampa[4411] = new ampa(0.5)")
        h("Epop[55] netConn_projEE_ampa[4411] = new NetCon(&v(0.5), syn_projEE_ampa[4411], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4412: cell 55, seg 0 (0.5) [0.5 on Epop[55]] -> cell 12, seg 0 (0.5) [0.5 on Epop[12]], weight: 4.1363508E-4, delay 1.5
        h("Epop[12] syn_projEE_ampa[4412] = new ampa(0.5)")
        h("Epop[55] netConn_projEE_ampa[4412] = new NetCon(&v(0.5), syn_projEE_ampa[4412], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4413: cell 55, seg 0 (0.5) [0.5 on Epop[55]] -> cell 13, seg 0 (0.5) [0.5 on Epop[13]], weight: 4.1363508E-4, delay 1.5
        h("Epop[13] syn_projEE_ampa[4413] = new ampa(0.5)")
        h("Epop[55] netConn_projEE_ampa[4413] = new NetCon(&v(0.5), syn_projEE_ampa[4413], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4414: cell 55, seg 0 (0.5) [0.5 on Epop[55]] -> cell 14, seg 0 (0.5) [0.5 on Epop[14]], weight: 4.1363508E-4, delay 1.5
        h("Epop[14] syn_projEE_ampa[4414] = new ampa(0.5)")
        h("Epop[55] netConn_projEE_ampa[4414] = new NetCon(&v(0.5), syn_projEE_ampa[4414], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4415: cell 55, seg 0 (0.5) [0.5 on Epop[55]] -> cell 15, seg 0 (0.5) [0.5 on Epop[15]], weight: 4.1363508E-4, delay 1.5
        h("Epop[15] syn_projEE_ampa[4415] = new ampa(0.5)")
        h("Epop[55] netConn_projEE_ampa[4415] = new NetCon(&v(0.5), syn_projEE_ampa[4415], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4416: cell 55, seg 0 (0.5) [0.5 on Epop[55]] -> cell 16, seg 0 (0.5) [0.5 on Epop[16]], weight: 4.1363508E-4, delay 1.5
        h("Epop[16] syn_projEE_ampa[4416] = new ampa(0.5)")
        h("Epop[55] netConn_projEE_ampa[4416] = new NetCon(&v(0.5), syn_projEE_ampa[4416], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4417: cell 55, seg 0 (0.5) [0.5 on Epop[55]] -> cell 17, seg 0 (0.5) [0.5 on Epop[17]], weight: 4.1363508E-4, delay 1.5
        h("Epop[17] syn_projEE_ampa[4417] = new ampa(0.5)")
        h("Epop[55] netConn_projEE_ampa[4417] = new NetCon(&v(0.5), syn_projEE_ampa[4417], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4418: cell 55, seg 0 (0.5) [0.5 on Epop[55]] -> cell 18, seg 0 (0.5) [0.5 on Epop[18]], weight: 4.1363508E-4, delay 1.5
        h("Epop[18] syn_projEE_ampa[4418] = new ampa(0.5)")
        h("Epop[55] netConn_projEE_ampa[4418] = new NetCon(&v(0.5), syn_projEE_ampa[4418], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4419: cell 55, seg 0 (0.5) [0.5 on Epop[55]] -> cell 19, seg 0 (0.5) [0.5 on Epop[19]], weight: 4.1363508E-4, delay 1.5
        h("Epop[19] syn_projEE_ampa[4419] = new ampa(0.5)")
        h("Epop[55] netConn_projEE_ampa[4419] = new NetCon(&v(0.5), syn_projEE_ampa[4419], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4420: cell 55, seg 0 (0.5) [0.5 on Epop[55]] -> cell 20, seg 0 (0.5) [0.5 on Epop[20]], weight: 4.1363508E-4, delay 1.5
        h("Epop[20] syn_projEE_ampa[4420] = new ampa(0.5)")
        h("Epop[55] netConn_projEE_ampa[4420] = new NetCon(&v(0.5), syn_projEE_ampa[4420], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4421: cell 55, seg 0 (0.5) [0.5 on Epop[55]] -> cell 21, seg 0 (0.5) [0.5 on Epop[21]], weight: 4.1363508E-4, delay 1.5
        h("Epop[21] syn_projEE_ampa[4421] = new ampa(0.5)")
        h("Epop[55] netConn_projEE_ampa[4421] = new NetCon(&v(0.5), syn_projEE_ampa[4421], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4422: cell 55, seg 0 (0.5) [0.5 on Epop[55]] -> cell 22, seg 0 (0.5) [0.5 on Epop[22]], weight: 4.1363508E-4, delay 1.5
        h("Epop[22] syn_projEE_ampa[4422] = new ampa(0.5)")
        h("Epop[55] netConn_projEE_ampa[4422] = new NetCon(&v(0.5), syn_projEE_ampa[4422], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4423: cell 55, seg 0 (0.5) [0.5 on Epop[55]] -> cell 23, seg 0 (0.5) [0.5 on Epop[23]], weight: 4.1363508E-4, delay 1.5
        h("Epop[23] syn_projEE_ampa[4423] = new ampa(0.5)")
        h("Epop[55] netConn_projEE_ampa[4423] = new NetCon(&v(0.5), syn_projEE_ampa[4423], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4424: cell 55, seg 0 (0.5) [0.5 on Epop[55]] -> cell 24, seg 0 (0.5) [0.5 on Epop[24]], weight: 4.1363508E-4, delay 1.5
        h("Epop[24] syn_projEE_ampa[4424] = new ampa(0.5)")
        h("Epop[55] netConn_projEE_ampa[4424] = new NetCon(&v(0.5), syn_projEE_ampa[4424], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4425: cell 55, seg 0 (0.5) [0.5 on Epop[55]] -> cell 25, seg 0 (0.5) [0.5 on Epop[25]], weight: 4.1363508E-4, delay 1.5
        h("Epop[25] syn_projEE_ampa[4425] = new ampa(0.5)")
        h("Epop[55] netConn_projEE_ampa[4425] = new NetCon(&v(0.5), syn_projEE_ampa[4425], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4426: cell 55, seg 0 (0.5) [0.5 on Epop[55]] -> cell 26, seg 0 (0.5) [0.5 on Epop[26]], weight: 4.1363508E-4, delay 1.5
        h("Epop[26] syn_projEE_ampa[4426] = new ampa(0.5)")
        h("Epop[55] netConn_projEE_ampa[4426] = new NetCon(&v(0.5), syn_projEE_ampa[4426], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4427: cell 55, seg 0 (0.5) [0.5 on Epop[55]] -> cell 27, seg 0 (0.5) [0.5 on Epop[27]], weight: 4.1363508E-4, delay 1.5
        h("Epop[27] syn_projEE_ampa[4427] = new ampa(0.5)")
        h("Epop[55] netConn_projEE_ampa[4427] = new NetCon(&v(0.5), syn_projEE_ampa[4427], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4428: cell 55, seg 0 (0.5) [0.5 on Epop[55]] -> cell 28, seg 0 (0.5) [0.5 on Epop[28]], weight: 4.1363508E-4, delay 1.5
        h("Epop[28] syn_projEE_ampa[4428] = new ampa(0.5)")
        h("Epop[55] netConn_projEE_ampa[4428] = new NetCon(&v(0.5), syn_projEE_ampa[4428], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4429: cell 55, seg 0 (0.5) [0.5 on Epop[55]] -> cell 29, seg 0 (0.5) [0.5 on Epop[29]], weight: 4.1363508E-4, delay 1.5
        h("Epop[29] syn_projEE_ampa[4429] = new ampa(0.5)")
        h("Epop[55] netConn_projEE_ampa[4429] = new NetCon(&v(0.5), syn_projEE_ampa[4429], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4430: cell 55, seg 0 (0.5) [0.5 on Epop[55]] -> cell 30, seg 0 (0.5) [0.5 on Epop[30]], weight: 4.1363508E-4, delay 1.5
        h("Epop[30] syn_projEE_ampa[4430] = new ampa(0.5)")
        h("Epop[55] netConn_projEE_ampa[4430] = new NetCon(&v(0.5), syn_projEE_ampa[4430], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4431: cell 55, seg 0 (0.5) [0.5 on Epop[55]] -> cell 31, seg 0 (0.5) [0.5 on Epop[31]], weight: 4.1363508E-4, delay 1.5
        h("Epop[31] syn_projEE_ampa[4431] = new ampa(0.5)")
        h("Epop[55] netConn_projEE_ampa[4431] = new NetCon(&v(0.5), syn_projEE_ampa[4431], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4432: cell 55, seg 0 (0.5) [0.5 on Epop[55]] -> cell 32, seg 0 (0.5) [0.5 on Epop[32]], weight: 4.1363508E-4, delay 1.5
        h("Epop[32] syn_projEE_ampa[4432] = new ampa(0.5)")
        h("Epop[55] netConn_projEE_ampa[4432] = new NetCon(&v(0.5), syn_projEE_ampa[4432], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4433: cell 55, seg 0 (0.5) [0.5 on Epop[55]] -> cell 33, seg 0 (0.5) [0.5 on Epop[33]], weight: 4.1363508E-4, delay 1.5
        h("Epop[33] syn_projEE_ampa[4433] = new ampa(0.5)")
        h("Epop[55] netConn_projEE_ampa[4433] = new NetCon(&v(0.5), syn_projEE_ampa[4433], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4434: cell 55, seg 0 (0.5) [0.5 on Epop[55]] -> cell 34, seg 0 (0.5) [0.5 on Epop[34]], weight: 4.1363508E-4, delay 1.5
        h("Epop[34] syn_projEE_ampa[4434] = new ampa(0.5)")
        h("Epop[55] netConn_projEE_ampa[4434] = new NetCon(&v(0.5), syn_projEE_ampa[4434], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4435: cell 55, seg 0 (0.5) [0.5 on Epop[55]] -> cell 35, seg 0 (0.5) [0.5 on Epop[35]], weight: 4.1363508E-4, delay 1.5
        h("Epop[35] syn_projEE_ampa[4435] = new ampa(0.5)")
        h("Epop[55] netConn_projEE_ampa[4435] = new NetCon(&v(0.5), syn_projEE_ampa[4435], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4436: cell 55, seg 0 (0.5) [0.5 on Epop[55]] -> cell 36, seg 0 (0.5) [0.5 on Epop[36]], weight: 4.1363508E-4, delay 1.5
        h("Epop[36] syn_projEE_ampa[4436] = new ampa(0.5)")
        h("Epop[55] netConn_projEE_ampa[4436] = new NetCon(&v(0.5), syn_projEE_ampa[4436], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4437: cell 55, seg 0 (0.5) [0.5 on Epop[55]] -> cell 37, seg 0 (0.5) [0.5 on Epop[37]], weight: 4.1363508E-4, delay 1.5
        h("Epop[37] syn_projEE_ampa[4437] = new ampa(0.5)")
        h("Epop[55] netConn_projEE_ampa[4437] = new NetCon(&v(0.5), syn_projEE_ampa[4437], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4438: cell 55, seg 0 (0.5) [0.5 on Epop[55]] -> cell 38, seg 0 (0.5) [0.5 on Epop[38]], weight: 4.1363508E-4, delay 1.5
        h("Epop[38] syn_projEE_ampa[4438] = new ampa(0.5)")
        h("Epop[55] netConn_projEE_ampa[4438] = new NetCon(&v(0.5), syn_projEE_ampa[4438], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4439: cell 55, seg 0 (0.5) [0.5 on Epop[55]] -> cell 39, seg 0 (0.5) [0.5 on Epop[39]], weight: 4.1363508E-4, delay 1.5
        h("Epop[39] syn_projEE_ampa[4439] = new ampa(0.5)")
        h("Epop[55] netConn_projEE_ampa[4439] = new NetCon(&v(0.5), syn_projEE_ampa[4439], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4440: cell 55, seg 0 (0.5) [0.5 on Epop[55]] -> cell 40, seg 0 (0.5) [0.5 on Epop[40]], weight: 4.1363508E-4, delay 1.5
        h("Epop[40] syn_projEE_ampa[4440] = new ampa(0.5)")
        h("Epop[55] netConn_projEE_ampa[4440] = new NetCon(&v(0.5), syn_projEE_ampa[4440], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4441: cell 55, seg 0 (0.5) [0.5 on Epop[55]] -> cell 41, seg 0 (0.5) [0.5 on Epop[41]], weight: 4.1363508E-4, delay 1.5
        h("Epop[41] syn_projEE_ampa[4441] = new ampa(0.5)")
        h("Epop[55] netConn_projEE_ampa[4441] = new NetCon(&v(0.5), syn_projEE_ampa[4441], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4442: cell 55, seg 0 (0.5) [0.5 on Epop[55]] -> cell 42, seg 0 (0.5) [0.5 on Epop[42]], weight: 4.1363508E-4, delay 1.5
        h("Epop[42] syn_projEE_ampa[4442] = new ampa(0.5)")
        h("Epop[55] netConn_projEE_ampa[4442] = new NetCon(&v(0.5), syn_projEE_ampa[4442], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4443: cell 55, seg 0 (0.5) [0.5 on Epop[55]] -> cell 43, seg 0 (0.5) [0.5 on Epop[43]], weight: 4.1363508E-4, delay 1.5
        h("Epop[43] syn_projEE_ampa[4443] = new ampa(0.5)")
        h("Epop[55] netConn_projEE_ampa[4443] = new NetCon(&v(0.5), syn_projEE_ampa[4443], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4444: cell 55, seg 0 (0.5) [0.5 on Epop[55]] -> cell 44, seg 0 (0.5) [0.5 on Epop[44]], weight: 4.1363508E-4, delay 1.5
        h("Epop[44] syn_projEE_ampa[4444] = new ampa(0.5)")
        h("Epop[55] netConn_projEE_ampa[4444] = new NetCon(&v(0.5), syn_projEE_ampa[4444], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4445: cell 55, seg 0 (0.5) [0.5 on Epop[55]] -> cell 45, seg 0 (0.5) [0.5 on Epop[45]], weight: 4.1363508E-4, delay 1.5
        h("Epop[45] syn_projEE_ampa[4445] = new ampa(0.5)")
        h("Epop[55] netConn_projEE_ampa[4445] = new NetCon(&v(0.5), syn_projEE_ampa[4445], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4446: cell 55, seg 0 (0.5) [0.5 on Epop[55]] -> cell 46, seg 0 (0.5) [0.5 on Epop[46]], weight: 4.1363508E-4, delay 1.5
        h("Epop[46] syn_projEE_ampa[4446] = new ampa(0.5)")
        h("Epop[55] netConn_projEE_ampa[4446] = new NetCon(&v(0.5), syn_projEE_ampa[4446], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4447: cell 55, seg 0 (0.5) [0.5 on Epop[55]] -> cell 47, seg 0 (0.5) [0.5 on Epop[47]], weight: 4.1363508E-4, delay 1.5
        h("Epop[47] syn_projEE_ampa[4447] = new ampa(0.5)")
        h("Epop[55] netConn_projEE_ampa[4447] = new NetCon(&v(0.5), syn_projEE_ampa[4447], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4448: cell 55, seg 0 (0.5) [0.5 on Epop[55]] -> cell 48, seg 0 (0.5) [0.5 on Epop[48]], weight: 4.1363508E-4, delay 1.5
        h("Epop[48] syn_projEE_ampa[4448] = new ampa(0.5)")
        h("Epop[55] netConn_projEE_ampa[4448] = new NetCon(&v(0.5), syn_projEE_ampa[4448], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4449: cell 55, seg 0 (0.5) [0.5 on Epop[55]] -> cell 49, seg 0 (0.5) [0.5 on Epop[49]], weight: 4.1363508E-4, delay 1.5
        h("Epop[49] syn_projEE_ampa[4449] = new ampa(0.5)")
        h("Epop[55] netConn_projEE_ampa[4449] = new NetCon(&v(0.5), syn_projEE_ampa[4449], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4450: cell 55, seg 0 (0.5) [0.5 on Epop[55]] -> cell 50, seg 0 (0.5) [0.5 on Epop[50]], weight: 4.1363508E-4, delay 1.5
        h("Epop[50] syn_projEE_ampa[4450] = new ampa(0.5)")
        h("Epop[55] netConn_projEE_ampa[4450] = new NetCon(&v(0.5), syn_projEE_ampa[4450], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4451: cell 55, seg 0 (0.5) [0.5 on Epop[55]] -> cell 51, seg 0 (0.5) [0.5 on Epop[51]], weight: 4.1363508E-4, delay 1.5
        h("Epop[51] syn_projEE_ampa[4451] = new ampa(0.5)")
        h("Epop[55] netConn_projEE_ampa[4451] = new NetCon(&v(0.5), syn_projEE_ampa[4451], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4452: cell 55, seg 0 (0.5) [0.5 on Epop[55]] -> cell 52, seg 0 (0.5) [0.5 on Epop[52]], weight: 4.1363508E-4, delay 1.5
        h("Epop[52] syn_projEE_ampa[4452] = new ampa(0.5)")
        h("Epop[55] netConn_projEE_ampa[4452] = new NetCon(&v(0.5), syn_projEE_ampa[4452], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4453: cell 55, seg 0 (0.5) [0.5 on Epop[55]] -> cell 53, seg 0 (0.5) [0.5 on Epop[53]], weight: 4.1363508E-4, delay 1.5
        h("Epop[53] syn_projEE_ampa[4453] = new ampa(0.5)")
        h("Epop[55] netConn_projEE_ampa[4453] = new NetCon(&v(0.5), syn_projEE_ampa[4453], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4454: cell 55, seg 0 (0.5) [0.5 on Epop[55]] -> cell 54, seg 0 (0.5) [0.5 on Epop[54]], weight: 4.1363508E-4, delay 1.5
        h("Epop[54] syn_projEE_ampa[4454] = new ampa(0.5)")
        h("Epop[55] netConn_projEE_ampa[4454] = new NetCon(&v(0.5), syn_projEE_ampa[4454], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4455: cell 55, seg 0 (0.5) [0.5 on Epop[55]] -> cell 55, seg 0 (0.5) [0.5 on Epop[55]], weight: 4.1363508E-4, delay 1.5
        h("Epop[55] syn_projEE_ampa[4455] = new ampa(0.5)")
        h("Epop[55] netConn_projEE_ampa[4455] = new NetCon(&v(0.5), syn_projEE_ampa[4455], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4456: cell 55, seg 0 (0.5) [0.5 on Epop[55]] -> cell 56, seg 0 (0.5) [0.5 on Epop[56]], weight: 4.1363508E-4, delay 1.5
        h("Epop[56] syn_projEE_ampa[4456] = new ampa(0.5)")
        h("Epop[55] netConn_projEE_ampa[4456] = new NetCon(&v(0.5), syn_projEE_ampa[4456], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4457: cell 55, seg 0 (0.5) [0.5 on Epop[55]] -> cell 57, seg 0 (0.5) [0.5 on Epop[57]], weight: 4.1363508E-4, delay 1.5
        h("Epop[57] syn_projEE_ampa[4457] = new ampa(0.5)")
        h("Epop[55] netConn_projEE_ampa[4457] = new NetCon(&v(0.5), syn_projEE_ampa[4457], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4458: cell 55, seg 0 (0.5) [0.5 on Epop[55]] -> cell 58, seg 0 (0.5) [0.5 on Epop[58]], weight: 4.1363508E-4, delay 1.5
        h("Epop[58] syn_projEE_ampa[4458] = new ampa(0.5)")
        h("Epop[55] netConn_projEE_ampa[4458] = new NetCon(&v(0.5), syn_projEE_ampa[4458], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4459: cell 55, seg 0 (0.5) [0.5 on Epop[55]] -> cell 59, seg 0 (0.5) [0.5 on Epop[59]], weight: 4.1363508E-4, delay 1.5
        h("Epop[59] syn_projEE_ampa[4459] = new ampa(0.5)")
        h("Epop[55] netConn_projEE_ampa[4459] = new NetCon(&v(0.5), syn_projEE_ampa[4459], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4460: cell 55, seg 0 (0.5) [0.5 on Epop[55]] -> cell 60, seg 0 (0.5) [0.5 on Epop[60]], weight: 4.1363508E-4, delay 1.5
        h("Epop[60] syn_projEE_ampa[4460] = new ampa(0.5)")
        h("Epop[55] netConn_projEE_ampa[4460] = new NetCon(&v(0.5), syn_projEE_ampa[4460], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4461: cell 55, seg 0 (0.5) [0.5 on Epop[55]] -> cell 61, seg 0 (0.5) [0.5 on Epop[61]], weight: 4.1363508E-4, delay 1.5
        h("Epop[61] syn_projEE_ampa[4461] = new ampa(0.5)")
        h("Epop[55] netConn_projEE_ampa[4461] = new NetCon(&v(0.5), syn_projEE_ampa[4461], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4462: cell 55, seg 0 (0.5) [0.5 on Epop[55]] -> cell 62, seg 0 (0.5) [0.5 on Epop[62]], weight: 4.1363508E-4, delay 1.5
        h("Epop[62] syn_projEE_ampa[4462] = new ampa(0.5)")
        h("Epop[55] netConn_projEE_ampa[4462] = new NetCon(&v(0.5), syn_projEE_ampa[4462], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4463: cell 55, seg 0 (0.5) [0.5 on Epop[55]] -> cell 63, seg 0 (0.5) [0.5 on Epop[63]], weight: 4.1363508E-4, delay 1.5
        h("Epop[63] syn_projEE_ampa[4463] = new ampa(0.5)")
        h("Epop[55] netConn_projEE_ampa[4463] = new NetCon(&v(0.5), syn_projEE_ampa[4463], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4464: cell 55, seg 0 (0.5) [0.5 on Epop[55]] -> cell 64, seg 0 (0.5) [0.5 on Epop[64]], weight: 4.1363508E-4, delay 1.5
        h("Epop[64] syn_projEE_ampa[4464] = new ampa(0.5)")
        h("Epop[55] netConn_projEE_ampa[4464] = new NetCon(&v(0.5), syn_projEE_ampa[4464], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4465: cell 55, seg 0 (0.5) [0.5 on Epop[55]] -> cell 65, seg 0 (0.5) [0.5 on Epop[65]], weight: 4.1363508E-4, delay 1.5
        h("Epop[65] syn_projEE_ampa[4465] = new ampa(0.5)")
        h("Epop[55] netConn_projEE_ampa[4465] = new NetCon(&v(0.5), syn_projEE_ampa[4465], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4466: cell 55, seg 0 (0.5) [0.5 on Epop[55]] -> cell 66, seg 0 (0.5) [0.5 on Epop[66]], weight: 4.1363508E-4, delay 1.5
        h("Epop[66] syn_projEE_ampa[4466] = new ampa(0.5)")
        h("Epop[55] netConn_projEE_ampa[4466] = new NetCon(&v(0.5), syn_projEE_ampa[4466], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4467: cell 55, seg 0 (0.5) [0.5 on Epop[55]] -> cell 67, seg 0 (0.5) [0.5 on Epop[67]], weight: 4.1363508E-4, delay 1.5
        h("Epop[67] syn_projEE_ampa[4467] = new ampa(0.5)")
        h("Epop[55] netConn_projEE_ampa[4467] = new NetCon(&v(0.5), syn_projEE_ampa[4467], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4468: cell 55, seg 0 (0.5) [0.5 on Epop[55]] -> cell 68, seg 0 (0.5) [0.5 on Epop[68]], weight: 4.1363508E-4, delay 1.5
        h("Epop[68] syn_projEE_ampa[4468] = new ampa(0.5)")
        h("Epop[55] netConn_projEE_ampa[4468] = new NetCon(&v(0.5), syn_projEE_ampa[4468], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4469: cell 55, seg 0 (0.5) [0.5 on Epop[55]] -> cell 69, seg 0 (0.5) [0.5 on Epop[69]], weight: 4.1363508E-4, delay 1.5
        h("Epop[69] syn_projEE_ampa[4469] = new ampa(0.5)")
        h("Epop[55] netConn_projEE_ampa[4469] = new NetCon(&v(0.5), syn_projEE_ampa[4469], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4470: cell 55, seg 0 (0.5) [0.5 on Epop[55]] -> cell 70, seg 0 (0.5) [0.5 on Epop[70]], weight: 4.1363508E-4, delay 1.5
        h("Epop[70] syn_projEE_ampa[4470] = new ampa(0.5)")
        h("Epop[55] netConn_projEE_ampa[4470] = new NetCon(&v(0.5), syn_projEE_ampa[4470], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4471: cell 55, seg 0 (0.5) [0.5 on Epop[55]] -> cell 71, seg 0 (0.5) [0.5 on Epop[71]], weight: 4.1363508E-4, delay 1.5
        h("Epop[71] syn_projEE_ampa[4471] = new ampa(0.5)")
        h("Epop[55] netConn_projEE_ampa[4471] = new NetCon(&v(0.5), syn_projEE_ampa[4471], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4472: cell 55, seg 0 (0.5) [0.5 on Epop[55]] -> cell 72, seg 0 (0.5) [0.5 on Epop[72]], weight: 4.1363508E-4, delay 1.5
        h("Epop[72] syn_projEE_ampa[4472] = new ampa(0.5)")
        h("Epop[55] netConn_projEE_ampa[4472] = new NetCon(&v(0.5), syn_projEE_ampa[4472], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4473: cell 55, seg 0 (0.5) [0.5 on Epop[55]] -> cell 73, seg 0 (0.5) [0.5 on Epop[73]], weight: 4.1363508E-4, delay 1.5
        h("Epop[73] syn_projEE_ampa[4473] = new ampa(0.5)")
        h("Epop[55] netConn_projEE_ampa[4473] = new NetCon(&v(0.5), syn_projEE_ampa[4473], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4474: cell 55, seg 0 (0.5) [0.5 on Epop[55]] -> cell 74, seg 0 (0.5) [0.5 on Epop[74]], weight: 4.1363508E-4, delay 1.5
        h("Epop[74] syn_projEE_ampa[4474] = new ampa(0.5)")
        h("Epop[55] netConn_projEE_ampa[4474] = new NetCon(&v(0.5), syn_projEE_ampa[4474], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4475: cell 55, seg 0 (0.5) [0.5 on Epop[55]] -> cell 75, seg 0 (0.5) [0.5 on Epop[75]], weight: 4.1363508E-4, delay 1.5
        h("Epop[75] syn_projEE_ampa[4475] = new ampa(0.5)")
        h("Epop[55] netConn_projEE_ampa[4475] = new NetCon(&v(0.5), syn_projEE_ampa[4475], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4476: cell 55, seg 0 (0.5) [0.5 on Epop[55]] -> cell 76, seg 0 (0.5) [0.5 on Epop[76]], weight: 4.1363508E-4, delay 1.5
        h("Epop[76] syn_projEE_ampa[4476] = new ampa(0.5)")
        h("Epop[55] netConn_projEE_ampa[4476] = new NetCon(&v(0.5), syn_projEE_ampa[4476], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4477: cell 55, seg 0 (0.5) [0.5 on Epop[55]] -> cell 77, seg 0 (0.5) [0.5 on Epop[77]], weight: 4.1363508E-4, delay 1.5
        h("Epop[77] syn_projEE_ampa[4477] = new ampa(0.5)")
        h("Epop[55] netConn_projEE_ampa[4477] = new NetCon(&v(0.5), syn_projEE_ampa[4477], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4478: cell 55, seg 0 (0.5) [0.5 on Epop[55]] -> cell 78, seg 0 (0.5) [0.5 on Epop[78]], weight: 4.1363508E-4, delay 1.5
        h("Epop[78] syn_projEE_ampa[4478] = new ampa(0.5)")
        h("Epop[55] netConn_projEE_ampa[4478] = new NetCon(&v(0.5), syn_projEE_ampa[4478], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4479: cell 55, seg 0 (0.5) [0.5 on Epop[55]] -> cell 79, seg 0 (0.5) [0.5 on Epop[79]], weight: 4.1363508E-4, delay 1.5
        h("Epop[79] syn_projEE_ampa[4479] = new ampa(0.5)")
        h("Epop[55] netConn_projEE_ampa[4479] = new NetCon(&v(0.5), syn_projEE_ampa[4479], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4480: cell 56, seg 0 (0.5) [0.5 on Epop[56]] -> cell 0, seg 0 (0.5) [0.5 on Epop[0]], weight: 4.1363508E-4, delay 1.5
        h("Epop[0] syn_projEE_ampa[4480] = new ampa(0.5)")
        h("Epop[56] netConn_projEE_ampa[4480] = new NetCon(&v(0.5), syn_projEE_ampa[4480], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4481: cell 56, seg 0 (0.5) [0.5 on Epop[56]] -> cell 1, seg 0 (0.5) [0.5 on Epop[1]], weight: 4.1363508E-4, delay 1.5
        h("Epop[1] syn_projEE_ampa[4481] = new ampa(0.5)")
        h("Epop[56] netConn_projEE_ampa[4481] = new NetCon(&v(0.5), syn_projEE_ampa[4481], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4482: cell 56, seg 0 (0.5) [0.5 on Epop[56]] -> cell 2, seg 0 (0.5) [0.5 on Epop[2]], weight: 4.1363508E-4, delay 1.5
        h("Epop[2] syn_projEE_ampa[4482] = new ampa(0.5)")
        h("Epop[56] netConn_projEE_ampa[4482] = new NetCon(&v(0.5), syn_projEE_ampa[4482], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4483: cell 56, seg 0 (0.5) [0.5 on Epop[56]] -> cell 3, seg 0 (0.5) [0.5 on Epop[3]], weight: 4.1363508E-4, delay 1.5
        h("Epop[3] syn_projEE_ampa[4483] = new ampa(0.5)")
        h("Epop[56] netConn_projEE_ampa[4483] = new NetCon(&v(0.5), syn_projEE_ampa[4483], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4484: cell 56, seg 0 (0.5) [0.5 on Epop[56]] -> cell 4, seg 0 (0.5) [0.5 on Epop[4]], weight: 4.1363508E-4, delay 1.5
        h("Epop[4] syn_projEE_ampa[4484] = new ampa(0.5)")
        h("Epop[56] netConn_projEE_ampa[4484] = new NetCon(&v(0.5), syn_projEE_ampa[4484], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4485: cell 56, seg 0 (0.5) [0.5 on Epop[56]] -> cell 5, seg 0 (0.5) [0.5 on Epop[5]], weight: 4.1363508E-4, delay 1.5
        h("Epop[5] syn_projEE_ampa[4485] = new ampa(0.5)")
        h("Epop[56] netConn_projEE_ampa[4485] = new NetCon(&v(0.5), syn_projEE_ampa[4485], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4486: cell 56, seg 0 (0.5) [0.5 on Epop[56]] -> cell 6, seg 0 (0.5) [0.5 on Epop[6]], weight: 4.1363508E-4, delay 1.5
        h("Epop[6] syn_projEE_ampa[4486] = new ampa(0.5)")
        h("Epop[56] netConn_projEE_ampa[4486] = new NetCon(&v(0.5), syn_projEE_ampa[4486], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4487: cell 56, seg 0 (0.5) [0.5 on Epop[56]] -> cell 7, seg 0 (0.5) [0.5 on Epop[7]], weight: 4.1363508E-4, delay 1.5
        h("Epop[7] syn_projEE_ampa[4487] = new ampa(0.5)")
        h("Epop[56] netConn_projEE_ampa[4487] = new NetCon(&v(0.5), syn_projEE_ampa[4487], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4488: cell 56, seg 0 (0.5) [0.5 on Epop[56]] -> cell 8, seg 0 (0.5) [0.5 on Epop[8]], weight: 4.1363508E-4, delay 1.5
        h("Epop[8] syn_projEE_ampa[4488] = new ampa(0.5)")
        h("Epop[56] netConn_projEE_ampa[4488] = new NetCon(&v(0.5), syn_projEE_ampa[4488], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4489: cell 56, seg 0 (0.5) [0.5 on Epop[56]] -> cell 9, seg 0 (0.5) [0.5 on Epop[9]], weight: 4.1363508E-4, delay 1.5
        h("Epop[9] syn_projEE_ampa[4489] = new ampa(0.5)")
        h("Epop[56] netConn_projEE_ampa[4489] = new NetCon(&v(0.5), syn_projEE_ampa[4489], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4490: cell 56, seg 0 (0.5) [0.5 on Epop[56]] -> cell 10, seg 0 (0.5) [0.5 on Epop[10]], weight: 4.1363508E-4, delay 1.5
        h("Epop[10] syn_projEE_ampa[4490] = new ampa(0.5)")
        h("Epop[56] netConn_projEE_ampa[4490] = new NetCon(&v(0.5), syn_projEE_ampa[4490], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4491: cell 56, seg 0 (0.5) [0.5 on Epop[56]] -> cell 11, seg 0 (0.5) [0.5 on Epop[11]], weight: 4.1363508E-4, delay 1.5
        h("Epop[11] syn_projEE_ampa[4491] = new ampa(0.5)")
        h("Epop[56] netConn_projEE_ampa[4491] = new NetCon(&v(0.5), syn_projEE_ampa[4491], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4492: cell 56, seg 0 (0.5) [0.5 on Epop[56]] -> cell 12, seg 0 (0.5) [0.5 on Epop[12]], weight: 4.1363508E-4, delay 1.5
        h("Epop[12] syn_projEE_ampa[4492] = new ampa(0.5)")
        h("Epop[56] netConn_projEE_ampa[4492] = new NetCon(&v(0.5), syn_projEE_ampa[4492], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4493: cell 56, seg 0 (0.5) [0.5 on Epop[56]] -> cell 13, seg 0 (0.5) [0.5 on Epop[13]], weight: 4.1363508E-4, delay 1.5
        h("Epop[13] syn_projEE_ampa[4493] = new ampa(0.5)")
        h("Epop[56] netConn_projEE_ampa[4493] = new NetCon(&v(0.5), syn_projEE_ampa[4493], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4494: cell 56, seg 0 (0.5) [0.5 on Epop[56]] -> cell 14, seg 0 (0.5) [0.5 on Epop[14]], weight: 4.1363508E-4, delay 1.5
        h("Epop[14] syn_projEE_ampa[4494] = new ampa(0.5)")
        h("Epop[56] netConn_projEE_ampa[4494] = new NetCon(&v(0.5), syn_projEE_ampa[4494], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4495: cell 56, seg 0 (0.5) [0.5 on Epop[56]] -> cell 15, seg 0 (0.5) [0.5 on Epop[15]], weight: 4.1363508E-4, delay 1.5
        h("Epop[15] syn_projEE_ampa[4495] = new ampa(0.5)")
        h("Epop[56] netConn_projEE_ampa[4495] = new NetCon(&v(0.5), syn_projEE_ampa[4495], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4496: cell 56, seg 0 (0.5) [0.5 on Epop[56]] -> cell 16, seg 0 (0.5) [0.5 on Epop[16]], weight: 4.1363508E-4, delay 1.5
        h("Epop[16] syn_projEE_ampa[4496] = new ampa(0.5)")
        h("Epop[56] netConn_projEE_ampa[4496] = new NetCon(&v(0.5), syn_projEE_ampa[4496], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4497: cell 56, seg 0 (0.5) [0.5 on Epop[56]] -> cell 17, seg 0 (0.5) [0.5 on Epop[17]], weight: 4.1363508E-4, delay 1.5
        h("Epop[17] syn_projEE_ampa[4497] = new ampa(0.5)")
        h("Epop[56] netConn_projEE_ampa[4497] = new NetCon(&v(0.5), syn_projEE_ampa[4497], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4498: cell 56, seg 0 (0.5) [0.5 on Epop[56]] -> cell 18, seg 0 (0.5) [0.5 on Epop[18]], weight: 4.1363508E-4, delay 1.5
        h("Epop[18] syn_projEE_ampa[4498] = new ampa(0.5)")
        h("Epop[56] netConn_projEE_ampa[4498] = new NetCon(&v(0.5), syn_projEE_ampa[4498], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4499: cell 56, seg 0 (0.5) [0.5 on Epop[56]] -> cell 19, seg 0 (0.5) [0.5 on Epop[19]], weight: 4.1363508E-4, delay 1.5
        h("Epop[19] syn_projEE_ampa[4499] = new ampa(0.5)")
        h("Epop[56] netConn_projEE_ampa[4499] = new NetCon(&v(0.5), syn_projEE_ampa[4499], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4500: cell 56, seg 0 (0.5) [0.5 on Epop[56]] -> cell 20, seg 0 (0.5) [0.5 on Epop[20]], weight: 4.1363508E-4, delay 1.5
        h("Epop[20] syn_projEE_ampa[4500] = new ampa(0.5)")
        h("Epop[56] netConn_projEE_ampa[4500] = new NetCon(&v(0.5), syn_projEE_ampa[4500], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4501: cell 56, seg 0 (0.5) [0.5 on Epop[56]] -> cell 21, seg 0 (0.5) [0.5 on Epop[21]], weight: 4.1363508E-4, delay 1.5
        h("Epop[21] syn_projEE_ampa[4501] = new ampa(0.5)")
        h("Epop[56] netConn_projEE_ampa[4501] = new NetCon(&v(0.5), syn_projEE_ampa[4501], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4502: cell 56, seg 0 (0.5) [0.5 on Epop[56]] -> cell 22, seg 0 (0.5) [0.5 on Epop[22]], weight: 4.1363508E-4, delay 1.5
        h("Epop[22] syn_projEE_ampa[4502] = new ampa(0.5)")
        h("Epop[56] netConn_projEE_ampa[4502] = new NetCon(&v(0.5), syn_projEE_ampa[4502], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4503: cell 56, seg 0 (0.5) [0.5 on Epop[56]] -> cell 23, seg 0 (0.5) [0.5 on Epop[23]], weight: 4.1363508E-4, delay 1.5
        h("Epop[23] syn_projEE_ampa[4503] = new ampa(0.5)")
        h("Epop[56] netConn_projEE_ampa[4503] = new NetCon(&v(0.5), syn_projEE_ampa[4503], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4504: cell 56, seg 0 (0.5) [0.5 on Epop[56]] -> cell 24, seg 0 (0.5) [0.5 on Epop[24]], weight: 4.1363508E-4, delay 1.5
        h("Epop[24] syn_projEE_ampa[4504] = new ampa(0.5)")
        h("Epop[56] netConn_projEE_ampa[4504] = new NetCon(&v(0.5), syn_projEE_ampa[4504], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4505: cell 56, seg 0 (0.5) [0.5 on Epop[56]] -> cell 25, seg 0 (0.5) [0.5 on Epop[25]], weight: 4.1363508E-4, delay 1.5
        h("Epop[25] syn_projEE_ampa[4505] = new ampa(0.5)")
        h("Epop[56] netConn_projEE_ampa[4505] = new NetCon(&v(0.5), syn_projEE_ampa[4505], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4506: cell 56, seg 0 (0.5) [0.5 on Epop[56]] -> cell 26, seg 0 (0.5) [0.5 on Epop[26]], weight: 4.1363508E-4, delay 1.5
        h("Epop[26] syn_projEE_ampa[4506] = new ampa(0.5)")
        h("Epop[56] netConn_projEE_ampa[4506] = new NetCon(&v(0.5), syn_projEE_ampa[4506], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4507: cell 56, seg 0 (0.5) [0.5 on Epop[56]] -> cell 27, seg 0 (0.5) [0.5 on Epop[27]], weight: 4.1363508E-4, delay 1.5
        h("Epop[27] syn_projEE_ampa[4507] = new ampa(0.5)")
        h("Epop[56] netConn_projEE_ampa[4507] = new NetCon(&v(0.5), syn_projEE_ampa[4507], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4508: cell 56, seg 0 (0.5) [0.5 on Epop[56]] -> cell 28, seg 0 (0.5) [0.5 on Epop[28]], weight: 4.1363508E-4, delay 1.5
        h("Epop[28] syn_projEE_ampa[4508] = new ampa(0.5)")
        h("Epop[56] netConn_projEE_ampa[4508] = new NetCon(&v(0.5), syn_projEE_ampa[4508], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4509: cell 56, seg 0 (0.5) [0.5 on Epop[56]] -> cell 29, seg 0 (0.5) [0.5 on Epop[29]], weight: 4.1363508E-4, delay 1.5
        h("Epop[29] syn_projEE_ampa[4509] = new ampa(0.5)")
        h("Epop[56] netConn_projEE_ampa[4509] = new NetCon(&v(0.5), syn_projEE_ampa[4509], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4510: cell 56, seg 0 (0.5) [0.5 on Epop[56]] -> cell 30, seg 0 (0.5) [0.5 on Epop[30]], weight: 4.1363508E-4, delay 1.5
        h("Epop[30] syn_projEE_ampa[4510] = new ampa(0.5)")
        h("Epop[56] netConn_projEE_ampa[4510] = new NetCon(&v(0.5), syn_projEE_ampa[4510], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4511: cell 56, seg 0 (0.5) [0.5 on Epop[56]] -> cell 31, seg 0 (0.5) [0.5 on Epop[31]], weight: 4.1363508E-4, delay 1.5
        h("Epop[31] syn_projEE_ampa[4511] = new ampa(0.5)")
        h("Epop[56] netConn_projEE_ampa[4511] = new NetCon(&v(0.5), syn_projEE_ampa[4511], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4512: cell 56, seg 0 (0.5) [0.5 on Epop[56]] -> cell 32, seg 0 (0.5) [0.5 on Epop[32]], weight: 4.1363508E-4, delay 1.5
        h("Epop[32] syn_projEE_ampa[4512] = new ampa(0.5)")
        h("Epop[56] netConn_projEE_ampa[4512] = new NetCon(&v(0.5), syn_projEE_ampa[4512], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4513: cell 56, seg 0 (0.5) [0.5 on Epop[56]] -> cell 33, seg 0 (0.5) [0.5 on Epop[33]], weight: 4.1363508E-4, delay 1.5
        h("Epop[33] syn_projEE_ampa[4513] = new ampa(0.5)")
        h("Epop[56] netConn_projEE_ampa[4513] = new NetCon(&v(0.5), syn_projEE_ampa[4513], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4514: cell 56, seg 0 (0.5) [0.5 on Epop[56]] -> cell 34, seg 0 (0.5) [0.5 on Epop[34]], weight: 4.1363508E-4, delay 1.5
        h("Epop[34] syn_projEE_ampa[4514] = new ampa(0.5)")
        h("Epop[56] netConn_projEE_ampa[4514] = new NetCon(&v(0.5), syn_projEE_ampa[4514], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4515: cell 56, seg 0 (0.5) [0.5 on Epop[56]] -> cell 35, seg 0 (0.5) [0.5 on Epop[35]], weight: 4.1363508E-4, delay 1.5
        h("Epop[35] syn_projEE_ampa[4515] = new ampa(0.5)")
        h("Epop[56] netConn_projEE_ampa[4515] = new NetCon(&v(0.5), syn_projEE_ampa[4515], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4516: cell 56, seg 0 (0.5) [0.5 on Epop[56]] -> cell 36, seg 0 (0.5) [0.5 on Epop[36]], weight: 4.1363508E-4, delay 1.5
        h("Epop[36] syn_projEE_ampa[4516] = new ampa(0.5)")
        h("Epop[56] netConn_projEE_ampa[4516] = new NetCon(&v(0.5), syn_projEE_ampa[4516], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4517: cell 56, seg 0 (0.5) [0.5 on Epop[56]] -> cell 37, seg 0 (0.5) [0.5 on Epop[37]], weight: 4.1363508E-4, delay 1.5
        h("Epop[37] syn_projEE_ampa[4517] = new ampa(0.5)")
        h("Epop[56] netConn_projEE_ampa[4517] = new NetCon(&v(0.5), syn_projEE_ampa[4517], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4518: cell 56, seg 0 (0.5) [0.5 on Epop[56]] -> cell 38, seg 0 (0.5) [0.5 on Epop[38]], weight: 4.1363508E-4, delay 1.5
        h("Epop[38] syn_projEE_ampa[4518] = new ampa(0.5)")
        h("Epop[56] netConn_projEE_ampa[4518] = new NetCon(&v(0.5), syn_projEE_ampa[4518], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4519: cell 56, seg 0 (0.5) [0.5 on Epop[56]] -> cell 39, seg 0 (0.5) [0.5 on Epop[39]], weight: 4.1363508E-4, delay 1.5
        h("Epop[39] syn_projEE_ampa[4519] = new ampa(0.5)")
        h("Epop[56] netConn_projEE_ampa[4519] = new NetCon(&v(0.5), syn_projEE_ampa[4519], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4520: cell 56, seg 0 (0.5) [0.5 on Epop[56]] -> cell 40, seg 0 (0.5) [0.5 on Epop[40]], weight: 4.1363508E-4, delay 1.5
        h("Epop[40] syn_projEE_ampa[4520] = new ampa(0.5)")
        h("Epop[56] netConn_projEE_ampa[4520] = new NetCon(&v(0.5), syn_projEE_ampa[4520], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4521: cell 56, seg 0 (0.5) [0.5 on Epop[56]] -> cell 41, seg 0 (0.5) [0.5 on Epop[41]], weight: 4.1363508E-4, delay 1.5
        h("Epop[41] syn_projEE_ampa[4521] = new ampa(0.5)")
        h("Epop[56] netConn_projEE_ampa[4521] = new NetCon(&v(0.5), syn_projEE_ampa[4521], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4522: cell 56, seg 0 (0.5) [0.5 on Epop[56]] -> cell 42, seg 0 (0.5) [0.5 on Epop[42]], weight: 4.1363508E-4, delay 1.5
        h("Epop[42] syn_projEE_ampa[4522] = new ampa(0.5)")
        h("Epop[56] netConn_projEE_ampa[4522] = new NetCon(&v(0.5), syn_projEE_ampa[4522], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4523: cell 56, seg 0 (0.5) [0.5 on Epop[56]] -> cell 43, seg 0 (0.5) [0.5 on Epop[43]], weight: 4.1363508E-4, delay 1.5
        h("Epop[43] syn_projEE_ampa[4523] = new ampa(0.5)")
        h("Epop[56] netConn_projEE_ampa[4523] = new NetCon(&v(0.5), syn_projEE_ampa[4523], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4524: cell 56, seg 0 (0.5) [0.5 on Epop[56]] -> cell 44, seg 0 (0.5) [0.5 on Epop[44]], weight: 4.1363508E-4, delay 1.5
        h("Epop[44] syn_projEE_ampa[4524] = new ampa(0.5)")
        h("Epop[56] netConn_projEE_ampa[4524] = new NetCon(&v(0.5), syn_projEE_ampa[4524], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4525: cell 56, seg 0 (0.5) [0.5 on Epop[56]] -> cell 45, seg 0 (0.5) [0.5 on Epop[45]], weight: 4.1363508E-4, delay 1.5
        h("Epop[45] syn_projEE_ampa[4525] = new ampa(0.5)")
        h("Epop[56] netConn_projEE_ampa[4525] = new NetCon(&v(0.5), syn_projEE_ampa[4525], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4526: cell 56, seg 0 (0.5) [0.5 on Epop[56]] -> cell 46, seg 0 (0.5) [0.5 on Epop[46]], weight: 4.1363508E-4, delay 1.5
        h("Epop[46] syn_projEE_ampa[4526] = new ampa(0.5)")
        h("Epop[56] netConn_projEE_ampa[4526] = new NetCon(&v(0.5), syn_projEE_ampa[4526], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4527: cell 56, seg 0 (0.5) [0.5 on Epop[56]] -> cell 47, seg 0 (0.5) [0.5 on Epop[47]], weight: 4.1363508E-4, delay 1.5
        h("Epop[47] syn_projEE_ampa[4527] = new ampa(0.5)")
        h("Epop[56] netConn_projEE_ampa[4527] = new NetCon(&v(0.5), syn_projEE_ampa[4527], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4528: cell 56, seg 0 (0.5) [0.5 on Epop[56]] -> cell 48, seg 0 (0.5) [0.5 on Epop[48]], weight: 4.1363508E-4, delay 1.5
        h("Epop[48] syn_projEE_ampa[4528] = new ampa(0.5)")
        h("Epop[56] netConn_projEE_ampa[4528] = new NetCon(&v(0.5), syn_projEE_ampa[4528], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4529: cell 56, seg 0 (0.5) [0.5 on Epop[56]] -> cell 49, seg 0 (0.5) [0.5 on Epop[49]], weight: 4.1363508E-4, delay 1.5
        h("Epop[49] syn_projEE_ampa[4529] = new ampa(0.5)")
        h("Epop[56] netConn_projEE_ampa[4529] = new NetCon(&v(0.5), syn_projEE_ampa[4529], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4530: cell 56, seg 0 (0.5) [0.5 on Epop[56]] -> cell 50, seg 0 (0.5) [0.5 on Epop[50]], weight: 4.1363508E-4, delay 1.5
        h("Epop[50] syn_projEE_ampa[4530] = new ampa(0.5)")
        h("Epop[56] netConn_projEE_ampa[4530] = new NetCon(&v(0.5), syn_projEE_ampa[4530], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4531: cell 56, seg 0 (0.5) [0.5 on Epop[56]] -> cell 51, seg 0 (0.5) [0.5 on Epop[51]], weight: 4.1363508E-4, delay 1.5
        h("Epop[51] syn_projEE_ampa[4531] = new ampa(0.5)")
        h("Epop[56] netConn_projEE_ampa[4531] = new NetCon(&v(0.5), syn_projEE_ampa[4531], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4532: cell 56, seg 0 (0.5) [0.5 on Epop[56]] -> cell 52, seg 0 (0.5) [0.5 on Epop[52]], weight: 4.1363508E-4, delay 1.5
        h("Epop[52] syn_projEE_ampa[4532] = new ampa(0.5)")
        h("Epop[56] netConn_projEE_ampa[4532] = new NetCon(&v(0.5), syn_projEE_ampa[4532], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4533: cell 56, seg 0 (0.5) [0.5 on Epop[56]] -> cell 53, seg 0 (0.5) [0.5 on Epop[53]], weight: 4.1363508E-4, delay 1.5
        h("Epop[53] syn_projEE_ampa[4533] = new ampa(0.5)")
        h("Epop[56] netConn_projEE_ampa[4533] = new NetCon(&v(0.5), syn_projEE_ampa[4533], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4534: cell 56, seg 0 (0.5) [0.5 on Epop[56]] -> cell 54, seg 0 (0.5) [0.5 on Epop[54]], weight: 4.1363508E-4, delay 1.5
        h("Epop[54] syn_projEE_ampa[4534] = new ampa(0.5)")
        h("Epop[56] netConn_projEE_ampa[4534] = new NetCon(&v(0.5), syn_projEE_ampa[4534], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4535: cell 56, seg 0 (0.5) [0.5 on Epop[56]] -> cell 55, seg 0 (0.5) [0.5 on Epop[55]], weight: 4.1363508E-4, delay 1.5
        h("Epop[55] syn_projEE_ampa[4535] = new ampa(0.5)")
        h("Epop[56] netConn_projEE_ampa[4535] = new NetCon(&v(0.5), syn_projEE_ampa[4535], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4536: cell 56, seg 0 (0.5) [0.5 on Epop[56]] -> cell 56, seg 0 (0.5) [0.5 on Epop[56]], weight: 4.1363508E-4, delay 1.5
        h("Epop[56] syn_projEE_ampa[4536] = new ampa(0.5)")
        h("Epop[56] netConn_projEE_ampa[4536] = new NetCon(&v(0.5), syn_projEE_ampa[4536], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4537: cell 56, seg 0 (0.5) [0.5 on Epop[56]] -> cell 57, seg 0 (0.5) [0.5 on Epop[57]], weight: 4.1363508E-4, delay 1.5
        h("Epop[57] syn_projEE_ampa[4537] = new ampa(0.5)")
        h("Epop[56] netConn_projEE_ampa[4537] = new NetCon(&v(0.5), syn_projEE_ampa[4537], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4538: cell 56, seg 0 (0.5) [0.5 on Epop[56]] -> cell 58, seg 0 (0.5) [0.5 on Epop[58]], weight: 4.1363508E-4, delay 1.5
        h("Epop[58] syn_projEE_ampa[4538] = new ampa(0.5)")
        h("Epop[56] netConn_projEE_ampa[4538] = new NetCon(&v(0.5), syn_projEE_ampa[4538], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4539: cell 56, seg 0 (0.5) [0.5 on Epop[56]] -> cell 59, seg 0 (0.5) [0.5 on Epop[59]], weight: 4.1363508E-4, delay 1.5
        h("Epop[59] syn_projEE_ampa[4539] = new ampa(0.5)")
        h("Epop[56] netConn_projEE_ampa[4539] = new NetCon(&v(0.5), syn_projEE_ampa[4539], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4540: cell 56, seg 0 (0.5) [0.5 on Epop[56]] -> cell 60, seg 0 (0.5) [0.5 on Epop[60]], weight: 4.1363508E-4, delay 1.5
        h("Epop[60] syn_projEE_ampa[4540] = new ampa(0.5)")
        h("Epop[56] netConn_projEE_ampa[4540] = new NetCon(&v(0.5), syn_projEE_ampa[4540], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4541: cell 56, seg 0 (0.5) [0.5 on Epop[56]] -> cell 61, seg 0 (0.5) [0.5 on Epop[61]], weight: 4.1363508E-4, delay 1.5
        h("Epop[61] syn_projEE_ampa[4541] = new ampa(0.5)")
        h("Epop[56] netConn_projEE_ampa[4541] = new NetCon(&v(0.5), syn_projEE_ampa[4541], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4542: cell 56, seg 0 (0.5) [0.5 on Epop[56]] -> cell 62, seg 0 (0.5) [0.5 on Epop[62]], weight: 4.1363508E-4, delay 1.5
        h("Epop[62] syn_projEE_ampa[4542] = new ampa(0.5)")
        h("Epop[56] netConn_projEE_ampa[4542] = new NetCon(&v(0.5), syn_projEE_ampa[4542], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4543: cell 56, seg 0 (0.5) [0.5 on Epop[56]] -> cell 63, seg 0 (0.5) [0.5 on Epop[63]], weight: 4.1363508E-4, delay 1.5
        h("Epop[63] syn_projEE_ampa[4543] = new ampa(0.5)")
        h("Epop[56] netConn_projEE_ampa[4543] = new NetCon(&v(0.5), syn_projEE_ampa[4543], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4544: cell 56, seg 0 (0.5) [0.5 on Epop[56]] -> cell 64, seg 0 (0.5) [0.5 on Epop[64]], weight: 4.1363508E-4, delay 1.5
        h("Epop[64] syn_projEE_ampa[4544] = new ampa(0.5)")
        h("Epop[56] netConn_projEE_ampa[4544] = new NetCon(&v(0.5), syn_projEE_ampa[4544], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4545: cell 56, seg 0 (0.5) [0.5 on Epop[56]] -> cell 65, seg 0 (0.5) [0.5 on Epop[65]], weight: 4.1363508E-4, delay 1.5
        h("Epop[65] syn_projEE_ampa[4545] = new ampa(0.5)")
        h("Epop[56] netConn_projEE_ampa[4545] = new NetCon(&v(0.5), syn_projEE_ampa[4545], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4546: cell 56, seg 0 (0.5) [0.5 on Epop[56]] -> cell 66, seg 0 (0.5) [0.5 on Epop[66]], weight: 4.1363508E-4, delay 1.5
        h("Epop[66] syn_projEE_ampa[4546] = new ampa(0.5)")
        h("Epop[56] netConn_projEE_ampa[4546] = new NetCon(&v(0.5), syn_projEE_ampa[4546], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4547: cell 56, seg 0 (0.5) [0.5 on Epop[56]] -> cell 67, seg 0 (0.5) [0.5 on Epop[67]], weight: 4.1363508E-4, delay 1.5
        h("Epop[67] syn_projEE_ampa[4547] = new ampa(0.5)")
        h("Epop[56] netConn_projEE_ampa[4547] = new NetCon(&v(0.5), syn_projEE_ampa[4547], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4548: cell 56, seg 0 (0.5) [0.5 on Epop[56]] -> cell 68, seg 0 (0.5) [0.5 on Epop[68]], weight: 4.1363508E-4, delay 1.5
        h("Epop[68] syn_projEE_ampa[4548] = new ampa(0.5)")
        h("Epop[56] netConn_projEE_ampa[4548] = new NetCon(&v(0.5), syn_projEE_ampa[4548], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4549: cell 56, seg 0 (0.5) [0.5 on Epop[56]] -> cell 69, seg 0 (0.5) [0.5 on Epop[69]], weight: 4.1363508E-4, delay 1.5
        h("Epop[69] syn_projEE_ampa[4549] = new ampa(0.5)")
        h("Epop[56] netConn_projEE_ampa[4549] = new NetCon(&v(0.5), syn_projEE_ampa[4549], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4550: cell 56, seg 0 (0.5) [0.5 on Epop[56]] -> cell 70, seg 0 (0.5) [0.5 on Epop[70]], weight: 4.1363508E-4, delay 1.5
        h("Epop[70] syn_projEE_ampa[4550] = new ampa(0.5)")
        h("Epop[56] netConn_projEE_ampa[4550] = new NetCon(&v(0.5), syn_projEE_ampa[4550], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4551: cell 56, seg 0 (0.5) [0.5 on Epop[56]] -> cell 71, seg 0 (0.5) [0.5 on Epop[71]], weight: 4.1363508E-4, delay 1.5
        h("Epop[71] syn_projEE_ampa[4551] = new ampa(0.5)")
        h("Epop[56] netConn_projEE_ampa[4551] = new NetCon(&v(0.5), syn_projEE_ampa[4551], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4552: cell 56, seg 0 (0.5) [0.5 on Epop[56]] -> cell 72, seg 0 (0.5) [0.5 on Epop[72]], weight: 4.1363508E-4, delay 1.5
        h("Epop[72] syn_projEE_ampa[4552] = new ampa(0.5)")
        h("Epop[56] netConn_projEE_ampa[4552] = new NetCon(&v(0.5), syn_projEE_ampa[4552], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4553: cell 56, seg 0 (0.5) [0.5 on Epop[56]] -> cell 73, seg 0 (0.5) [0.5 on Epop[73]], weight: 4.1363508E-4, delay 1.5
        h("Epop[73] syn_projEE_ampa[4553] = new ampa(0.5)")
        h("Epop[56] netConn_projEE_ampa[4553] = new NetCon(&v(0.5), syn_projEE_ampa[4553], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4554: cell 56, seg 0 (0.5) [0.5 on Epop[56]] -> cell 74, seg 0 (0.5) [0.5 on Epop[74]], weight: 4.1363508E-4, delay 1.5
        h("Epop[74] syn_projEE_ampa[4554] = new ampa(0.5)")
        h("Epop[56] netConn_projEE_ampa[4554] = new NetCon(&v(0.5), syn_projEE_ampa[4554], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4555: cell 56, seg 0 (0.5) [0.5 on Epop[56]] -> cell 75, seg 0 (0.5) [0.5 on Epop[75]], weight: 4.1363508E-4, delay 1.5
        h("Epop[75] syn_projEE_ampa[4555] = new ampa(0.5)")
        h("Epop[56] netConn_projEE_ampa[4555] = new NetCon(&v(0.5), syn_projEE_ampa[4555], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4556: cell 56, seg 0 (0.5) [0.5 on Epop[56]] -> cell 76, seg 0 (0.5) [0.5 on Epop[76]], weight: 4.1363508E-4, delay 1.5
        h("Epop[76] syn_projEE_ampa[4556] = new ampa(0.5)")
        h("Epop[56] netConn_projEE_ampa[4556] = new NetCon(&v(0.5), syn_projEE_ampa[4556], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4557: cell 56, seg 0 (0.5) [0.5 on Epop[56]] -> cell 77, seg 0 (0.5) [0.5 on Epop[77]], weight: 4.1363508E-4, delay 1.5
        h("Epop[77] syn_projEE_ampa[4557] = new ampa(0.5)")
        h("Epop[56] netConn_projEE_ampa[4557] = new NetCon(&v(0.5), syn_projEE_ampa[4557], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4558: cell 56, seg 0 (0.5) [0.5 on Epop[56]] -> cell 78, seg 0 (0.5) [0.5 on Epop[78]], weight: 4.1363508E-4, delay 1.5
        h("Epop[78] syn_projEE_ampa[4558] = new ampa(0.5)")
        h("Epop[56] netConn_projEE_ampa[4558] = new NetCon(&v(0.5), syn_projEE_ampa[4558], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4559: cell 56, seg 0 (0.5) [0.5 on Epop[56]] -> cell 79, seg 0 (0.5) [0.5 on Epop[79]], weight: 4.1363508E-4, delay 1.5
        h("Epop[79] syn_projEE_ampa[4559] = new ampa(0.5)")
        h("Epop[56] netConn_projEE_ampa[4559] = new NetCon(&v(0.5), syn_projEE_ampa[4559], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4560: cell 57, seg 0 (0.5) [0.5 on Epop[57]] -> cell 0, seg 0 (0.5) [0.5 on Epop[0]], weight: 4.1363508E-4, delay 1.5
        h("Epop[0] syn_projEE_ampa[4560] = new ampa(0.5)")
        h("Epop[57] netConn_projEE_ampa[4560] = new NetCon(&v(0.5), syn_projEE_ampa[4560], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4561: cell 57, seg 0 (0.5) [0.5 on Epop[57]] -> cell 1, seg 0 (0.5) [0.5 on Epop[1]], weight: 4.1363508E-4, delay 1.5
        h("Epop[1] syn_projEE_ampa[4561] = new ampa(0.5)")
        h("Epop[57] netConn_projEE_ampa[4561] = new NetCon(&v(0.5), syn_projEE_ampa[4561], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4562: cell 57, seg 0 (0.5) [0.5 on Epop[57]] -> cell 2, seg 0 (0.5) [0.5 on Epop[2]], weight: 4.1363508E-4, delay 1.5
        h("Epop[2] syn_projEE_ampa[4562] = new ampa(0.5)")
        h("Epop[57] netConn_projEE_ampa[4562] = new NetCon(&v(0.5), syn_projEE_ampa[4562], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4563: cell 57, seg 0 (0.5) [0.5 on Epop[57]] -> cell 3, seg 0 (0.5) [0.5 on Epop[3]], weight: 4.1363508E-4, delay 1.5
        h("Epop[3] syn_projEE_ampa[4563] = new ampa(0.5)")
        h("Epop[57] netConn_projEE_ampa[4563] = new NetCon(&v(0.5), syn_projEE_ampa[4563], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4564: cell 57, seg 0 (0.5) [0.5 on Epop[57]] -> cell 4, seg 0 (0.5) [0.5 on Epop[4]], weight: 4.1363508E-4, delay 1.5
        h("Epop[4] syn_projEE_ampa[4564] = new ampa(0.5)")
        h("Epop[57] netConn_projEE_ampa[4564] = new NetCon(&v(0.5), syn_projEE_ampa[4564], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4565: cell 57, seg 0 (0.5) [0.5 on Epop[57]] -> cell 5, seg 0 (0.5) [0.5 on Epop[5]], weight: 4.1363508E-4, delay 1.5
        h("Epop[5] syn_projEE_ampa[4565] = new ampa(0.5)")
        h("Epop[57] netConn_projEE_ampa[4565] = new NetCon(&v(0.5), syn_projEE_ampa[4565], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4566: cell 57, seg 0 (0.5) [0.5 on Epop[57]] -> cell 6, seg 0 (0.5) [0.5 on Epop[6]], weight: 4.1363508E-4, delay 1.5
        h("Epop[6] syn_projEE_ampa[4566] = new ampa(0.5)")
        h("Epop[57] netConn_projEE_ampa[4566] = new NetCon(&v(0.5), syn_projEE_ampa[4566], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4567: cell 57, seg 0 (0.5) [0.5 on Epop[57]] -> cell 7, seg 0 (0.5) [0.5 on Epop[7]], weight: 4.1363508E-4, delay 1.5
        h("Epop[7] syn_projEE_ampa[4567] = new ampa(0.5)")
        h("Epop[57] netConn_projEE_ampa[4567] = new NetCon(&v(0.5), syn_projEE_ampa[4567], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4568: cell 57, seg 0 (0.5) [0.5 on Epop[57]] -> cell 8, seg 0 (0.5) [0.5 on Epop[8]], weight: 4.1363508E-4, delay 1.5
        h("Epop[8] syn_projEE_ampa[4568] = new ampa(0.5)")
        h("Epop[57] netConn_projEE_ampa[4568] = new NetCon(&v(0.5), syn_projEE_ampa[4568], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4569: cell 57, seg 0 (0.5) [0.5 on Epop[57]] -> cell 9, seg 0 (0.5) [0.5 on Epop[9]], weight: 4.1363508E-4, delay 1.5
        h("Epop[9] syn_projEE_ampa[4569] = new ampa(0.5)")
        h("Epop[57] netConn_projEE_ampa[4569] = new NetCon(&v(0.5), syn_projEE_ampa[4569], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4570: cell 57, seg 0 (0.5) [0.5 on Epop[57]] -> cell 10, seg 0 (0.5) [0.5 on Epop[10]], weight: 4.1363508E-4, delay 1.5
        h("Epop[10] syn_projEE_ampa[4570] = new ampa(0.5)")
        h("Epop[57] netConn_projEE_ampa[4570] = new NetCon(&v(0.5), syn_projEE_ampa[4570], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4571: cell 57, seg 0 (0.5) [0.5 on Epop[57]] -> cell 11, seg 0 (0.5) [0.5 on Epop[11]], weight: 4.1363508E-4, delay 1.5
        h("Epop[11] syn_projEE_ampa[4571] = new ampa(0.5)")
        h("Epop[57] netConn_projEE_ampa[4571] = new NetCon(&v(0.5), syn_projEE_ampa[4571], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4572: cell 57, seg 0 (0.5) [0.5 on Epop[57]] -> cell 12, seg 0 (0.5) [0.5 on Epop[12]], weight: 4.1363508E-4, delay 1.5
        h("Epop[12] syn_projEE_ampa[4572] = new ampa(0.5)")
        h("Epop[57] netConn_projEE_ampa[4572] = new NetCon(&v(0.5), syn_projEE_ampa[4572], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4573: cell 57, seg 0 (0.5) [0.5 on Epop[57]] -> cell 13, seg 0 (0.5) [0.5 on Epop[13]], weight: 4.1363508E-4, delay 1.5
        h("Epop[13] syn_projEE_ampa[4573] = new ampa(0.5)")
        h("Epop[57] netConn_projEE_ampa[4573] = new NetCon(&v(0.5), syn_projEE_ampa[4573], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4574: cell 57, seg 0 (0.5) [0.5 on Epop[57]] -> cell 14, seg 0 (0.5) [0.5 on Epop[14]], weight: 4.1363508E-4, delay 1.5
        h("Epop[14] syn_projEE_ampa[4574] = new ampa(0.5)")
        h("Epop[57] netConn_projEE_ampa[4574] = new NetCon(&v(0.5), syn_projEE_ampa[4574], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4575: cell 57, seg 0 (0.5) [0.5 on Epop[57]] -> cell 15, seg 0 (0.5) [0.5 on Epop[15]], weight: 4.1363508E-4, delay 1.5
        h("Epop[15] syn_projEE_ampa[4575] = new ampa(0.5)")
        h("Epop[57] netConn_projEE_ampa[4575] = new NetCon(&v(0.5), syn_projEE_ampa[4575], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4576: cell 57, seg 0 (0.5) [0.5 on Epop[57]] -> cell 16, seg 0 (0.5) [0.5 on Epop[16]], weight: 4.1363508E-4, delay 1.5
        h("Epop[16] syn_projEE_ampa[4576] = new ampa(0.5)")
        h("Epop[57] netConn_projEE_ampa[4576] = new NetCon(&v(0.5), syn_projEE_ampa[4576], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4577: cell 57, seg 0 (0.5) [0.5 on Epop[57]] -> cell 17, seg 0 (0.5) [0.5 on Epop[17]], weight: 4.1363508E-4, delay 1.5
        h("Epop[17] syn_projEE_ampa[4577] = new ampa(0.5)")
        h("Epop[57] netConn_projEE_ampa[4577] = new NetCon(&v(0.5), syn_projEE_ampa[4577], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4578: cell 57, seg 0 (0.5) [0.5 on Epop[57]] -> cell 18, seg 0 (0.5) [0.5 on Epop[18]], weight: 4.1363508E-4, delay 1.5
        h("Epop[18] syn_projEE_ampa[4578] = new ampa(0.5)")
        h("Epop[57] netConn_projEE_ampa[4578] = new NetCon(&v(0.5), syn_projEE_ampa[4578], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4579: cell 57, seg 0 (0.5) [0.5 on Epop[57]] -> cell 19, seg 0 (0.5) [0.5 on Epop[19]], weight: 4.1363508E-4, delay 1.5
        h("Epop[19] syn_projEE_ampa[4579] = new ampa(0.5)")
        h("Epop[57] netConn_projEE_ampa[4579] = new NetCon(&v(0.5), syn_projEE_ampa[4579], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4580: cell 57, seg 0 (0.5) [0.5 on Epop[57]] -> cell 20, seg 0 (0.5) [0.5 on Epop[20]], weight: 4.1363508E-4, delay 1.5
        h("Epop[20] syn_projEE_ampa[4580] = new ampa(0.5)")
        h("Epop[57] netConn_projEE_ampa[4580] = new NetCon(&v(0.5), syn_projEE_ampa[4580], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4581: cell 57, seg 0 (0.5) [0.5 on Epop[57]] -> cell 21, seg 0 (0.5) [0.5 on Epop[21]], weight: 4.1363508E-4, delay 1.5
        h("Epop[21] syn_projEE_ampa[4581] = new ampa(0.5)")
        h("Epop[57] netConn_projEE_ampa[4581] = new NetCon(&v(0.5), syn_projEE_ampa[4581], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4582: cell 57, seg 0 (0.5) [0.5 on Epop[57]] -> cell 22, seg 0 (0.5) [0.5 on Epop[22]], weight: 4.1363508E-4, delay 1.5
        h("Epop[22] syn_projEE_ampa[4582] = new ampa(0.5)")
        h("Epop[57] netConn_projEE_ampa[4582] = new NetCon(&v(0.5), syn_projEE_ampa[4582], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4583: cell 57, seg 0 (0.5) [0.5 on Epop[57]] -> cell 23, seg 0 (0.5) [0.5 on Epop[23]], weight: 4.1363508E-4, delay 1.5
        h("Epop[23] syn_projEE_ampa[4583] = new ampa(0.5)")
        h("Epop[57] netConn_projEE_ampa[4583] = new NetCon(&v(0.5), syn_projEE_ampa[4583], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4584: cell 57, seg 0 (0.5) [0.5 on Epop[57]] -> cell 24, seg 0 (0.5) [0.5 on Epop[24]], weight: 4.1363508E-4, delay 1.5
        h("Epop[24] syn_projEE_ampa[4584] = new ampa(0.5)")
        h("Epop[57] netConn_projEE_ampa[4584] = new NetCon(&v(0.5), syn_projEE_ampa[4584], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4585: cell 57, seg 0 (0.5) [0.5 on Epop[57]] -> cell 25, seg 0 (0.5) [0.5 on Epop[25]], weight: 4.1363508E-4, delay 1.5
        h("Epop[25] syn_projEE_ampa[4585] = new ampa(0.5)")
        h("Epop[57] netConn_projEE_ampa[4585] = new NetCon(&v(0.5), syn_projEE_ampa[4585], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4586: cell 57, seg 0 (0.5) [0.5 on Epop[57]] -> cell 26, seg 0 (0.5) [0.5 on Epop[26]], weight: 4.1363508E-4, delay 1.5
        h("Epop[26] syn_projEE_ampa[4586] = new ampa(0.5)")
        h("Epop[57] netConn_projEE_ampa[4586] = new NetCon(&v(0.5), syn_projEE_ampa[4586], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4587: cell 57, seg 0 (0.5) [0.5 on Epop[57]] -> cell 27, seg 0 (0.5) [0.5 on Epop[27]], weight: 4.1363508E-4, delay 1.5
        h("Epop[27] syn_projEE_ampa[4587] = new ampa(0.5)")
        h("Epop[57] netConn_projEE_ampa[4587] = new NetCon(&v(0.5), syn_projEE_ampa[4587], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4588: cell 57, seg 0 (0.5) [0.5 on Epop[57]] -> cell 28, seg 0 (0.5) [0.5 on Epop[28]], weight: 4.1363508E-4, delay 1.5
        h("Epop[28] syn_projEE_ampa[4588] = new ampa(0.5)")
        h("Epop[57] netConn_projEE_ampa[4588] = new NetCon(&v(0.5), syn_projEE_ampa[4588], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4589: cell 57, seg 0 (0.5) [0.5 on Epop[57]] -> cell 29, seg 0 (0.5) [0.5 on Epop[29]], weight: 4.1363508E-4, delay 1.5
        h("Epop[29] syn_projEE_ampa[4589] = new ampa(0.5)")
        h("Epop[57] netConn_projEE_ampa[4589] = new NetCon(&v(0.5), syn_projEE_ampa[4589], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4590: cell 57, seg 0 (0.5) [0.5 on Epop[57]] -> cell 30, seg 0 (0.5) [0.5 on Epop[30]], weight: 4.1363508E-4, delay 1.5
        h("Epop[30] syn_projEE_ampa[4590] = new ampa(0.5)")
        h("Epop[57] netConn_projEE_ampa[4590] = new NetCon(&v(0.5), syn_projEE_ampa[4590], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4591: cell 57, seg 0 (0.5) [0.5 on Epop[57]] -> cell 31, seg 0 (0.5) [0.5 on Epop[31]], weight: 4.1363508E-4, delay 1.5
        h("Epop[31] syn_projEE_ampa[4591] = new ampa(0.5)")
        h("Epop[57] netConn_projEE_ampa[4591] = new NetCon(&v(0.5), syn_projEE_ampa[4591], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4592: cell 57, seg 0 (0.5) [0.5 on Epop[57]] -> cell 32, seg 0 (0.5) [0.5 on Epop[32]], weight: 4.1363508E-4, delay 1.5
        h("Epop[32] syn_projEE_ampa[4592] = new ampa(0.5)")
        h("Epop[57] netConn_projEE_ampa[4592] = new NetCon(&v(0.5), syn_projEE_ampa[4592], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4593: cell 57, seg 0 (0.5) [0.5 on Epop[57]] -> cell 33, seg 0 (0.5) [0.5 on Epop[33]], weight: 4.1363508E-4, delay 1.5
        h("Epop[33] syn_projEE_ampa[4593] = new ampa(0.5)")
        h("Epop[57] netConn_projEE_ampa[4593] = new NetCon(&v(0.5), syn_projEE_ampa[4593], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4594: cell 57, seg 0 (0.5) [0.5 on Epop[57]] -> cell 34, seg 0 (0.5) [0.5 on Epop[34]], weight: 4.1363508E-4, delay 1.5
        h("Epop[34] syn_projEE_ampa[4594] = new ampa(0.5)")
        h("Epop[57] netConn_projEE_ampa[4594] = new NetCon(&v(0.5), syn_projEE_ampa[4594], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4595: cell 57, seg 0 (0.5) [0.5 on Epop[57]] -> cell 35, seg 0 (0.5) [0.5 on Epop[35]], weight: 4.1363508E-4, delay 1.5
        h("Epop[35] syn_projEE_ampa[4595] = new ampa(0.5)")
        h("Epop[57] netConn_projEE_ampa[4595] = new NetCon(&v(0.5), syn_projEE_ampa[4595], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4596: cell 57, seg 0 (0.5) [0.5 on Epop[57]] -> cell 36, seg 0 (0.5) [0.5 on Epop[36]], weight: 4.1363508E-4, delay 1.5
        h("Epop[36] syn_projEE_ampa[4596] = new ampa(0.5)")
        h("Epop[57] netConn_projEE_ampa[4596] = new NetCon(&v(0.5), syn_projEE_ampa[4596], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4597: cell 57, seg 0 (0.5) [0.5 on Epop[57]] -> cell 37, seg 0 (0.5) [0.5 on Epop[37]], weight: 4.1363508E-4, delay 1.5
        h("Epop[37] syn_projEE_ampa[4597] = new ampa(0.5)")
        h("Epop[57] netConn_projEE_ampa[4597] = new NetCon(&v(0.5), syn_projEE_ampa[4597], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4598: cell 57, seg 0 (0.5) [0.5 on Epop[57]] -> cell 38, seg 0 (0.5) [0.5 on Epop[38]], weight: 4.1363508E-4, delay 1.5
        h("Epop[38] syn_projEE_ampa[4598] = new ampa(0.5)")
        h("Epop[57] netConn_projEE_ampa[4598] = new NetCon(&v(0.5), syn_projEE_ampa[4598], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4599: cell 57, seg 0 (0.5) [0.5 on Epop[57]] -> cell 39, seg 0 (0.5) [0.5 on Epop[39]], weight: 4.1363508E-4, delay 1.5
        h("Epop[39] syn_projEE_ampa[4599] = new ampa(0.5)")
        h("Epop[57] netConn_projEE_ampa[4599] = new NetCon(&v(0.5), syn_projEE_ampa[4599], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4600: cell 57, seg 0 (0.5) [0.5 on Epop[57]] -> cell 40, seg 0 (0.5) [0.5 on Epop[40]], weight: 4.1363508E-4, delay 1.5
        h("Epop[40] syn_projEE_ampa[4600] = new ampa(0.5)")
        h("Epop[57] netConn_projEE_ampa[4600] = new NetCon(&v(0.5), syn_projEE_ampa[4600], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4601: cell 57, seg 0 (0.5) [0.5 on Epop[57]] -> cell 41, seg 0 (0.5) [0.5 on Epop[41]], weight: 4.1363508E-4, delay 1.5
        h("Epop[41] syn_projEE_ampa[4601] = new ampa(0.5)")
        h("Epop[57] netConn_projEE_ampa[4601] = new NetCon(&v(0.5), syn_projEE_ampa[4601], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4602: cell 57, seg 0 (0.5) [0.5 on Epop[57]] -> cell 42, seg 0 (0.5) [0.5 on Epop[42]], weight: 4.1363508E-4, delay 1.5
        h("Epop[42] syn_projEE_ampa[4602] = new ampa(0.5)")
        h("Epop[57] netConn_projEE_ampa[4602] = new NetCon(&v(0.5), syn_projEE_ampa[4602], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4603: cell 57, seg 0 (0.5) [0.5 on Epop[57]] -> cell 43, seg 0 (0.5) [0.5 on Epop[43]], weight: 4.1363508E-4, delay 1.5
        h("Epop[43] syn_projEE_ampa[4603] = new ampa(0.5)")
        h("Epop[57] netConn_projEE_ampa[4603] = new NetCon(&v(0.5), syn_projEE_ampa[4603], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4604: cell 57, seg 0 (0.5) [0.5 on Epop[57]] -> cell 44, seg 0 (0.5) [0.5 on Epop[44]], weight: 4.1363508E-4, delay 1.5
        h("Epop[44] syn_projEE_ampa[4604] = new ampa(0.5)")
        h("Epop[57] netConn_projEE_ampa[4604] = new NetCon(&v(0.5), syn_projEE_ampa[4604], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4605: cell 57, seg 0 (0.5) [0.5 on Epop[57]] -> cell 45, seg 0 (0.5) [0.5 on Epop[45]], weight: 4.1363508E-4, delay 1.5
        h("Epop[45] syn_projEE_ampa[4605] = new ampa(0.5)")
        h("Epop[57] netConn_projEE_ampa[4605] = new NetCon(&v(0.5), syn_projEE_ampa[4605], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4606: cell 57, seg 0 (0.5) [0.5 on Epop[57]] -> cell 46, seg 0 (0.5) [0.5 on Epop[46]], weight: 4.1363508E-4, delay 1.5
        h("Epop[46] syn_projEE_ampa[4606] = new ampa(0.5)")
        h("Epop[57] netConn_projEE_ampa[4606] = new NetCon(&v(0.5), syn_projEE_ampa[4606], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4607: cell 57, seg 0 (0.5) [0.5 on Epop[57]] -> cell 47, seg 0 (0.5) [0.5 on Epop[47]], weight: 4.1363508E-4, delay 1.5
        h("Epop[47] syn_projEE_ampa[4607] = new ampa(0.5)")
        h("Epop[57] netConn_projEE_ampa[4607] = new NetCon(&v(0.5), syn_projEE_ampa[4607], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4608: cell 57, seg 0 (0.5) [0.5 on Epop[57]] -> cell 48, seg 0 (0.5) [0.5 on Epop[48]], weight: 4.1363508E-4, delay 1.5
        h("Epop[48] syn_projEE_ampa[4608] = new ampa(0.5)")
        h("Epop[57] netConn_projEE_ampa[4608] = new NetCon(&v(0.5), syn_projEE_ampa[4608], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4609: cell 57, seg 0 (0.5) [0.5 on Epop[57]] -> cell 49, seg 0 (0.5) [0.5 on Epop[49]], weight: 4.1363508E-4, delay 1.5
        h("Epop[49] syn_projEE_ampa[4609] = new ampa(0.5)")
        h("Epop[57] netConn_projEE_ampa[4609] = new NetCon(&v(0.5), syn_projEE_ampa[4609], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4610: cell 57, seg 0 (0.5) [0.5 on Epop[57]] -> cell 50, seg 0 (0.5) [0.5 on Epop[50]], weight: 4.1363508E-4, delay 1.5
        h("Epop[50] syn_projEE_ampa[4610] = new ampa(0.5)")
        h("Epop[57] netConn_projEE_ampa[4610] = new NetCon(&v(0.5), syn_projEE_ampa[4610], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4611: cell 57, seg 0 (0.5) [0.5 on Epop[57]] -> cell 51, seg 0 (0.5) [0.5 on Epop[51]], weight: 4.1363508E-4, delay 1.5
        h("Epop[51] syn_projEE_ampa[4611] = new ampa(0.5)")
        h("Epop[57] netConn_projEE_ampa[4611] = new NetCon(&v(0.5), syn_projEE_ampa[4611], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4612: cell 57, seg 0 (0.5) [0.5 on Epop[57]] -> cell 52, seg 0 (0.5) [0.5 on Epop[52]], weight: 4.1363508E-4, delay 1.5
        h("Epop[52] syn_projEE_ampa[4612] = new ampa(0.5)")
        h("Epop[57] netConn_projEE_ampa[4612] = new NetCon(&v(0.5), syn_projEE_ampa[4612], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4613: cell 57, seg 0 (0.5) [0.5 on Epop[57]] -> cell 53, seg 0 (0.5) [0.5 on Epop[53]], weight: 4.1363508E-4, delay 1.5
        h("Epop[53] syn_projEE_ampa[4613] = new ampa(0.5)")
        h("Epop[57] netConn_projEE_ampa[4613] = new NetCon(&v(0.5), syn_projEE_ampa[4613], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4614: cell 57, seg 0 (0.5) [0.5 on Epop[57]] -> cell 54, seg 0 (0.5) [0.5 on Epop[54]], weight: 4.1363508E-4, delay 1.5
        h("Epop[54] syn_projEE_ampa[4614] = new ampa(0.5)")
        h("Epop[57] netConn_projEE_ampa[4614] = new NetCon(&v(0.5), syn_projEE_ampa[4614], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4615: cell 57, seg 0 (0.5) [0.5 on Epop[57]] -> cell 55, seg 0 (0.5) [0.5 on Epop[55]], weight: 4.1363508E-4, delay 1.5
        h("Epop[55] syn_projEE_ampa[4615] = new ampa(0.5)")
        h("Epop[57] netConn_projEE_ampa[4615] = new NetCon(&v(0.5), syn_projEE_ampa[4615], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4616: cell 57, seg 0 (0.5) [0.5 on Epop[57]] -> cell 56, seg 0 (0.5) [0.5 on Epop[56]], weight: 4.1363508E-4, delay 1.5
        h("Epop[56] syn_projEE_ampa[4616] = new ampa(0.5)")
        h("Epop[57] netConn_projEE_ampa[4616] = new NetCon(&v(0.5), syn_projEE_ampa[4616], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4617: cell 57, seg 0 (0.5) [0.5 on Epop[57]] -> cell 57, seg 0 (0.5) [0.5 on Epop[57]], weight: 4.1363508E-4, delay 1.5
        h("Epop[57] syn_projEE_ampa[4617] = new ampa(0.5)")
        h("Epop[57] netConn_projEE_ampa[4617] = new NetCon(&v(0.5), syn_projEE_ampa[4617], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4618: cell 57, seg 0 (0.5) [0.5 on Epop[57]] -> cell 58, seg 0 (0.5) [0.5 on Epop[58]], weight: 4.1363508E-4, delay 1.5
        h("Epop[58] syn_projEE_ampa[4618] = new ampa(0.5)")
        h("Epop[57] netConn_projEE_ampa[4618] = new NetCon(&v(0.5), syn_projEE_ampa[4618], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4619: cell 57, seg 0 (0.5) [0.5 on Epop[57]] -> cell 59, seg 0 (0.5) [0.5 on Epop[59]], weight: 4.1363508E-4, delay 1.5
        h("Epop[59] syn_projEE_ampa[4619] = new ampa(0.5)")
        h("Epop[57] netConn_projEE_ampa[4619] = new NetCon(&v(0.5), syn_projEE_ampa[4619], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4620: cell 57, seg 0 (0.5) [0.5 on Epop[57]] -> cell 60, seg 0 (0.5) [0.5 on Epop[60]], weight: 4.1363508E-4, delay 1.5
        h("Epop[60] syn_projEE_ampa[4620] = new ampa(0.5)")
        h("Epop[57] netConn_projEE_ampa[4620] = new NetCon(&v(0.5), syn_projEE_ampa[4620], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4621: cell 57, seg 0 (0.5) [0.5 on Epop[57]] -> cell 61, seg 0 (0.5) [0.5 on Epop[61]], weight: 4.1363508E-4, delay 1.5
        h("Epop[61] syn_projEE_ampa[4621] = new ampa(0.5)")
        h("Epop[57] netConn_projEE_ampa[4621] = new NetCon(&v(0.5), syn_projEE_ampa[4621], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4622: cell 57, seg 0 (0.5) [0.5 on Epop[57]] -> cell 62, seg 0 (0.5) [0.5 on Epop[62]], weight: 4.1363508E-4, delay 1.5
        h("Epop[62] syn_projEE_ampa[4622] = new ampa(0.5)")
        h("Epop[57] netConn_projEE_ampa[4622] = new NetCon(&v(0.5), syn_projEE_ampa[4622], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4623: cell 57, seg 0 (0.5) [0.5 on Epop[57]] -> cell 63, seg 0 (0.5) [0.5 on Epop[63]], weight: 4.1363508E-4, delay 1.5
        h("Epop[63] syn_projEE_ampa[4623] = new ampa(0.5)")
        h("Epop[57] netConn_projEE_ampa[4623] = new NetCon(&v(0.5), syn_projEE_ampa[4623], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4624: cell 57, seg 0 (0.5) [0.5 on Epop[57]] -> cell 64, seg 0 (0.5) [0.5 on Epop[64]], weight: 4.1363508E-4, delay 1.5
        h("Epop[64] syn_projEE_ampa[4624] = new ampa(0.5)")
        h("Epop[57] netConn_projEE_ampa[4624] = new NetCon(&v(0.5), syn_projEE_ampa[4624], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4625: cell 57, seg 0 (0.5) [0.5 on Epop[57]] -> cell 65, seg 0 (0.5) [0.5 on Epop[65]], weight: 4.1363508E-4, delay 1.5
        h("Epop[65] syn_projEE_ampa[4625] = new ampa(0.5)")
        h("Epop[57] netConn_projEE_ampa[4625] = new NetCon(&v(0.5), syn_projEE_ampa[4625], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4626: cell 57, seg 0 (0.5) [0.5 on Epop[57]] -> cell 66, seg 0 (0.5) [0.5 on Epop[66]], weight: 4.1363508E-4, delay 1.5
        h("Epop[66] syn_projEE_ampa[4626] = new ampa(0.5)")
        h("Epop[57] netConn_projEE_ampa[4626] = new NetCon(&v(0.5), syn_projEE_ampa[4626], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4627: cell 57, seg 0 (0.5) [0.5 on Epop[57]] -> cell 67, seg 0 (0.5) [0.5 on Epop[67]], weight: 4.1363508E-4, delay 1.5
        h("Epop[67] syn_projEE_ampa[4627] = new ampa(0.5)")
        h("Epop[57] netConn_projEE_ampa[4627] = new NetCon(&v(0.5), syn_projEE_ampa[4627], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4628: cell 57, seg 0 (0.5) [0.5 on Epop[57]] -> cell 68, seg 0 (0.5) [0.5 on Epop[68]], weight: 4.1363508E-4, delay 1.5
        h("Epop[68] syn_projEE_ampa[4628] = new ampa(0.5)")
        h("Epop[57] netConn_projEE_ampa[4628] = new NetCon(&v(0.5), syn_projEE_ampa[4628], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4629: cell 57, seg 0 (0.5) [0.5 on Epop[57]] -> cell 69, seg 0 (0.5) [0.5 on Epop[69]], weight: 4.1363508E-4, delay 1.5
        h("Epop[69] syn_projEE_ampa[4629] = new ampa(0.5)")
        h("Epop[57] netConn_projEE_ampa[4629] = new NetCon(&v(0.5), syn_projEE_ampa[4629], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4630: cell 57, seg 0 (0.5) [0.5 on Epop[57]] -> cell 70, seg 0 (0.5) [0.5 on Epop[70]], weight: 4.1363508E-4, delay 1.5
        h("Epop[70] syn_projEE_ampa[4630] = new ampa(0.5)")
        h("Epop[57] netConn_projEE_ampa[4630] = new NetCon(&v(0.5), syn_projEE_ampa[4630], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4631: cell 57, seg 0 (0.5) [0.5 on Epop[57]] -> cell 71, seg 0 (0.5) [0.5 on Epop[71]], weight: 4.1363508E-4, delay 1.5
        h("Epop[71] syn_projEE_ampa[4631] = new ampa(0.5)")
        h("Epop[57] netConn_projEE_ampa[4631] = new NetCon(&v(0.5), syn_projEE_ampa[4631], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4632: cell 57, seg 0 (0.5) [0.5 on Epop[57]] -> cell 72, seg 0 (0.5) [0.5 on Epop[72]], weight: 4.1363508E-4, delay 1.5
        h("Epop[72] syn_projEE_ampa[4632] = new ampa(0.5)")
        h("Epop[57] netConn_projEE_ampa[4632] = new NetCon(&v(0.5), syn_projEE_ampa[4632], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4633: cell 57, seg 0 (0.5) [0.5 on Epop[57]] -> cell 73, seg 0 (0.5) [0.5 on Epop[73]], weight: 4.1363508E-4, delay 1.5
        h("Epop[73] syn_projEE_ampa[4633] = new ampa(0.5)")
        h("Epop[57] netConn_projEE_ampa[4633] = new NetCon(&v(0.5), syn_projEE_ampa[4633], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4634: cell 57, seg 0 (0.5) [0.5 on Epop[57]] -> cell 74, seg 0 (0.5) [0.5 on Epop[74]], weight: 4.1363508E-4, delay 1.5
        h("Epop[74] syn_projEE_ampa[4634] = new ampa(0.5)")
        h("Epop[57] netConn_projEE_ampa[4634] = new NetCon(&v(0.5), syn_projEE_ampa[4634], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4635: cell 57, seg 0 (0.5) [0.5 on Epop[57]] -> cell 75, seg 0 (0.5) [0.5 on Epop[75]], weight: 4.1363508E-4, delay 1.5
        h("Epop[75] syn_projEE_ampa[4635] = new ampa(0.5)")
        h("Epop[57] netConn_projEE_ampa[4635] = new NetCon(&v(0.5), syn_projEE_ampa[4635], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4636: cell 57, seg 0 (0.5) [0.5 on Epop[57]] -> cell 76, seg 0 (0.5) [0.5 on Epop[76]], weight: 4.1363508E-4, delay 1.5
        h("Epop[76] syn_projEE_ampa[4636] = new ampa(0.5)")
        h("Epop[57] netConn_projEE_ampa[4636] = new NetCon(&v(0.5), syn_projEE_ampa[4636], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4637: cell 57, seg 0 (0.5) [0.5 on Epop[57]] -> cell 77, seg 0 (0.5) [0.5 on Epop[77]], weight: 4.1363508E-4, delay 1.5
        h("Epop[77] syn_projEE_ampa[4637] = new ampa(0.5)")
        h("Epop[57] netConn_projEE_ampa[4637] = new NetCon(&v(0.5), syn_projEE_ampa[4637], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4638: cell 57, seg 0 (0.5) [0.5 on Epop[57]] -> cell 78, seg 0 (0.5) [0.5 on Epop[78]], weight: 4.1363508E-4, delay 1.5
        h("Epop[78] syn_projEE_ampa[4638] = new ampa(0.5)")
        h("Epop[57] netConn_projEE_ampa[4638] = new NetCon(&v(0.5), syn_projEE_ampa[4638], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4639: cell 57, seg 0 (0.5) [0.5 on Epop[57]] -> cell 79, seg 0 (0.5) [0.5 on Epop[79]], weight: 4.1363508E-4, delay 1.5
        h("Epop[79] syn_projEE_ampa[4639] = new ampa(0.5)")
        h("Epop[57] netConn_projEE_ampa[4639] = new NetCon(&v(0.5), syn_projEE_ampa[4639], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4640: cell 58, seg 0 (0.5) [0.5 on Epop[58]] -> cell 0, seg 0 (0.5) [0.5 on Epop[0]], weight: 4.1363508E-4, delay 1.5
        h("Epop[0] syn_projEE_ampa[4640] = new ampa(0.5)")
        h("Epop[58] netConn_projEE_ampa[4640] = new NetCon(&v(0.5), syn_projEE_ampa[4640], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4641: cell 58, seg 0 (0.5) [0.5 on Epop[58]] -> cell 1, seg 0 (0.5) [0.5 on Epop[1]], weight: 4.1363508E-4, delay 1.5
        h("Epop[1] syn_projEE_ampa[4641] = new ampa(0.5)")
        h("Epop[58] netConn_projEE_ampa[4641] = new NetCon(&v(0.5), syn_projEE_ampa[4641], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4642: cell 58, seg 0 (0.5) [0.5 on Epop[58]] -> cell 2, seg 0 (0.5) [0.5 on Epop[2]], weight: 4.1363508E-4, delay 1.5
        h("Epop[2] syn_projEE_ampa[4642] = new ampa(0.5)")
        h("Epop[58] netConn_projEE_ampa[4642] = new NetCon(&v(0.5), syn_projEE_ampa[4642], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4643: cell 58, seg 0 (0.5) [0.5 on Epop[58]] -> cell 3, seg 0 (0.5) [0.5 on Epop[3]], weight: 4.1363508E-4, delay 1.5
        h("Epop[3] syn_projEE_ampa[4643] = new ampa(0.5)")
        h("Epop[58] netConn_projEE_ampa[4643] = new NetCon(&v(0.5), syn_projEE_ampa[4643], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4644: cell 58, seg 0 (0.5) [0.5 on Epop[58]] -> cell 4, seg 0 (0.5) [0.5 on Epop[4]], weight: 4.1363508E-4, delay 1.5
        h("Epop[4] syn_projEE_ampa[4644] = new ampa(0.5)")
        h("Epop[58] netConn_projEE_ampa[4644] = new NetCon(&v(0.5), syn_projEE_ampa[4644], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4645: cell 58, seg 0 (0.5) [0.5 on Epop[58]] -> cell 5, seg 0 (0.5) [0.5 on Epop[5]], weight: 4.1363508E-4, delay 1.5
        h("Epop[5] syn_projEE_ampa[4645] = new ampa(0.5)")
        h("Epop[58] netConn_projEE_ampa[4645] = new NetCon(&v(0.5), syn_projEE_ampa[4645], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4646: cell 58, seg 0 (0.5) [0.5 on Epop[58]] -> cell 6, seg 0 (0.5) [0.5 on Epop[6]], weight: 4.1363508E-4, delay 1.5
        h("Epop[6] syn_projEE_ampa[4646] = new ampa(0.5)")
        h("Epop[58] netConn_projEE_ampa[4646] = new NetCon(&v(0.5), syn_projEE_ampa[4646], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4647: cell 58, seg 0 (0.5) [0.5 on Epop[58]] -> cell 7, seg 0 (0.5) [0.5 on Epop[7]], weight: 4.1363508E-4, delay 1.5
        h("Epop[7] syn_projEE_ampa[4647] = new ampa(0.5)")
        h("Epop[58] netConn_projEE_ampa[4647] = new NetCon(&v(0.5), syn_projEE_ampa[4647], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4648: cell 58, seg 0 (0.5) [0.5 on Epop[58]] -> cell 8, seg 0 (0.5) [0.5 on Epop[8]], weight: 4.1363508E-4, delay 1.5
        h("Epop[8] syn_projEE_ampa[4648] = new ampa(0.5)")
        h("Epop[58] netConn_projEE_ampa[4648] = new NetCon(&v(0.5), syn_projEE_ampa[4648], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4649: cell 58, seg 0 (0.5) [0.5 on Epop[58]] -> cell 9, seg 0 (0.5) [0.5 on Epop[9]], weight: 4.1363508E-4, delay 1.5
        h("Epop[9] syn_projEE_ampa[4649] = new ampa(0.5)")
        h("Epop[58] netConn_projEE_ampa[4649] = new NetCon(&v(0.5), syn_projEE_ampa[4649], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4650: cell 58, seg 0 (0.5) [0.5 on Epop[58]] -> cell 10, seg 0 (0.5) [0.5 on Epop[10]], weight: 4.1363508E-4, delay 1.5
        h("Epop[10] syn_projEE_ampa[4650] = new ampa(0.5)")
        h("Epop[58] netConn_projEE_ampa[4650] = new NetCon(&v(0.5), syn_projEE_ampa[4650], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4651: cell 58, seg 0 (0.5) [0.5 on Epop[58]] -> cell 11, seg 0 (0.5) [0.5 on Epop[11]], weight: 4.1363508E-4, delay 1.5
        h("Epop[11] syn_projEE_ampa[4651] = new ampa(0.5)")
        h("Epop[58] netConn_projEE_ampa[4651] = new NetCon(&v(0.5), syn_projEE_ampa[4651], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4652: cell 58, seg 0 (0.5) [0.5 on Epop[58]] -> cell 12, seg 0 (0.5) [0.5 on Epop[12]], weight: 4.1363508E-4, delay 1.5
        h("Epop[12] syn_projEE_ampa[4652] = new ampa(0.5)")
        h("Epop[58] netConn_projEE_ampa[4652] = new NetCon(&v(0.5), syn_projEE_ampa[4652], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4653: cell 58, seg 0 (0.5) [0.5 on Epop[58]] -> cell 13, seg 0 (0.5) [0.5 on Epop[13]], weight: 4.1363508E-4, delay 1.5
        h("Epop[13] syn_projEE_ampa[4653] = new ampa(0.5)")
        h("Epop[58] netConn_projEE_ampa[4653] = new NetCon(&v(0.5), syn_projEE_ampa[4653], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4654: cell 58, seg 0 (0.5) [0.5 on Epop[58]] -> cell 14, seg 0 (0.5) [0.5 on Epop[14]], weight: 4.1363508E-4, delay 1.5
        h("Epop[14] syn_projEE_ampa[4654] = new ampa(0.5)")
        h("Epop[58] netConn_projEE_ampa[4654] = new NetCon(&v(0.5), syn_projEE_ampa[4654], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4655: cell 58, seg 0 (0.5) [0.5 on Epop[58]] -> cell 15, seg 0 (0.5) [0.5 on Epop[15]], weight: 4.1363508E-4, delay 1.5
        h("Epop[15] syn_projEE_ampa[4655] = new ampa(0.5)")
        h("Epop[58] netConn_projEE_ampa[4655] = new NetCon(&v(0.5), syn_projEE_ampa[4655], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4656: cell 58, seg 0 (0.5) [0.5 on Epop[58]] -> cell 16, seg 0 (0.5) [0.5 on Epop[16]], weight: 4.1363508E-4, delay 1.5
        h("Epop[16] syn_projEE_ampa[4656] = new ampa(0.5)")
        h("Epop[58] netConn_projEE_ampa[4656] = new NetCon(&v(0.5), syn_projEE_ampa[4656], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4657: cell 58, seg 0 (0.5) [0.5 on Epop[58]] -> cell 17, seg 0 (0.5) [0.5 on Epop[17]], weight: 4.1363508E-4, delay 1.5
        h("Epop[17] syn_projEE_ampa[4657] = new ampa(0.5)")
        h("Epop[58] netConn_projEE_ampa[4657] = new NetCon(&v(0.5), syn_projEE_ampa[4657], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4658: cell 58, seg 0 (0.5) [0.5 on Epop[58]] -> cell 18, seg 0 (0.5) [0.5 on Epop[18]], weight: 4.1363508E-4, delay 1.5
        h("Epop[18] syn_projEE_ampa[4658] = new ampa(0.5)")
        h("Epop[58] netConn_projEE_ampa[4658] = new NetCon(&v(0.5), syn_projEE_ampa[4658], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4659: cell 58, seg 0 (0.5) [0.5 on Epop[58]] -> cell 19, seg 0 (0.5) [0.5 on Epop[19]], weight: 4.1363508E-4, delay 1.5
        h("Epop[19] syn_projEE_ampa[4659] = new ampa(0.5)")
        h("Epop[58] netConn_projEE_ampa[4659] = new NetCon(&v(0.5), syn_projEE_ampa[4659], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4660: cell 58, seg 0 (0.5) [0.5 on Epop[58]] -> cell 20, seg 0 (0.5) [0.5 on Epop[20]], weight: 4.1363508E-4, delay 1.5
        h("Epop[20] syn_projEE_ampa[4660] = new ampa(0.5)")
        h("Epop[58] netConn_projEE_ampa[4660] = new NetCon(&v(0.5), syn_projEE_ampa[4660], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4661: cell 58, seg 0 (0.5) [0.5 on Epop[58]] -> cell 21, seg 0 (0.5) [0.5 on Epop[21]], weight: 4.1363508E-4, delay 1.5
        h("Epop[21] syn_projEE_ampa[4661] = new ampa(0.5)")
        h("Epop[58] netConn_projEE_ampa[4661] = new NetCon(&v(0.5), syn_projEE_ampa[4661], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4662: cell 58, seg 0 (0.5) [0.5 on Epop[58]] -> cell 22, seg 0 (0.5) [0.5 on Epop[22]], weight: 4.1363508E-4, delay 1.5
        h("Epop[22] syn_projEE_ampa[4662] = new ampa(0.5)")
        h("Epop[58] netConn_projEE_ampa[4662] = new NetCon(&v(0.5), syn_projEE_ampa[4662], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4663: cell 58, seg 0 (0.5) [0.5 on Epop[58]] -> cell 23, seg 0 (0.5) [0.5 on Epop[23]], weight: 4.1363508E-4, delay 1.5
        h("Epop[23] syn_projEE_ampa[4663] = new ampa(0.5)")
        h("Epop[58] netConn_projEE_ampa[4663] = new NetCon(&v(0.5), syn_projEE_ampa[4663], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4664: cell 58, seg 0 (0.5) [0.5 on Epop[58]] -> cell 24, seg 0 (0.5) [0.5 on Epop[24]], weight: 4.1363508E-4, delay 1.5
        h("Epop[24] syn_projEE_ampa[4664] = new ampa(0.5)")
        h("Epop[58] netConn_projEE_ampa[4664] = new NetCon(&v(0.5), syn_projEE_ampa[4664], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4665: cell 58, seg 0 (0.5) [0.5 on Epop[58]] -> cell 25, seg 0 (0.5) [0.5 on Epop[25]], weight: 4.1363508E-4, delay 1.5
        h("Epop[25] syn_projEE_ampa[4665] = new ampa(0.5)")
        h("Epop[58] netConn_projEE_ampa[4665] = new NetCon(&v(0.5), syn_projEE_ampa[4665], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4666: cell 58, seg 0 (0.5) [0.5 on Epop[58]] -> cell 26, seg 0 (0.5) [0.5 on Epop[26]], weight: 4.1363508E-4, delay 1.5
        h("Epop[26] syn_projEE_ampa[4666] = new ampa(0.5)")
        h("Epop[58] netConn_projEE_ampa[4666] = new NetCon(&v(0.5), syn_projEE_ampa[4666], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4667: cell 58, seg 0 (0.5) [0.5 on Epop[58]] -> cell 27, seg 0 (0.5) [0.5 on Epop[27]], weight: 4.1363508E-4, delay 1.5
        h("Epop[27] syn_projEE_ampa[4667] = new ampa(0.5)")
        h("Epop[58] netConn_projEE_ampa[4667] = new NetCon(&v(0.5), syn_projEE_ampa[4667], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4668: cell 58, seg 0 (0.5) [0.5 on Epop[58]] -> cell 28, seg 0 (0.5) [0.5 on Epop[28]], weight: 4.1363508E-4, delay 1.5
        h("Epop[28] syn_projEE_ampa[4668] = new ampa(0.5)")
        h("Epop[58] netConn_projEE_ampa[4668] = new NetCon(&v(0.5), syn_projEE_ampa[4668], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4669: cell 58, seg 0 (0.5) [0.5 on Epop[58]] -> cell 29, seg 0 (0.5) [0.5 on Epop[29]], weight: 4.1363508E-4, delay 1.5
        h("Epop[29] syn_projEE_ampa[4669] = new ampa(0.5)")
        h("Epop[58] netConn_projEE_ampa[4669] = new NetCon(&v(0.5), syn_projEE_ampa[4669], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4670: cell 58, seg 0 (0.5) [0.5 on Epop[58]] -> cell 30, seg 0 (0.5) [0.5 on Epop[30]], weight: 4.1363508E-4, delay 1.5
        h("Epop[30] syn_projEE_ampa[4670] = new ampa(0.5)")
        h("Epop[58] netConn_projEE_ampa[4670] = new NetCon(&v(0.5), syn_projEE_ampa[4670], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4671: cell 58, seg 0 (0.5) [0.5 on Epop[58]] -> cell 31, seg 0 (0.5) [0.5 on Epop[31]], weight: 4.1363508E-4, delay 1.5
        h("Epop[31] syn_projEE_ampa[4671] = new ampa(0.5)")
        h("Epop[58] netConn_projEE_ampa[4671] = new NetCon(&v(0.5), syn_projEE_ampa[4671], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4672: cell 58, seg 0 (0.5) [0.5 on Epop[58]] -> cell 32, seg 0 (0.5) [0.5 on Epop[32]], weight: 4.1363508E-4, delay 1.5
        h("Epop[32] syn_projEE_ampa[4672] = new ampa(0.5)")
        h("Epop[58] netConn_projEE_ampa[4672] = new NetCon(&v(0.5), syn_projEE_ampa[4672], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4673: cell 58, seg 0 (0.5) [0.5 on Epop[58]] -> cell 33, seg 0 (0.5) [0.5 on Epop[33]], weight: 4.1363508E-4, delay 1.5
        h("Epop[33] syn_projEE_ampa[4673] = new ampa(0.5)")
        h("Epop[58] netConn_projEE_ampa[4673] = new NetCon(&v(0.5), syn_projEE_ampa[4673], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4674: cell 58, seg 0 (0.5) [0.5 on Epop[58]] -> cell 34, seg 0 (0.5) [0.5 on Epop[34]], weight: 4.1363508E-4, delay 1.5
        h("Epop[34] syn_projEE_ampa[4674] = new ampa(0.5)")
        h("Epop[58] netConn_projEE_ampa[4674] = new NetCon(&v(0.5), syn_projEE_ampa[4674], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4675: cell 58, seg 0 (0.5) [0.5 on Epop[58]] -> cell 35, seg 0 (0.5) [0.5 on Epop[35]], weight: 4.1363508E-4, delay 1.5
        h("Epop[35] syn_projEE_ampa[4675] = new ampa(0.5)")
        h("Epop[58] netConn_projEE_ampa[4675] = new NetCon(&v(0.5), syn_projEE_ampa[4675], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4676: cell 58, seg 0 (0.5) [0.5 on Epop[58]] -> cell 36, seg 0 (0.5) [0.5 on Epop[36]], weight: 4.1363508E-4, delay 1.5
        h("Epop[36] syn_projEE_ampa[4676] = new ampa(0.5)")
        h("Epop[58] netConn_projEE_ampa[4676] = new NetCon(&v(0.5), syn_projEE_ampa[4676], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4677: cell 58, seg 0 (0.5) [0.5 on Epop[58]] -> cell 37, seg 0 (0.5) [0.5 on Epop[37]], weight: 4.1363508E-4, delay 1.5
        h("Epop[37] syn_projEE_ampa[4677] = new ampa(0.5)")
        h("Epop[58] netConn_projEE_ampa[4677] = new NetCon(&v(0.5), syn_projEE_ampa[4677], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4678: cell 58, seg 0 (0.5) [0.5 on Epop[58]] -> cell 38, seg 0 (0.5) [0.5 on Epop[38]], weight: 4.1363508E-4, delay 1.5
        h("Epop[38] syn_projEE_ampa[4678] = new ampa(0.5)")
        h("Epop[58] netConn_projEE_ampa[4678] = new NetCon(&v(0.5), syn_projEE_ampa[4678], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4679: cell 58, seg 0 (0.5) [0.5 on Epop[58]] -> cell 39, seg 0 (0.5) [0.5 on Epop[39]], weight: 4.1363508E-4, delay 1.5
        h("Epop[39] syn_projEE_ampa[4679] = new ampa(0.5)")
        h("Epop[58] netConn_projEE_ampa[4679] = new NetCon(&v(0.5), syn_projEE_ampa[4679], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4680: cell 58, seg 0 (0.5) [0.5 on Epop[58]] -> cell 40, seg 0 (0.5) [0.5 on Epop[40]], weight: 4.1363508E-4, delay 1.5
        h("Epop[40] syn_projEE_ampa[4680] = new ampa(0.5)")
        h("Epop[58] netConn_projEE_ampa[4680] = new NetCon(&v(0.5), syn_projEE_ampa[4680], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4681: cell 58, seg 0 (0.5) [0.5 on Epop[58]] -> cell 41, seg 0 (0.5) [0.5 on Epop[41]], weight: 4.1363508E-4, delay 1.5
        h("Epop[41] syn_projEE_ampa[4681] = new ampa(0.5)")
        h("Epop[58] netConn_projEE_ampa[4681] = new NetCon(&v(0.5), syn_projEE_ampa[4681], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4682: cell 58, seg 0 (0.5) [0.5 on Epop[58]] -> cell 42, seg 0 (0.5) [0.5 on Epop[42]], weight: 4.1363508E-4, delay 1.5
        h("Epop[42] syn_projEE_ampa[4682] = new ampa(0.5)")
        h("Epop[58] netConn_projEE_ampa[4682] = new NetCon(&v(0.5), syn_projEE_ampa[4682], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4683: cell 58, seg 0 (0.5) [0.5 on Epop[58]] -> cell 43, seg 0 (0.5) [0.5 on Epop[43]], weight: 4.1363508E-4, delay 1.5
        h("Epop[43] syn_projEE_ampa[4683] = new ampa(0.5)")
        h("Epop[58] netConn_projEE_ampa[4683] = new NetCon(&v(0.5), syn_projEE_ampa[4683], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4684: cell 58, seg 0 (0.5) [0.5 on Epop[58]] -> cell 44, seg 0 (0.5) [0.5 on Epop[44]], weight: 4.1363508E-4, delay 1.5
        h("Epop[44] syn_projEE_ampa[4684] = new ampa(0.5)")
        h("Epop[58] netConn_projEE_ampa[4684] = new NetCon(&v(0.5), syn_projEE_ampa[4684], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4685: cell 58, seg 0 (0.5) [0.5 on Epop[58]] -> cell 45, seg 0 (0.5) [0.5 on Epop[45]], weight: 4.1363508E-4, delay 1.5
        h("Epop[45] syn_projEE_ampa[4685] = new ampa(0.5)")
        h("Epop[58] netConn_projEE_ampa[4685] = new NetCon(&v(0.5), syn_projEE_ampa[4685], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4686: cell 58, seg 0 (0.5) [0.5 on Epop[58]] -> cell 46, seg 0 (0.5) [0.5 on Epop[46]], weight: 4.1363508E-4, delay 1.5
        h("Epop[46] syn_projEE_ampa[4686] = new ampa(0.5)")
        h("Epop[58] netConn_projEE_ampa[4686] = new NetCon(&v(0.5), syn_projEE_ampa[4686], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4687: cell 58, seg 0 (0.5) [0.5 on Epop[58]] -> cell 47, seg 0 (0.5) [0.5 on Epop[47]], weight: 4.1363508E-4, delay 1.5
        h("Epop[47] syn_projEE_ampa[4687] = new ampa(0.5)")
        h("Epop[58] netConn_projEE_ampa[4687] = new NetCon(&v(0.5), syn_projEE_ampa[4687], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4688: cell 58, seg 0 (0.5) [0.5 on Epop[58]] -> cell 48, seg 0 (0.5) [0.5 on Epop[48]], weight: 4.1363508E-4, delay 1.5
        h("Epop[48] syn_projEE_ampa[4688] = new ampa(0.5)")
        h("Epop[58] netConn_projEE_ampa[4688] = new NetCon(&v(0.5), syn_projEE_ampa[4688], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4689: cell 58, seg 0 (0.5) [0.5 on Epop[58]] -> cell 49, seg 0 (0.5) [0.5 on Epop[49]], weight: 4.1363508E-4, delay 1.5
        h("Epop[49] syn_projEE_ampa[4689] = new ampa(0.5)")
        h("Epop[58] netConn_projEE_ampa[4689] = new NetCon(&v(0.5), syn_projEE_ampa[4689], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4690: cell 58, seg 0 (0.5) [0.5 on Epop[58]] -> cell 50, seg 0 (0.5) [0.5 on Epop[50]], weight: 4.1363508E-4, delay 1.5
        h("Epop[50] syn_projEE_ampa[4690] = new ampa(0.5)")
        h("Epop[58] netConn_projEE_ampa[4690] = new NetCon(&v(0.5), syn_projEE_ampa[4690], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4691: cell 58, seg 0 (0.5) [0.5 on Epop[58]] -> cell 51, seg 0 (0.5) [0.5 on Epop[51]], weight: 4.1363508E-4, delay 1.5
        h("Epop[51] syn_projEE_ampa[4691] = new ampa(0.5)")
        h("Epop[58] netConn_projEE_ampa[4691] = new NetCon(&v(0.5), syn_projEE_ampa[4691], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4692: cell 58, seg 0 (0.5) [0.5 on Epop[58]] -> cell 52, seg 0 (0.5) [0.5 on Epop[52]], weight: 4.1363508E-4, delay 1.5
        h("Epop[52] syn_projEE_ampa[4692] = new ampa(0.5)")
        h("Epop[58] netConn_projEE_ampa[4692] = new NetCon(&v(0.5), syn_projEE_ampa[4692], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4693: cell 58, seg 0 (0.5) [0.5 on Epop[58]] -> cell 53, seg 0 (0.5) [0.5 on Epop[53]], weight: 4.1363508E-4, delay 1.5
        h("Epop[53] syn_projEE_ampa[4693] = new ampa(0.5)")
        h("Epop[58] netConn_projEE_ampa[4693] = new NetCon(&v(0.5), syn_projEE_ampa[4693], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4694: cell 58, seg 0 (0.5) [0.5 on Epop[58]] -> cell 54, seg 0 (0.5) [0.5 on Epop[54]], weight: 4.1363508E-4, delay 1.5
        h("Epop[54] syn_projEE_ampa[4694] = new ampa(0.5)")
        h("Epop[58] netConn_projEE_ampa[4694] = new NetCon(&v(0.5), syn_projEE_ampa[4694], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4695: cell 58, seg 0 (0.5) [0.5 on Epop[58]] -> cell 55, seg 0 (0.5) [0.5 on Epop[55]], weight: 4.1363508E-4, delay 1.5
        h("Epop[55] syn_projEE_ampa[4695] = new ampa(0.5)")
        h("Epop[58] netConn_projEE_ampa[4695] = new NetCon(&v(0.5), syn_projEE_ampa[4695], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4696: cell 58, seg 0 (0.5) [0.5 on Epop[58]] -> cell 56, seg 0 (0.5) [0.5 on Epop[56]], weight: 4.1363508E-4, delay 1.5
        h("Epop[56] syn_projEE_ampa[4696] = new ampa(0.5)")
        h("Epop[58] netConn_projEE_ampa[4696] = new NetCon(&v(0.5), syn_projEE_ampa[4696], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4697: cell 58, seg 0 (0.5) [0.5 on Epop[58]] -> cell 57, seg 0 (0.5) [0.5 on Epop[57]], weight: 4.1363508E-4, delay 1.5
        h("Epop[57] syn_projEE_ampa[4697] = new ampa(0.5)")
        h("Epop[58] netConn_projEE_ampa[4697] = new NetCon(&v(0.5), syn_projEE_ampa[4697], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4698: cell 58, seg 0 (0.5) [0.5 on Epop[58]] -> cell 58, seg 0 (0.5) [0.5 on Epop[58]], weight: 4.1363508E-4, delay 1.5
        h("Epop[58] syn_projEE_ampa[4698] = new ampa(0.5)")
        h("Epop[58] netConn_projEE_ampa[4698] = new NetCon(&v(0.5), syn_projEE_ampa[4698], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4699: cell 58, seg 0 (0.5) [0.5 on Epop[58]] -> cell 59, seg 0 (0.5) [0.5 on Epop[59]], weight: 4.1363508E-4, delay 1.5
        h("Epop[59] syn_projEE_ampa[4699] = new ampa(0.5)")
        h("Epop[58] netConn_projEE_ampa[4699] = new NetCon(&v(0.5), syn_projEE_ampa[4699], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4700: cell 58, seg 0 (0.5) [0.5 on Epop[58]] -> cell 60, seg 0 (0.5) [0.5 on Epop[60]], weight: 4.1363508E-4, delay 1.5
        h("Epop[60] syn_projEE_ampa[4700] = new ampa(0.5)")
        h("Epop[58] netConn_projEE_ampa[4700] = new NetCon(&v(0.5), syn_projEE_ampa[4700], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4701: cell 58, seg 0 (0.5) [0.5 on Epop[58]] -> cell 61, seg 0 (0.5) [0.5 on Epop[61]], weight: 4.1363508E-4, delay 1.5
        h("Epop[61] syn_projEE_ampa[4701] = new ampa(0.5)")
        h("Epop[58] netConn_projEE_ampa[4701] = new NetCon(&v(0.5), syn_projEE_ampa[4701], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4702: cell 58, seg 0 (0.5) [0.5 on Epop[58]] -> cell 62, seg 0 (0.5) [0.5 on Epop[62]], weight: 4.1363508E-4, delay 1.5
        h("Epop[62] syn_projEE_ampa[4702] = new ampa(0.5)")
        h("Epop[58] netConn_projEE_ampa[4702] = new NetCon(&v(0.5), syn_projEE_ampa[4702], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4703: cell 58, seg 0 (0.5) [0.5 on Epop[58]] -> cell 63, seg 0 (0.5) [0.5 on Epop[63]], weight: 4.1363508E-4, delay 1.5
        h("Epop[63] syn_projEE_ampa[4703] = new ampa(0.5)")
        h("Epop[58] netConn_projEE_ampa[4703] = new NetCon(&v(0.5), syn_projEE_ampa[4703], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4704: cell 58, seg 0 (0.5) [0.5 on Epop[58]] -> cell 64, seg 0 (0.5) [0.5 on Epop[64]], weight: 4.1363508E-4, delay 1.5
        h("Epop[64] syn_projEE_ampa[4704] = new ampa(0.5)")
        h("Epop[58] netConn_projEE_ampa[4704] = new NetCon(&v(0.5), syn_projEE_ampa[4704], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4705: cell 58, seg 0 (0.5) [0.5 on Epop[58]] -> cell 65, seg 0 (0.5) [0.5 on Epop[65]], weight: 4.1363508E-4, delay 1.5
        h("Epop[65] syn_projEE_ampa[4705] = new ampa(0.5)")
        h("Epop[58] netConn_projEE_ampa[4705] = new NetCon(&v(0.5), syn_projEE_ampa[4705], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4706: cell 58, seg 0 (0.5) [0.5 on Epop[58]] -> cell 66, seg 0 (0.5) [0.5 on Epop[66]], weight: 4.1363508E-4, delay 1.5
        h("Epop[66] syn_projEE_ampa[4706] = new ampa(0.5)")
        h("Epop[58] netConn_projEE_ampa[4706] = new NetCon(&v(0.5), syn_projEE_ampa[4706], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4707: cell 58, seg 0 (0.5) [0.5 on Epop[58]] -> cell 67, seg 0 (0.5) [0.5 on Epop[67]], weight: 4.1363508E-4, delay 1.5
        h("Epop[67] syn_projEE_ampa[4707] = new ampa(0.5)")
        h("Epop[58] netConn_projEE_ampa[4707] = new NetCon(&v(0.5), syn_projEE_ampa[4707], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4708: cell 58, seg 0 (0.5) [0.5 on Epop[58]] -> cell 68, seg 0 (0.5) [0.5 on Epop[68]], weight: 4.1363508E-4, delay 1.5
        h("Epop[68] syn_projEE_ampa[4708] = new ampa(0.5)")
        h("Epop[58] netConn_projEE_ampa[4708] = new NetCon(&v(0.5), syn_projEE_ampa[4708], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4709: cell 58, seg 0 (0.5) [0.5 on Epop[58]] -> cell 69, seg 0 (0.5) [0.5 on Epop[69]], weight: 4.1363508E-4, delay 1.5
        h("Epop[69] syn_projEE_ampa[4709] = new ampa(0.5)")
        h("Epop[58] netConn_projEE_ampa[4709] = new NetCon(&v(0.5), syn_projEE_ampa[4709], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4710: cell 58, seg 0 (0.5) [0.5 on Epop[58]] -> cell 70, seg 0 (0.5) [0.5 on Epop[70]], weight: 4.1363508E-4, delay 1.5
        h("Epop[70] syn_projEE_ampa[4710] = new ampa(0.5)")
        h("Epop[58] netConn_projEE_ampa[4710] = new NetCon(&v(0.5), syn_projEE_ampa[4710], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4711: cell 58, seg 0 (0.5) [0.5 on Epop[58]] -> cell 71, seg 0 (0.5) [0.5 on Epop[71]], weight: 4.1363508E-4, delay 1.5
        h("Epop[71] syn_projEE_ampa[4711] = new ampa(0.5)")
        h("Epop[58] netConn_projEE_ampa[4711] = new NetCon(&v(0.5), syn_projEE_ampa[4711], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4712: cell 58, seg 0 (0.5) [0.5 on Epop[58]] -> cell 72, seg 0 (0.5) [0.5 on Epop[72]], weight: 4.1363508E-4, delay 1.5
        h("Epop[72] syn_projEE_ampa[4712] = new ampa(0.5)")
        h("Epop[58] netConn_projEE_ampa[4712] = new NetCon(&v(0.5), syn_projEE_ampa[4712], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4713: cell 58, seg 0 (0.5) [0.5 on Epop[58]] -> cell 73, seg 0 (0.5) [0.5 on Epop[73]], weight: 4.1363508E-4, delay 1.5
        h("Epop[73] syn_projEE_ampa[4713] = new ampa(0.5)")
        h("Epop[58] netConn_projEE_ampa[4713] = new NetCon(&v(0.5), syn_projEE_ampa[4713], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4714: cell 58, seg 0 (0.5) [0.5 on Epop[58]] -> cell 74, seg 0 (0.5) [0.5 on Epop[74]], weight: 4.1363508E-4, delay 1.5
        h("Epop[74] syn_projEE_ampa[4714] = new ampa(0.5)")
        h("Epop[58] netConn_projEE_ampa[4714] = new NetCon(&v(0.5), syn_projEE_ampa[4714], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4715: cell 58, seg 0 (0.5) [0.5 on Epop[58]] -> cell 75, seg 0 (0.5) [0.5 on Epop[75]], weight: 4.1363508E-4, delay 1.5
        h("Epop[75] syn_projEE_ampa[4715] = new ampa(0.5)")
        h("Epop[58] netConn_projEE_ampa[4715] = new NetCon(&v(0.5), syn_projEE_ampa[4715], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4716: cell 58, seg 0 (0.5) [0.5 on Epop[58]] -> cell 76, seg 0 (0.5) [0.5 on Epop[76]], weight: 4.1363508E-4, delay 1.5
        h("Epop[76] syn_projEE_ampa[4716] = new ampa(0.5)")
        h("Epop[58] netConn_projEE_ampa[4716] = new NetCon(&v(0.5), syn_projEE_ampa[4716], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4717: cell 58, seg 0 (0.5) [0.5 on Epop[58]] -> cell 77, seg 0 (0.5) [0.5 on Epop[77]], weight: 4.1363508E-4, delay 1.5
        h("Epop[77] syn_projEE_ampa[4717] = new ampa(0.5)")
        h("Epop[58] netConn_projEE_ampa[4717] = new NetCon(&v(0.5), syn_projEE_ampa[4717], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4718: cell 58, seg 0 (0.5) [0.5 on Epop[58]] -> cell 78, seg 0 (0.5) [0.5 on Epop[78]], weight: 4.1363508E-4, delay 1.5
        h("Epop[78] syn_projEE_ampa[4718] = new ampa(0.5)")
        h("Epop[58] netConn_projEE_ampa[4718] = new NetCon(&v(0.5), syn_projEE_ampa[4718], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4719: cell 58, seg 0 (0.5) [0.5 on Epop[58]] -> cell 79, seg 0 (0.5) [0.5 on Epop[79]], weight: 4.1363508E-4, delay 1.5
        h("Epop[79] syn_projEE_ampa[4719] = new ampa(0.5)")
        h("Epop[58] netConn_projEE_ampa[4719] = new NetCon(&v(0.5), syn_projEE_ampa[4719], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4720: cell 59, seg 0 (0.5) [0.5 on Epop[59]] -> cell 0, seg 0 (0.5) [0.5 on Epop[0]], weight: 4.1363508E-4, delay 1.5
        h("Epop[0] syn_projEE_ampa[4720] = new ampa(0.5)")
        h("Epop[59] netConn_projEE_ampa[4720] = new NetCon(&v(0.5), syn_projEE_ampa[4720], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4721: cell 59, seg 0 (0.5) [0.5 on Epop[59]] -> cell 1, seg 0 (0.5) [0.5 on Epop[1]], weight: 4.1363508E-4, delay 1.5
        h("Epop[1] syn_projEE_ampa[4721] = new ampa(0.5)")
        h("Epop[59] netConn_projEE_ampa[4721] = new NetCon(&v(0.5), syn_projEE_ampa[4721], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4722: cell 59, seg 0 (0.5) [0.5 on Epop[59]] -> cell 2, seg 0 (0.5) [0.5 on Epop[2]], weight: 4.1363508E-4, delay 1.5
        h("Epop[2] syn_projEE_ampa[4722] = new ampa(0.5)")
        h("Epop[59] netConn_projEE_ampa[4722] = new NetCon(&v(0.5), syn_projEE_ampa[4722], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4723: cell 59, seg 0 (0.5) [0.5 on Epop[59]] -> cell 3, seg 0 (0.5) [0.5 on Epop[3]], weight: 4.1363508E-4, delay 1.5
        h("Epop[3] syn_projEE_ampa[4723] = new ampa(0.5)")
        h("Epop[59] netConn_projEE_ampa[4723] = new NetCon(&v(0.5), syn_projEE_ampa[4723], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4724: cell 59, seg 0 (0.5) [0.5 on Epop[59]] -> cell 4, seg 0 (0.5) [0.5 on Epop[4]], weight: 4.1363508E-4, delay 1.5
        h("Epop[4] syn_projEE_ampa[4724] = new ampa(0.5)")
        h("Epop[59] netConn_projEE_ampa[4724] = new NetCon(&v(0.5), syn_projEE_ampa[4724], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4725: cell 59, seg 0 (0.5) [0.5 on Epop[59]] -> cell 5, seg 0 (0.5) [0.5 on Epop[5]], weight: 4.1363508E-4, delay 1.5
        h("Epop[5] syn_projEE_ampa[4725] = new ampa(0.5)")
        h("Epop[59] netConn_projEE_ampa[4725] = new NetCon(&v(0.5), syn_projEE_ampa[4725], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4726: cell 59, seg 0 (0.5) [0.5 on Epop[59]] -> cell 6, seg 0 (0.5) [0.5 on Epop[6]], weight: 4.1363508E-4, delay 1.5
        h("Epop[6] syn_projEE_ampa[4726] = new ampa(0.5)")
        h("Epop[59] netConn_projEE_ampa[4726] = new NetCon(&v(0.5), syn_projEE_ampa[4726], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4727: cell 59, seg 0 (0.5) [0.5 on Epop[59]] -> cell 7, seg 0 (0.5) [0.5 on Epop[7]], weight: 4.1363508E-4, delay 1.5
        h("Epop[7] syn_projEE_ampa[4727] = new ampa(0.5)")
        h("Epop[59] netConn_projEE_ampa[4727] = new NetCon(&v(0.5), syn_projEE_ampa[4727], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4728: cell 59, seg 0 (0.5) [0.5 on Epop[59]] -> cell 8, seg 0 (0.5) [0.5 on Epop[8]], weight: 4.1363508E-4, delay 1.5
        h("Epop[8] syn_projEE_ampa[4728] = new ampa(0.5)")
        h("Epop[59] netConn_projEE_ampa[4728] = new NetCon(&v(0.5), syn_projEE_ampa[4728], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4729: cell 59, seg 0 (0.5) [0.5 on Epop[59]] -> cell 9, seg 0 (0.5) [0.5 on Epop[9]], weight: 4.1363508E-4, delay 1.5
        h("Epop[9] syn_projEE_ampa[4729] = new ampa(0.5)")
        h("Epop[59] netConn_projEE_ampa[4729] = new NetCon(&v(0.5), syn_projEE_ampa[4729], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4730: cell 59, seg 0 (0.5) [0.5 on Epop[59]] -> cell 10, seg 0 (0.5) [0.5 on Epop[10]], weight: 4.1363508E-4, delay 1.5
        h("Epop[10] syn_projEE_ampa[4730] = new ampa(0.5)")
        h("Epop[59] netConn_projEE_ampa[4730] = new NetCon(&v(0.5), syn_projEE_ampa[4730], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4731: cell 59, seg 0 (0.5) [0.5 on Epop[59]] -> cell 11, seg 0 (0.5) [0.5 on Epop[11]], weight: 4.1363508E-4, delay 1.5
        h("Epop[11] syn_projEE_ampa[4731] = new ampa(0.5)")
        h("Epop[59] netConn_projEE_ampa[4731] = new NetCon(&v(0.5), syn_projEE_ampa[4731], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4732: cell 59, seg 0 (0.5) [0.5 on Epop[59]] -> cell 12, seg 0 (0.5) [0.5 on Epop[12]], weight: 4.1363508E-4, delay 1.5
        h("Epop[12] syn_projEE_ampa[4732] = new ampa(0.5)")
        h("Epop[59] netConn_projEE_ampa[4732] = new NetCon(&v(0.5), syn_projEE_ampa[4732], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4733: cell 59, seg 0 (0.5) [0.5 on Epop[59]] -> cell 13, seg 0 (0.5) [0.5 on Epop[13]], weight: 4.1363508E-4, delay 1.5
        h("Epop[13] syn_projEE_ampa[4733] = new ampa(0.5)")
        h("Epop[59] netConn_projEE_ampa[4733] = new NetCon(&v(0.5), syn_projEE_ampa[4733], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4734: cell 59, seg 0 (0.5) [0.5 on Epop[59]] -> cell 14, seg 0 (0.5) [0.5 on Epop[14]], weight: 4.1363508E-4, delay 1.5
        h("Epop[14] syn_projEE_ampa[4734] = new ampa(0.5)")
        h("Epop[59] netConn_projEE_ampa[4734] = new NetCon(&v(0.5), syn_projEE_ampa[4734], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4735: cell 59, seg 0 (0.5) [0.5 on Epop[59]] -> cell 15, seg 0 (0.5) [0.5 on Epop[15]], weight: 4.1363508E-4, delay 1.5
        h("Epop[15] syn_projEE_ampa[4735] = new ampa(0.5)")
        h("Epop[59] netConn_projEE_ampa[4735] = new NetCon(&v(0.5), syn_projEE_ampa[4735], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4736: cell 59, seg 0 (0.5) [0.5 on Epop[59]] -> cell 16, seg 0 (0.5) [0.5 on Epop[16]], weight: 4.1363508E-4, delay 1.5
        h("Epop[16] syn_projEE_ampa[4736] = new ampa(0.5)")
        h("Epop[59] netConn_projEE_ampa[4736] = new NetCon(&v(0.5), syn_projEE_ampa[4736], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4737: cell 59, seg 0 (0.5) [0.5 on Epop[59]] -> cell 17, seg 0 (0.5) [0.5 on Epop[17]], weight: 4.1363508E-4, delay 1.5
        h("Epop[17] syn_projEE_ampa[4737] = new ampa(0.5)")
        h("Epop[59] netConn_projEE_ampa[4737] = new NetCon(&v(0.5), syn_projEE_ampa[4737], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4738: cell 59, seg 0 (0.5) [0.5 on Epop[59]] -> cell 18, seg 0 (0.5) [0.5 on Epop[18]], weight: 4.1363508E-4, delay 1.5
        h("Epop[18] syn_projEE_ampa[4738] = new ampa(0.5)")
        h("Epop[59] netConn_projEE_ampa[4738] = new NetCon(&v(0.5), syn_projEE_ampa[4738], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4739: cell 59, seg 0 (0.5) [0.5 on Epop[59]] -> cell 19, seg 0 (0.5) [0.5 on Epop[19]], weight: 4.1363508E-4, delay 1.5
        h("Epop[19] syn_projEE_ampa[4739] = new ampa(0.5)")
        h("Epop[59] netConn_projEE_ampa[4739] = new NetCon(&v(0.5), syn_projEE_ampa[4739], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4740: cell 59, seg 0 (0.5) [0.5 on Epop[59]] -> cell 20, seg 0 (0.5) [0.5 on Epop[20]], weight: 4.1363508E-4, delay 1.5
        h("Epop[20] syn_projEE_ampa[4740] = new ampa(0.5)")
        h("Epop[59] netConn_projEE_ampa[4740] = new NetCon(&v(0.5), syn_projEE_ampa[4740], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4741: cell 59, seg 0 (0.5) [0.5 on Epop[59]] -> cell 21, seg 0 (0.5) [0.5 on Epop[21]], weight: 4.1363508E-4, delay 1.5
        h("Epop[21] syn_projEE_ampa[4741] = new ampa(0.5)")
        h("Epop[59] netConn_projEE_ampa[4741] = new NetCon(&v(0.5), syn_projEE_ampa[4741], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4742: cell 59, seg 0 (0.5) [0.5 on Epop[59]] -> cell 22, seg 0 (0.5) [0.5 on Epop[22]], weight: 4.1363508E-4, delay 1.5
        h("Epop[22] syn_projEE_ampa[4742] = new ampa(0.5)")
        h("Epop[59] netConn_projEE_ampa[4742] = new NetCon(&v(0.5), syn_projEE_ampa[4742], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4743: cell 59, seg 0 (0.5) [0.5 on Epop[59]] -> cell 23, seg 0 (0.5) [0.5 on Epop[23]], weight: 4.1363508E-4, delay 1.5
        h("Epop[23] syn_projEE_ampa[4743] = new ampa(0.5)")
        h("Epop[59] netConn_projEE_ampa[4743] = new NetCon(&v(0.5), syn_projEE_ampa[4743], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4744: cell 59, seg 0 (0.5) [0.5 on Epop[59]] -> cell 24, seg 0 (0.5) [0.5 on Epop[24]], weight: 4.1363508E-4, delay 1.5
        h("Epop[24] syn_projEE_ampa[4744] = new ampa(0.5)")
        h("Epop[59] netConn_projEE_ampa[4744] = new NetCon(&v(0.5), syn_projEE_ampa[4744], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4745: cell 59, seg 0 (0.5) [0.5 on Epop[59]] -> cell 25, seg 0 (0.5) [0.5 on Epop[25]], weight: 4.1363508E-4, delay 1.5
        h("Epop[25] syn_projEE_ampa[4745] = new ampa(0.5)")
        h("Epop[59] netConn_projEE_ampa[4745] = new NetCon(&v(0.5), syn_projEE_ampa[4745], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4746: cell 59, seg 0 (0.5) [0.5 on Epop[59]] -> cell 26, seg 0 (0.5) [0.5 on Epop[26]], weight: 4.1363508E-4, delay 1.5
        h("Epop[26] syn_projEE_ampa[4746] = new ampa(0.5)")
        h("Epop[59] netConn_projEE_ampa[4746] = new NetCon(&v(0.5), syn_projEE_ampa[4746], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4747: cell 59, seg 0 (0.5) [0.5 on Epop[59]] -> cell 27, seg 0 (0.5) [0.5 on Epop[27]], weight: 4.1363508E-4, delay 1.5
        h("Epop[27] syn_projEE_ampa[4747] = new ampa(0.5)")
        h("Epop[59] netConn_projEE_ampa[4747] = new NetCon(&v(0.5), syn_projEE_ampa[4747], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4748: cell 59, seg 0 (0.5) [0.5 on Epop[59]] -> cell 28, seg 0 (0.5) [0.5 on Epop[28]], weight: 4.1363508E-4, delay 1.5
        h("Epop[28] syn_projEE_ampa[4748] = new ampa(0.5)")
        h("Epop[59] netConn_projEE_ampa[4748] = new NetCon(&v(0.5), syn_projEE_ampa[4748], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4749: cell 59, seg 0 (0.5) [0.5 on Epop[59]] -> cell 29, seg 0 (0.5) [0.5 on Epop[29]], weight: 4.1363508E-4, delay 1.5
        h("Epop[29] syn_projEE_ampa[4749] = new ampa(0.5)")
        h("Epop[59] netConn_projEE_ampa[4749] = new NetCon(&v(0.5), syn_projEE_ampa[4749], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4750: cell 59, seg 0 (0.5) [0.5 on Epop[59]] -> cell 30, seg 0 (0.5) [0.5 on Epop[30]], weight: 4.1363508E-4, delay 1.5
        h("Epop[30] syn_projEE_ampa[4750] = new ampa(0.5)")
        h("Epop[59] netConn_projEE_ampa[4750] = new NetCon(&v(0.5), syn_projEE_ampa[4750], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4751: cell 59, seg 0 (0.5) [0.5 on Epop[59]] -> cell 31, seg 0 (0.5) [0.5 on Epop[31]], weight: 4.1363508E-4, delay 1.5
        h("Epop[31] syn_projEE_ampa[4751] = new ampa(0.5)")
        h("Epop[59] netConn_projEE_ampa[4751] = new NetCon(&v(0.5), syn_projEE_ampa[4751], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4752: cell 59, seg 0 (0.5) [0.5 on Epop[59]] -> cell 32, seg 0 (0.5) [0.5 on Epop[32]], weight: 4.1363508E-4, delay 1.5
        h("Epop[32] syn_projEE_ampa[4752] = new ampa(0.5)")
        h("Epop[59] netConn_projEE_ampa[4752] = new NetCon(&v(0.5), syn_projEE_ampa[4752], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4753: cell 59, seg 0 (0.5) [0.5 on Epop[59]] -> cell 33, seg 0 (0.5) [0.5 on Epop[33]], weight: 4.1363508E-4, delay 1.5
        h("Epop[33] syn_projEE_ampa[4753] = new ampa(0.5)")
        h("Epop[59] netConn_projEE_ampa[4753] = new NetCon(&v(0.5), syn_projEE_ampa[4753], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4754: cell 59, seg 0 (0.5) [0.5 on Epop[59]] -> cell 34, seg 0 (0.5) [0.5 on Epop[34]], weight: 4.1363508E-4, delay 1.5
        h("Epop[34] syn_projEE_ampa[4754] = new ampa(0.5)")
        h("Epop[59] netConn_projEE_ampa[4754] = new NetCon(&v(0.5), syn_projEE_ampa[4754], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4755: cell 59, seg 0 (0.5) [0.5 on Epop[59]] -> cell 35, seg 0 (0.5) [0.5 on Epop[35]], weight: 4.1363508E-4, delay 1.5
        h("Epop[35] syn_projEE_ampa[4755] = new ampa(0.5)")
        h("Epop[59] netConn_projEE_ampa[4755] = new NetCon(&v(0.5), syn_projEE_ampa[4755], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4756: cell 59, seg 0 (0.5) [0.5 on Epop[59]] -> cell 36, seg 0 (0.5) [0.5 on Epop[36]], weight: 4.1363508E-4, delay 1.5
        h("Epop[36] syn_projEE_ampa[4756] = new ampa(0.5)")
        h("Epop[59] netConn_projEE_ampa[4756] = new NetCon(&v(0.5), syn_projEE_ampa[4756], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4757: cell 59, seg 0 (0.5) [0.5 on Epop[59]] -> cell 37, seg 0 (0.5) [0.5 on Epop[37]], weight: 4.1363508E-4, delay 1.5
        h("Epop[37] syn_projEE_ampa[4757] = new ampa(0.5)")
        h("Epop[59] netConn_projEE_ampa[4757] = new NetCon(&v(0.5), syn_projEE_ampa[4757], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4758: cell 59, seg 0 (0.5) [0.5 on Epop[59]] -> cell 38, seg 0 (0.5) [0.5 on Epop[38]], weight: 4.1363508E-4, delay 1.5
        h("Epop[38] syn_projEE_ampa[4758] = new ampa(0.5)")
        h("Epop[59] netConn_projEE_ampa[4758] = new NetCon(&v(0.5), syn_projEE_ampa[4758], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4759: cell 59, seg 0 (0.5) [0.5 on Epop[59]] -> cell 39, seg 0 (0.5) [0.5 on Epop[39]], weight: 4.1363508E-4, delay 1.5
        h("Epop[39] syn_projEE_ampa[4759] = new ampa(0.5)")
        h("Epop[59] netConn_projEE_ampa[4759] = new NetCon(&v(0.5), syn_projEE_ampa[4759], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4760: cell 59, seg 0 (0.5) [0.5 on Epop[59]] -> cell 40, seg 0 (0.5) [0.5 on Epop[40]], weight: 4.1363508E-4, delay 1.5
        h("Epop[40] syn_projEE_ampa[4760] = new ampa(0.5)")
        h("Epop[59] netConn_projEE_ampa[4760] = new NetCon(&v(0.5), syn_projEE_ampa[4760], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4761: cell 59, seg 0 (0.5) [0.5 on Epop[59]] -> cell 41, seg 0 (0.5) [0.5 on Epop[41]], weight: 4.1363508E-4, delay 1.5
        h("Epop[41] syn_projEE_ampa[4761] = new ampa(0.5)")
        h("Epop[59] netConn_projEE_ampa[4761] = new NetCon(&v(0.5), syn_projEE_ampa[4761], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4762: cell 59, seg 0 (0.5) [0.5 on Epop[59]] -> cell 42, seg 0 (0.5) [0.5 on Epop[42]], weight: 4.1363508E-4, delay 1.5
        h("Epop[42] syn_projEE_ampa[4762] = new ampa(0.5)")
        h("Epop[59] netConn_projEE_ampa[4762] = new NetCon(&v(0.5), syn_projEE_ampa[4762], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4763: cell 59, seg 0 (0.5) [0.5 on Epop[59]] -> cell 43, seg 0 (0.5) [0.5 on Epop[43]], weight: 4.1363508E-4, delay 1.5
        h("Epop[43] syn_projEE_ampa[4763] = new ampa(0.5)")
        h("Epop[59] netConn_projEE_ampa[4763] = new NetCon(&v(0.5), syn_projEE_ampa[4763], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4764: cell 59, seg 0 (0.5) [0.5 on Epop[59]] -> cell 44, seg 0 (0.5) [0.5 on Epop[44]], weight: 4.1363508E-4, delay 1.5
        h("Epop[44] syn_projEE_ampa[4764] = new ampa(0.5)")
        h("Epop[59] netConn_projEE_ampa[4764] = new NetCon(&v(0.5), syn_projEE_ampa[4764], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4765: cell 59, seg 0 (0.5) [0.5 on Epop[59]] -> cell 45, seg 0 (0.5) [0.5 on Epop[45]], weight: 4.1363508E-4, delay 1.5
        h("Epop[45] syn_projEE_ampa[4765] = new ampa(0.5)")
        h("Epop[59] netConn_projEE_ampa[4765] = new NetCon(&v(0.5), syn_projEE_ampa[4765], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4766: cell 59, seg 0 (0.5) [0.5 on Epop[59]] -> cell 46, seg 0 (0.5) [0.5 on Epop[46]], weight: 4.1363508E-4, delay 1.5
        h("Epop[46] syn_projEE_ampa[4766] = new ampa(0.5)")
        h("Epop[59] netConn_projEE_ampa[4766] = new NetCon(&v(0.5), syn_projEE_ampa[4766], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4767: cell 59, seg 0 (0.5) [0.5 on Epop[59]] -> cell 47, seg 0 (0.5) [0.5 on Epop[47]], weight: 4.1363508E-4, delay 1.5
        h("Epop[47] syn_projEE_ampa[4767] = new ampa(0.5)")
        h("Epop[59] netConn_projEE_ampa[4767] = new NetCon(&v(0.5), syn_projEE_ampa[4767], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4768: cell 59, seg 0 (0.5) [0.5 on Epop[59]] -> cell 48, seg 0 (0.5) [0.5 on Epop[48]], weight: 4.1363508E-4, delay 1.5
        h("Epop[48] syn_projEE_ampa[4768] = new ampa(0.5)")
        h("Epop[59] netConn_projEE_ampa[4768] = new NetCon(&v(0.5), syn_projEE_ampa[4768], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4769: cell 59, seg 0 (0.5) [0.5 on Epop[59]] -> cell 49, seg 0 (0.5) [0.5 on Epop[49]], weight: 4.1363508E-4, delay 1.5
        h("Epop[49] syn_projEE_ampa[4769] = new ampa(0.5)")
        h("Epop[59] netConn_projEE_ampa[4769] = new NetCon(&v(0.5), syn_projEE_ampa[4769], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4770: cell 59, seg 0 (0.5) [0.5 on Epop[59]] -> cell 50, seg 0 (0.5) [0.5 on Epop[50]], weight: 4.1363508E-4, delay 1.5
        h("Epop[50] syn_projEE_ampa[4770] = new ampa(0.5)")
        h("Epop[59] netConn_projEE_ampa[4770] = new NetCon(&v(0.5), syn_projEE_ampa[4770], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4771: cell 59, seg 0 (0.5) [0.5 on Epop[59]] -> cell 51, seg 0 (0.5) [0.5 on Epop[51]], weight: 4.1363508E-4, delay 1.5
        h("Epop[51] syn_projEE_ampa[4771] = new ampa(0.5)")
        h("Epop[59] netConn_projEE_ampa[4771] = new NetCon(&v(0.5), syn_projEE_ampa[4771], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4772: cell 59, seg 0 (0.5) [0.5 on Epop[59]] -> cell 52, seg 0 (0.5) [0.5 on Epop[52]], weight: 4.1363508E-4, delay 1.5
        h("Epop[52] syn_projEE_ampa[4772] = new ampa(0.5)")
        h("Epop[59] netConn_projEE_ampa[4772] = new NetCon(&v(0.5), syn_projEE_ampa[4772], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4773: cell 59, seg 0 (0.5) [0.5 on Epop[59]] -> cell 53, seg 0 (0.5) [0.5 on Epop[53]], weight: 4.1363508E-4, delay 1.5
        h("Epop[53] syn_projEE_ampa[4773] = new ampa(0.5)")
        h("Epop[59] netConn_projEE_ampa[4773] = new NetCon(&v(0.5), syn_projEE_ampa[4773], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4774: cell 59, seg 0 (0.5) [0.5 on Epop[59]] -> cell 54, seg 0 (0.5) [0.5 on Epop[54]], weight: 4.1363508E-4, delay 1.5
        h("Epop[54] syn_projEE_ampa[4774] = new ampa(0.5)")
        h("Epop[59] netConn_projEE_ampa[4774] = new NetCon(&v(0.5), syn_projEE_ampa[4774], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4775: cell 59, seg 0 (0.5) [0.5 on Epop[59]] -> cell 55, seg 0 (0.5) [0.5 on Epop[55]], weight: 4.1363508E-4, delay 1.5
        h("Epop[55] syn_projEE_ampa[4775] = new ampa(0.5)")
        h("Epop[59] netConn_projEE_ampa[4775] = new NetCon(&v(0.5), syn_projEE_ampa[4775], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4776: cell 59, seg 0 (0.5) [0.5 on Epop[59]] -> cell 56, seg 0 (0.5) [0.5 on Epop[56]], weight: 4.1363508E-4, delay 1.5
        h("Epop[56] syn_projEE_ampa[4776] = new ampa(0.5)")
        h("Epop[59] netConn_projEE_ampa[4776] = new NetCon(&v(0.5), syn_projEE_ampa[4776], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4777: cell 59, seg 0 (0.5) [0.5 on Epop[59]] -> cell 57, seg 0 (0.5) [0.5 on Epop[57]], weight: 4.1363508E-4, delay 1.5
        h("Epop[57] syn_projEE_ampa[4777] = new ampa(0.5)")
        h("Epop[59] netConn_projEE_ampa[4777] = new NetCon(&v(0.5), syn_projEE_ampa[4777], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4778: cell 59, seg 0 (0.5) [0.5 on Epop[59]] -> cell 58, seg 0 (0.5) [0.5 on Epop[58]], weight: 4.1363508E-4, delay 1.5
        h("Epop[58] syn_projEE_ampa[4778] = new ampa(0.5)")
        h("Epop[59] netConn_projEE_ampa[4778] = new NetCon(&v(0.5), syn_projEE_ampa[4778], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4779: cell 59, seg 0 (0.5) [0.5 on Epop[59]] -> cell 59, seg 0 (0.5) [0.5 on Epop[59]], weight: 4.1363508E-4, delay 1.5
        h("Epop[59] syn_projEE_ampa[4779] = new ampa(0.5)")
        h("Epop[59] netConn_projEE_ampa[4779] = new NetCon(&v(0.5), syn_projEE_ampa[4779], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4780: cell 59, seg 0 (0.5) [0.5 on Epop[59]] -> cell 60, seg 0 (0.5) [0.5 on Epop[60]], weight: 4.1363508E-4, delay 1.5
        h("Epop[60] syn_projEE_ampa[4780] = new ampa(0.5)")
        h("Epop[59] netConn_projEE_ampa[4780] = new NetCon(&v(0.5), syn_projEE_ampa[4780], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4781: cell 59, seg 0 (0.5) [0.5 on Epop[59]] -> cell 61, seg 0 (0.5) [0.5 on Epop[61]], weight: 4.1363508E-4, delay 1.5
        h("Epop[61] syn_projEE_ampa[4781] = new ampa(0.5)")
        h("Epop[59] netConn_projEE_ampa[4781] = new NetCon(&v(0.5), syn_projEE_ampa[4781], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4782: cell 59, seg 0 (0.5) [0.5 on Epop[59]] -> cell 62, seg 0 (0.5) [0.5 on Epop[62]], weight: 4.1363508E-4, delay 1.5
        h("Epop[62] syn_projEE_ampa[4782] = new ampa(0.5)")
        h("Epop[59] netConn_projEE_ampa[4782] = new NetCon(&v(0.5), syn_projEE_ampa[4782], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4783: cell 59, seg 0 (0.5) [0.5 on Epop[59]] -> cell 63, seg 0 (0.5) [0.5 on Epop[63]], weight: 4.1363508E-4, delay 1.5
        h("Epop[63] syn_projEE_ampa[4783] = new ampa(0.5)")
        h("Epop[59] netConn_projEE_ampa[4783] = new NetCon(&v(0.5), syn_projEE_ampa[4783], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4784: cell 59, seg 0 (0.5) [0.5 on Epop[59]] -> cell 64, seg 0 (0.5) [0.5 on Epop[64]], weight: 4.1363508E-4, delay 1.5
        h("Epop[64] syn_projEE_ampa[4784] = new ampa(0.5)")
        h("Epop[59] netConn_projEE_ampa[4784] = new NetCon(&v(0.5), syn_projEE_ampa[4784], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4785: cell 59, seg 0 (0.5) [0.5 on Epop[59]] -> cell 65, seg 0 (0.5) [0.5 on Epop[65]], weight: 4.1363508E-4, delay 1.5
        h("Epop[65] syn_projEE_ampa[4785] = new ampa(0.5)")
        h("Epop[59] netConn_projEE_ampa[4785] = new NetCon(&v(0.5), syn_projEE_ampa[4785], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4786: cell 59, seg 0 (0.5) [0.5 on Epop[59]] -> cell 66, seg 0 (0.5) [0.5 on Epop[66]], weight: 4.1363508E-4, delay 1.5
        h("Epop[66] syn_projEE_ampa[4786] = new ampa(0.5)")
        h("Epop[59] netConn_projEE_ampa[4786] = new NetCon(&v(0.5), syn_projEE_ampa[4786], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4787: cell 59, seg 0 (0.5) [0.5 on Epop[59]] -> cell 67, seg 0 (0.5) [0.5 on Epop[67]], weight: 4.1363508E-4, delay 1.5
        h("Epop[67] syn_projEE_ampa[4787] = new ampa(0.5)")
        h("Epop[59] netConn_projEE_ampa[4787] = new NetCon(&v(0.5), syn_projEE_ampa[4787], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4788: cell 59, seg 0 (0.5) [0.5 on Epop[59]] -> cell 68, seg 0 (0.5) [0.5 on Epop[68]], weight: 4.1363508E-4, delay 1.5
        h("Epop[68] syn_projEE_ampa[4788] = new ampa(0.5)")
        h("Epop[59] netConn_projEE_ampa[4788] = new NetCon(&v(0.5), syn_projEE_ampa[4788], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4789: cell 59, seg 0 (0.5) [0.5 on Epop[59]] -> cell 69, seg 0 (0.5) [0.5 on Epop[69]], weight: 4.1363508E-4, delay 1.5
        h("Epop[69] syn_projEE_ampa[4789] = new ampa(0.5)")
        h("Epop[59] netConn_projEE_ampa[4789] = new NetCon(&v(0.5), syn_projEE_ampa[4789], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4790: cell 59, seg 0 (0.5) [0.5 on Epop[59]] -> cell 70, seg 0 (0.5) [0.5 on Epop[70]], weight: 4.1363508E-4, delay 1.5
        h("Epop[70] syn_projEE_ampa[4790] = new ampa(0.5)")
        h("Epop[59] netConn_projEE_ampa[4790] = new NetCon(&v(0.5), syn_projEE_ampa[4790], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4791: cell 59, seg 0 (0.5) [0.5 on Epop[59]] -> cell 71, seg 0 (0.5) [0.5 on Epop[71]], weight: 4.1363508E-4, delay 1.5
        h("Epop[71] syn_projEE_ampa[4791] = new ampa(0.5)")
        h("Epop[59] netConn_projEE_ampa[4791] = new NetCon(&v(0.5), syn_projEE_ampa[4791], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4792: cell 59, seg 0 (0.5) [0.5 on Epop[59]] -> cell 72, seg 0 (0.5) [0.5 on Epop[72]], weight: 4.1363508E-4, delay 1.5
        h("Epop[72] syn_projEE_ampa[4792] = new ampa(0.5)")
        h("Epop[59] netConn_projEE_ampa[4792] = new NetCon(&v(0.5), syn_projEE_ampa[4792], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4793: cell 59, seg 0 (0.5) [0.5 on Epop[59]] -> cell 73, seg 0 (0.5) [0.5 on Epop[73]], weight: 4.1363508E-4, delay 1.5
        h("Epop[73] syn_projEE_ampa[4793] = new ampa(0.5)")
        h("Epop[59] netConn_projEE_ampa[4793] = new NetCon(&v(0.5), syn_projEE_ampa[4793], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4794: cell 59, seg 0 (0.5) [0.5 on Epop[59]] -> cell 74, seg 0 (0.5) [0.5 on Epop[74]], weight: 4.1363508E-4, delay 1.5
        h("Epop[74] syn_projEE_ampa[4794] = new ampa(0.5)")
        h("Epop[59] netConn_projEE_ampa[4794] = new NetCon(&v(0.5), syn_projEE_ampa[4794], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4795: cell 59, seg 0 (0.5) [0.5 on Epop[59]] -> cell 75, seg 0 (0.5) [0.5 on Epop[75]], weight: 4.1363508E-4, delay 1.5
        h("Epop[75] syn_projEE_ampa[4795] = new ampa(0.5)")
        h("Epop[59] netConn_projEE_ampa[4795] = new NetCon(&v(0.5), syn_projEE_ampa[4795], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4796: cell 59, seg 0 (0.5) [0.5 on Epop[59]] -> cell 76, seg 0 (0.5) [0.5 on Epop[76]], weight: 4.1363508E-4, delay 1.5
        h("Epop[76] syn_projEE_ampa[4796] = new ampa(0.5)")
        h("Epop[59] netConn_projEE_ampa[4796] = new NetCon(&v(0.5), syn_projEE_ampa[4796], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4797: cell 59, seg 0 (0.5) [0.5 on Epop[59]] -> cell 77, seg 0 (0.5) [0.5 on Epop[77]], weight: 4.1363508E-4, delay 1.5
        h("Epop[77] syn_projEE_ampa[4797] = new ampa(0.5)")
        h("Epop[59] netConn_projEE_ampa[4797] = new NetCon(&v(0.5), syn_projEE_ampa[4797], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4798: cell 59, seg 0 (0.5) [0.5 on Epop[59]] -> cell 78, seg 0 (0.5) [0.5 on Epop[78]], weight: 4.1363508E-4, delay 1.5
        h("Epop[78] syn_projEE_ampa[4798] = new ampa(0.5)")
        h("Epop[59] netConn_projEE_ampa[4798] = new NetCon(&v(0.5), syn_projEE_ampa[4798], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4799: cell 59, seg 0 (0.5) [0.5 on Epop[59]] -> cell 79, seg 0 (0.5) [0.5 on Epop[79]], weight: 4.1363508E-4, delay 1.5
        h("Epop[79] syn_projEE_ampa[4799] = new ampa(0.5)")
        h("Epop[59] netConn_projEE_ampa[4799] = new NetCon(&v(0.5), syn_projEE_ampa[4799], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4800: cell 60, seg 0 (0.5) [0.5 on Epop[60]] -> cell 0, seg 0 (0.5) [0.5 on Epop[0]], weight: 4.1363508E-4, delay 1.5
        h("Epop[0] syn_projEE_ampa[4800] = new ampa(0.5)")
        h("Epop[60] netConn_projEE_ampa[4800] = new NetCon(&v(0.5), syn_projEE_ampa[4800], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4801: cell 60, seg 0 (0.5) [0.5 on Epop[60]] -> cell 1, seg 0 (0.5) [0.5 on Epop[1]], weight: 4.1363508E-4, delay 1.5
        h("Epop[1] syn_projEE_ampa[4801] = new ampa(0.5)")
        h("Epop[60] netConn_projEE_ampa[4801] = new NetCon(&v(0.5), syn_projEE_ampa[4801], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4802: cell 60, seg 0 (0.5) [0.5 on Epop[60]] -> cell 2, seg 0 (0.5) [0.5 on Epop[2]], weight: 4.1363508E-4, delay 1.5
        h("Epop[2] syn_projEE_ampa[4802] = new ampa(0.5)")
        h("Epop[60] netConn_projEE_ampa[4802] = new NetCon(&v(0.5), syn_projEE_ampa[4802], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4803: cell 60, seg 0 (0.5) [0.5 on Epop[60]] -> cell 3, seg 0 (0.5) [0.5 on Epop[3]], weight: 4.1363508E-4, delay 1.5
        h("Epop[3] syn_projEE_ampa[4803] = new ampa(0.5)")
        h("Epop[60] netConn_projEE_ampa[4803] = new NetCon(&v(0.5), syn_projEE_ampa[4803], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4804: cell 60, seg 0 (0.5) [0.5 on Epop[60]] -> cell 4, seg 0 (0.5) [0.5 on Epop[4]], weight: 4.1363508E-4, delay 1.5
        h("Epop[4] syn_projEE_ampa[4804] = new ampa(0.5)")
        h("Epop[60] netConn_projEE_ampa[4804] = new NetCon(&v(0.5), syn_projEE_ampa[4804], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4805: cell 60, seg 0 (0.5) [0.5 on Epop[60]] -> cell 5, seg 0 (0.5) [0.5 on Epop[5]], weight: 4.1363508E-4, delay 1.5
        h("Epop[5] syn_projEE_ampa[4805] = new ampa(0.5)")
        h("Epop[60] netConn_projEE_ampa[4805] = new NetCon(&v(0.5), syn_projEE_ampa[4805], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4806: cell 60, seg 0 (0.5) [0.5 on Epop[60]] -> cell 6, seg 0 (0.5) [0.5 on Epop[6]], weight: 4.1363508E-4, delay 1.5
        h("Epop[6] syn_projEE_ampa[4806] = new ampa(0.5)")
        h("Epop[60] netConn_projEE_ampa[4806] = new NetCon(&v(0.5), syn_projEE_ampa[4806], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4807: cell 60, seg 0 (0.5) [0.5 on Epop[60]] -> cell 7, seg 0 (0.5) [0.5 on Epop[7]], weight: 4.1363508E-4, delay 1.5
        h("Epop[7] syn_projEE_ampa[4807] = new ampa(0.5)")
        h("Epop[60] netConn_projEE_ampa[4807] = new NetCon(&v(0.5), syn_projEE_ampa[4807], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4808: cell 60, seg 0 (0.5) [0.5 on Epop[60]] -> cell 8, seg 0 (0.5) [0.5 on Epop[8]], weight: 4.1363508E-4, delay 1.5
        h("Epop[8] syn_projEE_ampa[4808] = new ampa(0.5)")
        h("Epop[60] netConn_projEE_ampa[4808] = new NetCon(&v(0.5), syn_projEE_ampa[4808], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4809: cell 60, seg 0 (0.5) [0.5 on Epop[60]] -> cell 9, seg 0 (0.5) [0.5 on Epop[9]], weight: 4.1363508E-4, delay 1.5
        h("Epop[9] syn_projEE_ampa[4809] = new ampa(0.5)")
        h("Epop[60] netConn_projEE_ampa[4809] = new NetCon(&v(0.5), syn_projEE_ampa[4809], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4810: cell 60, seg 0 (0.5) [0.5 on Epop[60]] -> cell 10, seg 0 (0.5) [0.5 on Epop[10]], weight: 4.1363508E-4, delay 1.5
        h("Epop[10] syn_projEE_ampa[4810] = new ampa(0.5)")
        h("Epop[60] netConn_projEE_ampa[4810] = new NetCon(&v(0.5), syn_projEE_ampa[4810], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4811: cell 60, seg 0 (0.5) [0.5 on Epop[60]] -> cell 11, seg 0 (0.5) [0.5 on Epop[11]], weight: 4.1363508E-4, delay 1.5
        h("Epop[11] syn_projEE_ampa[4811] = new ampa(0.5)")
        h("Epop[60] netConn_projEE_ampa[4811] = new NetCon(&v(0.5), syn_projEE_ampa[4811], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4812: cell 60, seg 0 (0.5) [0.5 on Epop[60]] -> cell 12, seg 0 (0.5) [0.5 on Epop[12]], weight: 4.1363508E-4, delay 1.5
        h("Epop[12] syn_projEE_ampa[4812] = new ampa(0.5)")
        h("Epop[60] netConn_projEE_ampa[4812] = new NetCon(&v(0.5), syn_projEE_ampa[4812], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4813: cell 60, seg 0 (0.5) [0.5 on Epop[60]] -> cell 13, seg 0 (0.5) [0.5 on Epop[13]], weight: 4.1363508E-4, delay 1.5
        h("Epop[13] syn_projEE_ampa[4813] = new ampa(0.5)")
        h("Epop[60] netConn_projEE_ampa[4813] = new NetCon(&v(0.5), syn_projEE_ampa[4813], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4814: cell 60, seg 0 (0.5) [0.5 on Epop[60]] -> cell 14, seg 0 (0.5) [0.5 on Epop[14]], weight: 4.1363508E-4, delay 1.5
        h("Epop[14] syn_projEE_ampa[4814] = new ampa(0.5)")
        h("Epop[60] netConn_projEE_ampa[4814] = new NetCon(&v(0.5), syn_projEE_ampa[4814], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4815: cell 60, seg 0 (0.5) [0.5 on Epop[60]] -> cell 15, seg 0 (0.5) [0.5 on Epop[15]], weight: 4.1363508E-4, delay 1.5
        h("Epop[15] syn_projEE_ampa[4815] = new ampa(0.5)")
        h("Epop[60] netConn_projEE_ampa[4815] = new NetCon(&v(0.5), syn_projEE_ampa[4815], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4816: cell 60, seg 0 (0.5) [0.5 on Epop[60]] -> cell 16, seg 0 (0.5) [0.5 on Epop[16]], weight: 4.1363508E-4, delay 1.5
        h("Epop[16] syn_projEE_ampa[4816] = new ampa(0.5)")
        h("Epop[60] netConn_projEE_ampa[4816] = new NetCon(&v(0.5), syn_projEE_ampa[4816], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4817: cell 60, seg 0 (0.5) [0.5 on Epop[60]] -> cell 17, seg 0 (0.5) [0.5 on Epop[17]], weight: 4.1363508E-4, delay 1.5
        h("Epop[17] syn_projEE_ampa[4817] = new ampa(0.5)")
        h("Epop[60] netConn_projEE_ampa[4817] = new NetCon(&v(0.5), syn_projEE_ampa[4817], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4818: cell 60, seg 0 (0.5) [0.5 on Epop[60]] -> cell 18, seg 0 (0.5) [0.5 on Epop[18]], weight: 4.1363508E-4, delay 1.5
        h("Epop[18] syn_projEE_ampa[4818] = new ampa(0.5)")
        h("Epop[60] netConn_projEE_ampa[4818] = new NetCon(&v(0.5), syn_projEE_ampa[4818], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4819: cell 60, seg 0 (0.5) [0.5 on Epop[60]] -> cell 19, seg 0 (0.5) [0.5 on Epop[19]], weight: 4.1363508E-4, delay 1.5
        h("Epop[19] syn_projEE_ampa[4819] = new ampa(0.5)")
        h("Epop[60] netConn_projEE_ampa[4819] = new NetCon(&v(0.5), syn_projEE_ampa[4819], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4820: cell 60, seg 0 (0.5) [0.5 on Epop[60]] -> cell 20, seg 0 (0.5) [0.5 on Epop[20]], weight: 4.1363508E-4, delay 1.5
        h("Epop[20] syn_projEE_ampa[4820] = new ampa(0.5)")
        h("Epop[60] netConn_projEE_ampa[4820] = new NetCon(&v(0.5), syn_projEE_ampa[4820], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4821: cell 60, seg 0 (0.5) [0.5 on Epop[60]] -> cell 21, seg 0 (0.5) [0.5 on Epop[21]], weight: 4.1363508E-4, delay 1.5
        h("Epop[21] syn_projEE_ampa[4821] = new ampa(0.5)")
        h("Epop[60] netConn_projEE_ampa[4821] = new NetCon(&v(0.5), syn_projEE_ampa[4821], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4822: cell 60, seg 0 (0.5) [0.5 on Epop[60]] -> cell 22, seg 0 (0.5) [0.5 on Epop[22]], weight: 4.1363508E-4, delay 1.5
        h("Epop[22] syn_projEE_ampa[4822] = new ampa(0.5)")
        h("Epop[60] netConn_projEE_ampa[4822] = new NetCon(&v(0.5), syn_projEE_ampa[4822], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4823: cell 60, seg 0 (0.5) [0.5 on Epop[60]] -> cell 23, seg 0 (0.5) [0.5 on Epop[23]], weight: 4.1363508E-4, delay 1.5
        h("Epop[23] syn_projEE_ampa[4823] = new ampa(0.5)")
        h("Epop[60] netConn_projEE_ampa[4823] = new NetCon(&v(0.5), syn_projEE_ampa[4823], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4824: cell 60, seg 0 (0.5) [0.5 on Epop[60]] -> cell 24, seg 0 (0.5) [0.5 on Epop[24]], weight: 4.1363508E-4, delay 1.5
        h("Epop[24] syn_projEE_ampa[4824] = new ampa(0.5)")
        h("Epop[60] netConn_projEE_ampa[4824] = new NetCon(&v(0.5), syn_projEE_ampa[4824], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4825: cell 60, seg 0 (0.5) [0.5 on Epop[60]] -> cell 25, seg 0 (0.5) [0.5 on Epop[25]], weight: 4.1363508E-4, delay 1.5
        h("Epop[25] syn_projEE_ampa[4825] = new ampa(0.5)")
        h("Epop[60] netConn_projEE_ampa[4825] = new NetCon(&v(0.5), syn_projEE_ampa[4825], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4826: cell 60, seg 0 (0.5) [0.5 on Epop[60]] -> cell 26, seg 0 (0.5) [0.5 on Epop[26]], weight: 4.1363508E-4, delay 1.5
        h("Epop[26] syn_projEE_ampa[4826] = new ampa(0.5)")
        h("Epop[60] netConn_projEE_ampa[4826] = new NetCon(&v(0.5), syn_projEE_ampa[4826], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4827: cell 60, seg 0 (0.5) [0.5 on Epop[60]] -> cell 27, seg 0 (0.5) [0.5 on Epop[27]], weight: 4.1363508E-4, delay 1.5
        h("Epop[27] syn_projEE_ampa[4827] = new ampa(0.5)")
        h("Epop[60] netConn_projEE_ampa[4827] = new NetCon(&v(0.5), syn_projEE_ampa[4827], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4828: cell 60, seg 0 (0.5) [0.5 on Epop[60]] -> cell 28, seg 0 (0.5) [0.5 on Epop[28]], weight: 4.1363508E-4, delay 1.5
        h("Epop[28] syn_projEE_ampa[4828] = new ampa(0.5)")
        h("Epop[60] netConn_projEE_ampa[4828] = new NetCon(&v(0.5), syn_projEE_ampa[4828], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4829: cell 60, seg 0 (0.5) [0.5 on Epop[60]] -> cell 29, seg 0 (0.5) [0.5 on Epop[29]], weight: 4.1363508E-4, delay 1.5
        h("Epop[29] syn_projEE_ampa[4829] = new ampa(0.5)")
        h("Epop[60] netConn_projEE_ampa[4829] = new NetCon(&v(0.5), syn_projEE_ampa[4829], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4830: cell 60, seg 0 (0.5) [0.5 on Epop[60]] -> cell 30, seg 0 (0.5) [0.5 on Epop[30]], weight: 4.1363508E-4, delay 1.5
        h("Epop[30] syn_projEE_ampa[4830] = new ampa(0.5)")
        h("Epop[60] netConn_projEE_ampa[4830] = new NetCon(&v(0.5), syn_projEE_ampa[4830], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4831: cell 60, seg 0 (0.5) [0.5 on Epop[60]] -> cell 31, seg 0 (0.5) [0.5 on Epop[31]], weight: 4.1363508E-4, delay 1.5
        h("Epop[31] syn_projEE_ampa[4831] = new ampa(0.5)")
        h("Epop[60] netConn_projEE_ampa[4831] = new NetCon(&v(0.5), syn_projEE_ampa[4831], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4832: cell 60, seg 0 (0.5) [0.5 on Epop[60]] -> cell 32, seg 0 (0.5) [0.5 on Epop[32]], weight: 4.1363508E-4, delay 1.5
        h("Epop[32] syn_projEE_ampa[4832] = new ampa(0.5)")
        h("Epop[60] netConn_projEE_ampa[4832] = new NetCon(&v(0.5), syn_projEE_ampa[4832], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4833: cell 60, seg 0 (0.5) [0.5 on Epop[60]] -> cell 33, seg 0 (0.5) [0.5 on Epop[33]], weight: 4.1363508E-4, delay 1.5
        h("Epop[33] syn_projEE_ampa[4833] = new ampa(0.5)")
        h("Epop[60] netConn_projEE_ampa[4833] = new NetCon(&v(0.5), syn_projEE_ampa[4833], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4834: cell 60, seg 0 (0.5) [0.5 on Epop[60]] -> cell 34, seg 0 (0.5) [0.5 on Epop[34]], weight: 4.1363508E-4, delay 1.5
        h("Epop[34] syn_projEE_ampa[4834] = new ampa(0.5)")
        h("Epop[60] netConn_projEE_ampa[4834] = new NetCon(&v(0.5), syn_projEE_ampa[4834], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4835: cell 60, seg 0 (0.5) [0.5 on Epop[60]] -> cell 35, seg 0 (0.5) [0.5 on Epop[35]], weight: 4.1363508E-4, delay 1.5
        h("Epop[35] syn_projEE_ampa[4835] = new ampa(0.5)")
        h("Epop[60] netConn_projEE_ampa[4835] = new NetCon(&v(0.5), syn_projEE_ampa[4835], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4836: cell 60, seg 0 (0.5) [0.5 on Epop[60]] -> cell 36, seg 0 (0.5) [0.5 on Epop[36]], weight: 4.1363508E-4, delay 1.5
        h("Epop[36] syn_projEE_ampa[4836] = new ampa(0.5)")
        h("Epop[60] netConn_projEE_ampa[4836] = new NetCon(&v(0.5), syn_projEE_ampa[4836], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4837: cell 60, seg 0 (0.5) [0.5 on Epop[60]] -> cell 37, seg 0 (0.5) [0.5 on Epop[37]], weight: 4.1363508E-4, delay 1.5
        h("Epop[37] syn_projEE_ampa[4837] = new ampa(0.5)")
        h("Epop[60] netConn_projEE_ampa[4837] = new NetCon(&v(0.5), syn_projEE_ampa[4837], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4838: cell 60, seg 0 (0.5) [0.5 on Epop[60]] -> cell 38, seg 0 (0.5) [0.5 on Epop[38]], weight: 4.1363508E-4, delay 1.5
        h("Epop[38] syn_projEE_ampa[4838] = new ampa(0.5)")
        h("Epop[60] netConn_projEE_ampa[4838] = new NetCon(&v(0.5), syn_projEE_ampa[4838], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4839: cell 60, seg 0 (0.5) [0.5 on Epop[60]] -> cell 39, seg 0 (0.5) [0.5 on Epop[39]], weight: 4.1363508E-4, delay 1.5
        h("Epop[39] syn_projEE_ampa[4839] = new ampa(0.5)")
        h("Epop[60] netConn_projEE_ampa[4839] = new NetCon(&v(0.5), syn_projEE_ampa[4839], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4840: cell 60, seg 0 (0.5) [0.5 on Epop[60]] -> cell 40, seg 0 (0.5) [0.5 on Epop[40]], weight: 4.1363508E-4, delay 1.5
        h("Epop[40] syn_projEE_ampa[4840] = new ampa(0.5)")
        h("Epop[60] netConn_projEE_ampa[4840] = new NetCon(&v(0.5), syn_projEE_ampa[4840], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4841: cell 60, seg 0 (0.5) [0.5 on Epop[60]] -> cell 41, seg 0 (0.5) [0.5 on Epop[41]], weight: 4.1363508E-4, delay 1.5
        h("Epop[41] syn_projEE_ampa[4841] = new ampa(0.5)")
        h("Epop[60] netConn_projEE_ampa[4841] = new NetCon(&v(0.5), syn_projEE_ampa[4841], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4842: cell 60, seg 0 (0.5) [0.5 on Epop[60]] -> cell 42, seg 0 (0.5) [0.5 on Epop[42]], weight: 4.1363508E-4, delay 1.5
        h("Epop[42] syn_projEE_ampa[4842] = new ampa(0.5)")
        h("Epop[60] netConn_projEE_ampa[4842] = new NetCon(&v(0.5), syn_projEE_ampa[4842], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4843: cell 60, seg 0 (0.5) [0.5 on Epop[60]] -> cell 43, seg 0 (0.5) [0.5 on Epop[43]], weight: 4.1363508E-4, delay 1.5
        h("Epop[43] syn_projEE_ampa[4843] = new ampa(0.5)")
        h("Epop[60] netConn_projEE_ampa[4843] = new NetCon(&v(0.5), syn_projEE_ampa[4843], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4844: cell 60, seg 0 (0.5) [0.5 on Epop[60]] -> cell 44, seg 0 (0.5) [0.5 on Epop[44]], weight: 4.1363508E-4, delay 1.5
        h("Epop[44] syn_projEE_ampa[4844] = new ampa(0.5)")
        h("Epop[60] netConn_projEE_ampa[4844] = new NetCon(&v(0.5), syn_projEE_ampa[4844], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4845: cell 60, seg 0 (0.5) [0.5 on Epop[60]] -> cell 45, seg 0 (0.5) [0.5 on Epop[45]], weight: 4.1363508E-4, delay 1.5
        h("Epop[45] syn_projEE_ampa[4845] = new ampa(0.5)")
        h("Epop[60] netConn_projEE_ampa[4845] = new NetCon(&v(0.5), syn_projEE_ampa[4845], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4846: cell 60, seg 0 (0.5) [0.5 on Epop[60]] -> cell 46, seg 0 (0.5) [0.5 on Epop[46]], weight: 4.1363508E-4, delay 1.5
        h("Epop[46] syn_projEE_ampa[4846] = new ampa(0.5)")
        h("Epop[60] netConn_projEE_ampa[4846] = new NetCon(&v(0.5), syn_projEE_ampa[4846], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4847: cell 60, seg 0 (0.5) [0.5 on Epop[60]] -> cell 47, seg 0 (0.5) [0.5 on Epop[47]], weight: 4.1363508E-4, delay 1.5
        h("Epop[47] syn_projEE_ampa[4847] = new ampa(0.5)")
        h("Epop[60] netConn_projEE_ampa[4847] = new NetCon(&v(0.5), syn_projEE_ampa[4847], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4848: cell 60, seg 0 (0.5) [0.5 on Epop[60]] -> cell 48, seg 0 (0.5) [0.5 on Epop[48]], weight: 4.1363508E-4, delay 1.5
        h("Epop[48] syn_projEE_ampa[4848] = new ampa(0.5)")
        h("Epop[60] netConn_projEE_ampa[4848] = new NetCon(&v(0.5), syn_projEE_ampa[4848], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4849: cell 60, seg 0 (0.5) [0.5 on Epop[60]] -> cell 49, seg 0 (0.5) [0.5 on Epop[49]], weight: 4.1363508E-4, delay 1.5
        h("Epop[49] syn_projEE_ampa[4849] = new ampa(0.5)")
        h("Epop[60] netConn_projEE_ampa[4849] = new NetCon(&v(0.5), syn_projEE_ampa[4849], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4850: cell 60, seg 0 (0.5) [0.5 on Epop[60]] -> cell 50, seg 0 (0.5) [0.5 on Epop[50]], weight: 4.1363508E-4, delay 1.5
        h("Epop[50] syn_projEE_ampa[4850] = new ampa(0.5)")
        h("Epop[60] netConn_projEE_ampa[4850] = new NetCon(&v(0.5), syn_projEE_ampa[4850], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4851: cell 60, seg 0 (0.5) [0.5 on Epop[60]] -> cell 51, seg 0 (0.5) [0.5 on Epop[51]], weight: 4.1363508E-4, delay 1.5
        h("Epop[51] syn_projEE_ampa[4851] = new ampa(0.5)")
        h("Epop[60] netConn_projEE_ampa[4851] = new NetCon(&v(0.5), syn_projEE_ampa[4851], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4852: cell 60, seg 0 (0.5) [0.5 on Epop[60]] -> cell 52, seg 0 (0.5) [0.5 on Epop[52]], weight: 4.1363508E-4, delay 1.5
        h("Epop[52] syn_projEE_ampa[4852] = new ampa(0.5)")
        h("Epop[60] netConn_projEE_ampa[4852] = new NetCon(&v(0.5), syn_projEE_ampa[4852], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4853: cell 60, seg 0 (0.5) [0.5 on Epop[60]] -> cell 53, seg 0 (0.5) [0.5 on Epop[53]], weight: 4.1363508E-4, delay 1.5
        h("Epop[53] syn_projEE_ampa[4853] = new ampa(0.5)")
        h("Epop[60] netConn_projEE_ampa[4853] = new NetCon(&v(0.5), syn_projEE_ampa[4853], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4854: cell 60, seg 0 (0.5) [0.5 on Epop[60]] -> cell 54, seg 0 (0.5) [0.5 on Epop[54]], weight: 4.1363508E-4, delay 1.5
        h("Epop[54] syn_projEE_ampa[4854] = new ampa(0.5)")
        h("Epop[60] netConn_projEE_ampa[4854] = new NetCon(&v(0.5), syn_projEE_ampa[4854], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4855: cell 60, seg 0 (0.5) [0.5 on Epop[60]] -> cell 55, seg 0 (0.5) [0.5 on Epop[55]], weight: 4.1363508E-4, delay 1.5
        h("Epop[55] syn_projEE_ampa[4855] = new ampa(0.5)")
        h("Epop[60] netConn_projEE_ampa[4855] = new NetCon(&v(0.5), syn_projEE_ampa[4855], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4856: cell 60, seg 0 (0.5) [0.5 on Epop[60]] -> cell 56, seg 0 (0.5) [0.5 on Epop[56]], weight: 4.1363508E-4, delay 1.5
        h("Epop[56] syn_projEE_ampa[4856] = new ampa(0.5)")
        h("Epop[60] netConn_projEE_ampa[4856] = new NetCon(&v(0.5), syn_projEE_ampa[4856], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4857: cell 60, seg 0 (0.5) [0.5 on Epop[60]] -> cell 57, seg 0 (0.5) [0.5 on Epop[57]], weight: 4.1363508E-4, delay 1.5
        h("Epop[57] syn_projEE_ampa[4857] = new ampa(0.5)")
        h("Epop[60] netConn_projEE_ampa[4857] = new NetCon(&v(0.5), syn_projEE_ampa[4857], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4858: cell 60, seg 0 (0.5) [0.5 on Epop[60]] -> cell 58, seg 0 (0.5) [0.5 on Epop[58]], weight: 4.1363508E-4, delay 1.5
        h("Epop[58] syn_projEE_ampa[4858] = new ampa(0.5)")
        h("Epop[60] netConn_projEE_ampa[4858] = new NetCon(&v(0.5), syn_projEE_ampa[4858], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4859: cell 60, seg 0 (0.5) [0.5 on Epop[60]] -> cell 59, seg 0 (0.5) [0.5 on Epop[59]], weight: 4.1363508E-4, delay 1.5
        h("Epop[59] syn_projEE_ampa[4859] = new ampa(0.5)")
        h("Epop[60] netConn_projEE_ampa[4859] = new NetCon(&v(0.5), syn_projEE_ampa[4859], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4860: cell 60, seg 0 (0.5) [0.5 on Epop[60]] -> cell 60, seg 0 (0.5) [0.5 on Epop[60]], weight: 4.1363508E-4, delay 1.5
        h("Epop[60] syn_projEE_ampa[4860] = new ampa(0.5)")
        h("Epop[60] netConn_projEE_ampa[4860] = new NetCon(&v(0.5), syn_projEE_ampa[4860], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4861: cell 60, seg 0 (0.5) [0.5 on Epop[60]] -> cell 61, seg 0 (0.5) [0.5 on Epop[61]], weight: 4.1363508E-4, delay 1.5
        h("Epop[61] syn_projEE_ampa[4861] = new ampa(0.5)")
        h("Epop[60] netConn_projEE_ampa[4861] = new NetCon(&v(0.5), syn_projEE_ampa[4861], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4862: cell 60, seg 0 (0.5) [0.5 on Epop[60]] -> cell 62, seg 0 (0.5) [0.5 on Epop[62]], weight: 4.1363508E-4, delay 1.5
        h("Epop[62] syn_projEE_ampa[4862] = new ampa(0.5)")
        h("Epop[60] netConn_projEE_ampa[4862] = new NetCon(&v(0.5), syn_projEE_ampa[4862], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4863: cell 60, seg 0 (0.5) [0.5 on Epop[60]] -> cell 63, seg 0 (0.5) [0.5 on Epop[63]], weight: 4.1363508E-4, delay 1.5
        h("Epop[63] syn_projEE_ampa[4863] = new ampa(0.5)")
        h("Epop[60] netConn_projEE_ampa[4863] = new NetCon(&v(0.5), syn_projEE_ampa[4863], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4864: cell 60, seg 0 (0.5) [0.5 on Epop[60]] -> cell 64, seg 0 (0.5) [0.5 on Epop[64]], weight: 4.1363508E-4, delay 1.5
        h("Epop[64] syn_projEE_ampa[4864] = new ampa(0.5)")
        h("Epop[60] netConn_projEE_ampa[4864] = new NetCon(&v(0.5), syn_projEE_ampa[4864], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4865: cell 60, seg 0 (0.5) [0.5 on Epop[60]] -> cell 65, seg 0 (0.5) [0.5 on Epop[65]], weight: 4.1363508E-4, delay 1.5
        h("Epop[65] syn_projEE_ampa[4865] = new ampa(0.5)")
        h("Epop[60] netConn_projEE_ampa[4865] = new NetCon(&v(0.5), syn_projEE_ampa[4865], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4866: cell 60, seg 0 (0.5) [0.5 on Epop[60]] -> cell 66, seg 0 (0.5) [0.5 on Epop[66]], weight: 4.1363508E-4, delay 1.5
        h("Epop[66] syn_projEE_ampa[4866] = new ampa(0.5)")
        h("Epop[60] netConn_projEE_ampa[4866] = new NetCon(&v(0.5), syn_projEE_ampa[4866], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4867: cell 60, seg 0 (0.5) [0.5 on Epop[60]] -> cell 67, seg 0 (0.5) [0.5 on Epop[67]], weight: 4.1363508E-4, delay 1.5
        h("Epop[67] syn_projEE_ampa[4867] = new ampa(0.5)")
        h("Epop[60] netConn_projEE_ampa[4867] = new NetCon(&v(0.5), syn_projEE_ampa[4867], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4868: cell 60, seg 0 (0.5) [0.5 on Epop[60]] -> cell 68, seg 0 (0.5) [0.5 on Epop[68]], weight: 4.1363508E-4, delay 1.5
        h("Epop[68] syn_projEE_ampa[4868] = new ampa(0.5)")
        h("Epop[60] netConn_projEE_ampa[4868] = new NetCon(&v(0.5), syn_projEE_ampa[4868], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4869: cell 60, seg 0 (0.5) [0.5 on Epop[60]] -> cell 69, seg 0 (0.5) [0.5 on Epop[69]], weight: 4.1363508E-4, delay 1.5
        h("Epop[69] syn_projEE_ampa[4869] = new ampa(0.5)")
        h("Epop[60] netConn_projEE_ampa[4869] = new NetCon(&v(0.5), syn_projEE_ampa[4869], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4870: cell 60, seg 0 (0.5) [0.5 on Epop[60]] -> cell 70, seg 0 (0.5) [0.5 on Epop[70]], weight: 4.1363508E-4, delay 1.5
        h("Epop[70] syn_projEE_ampa[4870] = new ampa(0.5)")
        h("Epop[60] netConn_projEE_ampa[4870] = new NetCon(&v(0.5), syn_projEE_ampa[4870], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4871: cell 60, seg 0 (0.5) [0.5 on Epop[60]] -> cell 71, seg 0 (0.5) [0.5 on Epop[71]], weight: 4.1363508E-4, delay 1.5
        h("Epop[71] syn_projEE_ampa[4871] = new ampa(0.5)")
        h("Epop[60] netConn_projEE_ampa[4871] = new NetCon(&v(0.5), syn_projEE_ampa[4871], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4872: cell 60, seg 0 (0.5) [0.5 on Epop[60]] -> cell 72, seg 0 (0.5) [0.5 on Epop[72]], weight: 4.1363508E-4, delay 1.5
        h("Epop[72] syn_projEE_ampa[4872] = new ampa(0.5)")
        h("Epop[60] netConn_projEE_ampa[4872] = new NetCon(&v(0.5), syn_projEE_ampa[4872], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4873: cell 60, seg 0 (0.5) [0.5 on Epop[60]] -> cell 73, seg 0 (0.5) [0.5 on Epop[73]], weight: 4.1363508E-4, delay 1.5
        h("Epop[73] syn_projEE_ampa[4873] = new ampa(0.5)")
        h("Epop[60] netConn_projEE_ampa[4873] = new NetCon(&v(0.5), syn_projEE_ampa[4873], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4874: cell 60, seg 0 (0.5) [0.5 on Epop[60]] -> cell 74, seg 0 (0.5) [0.5 on Epop[74]], weight: 4.1363508E-4, delay 1.5
        h("Epop[74] syn_projEE_ampa[4874] = new ampa(0.5)")
        h("Epop[60] netConn_projEE_ampa[4874] = new NetCon(&v(0.5), syn_projEE_ampa[4874], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4875: cell 60, seg 0 (0.5) [0.5 on Epop[60]] -> cell 75, seg 0 (0.5) [0.5 on Epop[75]], weight: 4.1363508E-4, delay 1.5
        h("Epop[75] syn_projEE_ampa[4875] = new ampa(0.5)")
        h("Epop[60] netConn_projEE_ampa[4875] = new NetCon(&v(0.5), syn_projEE_ampa[4875], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4876: cell 60, seg 0 (0.5) [0.5 on Epop[60]] -> cell 76, seg 0 (0.5) [0.5 on Epop[76]], weight: 4.1363508E-4, delay 1.5
        h("Epop[76] syn_projEE_ampa[4876] = new ampa(0.5)")
        h("Epop[60] netConn_projEE_ampa[4876] = new NetCon(&v(0.5), syn_projEE_ampa[4876], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4877: cell 60, seg 0 (0.5) [0.5 on Epop[60]] -> cell 77, seg 0 (0.5) [0.5 on Epop[77]], weight: 4.1363508E-4, delay 1.5
        h("Epop[77] syn_projEE_ampa[4877] = new ampa(0.5)")
        h("Epop[60] netConn_projEE_ampa[4877] = new NetCon(&v(0.5), syn_projEE_ampa[4877], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4878: cell 60, seg 0 (0.5) [0.5 on Epop[60]] -> cell 78, seg 0 (0.5) [0.5 on Epop[78]], weight: 4.1363508E-4, delay 1.5
        h("Epop[78] syn_projEE_ampa[4878] = new ampa(0.5)")
        h("Epop[60] netConn_projEE_ampa[4878] = new NetCon(&v(0.5), syn_projEE_ampa[4878], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4879: cell 60, seg 0 (0.5) [0.5 on Epop[60]] -> cell 79, seg 0 (0.5) [0.5 on Epop[79]], weight: 4.1363508E-4, delay 1.5
        h("Epop[79] syn_projEE_ampa[4879] = new ampa(0.5)")
        h("Epop[60] netConn_projEE_ampa[4879] = new NetCon(&v(0.5), syn_projEE_ampa[4879], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4880: cell 61, seg 0 (0.5) [0.5 on Epop[61]] -> cell 0, seg 0 (0.5) [0.5 on Epop[0]], weight: 4.1363508E-4, delay 1.5
        h("Epop[0] syn_projEE_ampa[4880] = new ampa(0.5)")
        h("Epop[61] netConn_projEE_ampa[4880] = new NetCon(&v(0.5), syn_projEE_ampa[4880], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4881: cell 61, seg 0 (0.5) [0.5 on Epop[61]] -> cell 1, seg 0 (0.5) [0.5 on Epop[1]], weight: 4.1363508E-4, delay 1.5
        h("Epop[1] syn_projEE_ampa[4881] = new ampa(0.5)")
        h("Epop[61] netConn_projEE_ampa[4881] = new NetCon(&v(0.5), syn_projEE_ampa[4881], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4882: cell 61, seg 0 (0.5) [0.5 on Epop[61]] -> cell 2, seg 0 (0.5) [0.5 on Epop[2]], weight: 4.1363508E-4, delay 1.5
        h("Epop[2] syn_projEE_ampa[4882] = new ampa(0.5)")
        h("Epop[61] netConn_projEE_ampa[4882] = new NetCon(&v(0.5), syn_projEE_ampa[4882], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4883: cell 61, seg 0 (0.5) [0.5 on Epop[61]] -> cell 3, seg 0 (0.5) [0.5 on Epop[3]], weight: 4.1363508E-4, delay 1.5
        h("Epop[3] syn_projEE_ampa[4883] = new ampa(0.5)")
        h("Epop[61] netConn_projEE_ampa[4883] = new NetCon(&v(0.5), syn_projEE_ampa[4883], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4884: cell 61, seg 0 (0.5) [0.5 on Epop[61]] -> cell 4, seg 0 (0.5) [0.5 on Epop[4]], weight: 4.1363508E-4, delay 1.5
        h("Epop[4] syn_projEE_ampa[4884] = new ampa(0.5)")
        h("Epop[61] netConn_projEE_ampa[4884] = new NetCon(&v(0.5), syn_projEE_ampa[4884], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4885: cell 61, seg 0 (0.5) [0.5 on Epop[61]] -> cell 5, seg 0 (0.5) [0.5 on Epop[5]], weight: 4.1363508E-4, delay 1.5
        h("Epop[5] syn_projEE_ampa[4885] = new ampa(0.5)")
        h("Epop[61] netConn_projEE_ampa[4885] = new NetCon(&v(0.5), syn_projEE_ampa[4885], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4886: cell 61, seg 0 (0.5) [0.5 on Epop[61]] -> cell 6, seg 0 (0.5) [0.5 on Epop[6]], weight: 4.1363508E-4, delay 1.5
        h("Epop[6] syn_projEE_ampa[4886] = new ampa(0.5)")
        h("Epop[61] netConn_projEE_ampa[4886] = new NetCon(&v(0.5), syn_projEE_ampa[4886], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4887: cell 61, seg 0 (0.5) [0.5 on Epop[61]] -> cell 7, seg 0 (0.5) [0.5 on Epop[7]], weight: 4.1363508E-4, delay 1.5
        h("Epop[7] syn_projEE_ampa[4887] = new ampa(0.5)")
        h("Epop[61] netConn_projEE_ampa[4887] = new NetCon(&v(0.5), syn_projEE_ampa[4887], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4888: cell 61, seg 0 (0.5) [0.5 on Epop[61]] -> cell 8, seg 0 (0.5) [0.5 on Epop[8]], weight: 4.1363508E-4, delay 1.5
        h("Epop[8] syn_projEE_ampa[4888] = new ampa(0.5)")
        h("Epop[61] netConn_projEE_ampa[4888] = new NetCon(&v(0.5), syn_projEE_ampa[4888], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4889: cell 61, seg 0 (0.5) [0.5 on Epop[61]] -> cell 9, seg 0 (0.5) [0.5 on Epop[9]], weight: 4.1363508E-4, delay 1.5
        h("Epop[9] syn_projEE_ampa[4889] = new ampa(0.5)")
        h("Epop[61] netConn_projEE_ampa[4889] = new NetCon(&v(0.5), syn_projEE_ampa[4889], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4890: cell 61, seg 0 (0.5) [0.5 on Epop[61]] -> cell 10, seg 0 (0.5) [0.5 on Epop[10]], weight: 4.1363508E-4, delay 1.5
        h("Epop[10] syn_projEE_ampa[4890] = new ampa(0.5)")
        h("Epop[61] netConn_projEE_ampa[4890] = new NetCon(&v(0.5), syn_projEE_ampa[4890], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4891: cell 61, seg 0 (0.5) [0.5 on Epop[61]] -> cell 11, seg 0 (0.5) [0.5 on Epop[11]], weight: 4.1363508E-4, delay 1.5
        h("Epop[11] syn_projEE_ampa[4891] = new ampa(0.5)")
        h("Epop[61] netConn_projEE_ampa[4891] = new NetCon(&v(0.5), syn_projEE_ampa[4891], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4892: cell 61, seg 0 (0.5) [0.5 on Epop[61]] -> cell 12, seg 0 (0.5) [0.5 on Epop[12]], weight: 4.1363508E-4, delay 1.5
        h("Epop[12] syn_projEE_ampa[4892] = new ampa(0.5)")
        h("Epop[61] netConn_projEE_ampa[4892] = new NetCon(&v(0.5), syn_projEE_ampa[4892], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4893: cell 61, seg 0 (0.5) [0.5 on Epop[61]] -> cell 13, seg 0 (0.5) [0.5 on Epop[13]], weight: 4.1363508E-4, delay 1.5
        h("Epop[13] syn_projEE_ampa[4893] = new ampa(0.5)")
        h("Epop[61] netConn_projEE_ampa[4893] = new NetCon(&v(0.5), syn_projEE_ampa[4893], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4894: cell 61, seg 0 (0.5) [0.5 on Epop[61]] -> cell 14, seg 0 (0.5) [0.5 on Epop[14]], weight: 4.1363508E-4, delay 1.5
        h("Epop[14] syn_projEE_ampa[4894] = new ampa(0.5)")
        h("Epop[61] netConn_projEE_ampa[4894] = new NetCon(&v(0.5), syn_projEE_ampa[4894], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4895: cell 61, seg 0 (0.5) [0.5 on Epop[61]] -> cell 15, seg 0 (0.5) [0.5 on Epop[15]], weight: 4.1363508E-4, delay 1.5
        h("Epop[15] syn_projEE_ampa[4895] = new ampa(0.5)")
        h("Epop[61] netConn_projEE_ampa[4895] = new NetCon(&v(0.5), syn_projEE_ampa[4895], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4896: cell 61, seg 0 (0.5) [0.5 on Epop[61]] -> cell 16, seg 0 (0.5) [0.5 on Epop[16]], weight: 4.1363508E-4, delay 1.5
        h("Epop[16] syn_projEE_ampa[4896] = new ampa(0.5)")
        h("Epop[61] netConn_projEE_ampa[4896] = new NetCon(&v(0.5), syn_projEE_ampa[4896], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4897: cell 61, seg 0 (0.5) [0.5 on Epop[61]] -> cell 17, seg 0 (0.5) [0.5 on Epop[17]], weight: 4.1363508E-4, delay 1.5
        h("Epop[17] syn_projEE_ampa[4897] = new ampa(0.5)")
        h("Epop[61] netConn_projEE_ampa[4897] = new NetCon(&v(0.5), syn_projEE_ampa[4897], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4898: cell 61, seg 0 (0.5) [0.5 on Epop[61]] -> cell 18, seg 0 (0.5) [0.5 on Epop[18]], weight: 4.1363508E-4, delay 1.5
        h("Epop[18] syn_projEE_ampa[4898] = new ampa(0.5)")
        h("Epop[61] netConn_projEE_ampa[4898] = new NetCon(&v(0.5), syn_projEE_ampa[4898], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4899: cell 61, seg 0 (0.5) [0.5 on Epop[61]] -> cell 19, seg 0 (0.5) [0.5 on Epop[19]], weight: 4.1363508E-4, delay 1.5
        h("Epop[19] syn_projEE_ampa[4899] = new ampa(0.5)")
        h("Epop[61] netConn_projEE_ampa[4899] = new NetCon(&v(0.5), syn_projEE_ampa[4899], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4900: cell 61, seg 0 (0.5) [0.5 on Epop[61]] -> cell 20, seg 0 (0.5) [0.5 on Epop[20]], weight: 4.1363508E-4, delay 1.5
        h("Epop[20] syn_projEE_ampa[4900] = new ampa(0.5)")
        h("Epop[61] netConn_projEE_ampa[4900] = new NetCon(&v(0.5), syn_projEE_ampa[4900], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4901: cell 61, seg 0 (0.5) [0.5 on Epop[61]] -> cell 21, seg 0 (0.5) [0.5 on Epop[21]], weight: 4.1363508E-4, delay 1.5
        h("Epop[21] syn_projEE_ampa[4901] = new ampa(0.5)")
        h("Epop[61] netConn_projEE_ampa[4901] = new NetCon(&v(0.5), syn_projEE_ampa[4901], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4902: cell 61, seg 0 (0.5) [0.5 on Epop[61]] -> cell 22, seg 0 (0.5) [0.5 on Epop[22]], weight: 4.1363508E-4, delay 1.5
        h("Epop[22] syn_projEE_ampa[4902] = new ampa(0.5)")
        h("Epop[61] netConn_projEE_ampa[4902] = new NetCon(&v(0.5), syn_projEE_ampa[4902], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4903: cell 61, seg 0 (0.5) [0.5 on Epop[61]] -> cell 23, seg 0 (0.5) [0.5 on Epop[23]], weight: 4.1363508E-4, delay 1.5
        h("Epop[23] syn_projEE_ampa[4903] = new ampa(0.5)")
        h("Epop[61] netConn_projEE_ampa[4903] = new NetCon(&v(0.5), syn_projEE_ampa[4903], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4904: cell 61, seg 0 (0.5) [0.5 on Epop[61]] -> cell 24, seg 0 (0.5) [0.5 on Epop[24]], weight: 4.1363508E-4, delay 1.5
        h("Epop[24] syn_projEE_ampa[4904] = new ampa(0.5)")
        h("Epop[61] netConn_projEE_ampa[4904] = new NetCon(&v(0.5), syn_projEE_ampa[4904], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4905: cell 61, seg 0 (0.5) [0.5 on Epop[61]] -> cell 25, seg 0 (0.5) [0.5 on Epop[25]], weight: 4.1363508E-4, delay 1.5
        h("Epop[25] syn_projEE_ampa[4905] = new ampa(0.5)")
        h("Epop[61] netConn_projEE_ampa[4905] = new NetCon(&v(0.5), syn_projEE_ampa[4905], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4906: cell 61, seg 0 (0.5) [0.5 on Epop[61]] -> cell 26, seg 0 (0.5) [0.5 on Epop[26]], weight: 4.1363508E-4, delay 1.5
        h("Epop[26] syn_projEE_ampa[4906] = new ampa(0.5)")
        h("Epop[61] netConn_projEE_ampa[4906] = new NetCon(&v(0.5), syn_projEE_ampa[4906], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4907: cell 61, seg 0 (0.5) [0.5 on Epop[61]] -> cell 27, seg 0 (0.5) [0.5 on Epop[27]], weight: 4.1363508E-4, delay 1.5
        h("Epop[27] syn_projEE_ampa[4907] = new ampa(0.5)")
        h("Epop[61] netConn_projEE_ampa[4907] = new NetCon(&v(0.5), syn_projEE_ampa[4907], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4908: cell 61, seg 0 (0.5) [0.5 on Epop[61]] -> cell 28, seg 0 (0.5) [0.5 on Epop[28]], weight: 4.1363508E-4, delay 1.5
        h("Epop[28] syn_projEE_ampa[4908] = new ampa(0.5)")
        h("Epop[61] netConn_projEE_ampa[4908] = new NetCon(&v(0.5), syn_projEE_ampa[4908], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4909: cell 61, seg 0 (0.5) [0.5 on Epop[61]] -> cell 29, seg 0 (0.5) [0.5 on Epop[29]], weight: 4.1363508E-4, delay 1.5
        h("Epop[29] syn_projEE_ampa[4909] = new ampa(0.5)")
        h("Epop[61] netConn_projEE_ampa[4909] = new NetCon(&v(0.5), syn_projEE_ampa[4909], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4910: cell 61, seg 0 (0.5) [0.5 on Epop[61]] -> cell 30, seg 0 (0.5) [0.5 on Epop[30]], weight: 4.1363508E-4, delay 1.5
        h("Epop[30] syn_projEE_ampa[4910] = new ampa(0.5)")
        h("Epop[61] netConn_projEE_ampa[4910] = new NetCon(&v(0.5), syn_projEE_ampa[4910], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4911: cell 61, seg 0 (0.5) [0.5 on Epop[61]] -> cell 31, seg 0 (0.5) [0.5 on Epop[31]], weight: 4.1363508E-4, delay 1.5
        h("Epop[31] syn_projEE_ampa[4911] = new ampa(0.5)")
        h("Epop[61] netConn_projEE_ampa[4911] = new NetCon(&v(0.5), syn_projEE_ampa[4911], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4912: cell 61, seg 0 (0.5) [0.5 on Epop[61]] -> cell 32, seg 0 (0.5) [0.5 on Epop[32]], weight: 4.1363508E-4, delay 1.5
        h("Epop[32] syn_projEE_ampa[4912] = new ampa(0.5)")
        h("Epop[61] netConn_projEE_ampa[4912] = new NetCon(&v(0.5), syn_projEE_ampa[4912], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4913: cell 61, seg 0 (0.5) [0.5 on Epop[61]] -> cell 33, seg 0 (0.5) [0.5 on Epop[33]], weight: 4.1363508E-4, delay 1.5
        h("Epop[33] syn_projEE_ampa[4913] = new ampa(0.5)")
        h("Epop[61] netConn_projEE_ampa[4913] = new NetCon(&v(0.5), syn_projEE_ampa[4913], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4914: cell 61, seg 0 (0.5) [0.5 on Epop[61]] -> cell 34, seg 0 (0.5) [0.5 on Epop[34]], weight: 4.1363508E-4, delay 1.5
        h("Epop[34] syn_projEE_ampa[4914] = new ampa(0.5)")
        h("Epop[61] netConn_projEE_ampa[4914] = new NetCon(&v(0.5), syn_projEE_ampa[4914], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4915: cell 61, seg 0 (0.5) [0.5 on Epop[61]] -> cell 35, seg 0 (0.5) [0.5 on Epop[35]], weight: 4.1363508E-4, delay 1.5
        h("Epop[35] syn_projEE_ampa[4915] = new ampa(0.5)")
        h("Epop[61] netConn_projEE_ampa[4915] = new NetCon(&v(0.5), syn_projEE_ampa[4915], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4916: cell 61, seg 0 (0.5) [0.5 on Epop[61]] -> cell 36, seg 0 (0.5) [0.5 on Epop[36]], weight: 4.1363508E-4, delay 1.5
        h("Epop[36] syn_projEE_ampa[4916] = new ampa(0.5)")
        h("Epop[61] netConn_projEE_ampa[4916] = new NetCon(&v(0.5), syn_projEE_ampa[4916], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4917: cell 61, seg 0 (0.5) [0.5 on Epop[61]] -> cell 37, seg 0 (0.5) [0.5 on Epop[37]], weight: 4.1363508E-4, delay 1.5
        h("Epop[37] syn_projEE_ampa[4917] = new ampa(0.5)")
        h("Epop[61] netConn_projEE_ampa[4917] = new NetCon(&v(0.5), syn_projEE_ampa[4917], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4918: cell 61, seg 0 (0.5) [0.5 on Epop[61]] -> cell 38, seg 0 (0.5) [0.5 on Epop[38]], weight: 4.1363508E-4, delay 1.5
        h("Epop[38] syn_projEE_ampa[4918] = new ampa(0.5)")
        h("Epop[61] netConn_projEE_ampa[4918] = new NetCon(&v(0.5), syn_projEE_ampa[4918], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4919: cell 61, seg 0 (0.5) [0.5 on Epop[61]] -> cell 39, seg 0 (0.5) [0.5 on Epop[39]], weight: 4.1363508E-4, delay 1.5
        h("Epop[39] syn_projEE_ampa[4919] = new ampa(0.5)")
        h("Epop[61] netConn_projEE_ampa[4919] = new NetCon(&v(0.5), syn_projEE_ampa[4919], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4920: cell 61, seg 0 (0.5) [0.5 on Epop[61]] -> cell 40, seg 0 (0.5) [0.5 on Epop[40]], weight: 4.1363508E-4, delay 1.5
        h("Epop[40] syn_projEE_ampa[4920] = new ampa(0.5)")
        h("Epop[61] netConn_projEE_ampa[4920] = new NetCon(&v(0.5), syn_projEE_ampa[4920], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4921: cell 61, seg 0 (0.5) [0.5 on Epop[61]] -> cell 41, seg 0 (0.5) [0.5 on Epop[41]], weight: 4.1363508E-4, delay 1.5
        h("Epop[41] syn_projEE_ampa[4921] = new ampa(0.5)")
        h("Epop[61] netConn_projEE_ampa[4921] = new NetCon(&v(0.5), syn_projEE_ampa[4921], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4922: cell 61, seg 0 (0.5) [0.5 on Epop[61]] -> cell 42, seg 0 (0.5) [0.5 on Epop[42]], weight: 4.1363508E-4, delay 1.5
        h("Epop[42] syn_projEE_ampa[4922] = new ampa(0.5)")
        h("Epop[61] netConn_projEE_ampa[4922] = new NetCon(&v(0.5), syn_projEE_ampa[4922], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4923: cell 61, seg 0 (0.5) [0.5 on Epop[61]] -> cell 43, seg 0 (0.5) [0.5 on Epop[43]], weight: 4.1363508E-4, delay 1.5
        h("Epop[43] syn_projEE_ampa[4923] = new ampa(0.5)")
        h("Epop[61] netConn_projEE_ampa[4923] = new NetCon(&v(0.5), syn_projEE_ampa[4923], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4924: cell 61, seg 0 (0.5) [0.5 on Epop[61]] -> cell 44, seg 0 (0.5) [0.5 on Epop[44]], weight: 4.1363508E-4, delay 1.5
        h("Epop[44] syn_projEE_ampa[4924] = new ampa(0.5)")
        h("Epop[61] netConn_projEE_ampa[4924] = new NetCon(&v(0.5), syn_projEE_ampa[4924], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4925: cell 61, seg 0 (0.5) [0.5 on Epop[61]] -> cell 45, seg 0 (0.5) [0.5 on Epop[45]], weight: 4.1363508E-4, delay 1.5
        h("Epop[45] syn_projEE_ampa[4925] = new ampa(0.5)")
        h("Epop[61] netConn_projEE_ampa[4925] = new NetCon(&v(0.5), syn_projEE_ampa[4925], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4926: cell 61, seg 0 (0.5) [0.5 on Epop[61]] -> cell 46, seg 0 (0.5) [0.5 on Epop[46]], weight: 4.1363508E-4, delay 1.5
        h("Epop[46] syn_projEE_ampa[4926] = new ampa(0.5)")
        h("Epop[61] netConn_projEE_ampa[4926] = new NetCon(&v(0.5), syn_projEE_ampa[4926], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4927: cell 61, seg 0 (0.5) [0.5 on Epop[61]] -> cell 47, seg 0 (0.5) [0.5 on Epop[47]], weight: 4.1363508E-4, delay 1.5
        h("Epop[47] syn_projEE_ampa[4927] = new ampa(0.5)")
        h("Epop[61] netConn_projEE_ampa[4927] = new NetCon(&v(0.5), syn_projEE_ampa[4927], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4928: cell 61, seg 0 (0.5) [0.5 on Epop[61]] -> cell 48, seg 0 (0.5) [0.5 on Epop[48]], weight: 4.1363508E-4, delay 1.5
        h("Epop[48] syn_projEE_ampa[4928] = new ampa(0.5)")
        h("Epop[61] netConn_projEE_ampa[4928] = new NetCon(&v(0.5), syn_projEE_ampa[4928], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4929: cell 61, seg 0 (0.5) [0.5 on Epop[61]] -> cell 49, seg 0 (0.5) [0.5 on Epop[49]], weight: 4.1363508E-4, delay 1.5
        h("Epop[49] syn_projEE_ampa[4929] = new ampa(0.5)")
        h("Epop[61] netConn_projEE_ampa[4929] = new NetCon(&v(0.5), syn_projEE_ampa[4929], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4930: cell 61, seg 0 (0.5) [0.5 on Epop[61]] -> cell 50, seg 0 (0.5) [0.5 on Epop[50]], weight: 4.1363508E-4, delay 1.5
        h("Epop[50] syn_projEE_ampa[4930] = new ampa(0.5)")
        h("Epop[61] netConn_projEE_ampa[4930] = new NetCon(&v(0.5), syn_projEE_ampa[4930], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4931: cell 61, seg 0 (0.5) [0.5 on Epop[61]] -> cell 51, seg 0 (0.5) [0.5 on Epop[51]], weight: 4.1363508E-4, delay 1.5
        h("Epop[51] syn_projEE_ampa[4931] = new ampa(0.5)")
        h("Epop[61] netConn_projEE_ampa[4931] = new NetCon(&v(0.5), syn_projEE_ampa[4931], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4932: cell 61, seg 0 (0.5) [0.5 on Epop[61]] -> cell 52, seg 0 (0.5) [0.5 on Epop[52]], weight: 4.1363508E-4, delay 1.5
        h("Epop[52] syn_projEE_ampa[4932] = new ampa(0.5)")
        h("Epop[61] netConn_projEE_ampa[4932] = new NetCon(&v(0.5), syn_projEE_ampa[4932], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4933: cell 61, seg 0 (0.5) [0.5 on Epop[61]] -> cell 53, seg 0 (0.5) [0.5 on Epop[53]], weight: 4.1363508E-4, delay 1.5
        h("Epop[53] syn_projEE_ampa[4933] = new ampa(0.5)")
        h("Epop[61] netConn_projEE_ampa[4933] = new NetCon(&v(0.5), syn_projEE_ampa[4933], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4934: cell 61, seg 0 (0.5) [0.5 on Epop[61]] -> cell 54, seg 0 (0.5) [0.5 on Epop[54]], weight: 4.1363508E-4, delay 1.5
        h("Epop[54] syn_projEE_ampa[4934] = new ampa(0.5)")
        h("Epop[61] netConn_projEE_ampa[4934] = new NetCon(&v(0.5), syn_projEE_ampa[4934], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4935: cell 61, seg 0 (0.5) [0.5 on Epop[61]] -> cell 55, seg 0 (0.5) [0.5 on Epop[55]], weight: 4.1363508E-4, delay 1.5
        h("Epop[55] syn_projEE_ampa[4935] = new ampa(0.5)")
        h("Epop[61] netConn_projEE_ampa[4935] = new NetCon(&v(0.5), syn_projEE_ampa[4935], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4936: cell 61, seg 0 (0.5) [0.5 on Epop[61]] -> cell 56, seg 0 (0.5) [0.5 on Epop[56]], weight: 4.1363508E-4, delay 1.5
        h("Epop[56] syn_projEE_ampa[4936] = new ampa(0.5)")
        h("Epop[61] netConn_projEE_ampa[4936] = new NetCon(&v(0.5), syn_projEE_ampa[4936], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4937: cell 61, seg 0 (0.5) [0.5 on Epop[61]] -> cell 57, seg 0 (0.5) [0.5 on Epop[57]], weight: 4.1363508E-4, delay 1.5
        h("Epop[57] syn_projEE_ampa[4937] = new ampa(0.5)")
        h("Epop[61] netConn_projEE_ampa[4937] = new NetCon(&v(0.5), syn_projEE_ampa[4937], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4938: cell 61, seg 0 (0.5) [0.5 on Epop[61]] -> cell 58, seg 0 (0.5) [0.5 on Epop[58]], weight: 4.1363508E-4, delay 1.5
        h("Epop[58] syn_projEE_ampa[4938] = new ampa(0.5)")
        h("Epop[61] netConn_projEE_ampa[4938] = new NetCon(&v(0.5), syn_projEE_ampa[4938], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4939: cell 61, seg 0 (0.5) [0.5 on Epop[61]] -> cell 59, seg 0 (0.5) [0.5 on Epop[59]], weight: 4.1363508E-4, delay 1.5
        h("Epop[59] syn_projEE_ampa[4939] = new ampa(0.5)")
        h("Epop[61] netConn_projEE_ampa[4939] = new NetCon(&v(0.5), syn_projEE_ampa[4939], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4940: cell 61, seg 0 (0.5) [0.5 on Epop[61]] -> cell 60, seg 0 (0.5) [0.5 on Epop[60]], weight: 4.1363508E-4, delay 1.5
        h("Epop[60] syn_projEE_ampa[4940] = new ampa(0.5)")
        h("Epop[61] netConn_projEE_ampa[4940] = new NetCon(&v(0.5), syn_projEE_ampa[4940], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4941: cell 61, seg 0 (0.5) [0.5 on Epop[61]] -> cell 61, seg 0 (0.5) [0.5 on Epop[61]], weight: 4.1363508E-4, delay 1.5
        h("Epop[61] syn_projEE_ampa[4941] = new ampa(0.5)")
        h("Epop[61] netConn_projEE_ampa[4941] = new NetCon(&v(0.5), syn_projEE_ampa[4941], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4942: cell 61, seg 0 (0.5) [0.5 on Epop[61]] -> cell 62, seg 0 (0.5) [0.5 on Epop[62]], weight: 4.1363508E-4, delay 1.5
        h("Epop[62] syn_projEE_ampa[4942] = new ampa(0.5)")
        h("Epop[61] netConn_projEE_ampa[4942] = new NetCon(&v(0.5), syn_projEE_ampa[4942], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4943: cell 61, seg 0 (0.5) [0.5 on Epop[61]] -> cell 63, seg 0 (0.5) [0.5 on Epop[63]], weight: 4.1363508E-4, delay 1.5
        h("Epop[63] syn_projEE_ampa[4943] = new ampa(0.5)")
        h("Epop[61] netConn_projEE_ampa[4943] = new NetCon(&v(0.5), syn_projEE_ampa[4943], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4944: cell 61, seg 0 (0.5) [0.5 on Epop[61]] -> cell 64, seg 0 (0.5) [0.5 on Epop[64]], weight: 4.1363508E-4, delay 1.5
        h("Epop[64] syn_projEE_ampa[4944] = new ampa(0.5)")
        h("Epop[61] netConn_projEE_ampa[4944] = new NetCon(&v(0.5), syn_projEE_ampa[4944], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4945: cell 61, seg 0 (0.5) [0.5 on Epop[61]] -> cell 65, seg 0 (0.5) [0.5 on Epop[65]], weight: 4.1363508E-4, delay 1.5
        h("Epop[65] syn_projEE_ampa[4945] = new ampa(0.5)")
        h("Epop[61] netConn_projEE_ampa[4945] = new NetCon(&v(0.5), syn_projEE_ampa[4945], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4946: cell 61, seg 0 (0.5) [0.5 on Epop[61]] -> cell 66, seg 0 (0.5) [0.5 on Epop[66]], weight: 4.1363508E-4, delay 1.5
        h("Epop[66] syn_projEE_ampa[4946] = new ampa(0.5)")
        h("Epop[61] netConn_projEE_ampa[4946] = new NetCon(&v(0.5), syn_projEE_ampa[4946], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4947: cell 61, seg 0 (0.5) [0.5 on Epop[61]] -> cell 67, seg 0 (0.5) [0.5 on Epop[67]], weight: 4.1363508E-4, delay 1.5
        h("Epop[67] syn_projEE_ampa[4947] = new ampa(0.5)")
        h("Epop[61] netConn_projEE_ampa[4947] = new NetCon(&v(0.5), syn_projEE_ampa[4947], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4948: cell 61, seg 0 (0.5) [0.5 on Epop[61]] -> cell 68, seg 0 (0.5) [0.5 on Epop[68]], weight: 4.1363508E-4, delay 1.5
        h("Epop[68] syn_projEE_ampa[4948] = new ampa(0.5)")
        h("Epop[61] netConn_projEE_ampa[4948] = new NetCon(&v(0.5), syn_projEE_ampa[4948], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4949: cell 61, seg 0 (0.5) [0.5 on Epop[61]] -> cell 69, seg 0 (0.5) [0.5 on Epop[69]], weight: 4.1363508E-4, delay 1.5
        h("Epop[69] syn_projEE_ampa[4949] = new ampa(0.5)")
        h("Epop[61] netConn_projEE_ampa[4949] = new NetCon(&v(0.5), syn_projEE_ampa[4949], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4950: cell 61, seg 0 (0.5) [0.5 on Epop[61]] -> cell 70, seg 0 (0.5) [0.5 on Epop[70]], weight: 4.1363508E-4, delay 1.5
        h("Epop[70] syn_projEE_ampa[4950] = new ampa(0.5)")
        h("Epop[61] netConn_projEE_ampa[4950] = new NetCon(&v(0.5), syn_projEE_ampa[4950], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4951: cell 61, seg 0 (0.5) [0.5 on Epop[61]] -> cell 71, seg 0 (0.5) [0.5 on Epop[71]], weight: 4.1363508E-4, delay 1.5
        h("Epop[71] syn_projEE_ampa[4951] = new ampa(0.5)")
        h("Epop[61] netConn_projEE_ampa[4951] = new NetCon(&v(0.5), syn_projEE_ampa[4951], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4952: cell 61, seg 0 (0.5) [0.5 on Epop[61]] -> cell 72, seg 0 (0.5) [0.5 on Epop[72]], weight: 4.1363508E-4, delay 1.5
        h("Epop[72] syn_projEE_ampa[4952] = new ampa(0.5)")
        h("Epop[61] netConn_projEE_ampa[4952] = new NetCon(&v(0.5), syn_projEE_ampa[4952], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4953: cell 61, seg 0 (0.5) [0.5 on Epop[61]] -> cell 73, seg 0 (0.5) [0.5 on Epop[73]], weight: 4.1363508E-4, delay 1.5
        h("Epop[73] syn_projEE_ampa[4953] = new ampa(0.5)")
        h("Epop[61] netConn_projEE_ampa[4953] = new NetCon(&v(0.5), syn_projEE_ampa[4953], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4954: cell 61, seg 0 (0.5) [0.5 on Epop[61]] -> cell 74, seg 0 (0.5) [0.5 on Epop[74]], weight: 4.1363508E-4, delay 1.5
        h("Epop[74] syn_projEE_ampa[4954] = new ampa(0.5)")
        h("Epop[61] netConn_projEE_ampa[4954] = new NetCon(&v(0.5), syn_projEE_ampa[4954], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4955: cell 61, seg 0 (0.5) [0.5 on Epop[61]] -> cell 75, seg 0 (0.5) [0.5 on Epop[75]], weight: 4.1363508E-4, delay 1.5
        h("Epop[75] syn_projEE_ampa[4955] = new ampa(0.5)")
        h("Epop[61] netConn_projEE_ampa[4955] = new NetCon(&v(0.5), syn_projEE_ampa[4955], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4956: cell 61, seg 0 (0.5) [0.5 on Epop[61]] -> cell 76, seg 0 (0.5) [0.5 on Epop[76]], weight: 4.1363508E-4, delay 1.5
        h("Epop[76] syn_projEE_ampa[4956] = new ampa(0.5)")
        h("Epop[61] netConn_projEE_ampa[4956] = new NetCon(&v(0.5), syn_projEE_ampa[4956], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4957: cell 61, seg 0 (0.5) [0.5 on Epop[61]] -> cell 77, seg 0 (0.5) [0.5 on Epop[77]], weight: 4.1363508E-4, delay 1.5
        h("Epop[77] syn_projEE_ampa[4957] = new ampa(0.5)")
        h("Epop[61] netConn_projEE_ampa[4957] = new NetCon(&v(0.5), syn_projEE_ampa[4957], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4958: cell 61, seg 0 (0.5) [0.5 on Epop[61]] -> cell 78, seg 0 (0.5) [0.5 on Epop[78]], weight: 4.1363508E-4, delay 1.5
        h("Epop[78] syn_projEE_ampa[4958] = new ampa(0.5)")
        h("Epop[61] netConn_projEE_ampa[4958] = new NetCon(&v(0.5), syn_projEE_ampa[4958], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4959: cell 61, seg 0 (0.5) [0.5 on Epop[61]] -> cell 79, seg 0 (0.5) [0.5 on Epop[79]], weight: 4.1363508E-4, delay 1.5
        h("Epop[79] syn_projEE_ampa[4959] = new ampa(0.5)")
        h("Epop[61] netConn_projEE_ampa[4959] = new NetCon(&v(0.5), syn_projEE_ampa[4959], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4960: cell 62, seg 0 (0.5) [0.5 on Epop[62]] -> cell 0, seg 0 (0.5) [0.5 on Epop[0]], weight: 4.1363508E-4, delay 1.5
        h("Epop[0] syn_projEE_ampa[4960] = new ampa(0.5)")
        h("Epop[62] netConn_projEE_ampa[4960] = new NetCon(&v(0.5), syn_projEE_ampa[4960], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4961: cell 62, seg 0 (0.5) [0.5 on Epop[62]] -> cell 1, seg 0 (0.5) [0.5 on Epop[1]], weight: 4.1363508E-4, delay 1.5
        h("Epop[1] syn_projEE_ampa[4961] = new ampa(0.5)")
        h("Epop[62] netConn_projEE_ampa[4961] = new NetCon(&v(0.5), syn_projEE_ampa[4961], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4962: cell 62, seg 0 (0.5) [0.5 on Epop[62]] -> cell 2, seg 0 (0.5) [0.5 on Epop[2]], weight: 4.1363508E-4, delay 1.5
        h("Epop[2] syn_projEE_ampa[4962] = new ampa(0.5)")
        h("Epop[62] netConn_projEE_ampa[4962] = new NetCon(&v(0.5), syn_projEE_ampa[4962], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4963: cell 62, seg 0 (0.5) [0.5 on Epop[62]] -> cell 3, seg 0 (0.5) [0.5 on Epop[3]], weight: 4.1363508E-4, delay 1.5
        h("Epop[3] syn_projEE_ampa[4963] = new ampa(0.5)")
        h("Epop[62] netConn_projEE_ampa[4963] = new NetCon(&v(0.5), syn_projEE_ampa[4963], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4964: cell 62, seg 0 (0.5) [0.5 on Epop[62]] -> cell 4, seg 0 (0.5) [0.5 on Epop[4]], weight: 4.1363508E-4, delay 1.5
        h("Epop[4] syn_projEE_ampa[4964] = new ampa(0.5)")
        h("Epop[62] netConn_projEE_ampa[4964] = new NetCon(&v(0.5), syn_projEE_ampa[4964], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4965: cell 62, seg 0 (0.5) [0.5 on Epop[62]] -> cell 5, seg 0 (0.5) [0.5 on Epop[5]], weight: 4.1363508E-4, delay 1.5
        h("Epop[5] syn_projEE_ampa[4965] = new ampa(0.5)")
        h("Epop[62] netConn_projEE_ampa[4965] = new NetCon(&v(0.5), syn_projEE_ampa[4965], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4966: cell 62, seg 0 (0.5) [0.5 on Epop[62]] -> cell 6, seg 0 (0.5) [0.5 on Epop[6]], weight: 4.1363508E-4, delay 1.5
        h("Epop[6] syn_projEE_ampa[4966] = new ampa(0.5)")
        h("Epop[62] netConn_projEE_ampa[4966] = new NetCon(&v(0.5), syn_projEE_ampa[4966], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4967: cell 62, seg 0 (0.5) [0.5 on Epop[62]] -> cell 7, seg 0 (0.5) [0.5 on Epop[7]], weight: 4.1363508E-4, delay 1.5
        h("Epop[7] syn_projEE_ampa[4967] = new ampa(0.5)")
        h("Epop[62] netConn_projEE_ampa[4967] = new NetCon(&v(0.5), syn_projEE_ampa[4967], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4968: cell 62, seg 0 (0.5) [0.5 on Epop[62]] -> cell 8, seg 0 (0.5) [0.5 on Epop[8]], weight: 4.1363508E-4, delay 1.5
        h("Epop[8] syn_projEE_ampa[4968] = new ampa(0.5)")
        h("Epop[62] netConn_projEE_ampa[4968] = new NetCon(&v(0.5), syn_projEE_ampa[4968], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4969: cell 62, seg 0 (0.5) [0.5 on Epop[62]] -> cell 9, seg 0 (0.5) [0.5 on Epop[9]], weight: 4.1363508E-4, delay 1.5
        h("Epop[9] syn_projEE_ampa[4969] = new ampa(0.5)")
        h("Epop[62] netConn_projEE_ampa[4969] = new NetCon(&v(0.5), syn_projEE_ampa[4969], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4970: cell 62, seg 0 (0.5) [0.5 on Epop[62]] -> cell 10, seg 0 (0.5) [0.5 on Epop[10]], weight: 4.1363508E-4, delay 1.5
        h("Epop[10] syn_projEE_ampa[4970] = new ampa(0.5)")
        h("Epop[62] netConn_projEE_ampa[4970] = new NetCon(&v(0.5), syn_projEE_ampa[4970], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4971: cell 62, seg 0 (0.5) [0.5 on Epop[62]] -> cell 11, seg 0 (0.5) [0.5 on Epop[11]], weight: 4.1363508E-4, delay 1.5
        h("Epop[11] syn_projEE_ampa[4971] = new ampa(0.5)")
        h("Epop[62] netConn_projEE_ampa[4971] = new NetCon(&v(0.5), syn_projEE_ampa[4971], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4972: cell 62, seg 0 (0.5) [0.5 on Epop[62]] -> cell 12, seg 0 (0.5) [0.5 on Epop[12]], weight: 4.1363508E-4, delay 1.5
        h("Epop[12] syn_projEE_ampa[4972] = new ampa(0.5)")
        h("Epop[62] netConn_projEE_ampa[4972] = new NetCon(&v(0.5), syn_projEE_ampa[4972], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4973: cell 62, seg 0 (0.5) [0.5 on Epop[62]] -> cell 13, seg 0 (0.5) [0.5 on Epop[13]], weight: 4.1363508E-4, delay 1.5
        h("Epop[13] syn_projEE_ampa[4973] = new ampa(0.5)")
        h("Epop[62] netConn_projEE_ampa[4973] = new NetCon(&v(0.5), syn_projEE_ampa[4973], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4974: cell 62, seg 0 (0.5) [0.5 on Epop[62]] -> cell 14, seg 0 (0.5) [0.5 on Epop[14]], weight: 4.1363508E-4, delay 1.5
        h("Epop[14] syn_projEE_ampa[4974] = new ampa(0.5)")
        h("Epop[62] netConn_projEE_ampa[4974] = new NetCon(&v(0.5), syn_projEE_ampa[4974], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4975: cell 62, seg 0 (0.5) [0.5 on Epop[62]] -> cell 15, seg 0 (0.5) [0.5 on Epop[15]], weight: 4.1363508E-4, delay 1.5
        h("Epop[15] syn_projEE_ampa[4975] = new ampa(0.5)")
        h("Epop[62] netConn_projEE_ampa[4975] = new NetCon(&v(0.5), syn_projEE_ampa[4975], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4976: cell 62, seg 0 (0.5) [0.5 on Epop[62]] -> cell 16, seg 0 (0.5) [0.5 on Epop[16]], weight: 4.1363508E-4, delay 1.5
        h("Epop[16] syn_projEE_ampa[4976] = new ampa(0.5)")
        h("Epop[62] netConn_projEE_ampa[4976] = new NetCon(&v(0.5), syn_projEE_ampa[4976], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4977: cell 62, seg 0 (0.5) [0.5 on Epop[62]] -> cell 17, seg 0 (0.5) [0.5 on Epop[17]], weight: 4.1363508E-4, delay 1.5
        h("Epop[17] syn_projEE_ampa[4977] = new ampa(0.5)")
        h("Epop[62] netConn_projEE_ampa[4977] = new NetCon(&v(0.5), syn_projEE_ampa[4977], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4978: cell 62, seg 0 (0.5) [0.5 on Epop[62]] -> cell 18, seg 0 (0.5) [0.5 on Epop[18]], weight: 4.1363508E-4, delay 1.5
        h("Epop[18] syn_projEE_ampa[4978] = new ampa(0.5)")
        h("Epop[62] netConn_projEE_ampa[4978] = new NetCon(&v(0.5), syn_projEE_ampa[4978], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4979: cell 62, seg 0 (0.5) [0.5 on Epop[62]] -> cell 19, seg 0 (0.5) [0.5 on Epop[19]], weight: 4.1363508E-4, delay 1.5
        h("Epop[19] syn_projEE_ampa[4979] = new ampa(0.5)")
        h("Epop[62] netConn_projEE_ampa[4979] = new NetCon(&v(0.5), syn_projEE_ampa[4979], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4980: cell 62, seg 0 (0.5) [0.5 on Epop[62]] -> cell 20, seg 0 (0.5) [0.5 on Epop[20]], weight: 4.1363508E-4, delay 1.5
        h("Epop[20] syn_projEE_ampa[4980] = new ampa(0.5)")
        h("Epop[62] netConn_projEE_ampa[4980] = new NetCon(&v(0.5), syn_projEE_ampa[4980], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4981: cell 62, seg 0 (0.5) [0.5 on Epop[62]] -> cell 21, seg 0 (0.5) [0.5 on Epop[21]], weight: 4.1363508E-4, delay 1.5
        h("Epop[21] syn_projEE_ampa[4981] = new ampa(0.5)")
        h("Epop[62] netConn_projEE_ampa[4981] = new NetCon(&v(0.5), syn_projEE_ampa[4981], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4982: cell 62, seg 0 (0.5) [0.5 on Epop[62]] -> cell 22, seg 0 (0.5) [0.5 on Epop[22]], weight: 4.1363508E-4, delay 1.5
        h("Epop[22] syn_projEE_ampa[4982] = new ampa(0.5)")
        h("Epop[62] netConn_projEE_ampa[4982] = new NetCon(&v(0.5), syn_projEE_ampa[4982], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4983: cell 62, seg 0 (0.5) [0.5 on Epop[62]] -> cell 23, seg 0 (0.5) [0.5 on Epop[23]], weight: 4.1363508E-4, delay 1.5
        h("Epop[23] syn_projEE_ampa[4983] = new ampa(0.5)")
        h("Epop[62] netConn_projEE_ampa[4983] = new NetCon(&v(0.5), syn_projEE_ampa[4983], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4984: cell 62, seg 0 (0.5) [0.5 on Epop[62]] -> cell 24, seg 0 (0.5) [0.5 on Epop[24]], weight: 4.1363508E-4, delay 1.5
        h("Epop[24] syn_projEE_ampa[4984] = new ampa(0.5)")
        h("Epop[62] netConn_projEE_ampa[4984] = new NetCon(&v(0.5), syn_projEE_ampa[4984], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4985: cell 62, seg 0 (0.5) [0.5 on Epop[62]] -> cell 25, seg 0 (0.5) [0.5 on Epop[25]], weight: 4.1363508E-4, delay 1.5
        h("Epop[25] syn_projEE_ampa[4985] = new ampa(0.5)")
        h("Epop[62] netConn_projEE_ampa[4985] = new NetCon(&v(0.5), syn_projEE_ampa[4985], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4986: cell 62, seg 0 (0.5) [0.5 on Epop[62]] -> cell 26, seg 0 (0.5) [0.5 on Epop[26]], weight: 4.1363508E-4, delay 1.5
        h("Epop[26] syn_projEE_ampa[4986] = new ampa(0.5)")
        h("Epop[62] netConn_projEE_ampa[4986] = new NetCon(&v(0.5), syn_projEE_ampa[4986], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4987: cell 62, seg 0 (0.5) [0.5 on Epop[62]] -> cell 27, seg 0 (0.5) [0.5 on Epop[27]], weight: 4.1363508E-4, delay 1.5
        h("Epop[27] syn_projEE_ampa[4987] = new ampa(0.5)")
        h("Epop[62] netConn_projEE_ampa[4987] = new NetCon(&v(0.5), syn_projEE_ampa[4987], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4988: cell 62, seg 0 (0.5) [0.5 on Epop[62]] -> cell 28, seg 0 (0.5) [0.5 on Epop[28]], weight: 4.1363508E-4, delay 1.5
        h("Epop[28] syn_projEE_ampa[4988] = new ampa(0.5)")
        h("Epop[62] netConn_projEE_ampa[4988] = new NetCon(&v(0.5), syn_projEE_ampa[4988], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4989: cell 62, seg 0 (0.5) [0.5 on Epop[62]] -> cell 29, seg 0 (0.5) [0.5 on Epop[29]], weight: 4.1363508E-4, delay 1.5
        h("Epop[29] syn_projEE_ampa[4989] = new ampa(0.5)")
        h("Epop[62] netConn_projEE_ampa[4989] = new NetCon(&v(0.5), syn_projEE_ampa[4989], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4990: cell 62, seg 0 (0.5) [0.5 on Epop[62]] -> cell 30, seg 0 (0.5) [0.5 on Epop[30]], weight: 4.1363508E-4, delay 1.5
        h("Epop[30] syn_projEE_ampa[4990] = new ampa(0.5)")
        h("Epop[62] netConn_projEE_ampa[4990] = new NetCon(&v(0.5), syn_projEE_ampa[4990], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4991: cell 62, seg 0 (0.5) [0.5 on Epop[62]] -> cell 31, seg 0 (0.5) [0.5 on Epop[31]], weight: 4.1363508E-4, delay 1.5
        h("Epop[31] syn_projEE_ampa[4991] = new ampa(0.5)")
        h("Epop[62] netConn_projEE_ampa[4991] = new NetCon(&v(0.5), syn_projEE_ampa[4991], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4992: cell 62, seg 0 (0.5) [0.5 on Epop[62]] -> cell 32, seg 0 (0.5) [0.5 on Epop[32]], weight: 4.1363508E-4, delay 1.5
        h("Epop[32] syn_projEE_ampa[4992] = new ampa(0.5)")
        h("Epop[62] netConn_projEE_ampa[4992] = new NetCon(&v(0.5), syn_projEE_ampa[4992], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4993: cell 62, seg 0 (0.5) [0.5 on Epop[62]] -> cell 33, seg 0 (0.5) [0.5 on Epop[33]], weight: 4.1363508E-4, delay 1.5
        h("Epop[33] syn_projEE_ampa[4993] = new ampa(0.5)")
        h("Epop[62] netConn_projEE_ampa[4993] = new NetCon(&v(0.5), syn_projEE_ampa[4993], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4994: cell 62, seg 0 (0.5) [0.5 on Epop[62]] -> cell 34, seg 0 (0.5) [0.5 on Epop[34]], weight: 4.1363508E-4, delay 1.5
        h("Epop[34] syn_projEE_ampa[4994] = new ampa(0.5)")
        h("Epop[62] netConn_projEE_ampa[4994] = new NetCon(&v(0.5), syn_projEE_ampa[4994], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4995: cell 62, seg 0 (0.5) [0.5 on Epop[62]] -> cell 35, seg 0 (0.5) [0.5 on Epop[35]], weight: 4.1363508E-4, delay 1.5
        h("Epop[35] syn_projEE_ampa[4995] = new ampa(0.5)")
        h("Epop[62] netConn_projEE_ampa[4995] = new NetCon(&v(0.5), syn_projEE_ampa[4995], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4996: cell 62, seg 0 (0.5) [0.5 on Epop[62]] -> cell 36, seg 0 (0.5) [0.5 on Epop[36]], weight: 4.1363508E-4, delay 1.5
        h("Epop[36] syn_projEE_ampa[4996] = new ampa(0.5)")
        h("Epop[62] netConn_projEE_ampa[4996] = new NetCon(&v(0.5), syn_projEE_ampa[4996], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4997: cell 62, seg 0 (0.5) [0.5 on Epop[62]] -> cell 37, seg 0 (0.5) [0.5 on Epop[37]], weight: 4.1363508E-4, delay 1.5
        h("Epop[37] syn_projEE_ampa[4997] = new ampa(0.5)")
        h("Epop[62] netConn_projEE_ampa[4997] = new NetCon(&v(0.5), syn_projEE_ampa[4997], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4998: cell 62, seg 0 (0.5) [0.5 on Epop[62]] -> cell 38, seg 0 (0.5) [0.5 on Epop[38]], weight: 4.1363508E-4, delay 1.5
        h("Epop[38] syn_projEE_ampa[4998] = new ampa(0.5)")
        h("Epop[62] netConn_projEE_ampa[4998] = new NetCon(&v(0.5), syn_projEE_ampa[4998], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4999: cell 62, seg 0 (0.5) [0.5 on Epop[62]] -> cell 39, seg 0 (0.5) [0.5 on Epop[39]], weight: 4.1363508E-4, delay 1.5
        h("Epop[39] syn_projEE_ampa[4999] = new ampa(0.5)")
        h("Epop[62] netConn_projEE_ampa[4999] = new NetCon(&v(0.5), syn_projEE_ampa[4999], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5000: cell 62, seg 0 (0.5) [0.5 on Epop[62]] -> cell 40, seg 0 (0.5) [0.5 on Epop[40]], weight: 4.1363508E-4, delay 1.5
        h("Epop[40] syn_projEE_ampa[5000] = new ampa(0.5)")
        h("Epop[62] netConn_projEE_ampa[5000] = new NetCon(&v(0.5), syn_projEE_ampa[5000], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5001: cell 62, seg 0 (0.5) [0.5 on Epop[62]] -> cell 41, seg 0 (0.5) [0.5 on Epop[41]], weight: 4.1363508E-4, delay 1.5
        h("Epop[41] syn_projEE_ampa[5001] = new ampa(0.5)")
        h("Epop[62] netConn_projEE_ampa[5001] = new NetCon(&v(0.5), syn_projEE_ampa[5001], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5002: cell 62, seg 0 (0.5) [0.5 on Epop[62]] -> cell 42, seg 0 (0.5) [0.5 on Epop[42]], weight: 4.1363508E-4, delay 1.5
        h("Epop[42] syn_projEE_ampa[5002] = new ampa(0.5)")
        h("Epop[62] netConn_projEE_ampa[5002] = new NetCon(&v(0.5), syn_projEE_ampa[5002], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5003: cell 62, seg 0 (0.5) [0.5 on Epop[62]] -> cell 43, seg 0 (0.5) [0.5 on Epop[43]], weight: 4.1363508E-4, delay 1.5
        h("Epop[43] syn_projEE_ampa[5003] = new ampa(0.5)")
        h("Epop[62] netConn_projEE_ampa[5003] = new NetCon(&v(0.5), syn_projEE_ampa[5003], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5004: cell 62, seg 0 (0.5) [0.5 on Epop[62]] -> cell 44, seg 0 (0.5) [0.5 on Epop[44]], weight: 4.1363508E-4, delay 1.5
        h("Epop[44] syn_projEE_ampa[5004] = new ampa(0.5)")
        h("Epop[62] netConn_projEE_ampa[5004] = new NetCon(&v(0.5), syn_projEE_ampa[5004], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5005: cell 62, seg 0 (0.5) [0.5 on Epop[62]] -> cell 45, seg 0 (0.5) [0.5 on Epop[45]], weight: 4.1363508E-4, delay 1.5
        h("Epop[45] syn_projEE_ampa[5005] = new ampa(0.5)")
        h("Epop[62] netConn_projEE_ampa[5005] = new NetCon(&v(0.5), syn_projEE_ampa[5005], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5006: cell 62, seg 0 (0.5) [0.5 on Epop[62]] -> cell 46, seg 0 (0.5) [0.5 on Epop[46]], weight: 4.1363508E-4, delay 1.5
        h("Epop[46] syn_projEE_ampa[5006] = new ampa(0.5)")
        h("Epop[62] netConn_projEE_ampa[5006] = new NetCon(&v(0.5), syn_projEE_ampa[5006], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5007: cell 62, seg 0 (0.5) [0.5 on Epop[62]] -> cell 47, seg 0 (0.5) [0.5 on Epop[47]], weight: 4.1363508E-4, delay 1.5
        h("Epop[47] syn_projEE_ampa[5007] = new ampa(0.5)")
        h("Epop[62] netConn_projEE_ampa[5007] = new NetCon(&v(0.5), syn_projEE_ampa[5007], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5008: cell 62, seg 0 (0.5) [0.5 on Epop[62]] -> cell 48, seg 0 (0.5) [0.5 on Epop[48]], weight: 4.1363508E-4, delay 1.5
        h("Epop[48] syn_projEE_ampa[5008] = new ampa(0.5)")
        h("Epop[62] netConn_projEE_ampa[5008] = new NetCon(&v(0.5), syn_projEE_ampa[5008], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5009: cell 62, seg 0 (0.5) [0.5 on Epop[62]] -> cell 49, seg 0 (0.5) [0.5 on Epop[49]], weight: 4.1363508E-4, delay 1.5
        h("Epop[49] syn_projEE_ampa[5009] = new ampa(0.5)")
        h("Epop[62] netConn_projEE_ampa[5009] = new NetCon(&v(0.5), syn_projEE_ampa[5009], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5010: cell 62, seg 0 (0.5) [0.5 on Epop[62]] -> cell 50, seg 0 (0.5) [0.5 on Epop[50]], weight: 4.1363508E-4, delay 1.5
        h("Epop[50] syn_projEE_ampa[5010] = new ampa(0.5)")
        h("Epop[62] netConn_projEE_ampa[5010] = new NetCon(&v(0.5), syn_projEE_ampa[5010], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5011: cell 62, seg 0 (0.5) [0.5 on Epop[62]] -> cell 51, seg 0 (0.5) [0.5 on Epop[51]], weight: 4.1363508E-4, delay 1.5
        h("Epop[51] syn_projEE_ampa[5011] = new ampa(0.5)")
        h("Epop[62] netConn_projEE_ampa[5011] = new NetCon(&v(0.5), syn_projEE_ampa[5011], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5012: cell 62, seg 0 (0.5) [0.5 on Epop[62]] -> cell 52, seg 0 (0.5) [0.5 on Epop[52]], weight: 4.1363508E-4, delay 1.5
        h("Epop[52] syn_projEE_ampa[5012] = new ampa(0.5)")
        h("Epop[62] netConn_projEE_ampa[5012] = new NetCon(&v(0.5), syn_projEE_ampa[5012], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5013: cell 62, seg 0 (0.5) [0.5 on Epop[62]] -> cell 53, seg 0 (0.5) [0.5 on Epop[53]], weight: 4.1363508E-4, delay 1.5
        h("Epop[53] syn_projEE_ampa[5013] = new ampa(0.5)")
        h("Epop[62] netConn_projEE_ampa[5013] = new NetCon(&v(0.5), syn_projEE_ampa[5013], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5014: cell 62, seg 0 (0.5) [0.5 on Epop[62]] -> cell 54, seg 0 (0.5) [0.5 on Epop[54]], weight: 4.1363508E-4, delay 1.5
        h("Epop[54] syn_projEE_ampa[5014] = new ampa(0.5)")
        h("Epop[62] netConn_projEE_ampa[5014] = new NetCon(&v(0.5), syn_projEE_ampa[5014], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5015: cell 62, seg 0 (0.5) [0.5 on Epop[62]] -> cell 55, seg 0 (0.5) [0.5 on Epop[55]], weight: 4.1363508E-4, delay 1.5
        h("Epop[55] syn_projEE_ampa[5015] = new ampa(0.5)")
        h("Epop[62] netConn_projEE_ampa[5015] = new NetCon(&v(0.5), syn_projEE_ampa[5015], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5016: cell 62, seg 0 (0.5) [0.5 on Epop[62]] -> cell 56, seg 0 (0.5) [0.5 on Epop[56]], weight: 4.1363508E-4, delay 1.5
        h("Epop[56] syn_projEE_ampa[5016] = new ampa(0.5)")
        h("Epop[62] netConn_projEE_ampa[5016] = new NetCon(&v(0.5), syn_projEE_ampa[5016], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5017: cell 62, seg 0 (0.5) [0.5 on Epop[62]] -> cell 57, seg 0 (0.5) [0.5 on Epop[57]], weight: 4.1363508E-4, delay 1.5
        h("Epop[57] syn_projEE_ampa[5017] = new ampa(0.5)")
        h("Epop[62] netConn_projEE_ampa[5017] = new NetCon(&v(0.5), syn_projEE_ampa[5017], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5018: cell 62, seg 0 (0.5) [0.5 on Epop[62]] -> cell 58, seg 0 (0.5) [0.5 on Epop[58]], weight: 4.1363508E-4, delay 1.5
        h("Epop[58] syn_projEE_ampa[5018] = new ampa(0.5)")
        h("Epop[62] netConn_projEE_ampa[5018] = new NetCon(&v(0.5), syn_projEE_ampa[5018], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5019: cell 62, seg 0 (0.5) [0.5 on Epop[62]] -> cell 59, seg 0 (0.5) [0.5 on Epop[59]], weight: 4.1363508E-4, delay 1.5
        h("Epop[59] syn_projEE_ampa[5019] = new ampa(0.5)")
        h("Epop[62] netConn_projEE_ampa[5019] = new NetCon(&v(0.5), syn_projEE_ampa[5019], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5020: cell 62, seg 0 (0.5) [0.5 on Epop[62]] -> cell 60, seg 0 (0.5) [0.5 on Epop[60]], weight: 4.1363508E-4, delay 1.5
        h("Epop[60] syn_projEE_ampa[5020] = new ampa(0.5)")
        h("Epop[62] netConn_projEE_ampa[5020] = new NetCon(&v(0.5), syn_projEE_ampa[5020], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5021: cell 62, seg 0 (0.5) [0.5 on Epop[62]] -> cell 61, seg 0 (0.5) [0.5 on Epop[61]], weight: 4.1363508E-4, delay 1.5
        h("Epop[61] syn_projEE_ampa[5021] = new ampa(0.5)")
        h("Epop[62] netConn_projEE_ampa[5021] = new NetCon(&v(0.5), syn_projEE_ampa[5021], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5022: cell 62, seg 0 (0.5) [0.5 on Epop[62]] -> cell 62, seg 0 (0.5) [0.5 on Epop[62]], weight: 4.1363508E-4, delay 1.5
        h("Epop[62] syn_projEE_ampa[5022] = new ampa(0.5)")
        h("Epop[62] netConn_projEE_ampa[5022] = new NetCon(&v(0.5), syn_projEE_ampa[5022], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5023: cell 62, seg 0 (0.5) [0.5 on Epop[62]] -> cell 63, seg 0 (0.5) [0.5 on Epop[63]], weight: 4.1363508E-4, delay 1.5
        h("Epop[63] syn_projEE_ampa[5023] = new ampa(0.5)")
        h("Epop[62] netConn_projEE_ampa[5023] = new NetCon(&v(0.5), syn_projEE_ampa[5023], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5024: cell 62, seg 0 (0.5) [0.5 on Epop[62]] -> cell 64, seg 0 (0.5) [0.5 on Epop[64]], weight: 4.1363508E-4, delay 1.5
        h("Epop[64] syn_projEE_ampa[5024] = new ampa(0.5)")
        h("Epop[62] netConn_projEE_ampa[5024] = new NetCon(&v(0.5), syn_projEE_ampa[5024], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5025: cell 62, seg 0 (0.5) [0.5 on Epop[62]] -> cell 65, seg 0 (0.5) [0.5 on Epop[65]], weight: 4.1363508E-4, delay 1.5
        h("Epop[65] syn_projEE_ampa[5025] = new ampa(0.5)")
        h("Epop[62] netConn_projEE_ampa[5025] = new NetCon(&v(0.5), syn_projEE_ampa[5025], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5026: cell 62, seg 0 (0.5) [0.5 on Epop[62]] -> cell 66, seg 0 (0.5) [0.5 on Epop[66]], weight: 4.1363508E-4, delay 1.5
        h("Epop[66] syn_projEE_ampa[5026] = new ampa(0.5)")
        h("Epop[62] netConn_projEE_ampa[5026] = new NetCon(&v(0.5), syn_projEE_ampa[5026], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5027: cell 62, seg 0 (0.5) [0.5 on Epop[62]] -> cell 67, seg 0 (0.5) [0.5 on Epop[67]], weight: 4.1363508E-4, delay 1.5
        h("Epop[67] syn_projEE_ampa[5027] = new ampa(0.5)")
        h("Epop[62] netConn_projEE_ampa[5027] = new NetCon(&v(0.5), syn_projEE_ampa[5027], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5028: cell 62, seg 0 (0.5) [0.5 on Epop[62]] -> cell 68, seg 0 (0.5) [0.5 on Epop[68]], weight: 4.1363508E-4, delay 1.5
        h("Epop[68] syn_projEE_ampa[5028] = new ampa(0.5)")
        h("Epop[62] netConn_projEE_ampa[5028] = new NetCon(&v(0.5), syn_projEE_ampa[5028], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5029: cell 62, seg 0 (0.5) [0.5 on Epop[62]] -> cell 69, seg 0 (0.5) [0.5 on Epop[69]], weight: 4.1363508E-4, delay 1.5
        h("Epop[69] syn_projEE_ampa[5029] = new ampa(0.5)")
        h("Epop[62] netConn_projEE_ampa[5029] = new NetCon(&v(0.5), syn_projEE_ampa[5029], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5030: cell 62, seg 0 (0.5) [0.5 on Epop[62]] -> cell 70, seg 0 (0.5) [0.5 on Epop[70]], weight: 4.1363508E-4, delay 1.5
        h("Epop[70] syn_projEE_ampa[5030] = new ampa(0.5)")
        h("Epop[62] netConn_projEE_ampa[5030] = new NetCon(&v(0.5), syn_projEE_ampa[5030], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5031: cell 62, seg 0 (0.5) [0.5 on Epop[62]] -> cell 71, seg 0 (0.5) [0.5 on Epop[71]], weight: 4.1363508E-4, delay 1.5
        h("Epop[71] syn_projEE_ampa[5031] = new ampa(0.5)")
        h("Epop[62] netConn_projEE_ampa[5031] = new NetCon(&v(0.5), syn_projEE_ampa[5031], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5032: cell 62, seg 0 (0.5) [0.5 on Epop[62]] -> cell 72, seg 0 (0.5) [0.5 on Epop[72]], weight: 4.1363508E-4, delay 1.5
        h("Epop[72] syn_projEE_ampa[5032] = new ampa(0.5)")
        h("Epop[62] netConn_projEE_ampa[5032] = new NetCon(&v(0.5), syn_projEE_ampa[5032], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5033: cell 62, seg 0 (0.5) [0.5 on Epop[62]] -> cell 73, seg 0 (0.5) [0.5 on Epop[73]], weight: 4.1363508E-4, delay 1.5
        h("Epop[73] syn_projEE_ampa[5033] = new ampa(0.5)")
        h("Epop[62] netConn_projEE_ampa[5033] = new NetCon(&v(0.5), syn_projEE_ampa[5033], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5034: cell 62, seg 0 (0.5) [0.5 on Epop[62]] -> cell 74, seg 0 (0.5) [0.5 on Epop[74]], weight: 4.1363508E-4, delay 1.5
        h("Epop[74] syn_projEE_ampa[5034] = new ampa(0.5)")
        h("Epop[62] netConn_projEE_ampa[5034] = new NetCon(&v(0.5), syn_projEE_ampa[5034], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5035: cell 62, seg 0 (0.5) [0.5 on Epop[62]] -> cell 75, seg 0 (0.5) [0.5 on Epop[75]], weight: 4.1363508E-4, delay 1.5
        h("Epop[75] syn_projEE_ampa[5035] = new ampa(0.5)")
        h("Epop[62] netConn_projEE_ampa[5035] = new NetCon(&v(0.5), syn_projEE_ampa[5035], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5036: cell 62, seg 0 (0.5) [0.5 on Epop[62]] -> cell 76, seg 0 (0.5) [0.5 on Epop[76]], weight: 4.1363508E-4, delay 1.5
        h("Epop[76] syn_projEE_ampa[5036] = new ampa(0.5)")
        h("Epop[62] netConn_projEE_ampa[5036] = new NetCon(&v(0.5), syn_projEE_ampa[5036], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5037: cell 62, seg 0 (0.5) [0.5 on Epop[62]] -> cell 77, seg 0 (0.5) [0.5 on Epop[77]], weight: 4.1363508E-4, delay 1.5
        h("Epop[77] syn_projEE_ampa[5037] = new ampa(0.5)")
        h("Epop[62] netConn_projEE_ampa[5037] = new NetCon(&v(0.5), syn_projEE_ampa[5037], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5038: cell 62, seg 0 (0.5) [0.5 on Epop[62]] -> cell 78, seg 0 (0.5) [0.5 on Epop[78]], weight: 4.1363508E-4, delay 1.5
        h("Epop[78] syn_projEE_ampa[5038] = new ampa(0.5)")
        h("Epop[62] netConn_projEE_ampa[5038] = new NetCon(&v(0.5), syn_projEE_ampa[5038], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5039: cell 62, seg 0 (0.5) [0.5 on Epop[62]] -> cell 79, seg 0 (0.5) [0.5 on Epop[79]], weight: 4.1363508E-4, delay 1.5
        h("Epop[79] syn_projEE_ampa[5039] = new ampa(0.5)")
        h("Epop[62] netConn_projEE_ampa[5039] = new NetCon(&v(0.5), syn_projEE_ampa[5039], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5040: cell 63, seg 0 (0.5) [0.5 on Epop[63]] -> cell 0, seg 0 (0.5) [0.5 on Epop[0]], weight: 4.1363508E-4, delay 1.5
        h("Epop[0] syn_projEE_ampa[5040] = new ampa(0.5)")
        h("Epop[63] netConn_projEE_ampa[5040] = new NetCon(&v(0.5), syn_projEE_ampa[5040], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5041: cell 63, seg 0 (0.5) [0.5 on Epop[63]] -> cell 1, seg 0 (0.5) [0.5 on Epop[1]], weight: 4.1363508E-4, delay 1.5
        h("Epop[1] syn_projEE_ampa[5041] = new ampa(0.5)")
        h("Epop[63] netConn_projEE_ampa[5041] = new NetCon(&v(0.5), syn_projEE_ampa[5041], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5042: cell 63, seg 0 (0.5) [0.5 on Epop[63]] -> cell 2, seg 0 (0.5) [0.5 on Epop[2]], weight: 4.1363508E-4, delay 1.5
        h("Epop[2] syn_projEE_ampa[5042] = new ampa(0.5)")
        h("Epop[63] netConn_projEE_ampa[5042] = new NetCon(&v(0.5), syn_projEE_ampa[5042], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5043: cell 63, seg 0 (0.5) [0.5 on Epop[63]] -> cell 3, seg 0 (0.5) [0.5 on Epop[3]], weight: 4.1363508E-4, delay 1.5
        h("Epop[3] syn_projEE_ampa[5043] = new ampa(0.5)")
        h("Epop[63] netConn_projEE_ampa[5043] = new NetCon(&v(0.5), syn_projEE_ampa[5043], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5044: cell 63, seg 0 (0.5) [0.5 on Epop[63]] -> cell 4, seg 0 (0.5) [0.5 on Epop[4]], weight: 4.1363508E-4, delay 1.5
        h("Epop[4] syn_projEE_ampa[5044] = new ampa(0.5)")
        h("Epop[63] netConn_projEE_ampa[5044] = new NetCon(&v(0.5), syn_projEE_ampa[5044], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5045: cell 63, seg 0 (0.5) [0.5 on Epop[63]] -> cell 5, seg 0 (0.5) [0.5 on Epop[5]], weight: 4.1363508E-4, delay 1.5
        h("Epop[5] syn_projEE_ampa[5045] = new ampa(0.5)")
        h("Epop[63] netConn_projEE_ampa[5045] = new NetCon(&v(0.5), syn_projEE_ampa[5045], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5046: cell 63, seg 0 (0.5) [0.5 on Epop[63]] -> cell 6, seg 0 (0.5) [0.5 on Epop[6]], weight: 4.1363508E-4, delay 1.5
        h("Epop[6] syn_projEE_ampa[5046] = new ampa(0.5)")
        h("Epop[63] netConn_projEE_ampa[5046] = new NetCon(&v(0.5), syn_projEE_ampa[5046], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5047: cell 63, seg 0 (0.5) [0.5 on Epop[63]] -> cell 7, seg 0 (0.5) [0.5 on Epop[7]], weight: 4.1363508E-4, delay 1.5
        h("Epop[7] syn_projEE_ampa[5047] = new ampa(0.5)")
        h("Epop[63] netConn_projEE_ampa[5047] = new NetCon(&v(0.5), syn_projEE_ampa[5047], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5048: cell 63, seg 0 (0.5) [0.5 on Epop[63]] -> cell 8, seg 0 (0.5) [0.5 on Epop[8]], weight: 4.1363508E-4, delay 1.5
        h("Epop[8] syn_projEE_ampa[5048] = new ampa(0.5)")
        h("Epop[63] netConn_projEE_ampa[5048] = new NetCon(&v(0.5), syn_projEE_ampa[5048], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5049: cell 63, seg 0 (0.5) [0.5 on Epop[63]] -> cell 9, seg 0 (0.5) [0.5 on Epop[9]], weight: 4.1363508E-4, delay 1.5
        h("Epop[9] syn_projEE_ampa[5049] = new ampa(0.5)")
        h("Epop[63] netConn_projEE_ampa[5049] = new NetCon(&v(0.5), syn_projEE_ampa[5049], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5050: cell 63, seg 0 (0.5) [0.5 on Epop[63]] -> cell 10, seg 0 (0.5) [0.5 on Epop[10]], weight: 4.1363508E-4, delay 1.5
        h("Epop[10] syn_projEE_ampa[5050] = new ampa(0.5)")
        h("Epop[63] netConn_projEE_ampa[5050] = new NetCon(&v(0.5), syn_projEE_ampa[5050], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5051: cell 63, seg 0 (0.5) [0.5 on Epop[63]] -> cell 11, seg 0 (0.5) [0.5 on Epop[11]], weight: 4.1363508E-4, delay 1.5
        h("Epop[11] syn_projEE_ampa[5051] = new ampa(0.5)")
        h("Epop[63] netConn_projEE_ampa[5051] = new NetCon(&v(0.5), syn_projEE_ampa[5051], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5052: cell 63, seg 0 (0.5) [0.5 on Epop[63]] -> cell 12, seg 0 (0.5) [0.5 on Epop[12]], weight: 4.1363508E-4, delay 1.5
        h("Epop[12] syn_projEE_ampa[5052] = new ampa(0.5)")
        h("Epop[63] netConn_projEE_ampa[5052] = new NetCon(&v(0.5), syn_projEE_ampa[5052], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5053: cell 63, seg 0 (0.5) [0.5 on Epop[63]] -> cell 13, seg 0 (0.5) [0.5 on Epop[13]], weight: 4.1363508E-4, delay 1.5
        h("Epop[13] syn_projEE_ampa[5053] = new ampa(0.5)")
        h("Epop[63] netConn_projEE_ampa[5053] = new NetCon(&v(0.5), syn_projEE_ampa[5053], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5054: cell 63, seg 0 (0.5) [0.5 on Epop[63]] -> cell 14, seg 0 (0.5) [0.5 on Epop[14]], weight: 4.1363508E-4, delay 1.5
        h("Epop[14] syn_projEE_ampa[5054] = new ampa(0.5)")
        h("Epop[63] netConn_projEE_ampa[5054] = new NetCon(&v(0.5), syn_projEE_ampa[5054], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5055: cell 63, seg 0 (0.5) [0.5 on Epop[63]] -> cell 15, seg 0 (0.5) [0.5 on Epop[15]], weight: 4.1363508E-4, delay 1.5
        h("Epop[15] syn_projEE_ampa[5055] = new ampa(0.5)")
        h("Epop[63] netConn_projEE_ampa[5055] = new NetCon(&v(0.5), syn_projEE_ampa[5055], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5056: cell 63, seg 0 (0.5) [0.5 on Epop[63]] -> cell 16, seg 0 (0.5) [0.5 on Epop[16]], weight: 4.1363508E-4, delay 1.5
        h("Epop[16] syn_projEE_ampa[5056] = new ampa(0.5)")
        h("Epop[63] netConn_projEE_ampa[5056] = new NetCon(&v(0.5), syn_projEE_ampa[5056], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5057: cell 63, seg 0 (0.5) [0.5 on Epop[63]] -> cell 17, seg 0 (0.5) [0.5 on Epop[17]], weight: 4.1363508E-4, delay 1.5
        h("Epop[17] syn_projEE_ampa[5057] = new ampa(0.5)")
        h("Epop[63] netConn_projEE_ampa[5057] = new NetCon(&v(0.5), syn_projEE_ampa[5057], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5058: cell 63, seg 0 (0.5) [0.5 on Epop[63]] -> cell 18, seg 0 (0.5) [0.5 on Epop[18]], weight: 4.1363508E-4, delay 1.5
        h("Epop[18] syn_projEE_ampa[5058] = new ampa(0.5)")
        h("Epop[63] netConn_projEE_ampa[5058] = new NetCon(&v(0.5), syn_projEE_ampa[5058], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5059: cell 63, seg 0 (0.5) [0.5 on Epop[63]] -> cell 19, seg 0 (0.5) [0.5 on Epop[19]], weight: 4.1363508E-4, delay 1.5
        h("Epop[19] syn_projEE_ampa[5059] = new ampa(0.5)")
        h("Epop[63] netConn_projEE_ampa[5059] = new NetCon(&v(0.5), syn_projEE_ampa[5059], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5060: cell 63, seg 0 (0.5) [0.5 on Epop[63]] -> cell 20, seg 0 (0.5) [0.5 on Epop[20]], weight: 4.1363508E-4, delay 1.5
        h("Epop[20] syn_projEE_ampa[5060] = new ampa(0.5)")
        h("Epop[63] netConn_projEE_ampa[5060] = new NetCon(&v(0.5), syn_projEE_ampa[5060], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5061: cell 63, seg 0 (0.5) [0.5 on Epop[63]] -> cell 21, seg 0 (0.5) [0.5 on Epop[21]], weight: 4.1363508E-4, delay 1.5
        h("Epop[21] syn_projEE_ampa[5061] = new ampa(0.5)")
        h("Epop[63] netConn_projEE_ampa[5061] = new NetCon(&v(0.5), syn_projEE_ampa[5061], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5062: cell 63, seg 0 (0.5) [0.5 on Epop[63]] -> cell 22, seg 0 (0.5) [0.5 on Epop[22]], weight: 4.1363508E-4, delay 1.5
        h("Epop[22] syn_projEE_ampa[5062] = new ampa(0.5)")
        h("Epop[63] netConn_projEE_ampa[5062] = new NetCon(&v(0.5), syn_projEE_ampa[5062], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5063: cell 63, seg 0 (0.5) [0.5 on Epop[63]] -> cell 23, seg 0 (0.5) [0.5 on Epop[23]], weight: 4.1363508E-4, delay 1.5
        h("Epop[23] syn_projEE_ampa[5063] = new ampa(0.5)")
        h("Epop[63] netConn_projEE_ampa[5063] = new NetCon(&v(0.5), syn_projEE_ampa[5063], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5064: cell 63, seg 0 (0.5) [0.5 on Epop[63]] -> cell 24, seg 0 (0.5) [0.5 on Epop[24]], weight: 4.1363508E-4, delay 1.5
        h("Epop[24] syn_projEE_ampa[5064] = new ampa(0.5)")
        h("Epop[63] netConn_projEE_ampa[5064] = new NetCon(&v(0.5), syn_projEE_ampa[5064], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5065: cell 63, seg 0 (0.5) [0.5 on Epop[63]] -> cell 25, seg 0 (0.5) [0.5 on Epop[25]], weight: 4.1363508E-4, delay 1.5
        h("Epop[25] syn_projEE_ampa[5065] = new ampa(0.5)")
        h("Epop[63] netConn_projEE_ampa[5065] = new NetCon(&v(0.5), syn_projEE_ampa[5065], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5066: cell 63, seg 0 (0.5) [0.5 on Epop[63]] -> cell 26, seg 0 (0.5) [0.5 on Epop[26]], weight: 4.1363508E-4, delay 1.5
        h("Epop[26] syn_projEE_ampa[5066] = new ampa(0.5)")
        h("Epop[63] netConn_projEE_ampa[5066] = new NetCon(&v(0.5), syn_projEE_ampa[5066], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5067: cell 63, seg 0 (0.5) [0.5 on Epop[63]] -> cell 27, seg 0 (0.5) [0.5 on Epop[27]], weight: 4.1363508E-4, delay 1.5
        h("Epop[27] syn_projEE_ampa[5067] = new ampa(0.5)")
        h("Epop[63] netConn_projEE_ampa[5067] = new NetCon(&v(0.5), syn_projEE_ampa[5067], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5068: cell 63, seg 0 (0.5) [0.5 on Epop[63]] -> cell 28, seg 0 (0.5) [0.5 on Epop[28]], weight: 4.1363508E-4, delay 1.5
        h("Epop[28] syn_projEE_ampa[5068] = new ampa(0.5)")
        h("Epop[63] netConn_projEE_ampa[5068] = new NetCon(&v(0.5), syn_projEE_ampa[5068], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5069: cell 63, seg 0 (0.5) [0.5 on Epop[63]] -> cell 29, seg 0 (0.5) [0.5 on Epop[29]], weight: 4.1363508E-4, delay 1.5
        h("Epop[29] syn_projEE_ampa[5069] = new ampa(0.5)")
        h("Epop[63] netConn_projEE_ampa[5069] = new NetCon(&v(0.5), syn_projEE_ampa[5069], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5070: cell 63, seg 0 (0.5) [0.5 on Epop[63]] -> cell 30, seg 0 (0.5) [0.5 on Epop[30]], weight: 4.1363508E-4, delay 1.5
        h("Epop[30] syn_projEE_ampa[5070] = new ampa(0.5)")
        h("Epop[63] netConn_projEE_ampa[5070] = new NetCon(&v(0.5), syn_projEE_ampa[5070], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5071: cell 63, seg 0 (0.5) [0.5 on Epop[63]] -> cell 31, seg 0 (0.5) [0.5 on Epop[31]], weight: 4.1363508E-4, delay 1.5
        h("Epop[31] syn_projEE_ampa[5071] = new ampa(0.5)")
        h("Epop[63] netConn_projEE_ampa[5071] = new NetCon(&v(0.5), syn_projEE_ampa[5071], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5072: cell 63, seg 0 (0.5) [0.5 on Epop[63]] -> cell 32, seg 0 (0.5) [0.5 on Epop[32]], weight: 4.1363508E-4, delay 1.5
        h("Epop[32] syn_projEE_ampa[5072] = new ampa(0.5)")
        h("Epop[63] netConn_projEE_ampa[5072] = new NetCon(&v(0.5), syn_projEE_ampa[5072], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5073: cell 63, seg 0 (0.5) [0.5 on Epop[63]] -> cell 33, seg 0 (0.5) [0.5 on Epop[33]], weight: 4.1363508E-4, delay 1.5
        h("Epop[33] syn_projEE_ampa[5073] = new ampa(0.5)")
        h("Epop[63] netConn_projEE_ampa[5073] = new NetCon(&v(0.5), syn_projEE_ampa[5073], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5074: cell 63, seg 0 (0.5) [0.5 on Epop[63]] -> cell 34, seg 0 (0.5) [0.5 on Epop[34]], weight: 4.1363508E-4, delay 1.5
        h("Epop[34] syn_projEE_ampa[5074] = new ampa(0.5)")
        h("Epop[63] netConn_projEE_ampa[5074] = new NetCon(&v(0.5), syn_projEE_ampa[5074], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5075: cell 63, seg 0 (0.5) [0.5 on Epop[63]] -> cell 35, seg 0 (0.5) [0.5 on Epop[35]], weight: 4.1363508E-4, delay 1.5
        h("Epop[35] syn_projEE_ampa[5075] = new ampa(0.5)")
        h("Epop[63] netConn_projEE_ampa[5075] = new NetCon(&v(0.5), syn_projEE_ampa[5075], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5076: cell 63, seg 0 (0.5) [0.5 on Epop[63]] -> cell 36, seg 0 (0.5) [0.5 on Epop[36]], weight: 4.1363508E-4, delay 1.5
        h("Epop[36] syn_projEE_ampa[5076] = new ampa(0.5)")
        h("Epop[63] netConn_projEE_ampa[5076] = new NetCon(&v(0.5), syn_projEE_ampa[5076], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5077: cell 63, seg 0 (0.5) [0.5 on Epop[63]] -> cell 37, seg 0 (0.5) [0.5 on Epop[37]], weight: 4.1363508E-4, delay 1.5
        h("Epop[37] syn_projEE_ampa[5077] = new ampa(0.5)")
        h("Epop[63] netConn_projEE_ampa[5077] = new NetCon(&v(0.5), syn_projEE_ampa[5077], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5078: cell 63, seg 0 (0.5) [0.5 on Epop[63]] -> cell 38, seg 0 (0.5) [0.5 on Epop[38]], weight: 4.1363508E-4, delay 1.5
        h("Epop[38] syn_projEE_ampa[5078] = new ampa(0.5)")
        h("Epop[63] netConn_projEE_ampa[5078] = new NetCon(&v(0.5), syn_projEE_ampa[5078], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5079: cell 63, seg 0 (0.5) [0.5 on Epop[63]] -> cell 39, seg 0 (0.5) [0.5 on Epop[39]], weight: 4.1363508E-4, delay 1.5
        h("Epop[39] syn_projEE_ampa[5079] = new ampa(0.5)")
        h("Epop[63] netConn_projEE_ampa[5079] = new NetCon(&v(0.5), syn_projEE_ampa[5079], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5080: cell 63, seg 0 (0.5) [0.5 on Epop[63]] -> cell 40, seg 0 (0.5) [0.5 on Epop[40]], weight: 4.1363508E-4, delay 1.5
        h("Epop[40] syn_projEE_ampa[5080] = new ampa(0.5)")
        h("Epop[63] netConn_projEE_ampa[5080] = new NetCon(&v(0.5), syn_projEE_ampa[5080], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5081: cell 63, seg 0 (0.5) [0.5 on Epop[63]] -> cell 41, seg 0 (0.5) [0.5 on Epop[41]], weight: 4.1363508E-4, delay 1.5
        h("Epop[41] syn_projEE_ampa[5081] = new ampa(0.5)")
        h("Epop[63] netConn_projEE_ampa[5081] = new NetCon(&v(0.5), syn_projEE_ampa[5081], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5082: cell 63, seg 0 (0.5) [0.5 on Epop[63]] -> cell 42, seg 0 (0.5) [0.5 on Epop[42]], weight: 4.1363508E-4, delay 1.5
        h("Epop[42] syn_projEE_ampa[5082] = new ampa(0.5)")
        h("Epop[63] netConn_projEE_ampa[5082] = new NetCon(&v(0.5), syn_projEE_ampa[5082], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5083: cell 63, seg 0 (0.5) [0.5 on Epop[63]] -> cell 43, seg 0 (0.5) [0.5 on Epop[43]], weight: 4.1363508E-4, delay 1.5
        h("Epop[43] syn_projEE_ampa[5083] = new ampa(0.5)")
        h("Epop[63] netConn_projEE_ampa[5083] = new NetCon(&v(0.5), syn_projEE_ampa[5083], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5084: cell 63, seg 0 (0.5) [0.5 on Epop[63]] -> cell 44, seg 0 (0.5) [0.5 on Epop[44]], weight: 4.1363508E-4, delay 1.5
        h("Epop[44] syn_projEE_ampa[5084] = new ampa(0.5)")
        h("Epop[63] netConn_projEE_ampa[5084] = new NetCon(&v(0.5), syn_projEE_ampa[5084], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5085: cell 63, seg 0 (0.5) [0.5 on Epop[63]] -> cell 45, seg 0 (0.5) [0.5 on Epop[45]], weight: 4.1363508E-4, delay 1.5
        h("Epop[45] syn_projEE_ampa[5085] = new ampa(0.5)")
        h("Epop[63] netConn_projEE_ampa[5085] = new NetCon(&v(0.5), syn_projEE_ampa[5085], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5086: cell 63, seg 0 (0.5) [0.5 on Epop[63]] -> cell 46, seg 0 (0.5) [0.5 on Epop[46]], weight: 4.1363508E-4, delay 1.5
        h("Epop[46] syn_projEE_ampa[5086] = new ampa(0.5)")
        h("Epop[63] netConn_projEE_ampa[5086] = new NetCon(&v(0.5), syn_projEE_ampa[5086], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5087: cell 63, seg 0 (0.5) [0.5 on Epop[63]] -> cell 47, seg 0 (0.5) [0.5 on Epop[47]], weight: 4.1363508E-4, delay 1.5
        h("Epop[47] syn_projEE_ampa[5087] = new ampa(0.5)")
        h("Epop[63] netConn_projEE_ampa[5087] = new NetCon(&v(0.5), syn_projEE_ampa[5087], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5088: cell 63, seg 0 (0.5) [0.5 on Epop[63]] -> cell 48, seg 0 (0.5) [0.5 on Epop[48]], weight: 4.1363508E-4, delay 1.5
        h("Epop[48] syn_projEE_ampa[5088] = new ampa(0.5)")
        h("Epop[63] netConn_projEE_ampa[5088] = new NetCon(&v(0.5), syn_projEE_ampa[5088], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5089: cell 63, seg 0 (0.5) [0.5 on Epop[63]] -> cell 49, seg 0 (0.5) [0.5 on Epop[49]], weight: 4.1363508E-4, delay 1.5
        h("Epop[49] syn_projEE_ampa[5089] = new ampa(0.5)")
        h("Epop[63] netConn_projEE_ampa[5089] = new NetCon(&v(0.5), syn_projEE_ampa[5089], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5090: cell 63, seg 0 (0.5) [0.5 on Epop[63]] -> cell 50, seg 0 (0.5) [0.5 on Epop[50]], weight: 4.1363508E-4, delay 1.5
        h("Epop[50] syn_projEE_ampa[5090] = new ampa(0.5)")
        h("Epop[63] netConn_projEE_ampa[5090] = new NetCon(&v(0.5), syn_projEE_ampa[5090], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5091: cell 63, seg 0 (0.5) [0.5 on Epop[63]] -> cell 51, seg 0 (0.5) [0.5 on Epop[51]], weight: 4.1363508E-4, delay 1.5
        h("Epop[51] syn_projEE_ampa[5091] = new ampa(0.5)")
        h("Epop[63] netConn_projEE_ampa[5091] = new NetCon(&v(0.5), syn_projEE_ampa[5091], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5092: cell 63, seg 0 (0.5) [0.5 on Epop[63]] -> cell 52, seg 0 (0.5) [0.5 on Epop[52]], weight: 4.1363508E-4, delay 1.5
        h("Epop[52] syn_projEE_ampa[5092] = new ampa(0.5)")
        h("Epop[63] netConn_projEE_ampa[5092] = new NetCon(&v(0.5), syn_projEE_ampa[5092], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5093: cell 63, seg 0 (0.5) [0.5 on Epop[63]] -> cell 53, seg 0 (0.5) [0.5 on Epop[53]], weight: 4.1363508E-4, delay 1.5
        h("Epop[53] syn_projEE_ampa[5093] = new ampa(0.5)")
        h("Epop[63] netConn_projEE_ampa[5093] = new NetCon(&v(0.5), syn_projEE_ampa[5093], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5094: cell 63, seg 0 (0.5) [0.5 on Epop[63]] -> cell 54, seg 0 (0.5) [0.5 on Epop[54]], weight: 4.1363508E-4, delay 1.5
        h("Epop[54] syn_projEE_ampa[5094] = new ampa(0.5)")
        h("Epop[63] netConn_projEE_ampa[5094] = new NetCon(&v(0.5), syn_projEE_ampa[5094], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5095: cell 63, seg 0 (0.5) [0.5 on Epop[63]] -> cell 55, seg 0 (0.5) [0.5 on Epop[55]], weight: 4.1363508E-4, delay 1.5
        h("Epop[55] syn_projEE_ampa[5095] = new ampa(0.5)")
        h("Epop[63] netConn_projEE_ampa[5095] = new NetCon(&v(0.5), syn_projEE_ampa[5095], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5096: cell 63, seg 0 (0.5) [0.5 on Epop[63]] -> cell 56, seg 0 (0.5) [0.5 on Epop[56]], weight: 4.1363508E-4, delay 1.5
        h("Epop[56] syn_projEE_ampa[5096] = new ampa(0.5)")
        h("Epop[63] netConn_projEE_ampa[5096] = new NetCon(&v(0.5), syn_projEE_ampa[5096], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5097: cell 63, seg 0 (0.5) [0.5 on Epop[63]] -> cell 57, seg 0 (0.5) [0.5 on Epop[57]], weight: 4.1363508E-4, delay 1.5
        h("Epop[57] syn_projEE_ampa[5097] = new ampa(0.5)")
        h("Epop[63] netConn_projEE_ampa[5097] = new NetCon(&v(0.5), syn_projEE_ampa[5097], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5098: cell 63, seg 0 (0.5) [0.5 on Epop[63]] -> cell 58, seg 0 (0.5) [0.5 on Epop[58]], weight: 4.1363508E-4, delay 1.5
        h("Epop[58] syn_projEE_ampa[5098] = new ampa(0.5)")
        h("Epop[63] netConn_projEE_ampa[5098] = new NetCon(&v(0.5), syn_projEE_ampa[5098], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5099: cell 63, seg 0 (0.5) [0.5 on Epop[63]] -> cell 59, seg 0 (0.5) [0.5 on Epop[59]], weight: 4.1363508E-4, delay 1.5
        h("Epop[59] syn_projEE_ampa[5099] = new ampa(0.5)")
        h("Epop[63] netConn_projEE_ampa[5099] = new NetCon(&v(0.5), syn_projEE_ampa[5099], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5100: cell 63, seg 0 (0.5) [0.5 on Epop[63]] -> cell 60, seg 0 (0.5) [0.5 on Epop[60]], weight: 4.1363508E-4, delay 1.5
        h("Epop[60] syn_projEE_ampa[5100] = new ampa(0.5)")
        h("Epop[63] netConn_projEE_ampa[5100] = new NetCon(&v(0.5), syn_projEE_ampa[5100], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5101: cell 63, seg 0 (0.5) [0.5 on Epop[63]] -> cell 61, seg 0 (0.5) [0.5 on Epop[61]], weight: 4.1363508E-4, delay 1.5
        h("Epop[61] syn_projEE_ampa[5101] = new ampa(0.5)")
        h("Epop[63] netConn_projEE_ampa[5101] = new NetCon(&v(0.5), syn_projEE_ampa[5101], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5102: cell 63, seg 0 (0.5) [0.5 on Epop[63]] -> cell 62, seg 0 (0.5) [0.5 on Epop[62]], weight: 4.1363508E-4, delay 1.5
        h("Epop[62] syn_projEE_ampa[5102] = new ampa(0.5)")
        h("Epop[63] netConn_projEE_ampa[5102] = new NetCon(&v(0.5), syn_projEE_ampa[5102], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5103: cell 63, seg 0 (0.5) [0.5 on Epop[63]] -> cell 63, seg 0 (0.5) [0.5 on Epop[63]], weight: 4.1363508E-4, delay 1.5
        h("Epop[63] syn_projEE_ampa[5103] = new ampa(0.5)")
        h("Epop[63] netConn_projEE_ampa[5103] = new NetCon(&v(0.5), syn_projEE_ampa[5103], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5104: cell 63, seg 0 (0.5) [0.5 on Epop[63]] -> cell 64, seg 0 (0.5) [0.5 on Epop[64]], weight: 4.1363508E-4, delay 1.5
        h("Epop[64] syn_projEE_ampa[5104] = new ampa(0.5)")
        h("Epop[63] netConn_projEE_ampa[5104] = new NetCon(&v(0.5), syn_projEE_ampa[5104], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5105: cell 63, seg 0 (0.5) [0.5 on Epop[63]] -> cell 65, seg 0 (0.5) [0.5 on Epop[65]], weight: 4.1363508E-4, delay 1.5
        h("Epop[65] syn_projEE_ampa[5105] = new ampa(0.5)")
        h("Epop[63] netConn_projEE_ampa[5105] = new NetCon(&v(0.5), syn_projEE_ampa[5105], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5106: cell 63, seg 0 (0.5) [0.5 on Epop[63]] -> cell 66, seg 0 (0.5) [0.5 on Epop[66]], weight: 4.1363508E-4, delay 1.5
        h("Epop[66] syn_projEE_ampa[5106] = new ampa(0.5)")
        h("Epop[63] netConn_projEE_ampa[5106] = new NetCon(&v(0.5), syn_projEE_ampa[5106], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5107: cell 63, seg 0 (0.5) [0.5 on Epop[63]] -> cell 67, seg 0 (0.5) [0.5 on Epop[67]], weight: 4.1363508E-4, delay 1.5
        h("Epop[67] syn_projEE_ampa[5107] = new ampa(0.5)")
        h("Epop[63] netConn_projEE_ampa[5107] = new NetCon(&v(0.5), syn_projEE_ampa[5107], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5108: cell 63, seg 0 (0.5) [0.5 on Epop[63]] -> cell 68, seg 0 (0.5) [0.5 on Epop[68]], weight: 4.1363508E-4, delay 1.5
        h("Epop[68] syn_projEE_ampa[5108] = new ampa(0.5)")
        h("Epop[63] netConn_projEE_ampa[5108] = new NetCon(&v(0.5), syn_projEE_ampa[5108], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5109: cell 63, seg 0 (0.5) [0.5 on Epop[63]] -> cell 69, seg 0 (0.5) [0.5 on Epop[69]], weight: 4.1363508E-4, delay 1.5
        h("Epop[69] syn_projEE_ampa[5109] = new ampa(0.5)")
        h("Epop[63] netConn_projEE_ampa[5109] = new NetCon(&v(0.5), syn_projEE_ampa[5109], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5110: cell 63, seg 0 (0.5) [0.5 on Epop[63]] -> cell 70, seg 0 (0.5) [0.5 on Epop[70]], weight: 4.1363508E-4, delay 1.5
        h("Epop[70] syn_projEE_ampa[5110] = new ampa(0.5)")
        h("Epop[63] netConn_projEE_ampa[5110] = new NetCon(&v(0.5), syn_projEE_ampa[5110], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5111: cell 63, seg 0 (0.5) [0.5 on Epop[63]] -> cell 71, seg 0 (0.5) [0.5 on Epop[71]], weight: 4.1363508E-4, delay 1.5
        h("Epop[71] syn_projEE_ampa[5111] = new ampa(0.5)")
        h("Epop[63] netConn_projEE_ampa[5111] = new NetCon(&v(0.5), syn_projEE_ampa[5111], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5112: cell 63, seg 0 (0.5) [0.5 on Epop[63]] -> cell 72, seg 0 (0.5) [0.5 on Epop[72]], weight: 4.1363508E-4, delay 1.5
        h("Epop[72] syn_projEE_ampa[5112] = new ampa(0.5)")
        h("Epop[63] netConn_projEE_ampa[5112] = new NetCon(&v(0.5), syn_projEE_ampa[5112], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5113: cell 63, seg 0 (0.5) [0.5 on Epop[63]] -> cell 73, seg 0 (0.5) [0.5 on Epop[73]], weight: 4.1363508E-4, delay 1.5
        h("Epop[73] syn_projEE_ampa[5113] = new ampa(0.5)")
        h("Epop[63] netConn_projEE_ampa[5113] = new NetCon(&v(0.5), syn_projEE_ampa[5113], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5114: cell 63, seg 0 (0.5) [0.5 on Epop[63]] -> cell 74, seg 0 (0.5) [0.5 on Epop[74]], weight: 4.1363508E-4, delay 1.5
        h("Epop[74] syn_projEE_ampa[5114] = new ampa(0.5)")
        h("Epop[63] netConn_projEE_ampa[5114] = new NetCon(&v(0.5), syn_projEE_ampa[5114], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5115: cell 63, seg 0 (0.5) [0.5 on Epop[63]] -> cell 75, seg 0 (0.5) [0.5 on Epop[75]], weight: 4.1363508E-4, delay 1.5
        h("Epop[75] syn_projEE_ampa[5115] = new ampa(0.5)")
        h("Epop[63] netConn_projEE_ampa[5115] = new NetCon(&v(0.5), syn_projEE_ampa[5115], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5116: cell 63, seg 0 (0.5) [0.5 on Epop[63]] -> cell 76, seg 0 (0.5) [0.5 on Epop[76]], weight: 4.1363508E-4, delay 1.5
        h("Epop[76] syn_projEE_ampa[5116] = new ampa(0.5)")
        h("Epop[63] netConn_projEE_ampa[5116] = new NetCon(&v(0.5), syn_projEE_ampa[5116], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5117: cell 63, seg 0 (0.5) [0.5 on Epop[63]] -> cell 77, seg 0 (0.5) [0.5 on Epop[77]], weight: 4.1363508E-4, delay 1.5
        h("Epop[77] syn_projEE_ampa[5117] = new ampa(0.5)")
        h("Epop[63] netConn_projEE_ampa[5117] = new NetCon(&v(0.5), syn_projEE_ampa[5117], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5118: cell 63, seg 0 (0.5) [0.5 on Epop[63]] -> cell 78, seg 0 (0.5) [0.5 on Epop[78]], weight: 4.1363508E-4, delay 1.5
        h("Epop[78] syn_projEE_ampa[5118] = new ampa(0.5)")
        h("Epop[63] netConn_projEE_ampa[5118] = new NetCon(&v(0.5), syn_projEE_ampa[5118], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5119: cell 63, seg 0 (0.5) [0.5 on Epop[63]] -> cell 79, seg 0 (0.5) [0.5 on Epop[79]], weight: 4.1363508E-4, delay 1.5
        h("Epop[79] syn_projEE_ampa[5119] = new ampa(0.5)")
        h("Epop[63] netConn_projEE_ampa[5119] = new NetCon(&v(0.5), syn_projEE_ampa[5119], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5120: cell 64, seg 0 (0.5) [0.5 on Epop[64]] -> cell 0, seg 0 (0.5) [0.5 on Epop[0]], weight: 4.1363508E-4, delay 1.5
        h("Epop[0] syn_projEE_ampa[5120] = new ampa(0.5)")
        h("Epop[64] netConn_projEE_ampa[5120] = new NetCon(&v(0.5), syn_projEE_ampa[5120], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5121: cell 64, seg 0 (0.5) [0.5 on Epop[64]] -> cell 1, seg 0 (0.5) [0.5 on Epop[1]], weight: 4.1363508E-4, delay 1.5
        h("Epop[1] syn_projEE_ampa[5121] = new ampa(0.5)")
        h("Epop[64] netConn_projEE_ampa[5121] = new NetCon(&v(0.5), syn_projEE_ampa[5121], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5122: cell 64, seg 0 (0.5) [0.5 on Epop[64]] -> cell 2, seg 0 (0.5) [0.5 on Epop[2]], weight: 4.1363508E-4, delay 1.5
        h("Epop[2] syn_projEE_ampa[5122] = new ampa(0.5)")
        h("Epop[64] netConn_projEE_ampa[5122] = new NetCon(&v(0.5), syn_projEE_ampa[5122], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5123: cell 64, seg 0 (0.5) [0.5 on Epop[64]] -> cell 3, seg 0 (0.5) [0.5 on Epop[3]], weight: 4.1363508E-4, delay 1.5
        h("Epop[3] syn_projEE_ampa[5123] = new ampa(0.5)")
        h("Epop[64] netConn_projEE_ampa[5123] = new NetCon(&v(0.5), syn_projEE_ampa[5123], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5124: cell 64, seg 0 (0.5) [0.5 on Epop[64]] -> cell 4, seg 0 (0.5) [0.5 on Epop[4]], weight: 4.1363508E-4, delay 1.5
        h("Epop[4] syn_projEE_ampa[5124] = new ampa(0.5)")
        h("Epop[64] netConn_projEE_ampa[5124] = new NetCon(&v(0.5), syn_projEE_ampa[5124], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5125: cell 64, seg 0 (0.5) [0.5 on Epop[64]] -> cell 5, seg 0 (0.5) [0.5 on Epop[5]], weight: 4.1363508E-4, delay 1.5
        h("Epop[5] syn_projEE_ampa[5125] = new ampa(0.5)")
        h("Epop[64] netConn_projEE_ampa[5125] = new NetCon(&v(0.5), syn_projEE_ampa[5125], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5126: cell 64, seg 0 (0.5) [0.5 on Epop[64]] -> cell 6, seg 0 (0.5) [0.5 on Epop[6]], weight: 4.1363508E-4, delay 1.5
        h("Epop[6] syn_projEE_ampa[5126] = new ampa(0.5)")
        h("Epop[64] netConn_projEE_ampa[5126] = new NetCon(&v(0.5), syn_projEE_ampa[5126], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5127: cell 64, seg 0 (0.5) [0.5 on Epop[64]] -> cell 7, seg 0 (0.5) [0.5 on Epop[7]], weight: 4.1363508E-4, delay 1.5
        h("Epop[7] syn_projEE_ampa[5127] = new ampa(0.5)")
        h("Epop[64] netConn_projEE_ampa[5127] = new NetCon(&v(0.5), syn_projEE_ampa[5127], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5128: cell 64, seg 0 (0.5) [0.5 on Epop[64]] -> cell 8, seg 0 (0.5) [0.5 on Epop[8]], weight: 4.1363508E-4, delay 1.5
        h("Epop[8] syn_projEE_ampa[5128] = new ampa(0.5)")
        h("Epop[64] netConn_projEE_ampa[5128] = new NetCon(&v(0.5), syn_projEE_ampa[5128], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5129: cell 64, seg 0 (0.5) [0.5 on Epop[64]] -> cell 9, seg 0 (0.5) [0.5 on Epop[9]], weight: 4.1363508E-4, delay 1.5
        h("Epop[9] syn_projEE_ampa[5129] = new ampa(0.5)")
        h("Epop[64] netConn_projEE_ampa[5129] = new NetCon(&v(0.5), syn_projEE_ampa[5129], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5130: cell 64, seg 0 (0.5) [0.5 on Epop[64]] -> cell 10, seg 0 (0.5) [0.5 on Epop[10]], weight: 4.1363508E-4, delay 1.5
        h("Epop[10] syn_projEE_ampa[5130] = new ampa(0.5)")
        h("Epop[64] netConn_projEE_ampa[5130] = new NetCon(&v(0.5), syn_projEE_ampa[5130], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5131: cell 64, seg 0 (0.5) [0.5 on Epop[64]] -> cell 11, seg 0 (0.5) [0.5 on Epop[11]], weight: 4.1363508E-4, delay 1.5
        h("Epop[11] syn_projEE_ampa[5131] = new ampa(0.5)")
        h("Epop[64] netConn_projEE_ampa[5131] = new NetCon(&v(0.5), syn_projEE_ampa[5131], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5132: cell 64, seg 0 (0.5) [0.5 on Epop[64]] -> cell 12, seg 0 (0.5) [0.5 on Epop[12]], weight: 4.1363508E-4, delay 1.5
        h("Epop[12] syn_projEE_ampa[5132] = new ampa(0.5)")
        h("Epop[64] netConn_projEE_ampa[5132] = new NetCon(&v(0.5), syn_projEE_ampa[5132], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5133: cell 64, seg 0 (0.5) [0.5 on Epop[64]] -> cell 13, seg 0 (0.5) [0.5 on Epop[13]], weight: 4.1363508E-4, delay 1.5
        h("Epop[13] syn_projEE_ampa[5133] = new ampa(0.5)")
        h("Epop[64] netConn_projEE_ampa[5133] = new NetCon(&v(0.5), syn_projEE_ampa[5133], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5134: cell 64, seg 0 (0.5) [0.5 on Epop[64]] -> cell 14, seg 0 (0.5) [0.5 on Epop[14]], weight: 4.1363508E-4, delay 1.5
        h("Epop[14] syn_projEE_ampa[5134] = new ampa(0.5)")
        h("Epop[64] netConn_projEE_ampa[5134] = new NetCon(&v(0.5), syn_projEE_ampa[5134], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5135: cell 64, seg 0 (0.5) [0.5 on Epop[64]] -> cell 15, seg 0 (0.5) [0.5 on Epop[15]], weight: 4.1363508E-4, delay 1.5
        h("Epop[15] syn_projEE_ampa[5135] = new ampa(0.5)")
        h("Epop[64] netConn_projEE_ampa[5135] = new NetCon(&v(0.5), syn_projEE_ampa[5135], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5136: cell 64, seg 0 (0.5) [0.5 on Epop[64]] -> cell 16, seg 0 (0.5) [0.5 on Epop[16]], weight: 4.1363508E-4, delay 1.5
        h("Epop[16] syn_projEE_ampa[5136] = new ampa(0.5)")
        h("Epop[64] netConn_projEE_ampa[5136] = new NetCon(&v(0.5), syn_projEE_ampa[5136], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5137: cell 64, seg 0 (0.5) [0.5 on Epop[64]] -> cell 17, seg 0 (0.5) [0.5 on Epop[17]], weight: 4.1363508E-4, delay 1.5
        h("Epop[17] syn_projEE_ampa[5137] = new ampa(0.5)")
        h("Epop[64] netConn_projEE_ampa[5137] = new NetCon(&v(0.5), syn_projEE_ampa[5137], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5138: cell 64, seg 0 (0.5) [0.5 on Epop[64]] -> cell 18, seg 0 (0.5) [0.5 on Epop[18]], weight: 4.1363508E-4, delay 1.5
        h("Epop[18] syn_projEE_ampa[5138] = new ampa(0.5)")
        h("Epop[64] netConn_projEE_ampa[5138] = new NetCon(&v(0.5), syn_projEE_ampa[5138], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5139: cell 64, seg 0 (0.5) [0.5 on Epop[64]] -> cell 19, seg 0 (0.5) [0.5 on Epop[19]], weight: 4.1363508E-4, delay 1.5
        h("Epop[19] syn_projEE_ampa[5139] = new ampa(0.5)")
        h("Epop[64] netConn_projEE_ampa[5139] = new NetCon(&v(0.5), syn_projEE_ampa[5139], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5140: cell 64, seg 0 (0.5) [0.5 on Epop[64]] -> cell 20, seg 0 (0.5) [0.5 on Epop[20]], weight: 4.1363508E-4, delay 1.5
        h("Epop[20] syn_projEE_ampa[5140] = new ampa(0.5)")
        h("Epop[64] netConn_projEE_ampa[5140] = new NetCon(&v(0.5), syn_projEE_ampa[5140], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5141: cell 64, seg 0 (0.5) [0.5 on Epop[64]] -> cell 21, seg 0 (0.5) [0.5 on Epop[21]], weight: 4.1363508E-4, delay 1.5
        h("Epop[21] syn_projEE_ampa[5141] = new ampa(0.5)")
        h("Epop[64] netConn_projEE_ampa[5141] = new NetCon(&v(0.5), syn_projEE_ampa[5141], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5142: cell 64, seg 0 (0.5) [0.5 on Epop[64]] -> cell 22, seg 0 (0.5) [0.5 on Epop[22]], weight: 4.1363508E-4, delay 1.5
        h("Epop[22] syn_projEE_ampa[5142] = new ampa(0.5)")
        h("Epop[64] netConn_projEE_ampa[5142] = new NetCon(&v(0.5), syn_projEE_ampa[5142], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5143: cell 64, seg 0 (0.5) [0.5 on Epop[64]] -> cell 23, seg 0 (0.5) [0.5 on Epop[23]], weight: 4.1363508E-4, delay 1.5
        h("Epop[23] syn_projEE_ampa[5143] = new ampa(0.5)")
        h("Epop[64] netConn_projEE_ampa[5143] = new NetCon(&v(0.5), syn_projEE_ampa[5143], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5144: cell 64, seg 0 (0.5) [0.5 on Epop[64]] -> cell 24, seg 0 (0.5) [0.5 on Epop[24]], weight: 4.1363508E-4, delay 1.5
        h("Epop[24] syn_projEE_ampa[5144] = new ampa(0.5)")
        h("Epop[64] netConn_projEE_ampa[5144] = new NetCon(&v(0.5), syn_projEE_ampa[5144], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5145: cell 64, seg 0 (0.5) [0.5 on Epop[64]] -> cell 25, seg 0 (0.5) [0.5 on Epop[25]], weight: 4.1363508E-4, delay 1.5
        h("Epop[25] syn_projEE_ampa[5145] = new ampa(0.5)")
        h("Epop[64] netConn_projEE_ampa[5145] = new NetCon(&v(0.5), syn_projEE_ampa[5145], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5146: cell 64, seg 0 (0.5) [0.5 on Epop[64]] -> cell 26, seg 0 (0.5) [0.5 on Epop[26]], weight: 4.1363508E-4, delay 1.5
        h("Epop[26] syn_projEE_ampa[5146] = new ampa(0.5)")
        h("Epop[64] netConn_projEE_ampa[5146] = new NetCon(&v(0.5), syn_projEE_ampa[5146], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5147: cell 64, seg 0 (0.5) [0.5 on Epop[64]] -> cell 27, seg 0 (0.5) [0.5 on Epop[27]], weight: 4.1363508E-4, delay 1.5
        h("Epop[27] syn_projEE_ampa[5147] = new ampa(0.5)")
        h("Epop[64] netConn_projEE_ampa[5147] = new NetCon(&v(0.5), syn_projEE_ampa[5147], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5148: cell 64, seg 0 (0.5) [0.5 on Epop[64]] -> cell 28, seg 0 (0.5) [0.5 on Epop[28]], weight: 4.1363508E-4, delay 1.5
        h("Epop[28] syn_projEE_ampa[5148] = new ampa(0.5)")
        h("Epop[64] netConn_projEE_ampa[5148] = new NetCon(&v(0.5), syn_projEE_ampa[5148], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5149: cell 64, seg 0 (0.5) [0.5 on Epop[64]] -> cell 29, seg 0 (0.5) [0.5 on Epop[29]], weight: 4.1363508E-4, delay 1.5
        h("Epop[29] syn_projEE_ampa[5149] = new ampa(0.5)")
        h("Epop[64] netConn_projEE_ampa[5149] = new NetCon(&v(0.5), syn_projEE_ampa[5149], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5150: cell 64, seg 0 (0.5) [0.5 on Epop[64]] -> cell 30, seg 0 (0.5) [0.5 on Epop[30]], weight: 4.1363508E-4, delay 1.5
        h("Epop[30] syn_projEE_ampa[5150] = new ampa(0.5)")
        h("Epop[64] netConn_projEE_ampa[5150] = new NetCon(&v(0.5), syn_projEE_ampa[5150], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5151: cell 64, seg 0 (0.5) [0.5 on Epop[64]] -> cell 31, seg 0 (0.5) [0.5 on Epop[31]], weight: 4.1363508E-4, delay 1.5
        h("Epop[31] syn_projEE_ampa[5151] = new ampa(0.5)")
        h("Epop[64] netConn_projEE_ampa[5151] = new NetCon(&v(0.5), syn_projEE_ampa[5151], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5152: cell 64, seg 0 (0.5) [0.5 on Epop[64]] -> cell 32, seg 0 (0.5) [0.5 on Epop[32]], weight: 4.1363508E-4, delay 1.5
        h("Epop[32] syn_projEE_ampa[5152] = new ampa(0.5)")
        h("Epop[64] netConn_projEE_ampa[5152] = new NetCon(&v(0.5), syn_projEE_ampa[5152], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5153: cell 64, seg 0 (0.5) [0.5 on Epop[64]] -> cell 33, seg 0 (0.5) [0.5 on Epop[33]], weight: 4.1363508E-4, delay 1.5
        h("Epop[33] syn_projEE_ampa[5153] = new ampa(0.5)")
        h("Epop[64] netConn_projEE_ampa[5153] = new NetCon(&v(0.5), syn_projEE_ampa[5153], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5154: cell 64, seg 0 (0.5) [0.5 on Epop[64]] -> cell 34, seg 0 (0.5) [0.5 on Epop[34]], weight: 4.1363508E-4, delay 1.5
        h("Epop[34] syn_projEE_ampa[5154] = new ampa(0.5)")
        h("Epop[64] netConn_projEE_ampa[5154] = new NetCon(&v(0.5), syn_projEE_ampa[5154], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5155: cell 64, seg 0 (0.5) [0.5 on Epop[64]] -> cell 35, seg 0 (0.5) [0.5 on Epop[35]], weight: 4.1363508E-4, delay 1.5
        h("Epop[35] syn_projEE_ampa[5155] = new ampa(0.5)")
        h("Epop[64] netConn_projEE_ampa[5155] = new NetCon(&v(0.5), syn_projEE_ampa[5155], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5156: cell 64, seg 0 (0.5) [0.5 on Epop[64]] -> cell 36, seg 0 (0.5) [0.5 on Epop[36]], weight: 4.1363508E-4, delay 1.5
        h("Epop[36] syn_projEE_ampa[5156] = new ampa(0.5)")
        h("Epop[64] netConn_projEE_ampa[5156] = new NetCon(&v(0.5), syn_projEE_ampa[5156], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5157: cell 64, seg 0 (0.5) [0.5 on Epop[64]] -> cell 37, seg 0 (0.5) [0.5 on Epop[37]], weight: 4.1363508E-4, delay 1.5
        h("Epop[37] syn_projEE_ampa[5157] = new ampa(0.5)")
        h("Epop[64] netConn_projEE_ampa[5157] = new NetCon(&v(0.5), syn_projEE_ampa[5157], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5158: cell 64, seg 0 (0.5) [0.5 on Epop[64]] -> cell 38, seg 0 (0.5) [0.5 on Epop[38]], weight: 4.1363508E-4, delay 1.5
        h("Epop[38] syn_projEE_ampa[5158] = new ampa(0.5)")
        h("Epop[64] netConn_projEE_ampa[5158] = new NetCon(&v(0.5), syn_projEE_ampa[5158], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5159: cell 64, seg 0 (0.5) [0.5 on Epop[64]] -> cell 39, seg 0 (0.5) [0.5 on Epop[39]], weight: 4.1363508E-4, delay 1.5
        h("Epop[39] syn_projEE_ampa[5159] = new ampa(0.5)")
        h("Epop[64] netConn_projEE_ampa[5159] = new NetCon(&v(0.5), syn_projEE_ampa[5159], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5160: cell 64, seg 0 (0.5) [0.5 on Epop[64]] -> cell 40, seg 0 (0.5) [0.5 on Epop[40]], weight: 4.1363508E-4, delay 1.5
        h("Epop[40] syn_projEE_ampa[5160] = new ampa(0.5)")
        h("Epop[64] netConn_projEE_ampa[5160] = new NetCon(&v(0.5), syn_projEE_ampa[5160], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5161: cell 64, seg 0 (0.5) [0.5 on Epop[64]] -> cell 41, seg 0 (0.5) [0.5 on Epop[41]], weight: 4.1363508E-4, delay 1.5
        h("Epop[41] syn_projEE_ampa[5161] = new ampa(0.5)")
        h("Epop[64] netConn_projEE_ampa[5161] = new NetCon(&v(0.5), syn_projEE_ampa[5161], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5162: cell 64, seg 0 (0.5) [0.5 on Epop[64]] -> cell 42, seg 0 (0.5) [0.5 on Epop[42]], weight: 4.1363508E-4, delay 1.5
        h("Epop[42] syn_projEE_ampa[5162] = new ampa(0.5)")
        h("Epop[64] netConn_projEE_ampa[5162] = new NetCon(&v(0.5), syn_projEE_ampa[5162], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5163: cell 64, seg 0 (0.5) [0.5 on Epop[64]] -> cell 43, seg 0 (0.5) [0.5 on Epop[43]], weight: 4.1363508E-4, delay 1.5
        h("Epop[43] syn_projEE_ampa[5163] = new ampa(0.5)")
        h("Epop[64] netConn_projEE_ampa[5163] = new NetCon(&v(0.5), syn_projEE_ampa[5163], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5164: cell 64, seg 0 (0.5) [0.5 on Epop[64]] -> cell 44, seg 0 (0.5) [0.5 on Epop[44]], weight: 4.1363508E-4, delay 1.5
        h("Epop[44] syn_projEE_ampa[5164] = new ampa(0.5)")
        h("Epop[64] netConn_projEE_ampa[5164] = new NetCon(&v(0.5), syn_projEE_ampa[5164], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5165: cell 64, seg 0 (0.5) [0.5 on Epop[64]] -> cell 45, seg 0 (0.5) [0.5 on Epop[45]], weight: 4.1363508E-4, delay 1.5
        h("Epop[45] syn_projEE_ampa[5165] = new ampa(0.5)")
        h("Epop[64] netConn_projEE_ampa[5165] = new NetCon(&v(0.5), syn_projEE_ampa[5165], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5166: cell 64, seg 0 (0.5) [0.5 on Epop[64]] -> cell 46, seg 0 (0.5) [0.5 on Epop[46]], weight: 4.1363508E-4, delay 1.5
        h("Epop[46] syn_projEE_ampa[5166] = new ampa(0.5)")
        h("Epop[64] netConn_projEE_ampa[5166] = new NetCon(&v(0.5), syn_projEE_ampa[5166], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5167: cell 64, seg 0 (0.5) [0.5 on Epop[64]] -> cell 47, seg 0 (0.5) [0.5 on Epop[47]], weight: 4.1363508E-4, delay 1.5
        h("Epop[47] syn_projEE_ampa[5167] = new ampa(0.5)")
        h("Epop[64] netConn_projEE_ampa[5167] = new NetCon(&v(0.5), syn_projEE_ampa[5167], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5168: cell 64, seg 0 (0.5) [0.5 on Epop[64]] -> cell 48, seg 0 (0.5) [0.5 on Epop[48]], weight: 4.1363508E-4, delay 1.5
        h("Epop[48] syn_projEE_ampa[5168] = new ampa(0.5)")
        h("Epop[64] netConn_projEE_ampa[5168] = new NetCon(&v(0.5), syn_projEE_ampa[5168], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5169: cell 64, seg 0 (0.5) [0.5 on Epop[64]] -> cell 49, seg 0 (0.5) [0.5 on Epop[49]], weight: 4.1363508E-4, delay 1.5
        h("Epop[49] syn_projEE_ampa[5169] = new ampa(0.5)")
        h("Epop[64] netConn_projEE_ampa[5169] = new NetCon(&v(0.5), syn_projEE_ampa[5169], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5170: cell 64, seg 0 (0.5) [0.5 on Epop[64]] -> cell 50, seg 0 (0.5) [0.5 on Epop[50]], weight: 4.1363508E-4, delay 1.5
        h("Epop[50] syn_projEE_ampa[5170] = new ampa(0.5)")
        h("Epop[64] netConn_projEE_ampa[5170] = new NetCon(&v(0.5), syn_projEE_ampa[5170], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5171: cell 64, seg 0 (0.5) [0.5 on Epop[64]] -> cell 51, seg 0 (0.5) [0.5 on Epop[51]], weight: 4.1363508E-4, delay 1.5
        h("Epop[51] syn_projEE_ampa[5171] = new ampa(0.5)")
        h("Epop[64] netConn_projEE_ampa[5171] = new NetCon(&v(0.5), syn_projEE_ampa[5171], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5172: cell 64, seg 0 (0.5) [0.5 on Epop[64]] -> cell 52, seg 0 (0.5) [0.5 on Epop[52]], weight: 4.1363508E-4, delay 1.5
        h("Epop[52] syn_projEE_ampa[5172] = new ampa(0.5)")
        h("Epop[64] netConn_projEE_ampa[5172] = new NetCon(&v(0.5), syn_projEE_ampa[5172], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5173: cell 64, seg 0 (0.5) [0.5 on Epop[64]] -> cell 53, seg 0 (0.5) [0.5 on Epop[53]], weight: 4.1363508E-4, delay 1.5
        h("Epop[53] syn_projEE_ampa[5173] = new ampa(0.5)")
        h("Epop[64] netConn_projEE_ampa[5173] = new NetCon(&v(0.5), syn_projEE_ampa[5173], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5174: cell 64, seg 0 (0.5) [0.5 on Epop[64]] -> cell 54, seg 0 (0.5) [0.5 on Epop[54]], weight: 4.1363508E-4, delay 1.5
        h("Epop[54] syn_projEE_ampa[5174] = new ampa(0.5)")
        h("Epop[64] netConn_projEE_ampa[5174] = new NetCon(&v(0.5), syn_projEE_ampa[5174], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5175: cell 64, seg 0 (0.5) [0.5 on Epop[64]] -> cell 55, seg 0 (0.5) [0.5 on Epop[55]], weight: 4.1363508E-4, delay 1.5
        h("Epop[55] syn_projEE_ampa[5175] = new ampa(0.5)")
        h("Epop[64] netConn_projEE_ampa[5175] = new NetCon(&v(0.5), syn_projEE_ampa[5175], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5176: cell 64, seg 0 (0.5) [0.5 on Epop[64]] -> cell 56, seg 0 (0.5) [0.5 on Epop[56]], weight: 4.1363508E-4, delay 1.5
        h("Epop[56] syn_projEE_ampa[5176] = new ampa(0.5)")
        h("Epop[64] netConn_projEE_ampa[5176] = new NetCon(&v(0.5), syn_projEE_ampa[5176], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5177: cell 64, seg 0 (0.5) [0.5 on Epop[64]] -> cell 57, seg 0 (0.5) [0.5 on Epop[57]], weight: 4.1363508E-4, delay 1.5
        h("Epop[57] syn_projEE_ampa[5177] = new ampa(0.5)")
        h("Epop[64] netConn_projEE_ampa[5177] = new NetCon(&v(0.5), syn_projEE_ampa[5177], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5178: cell 64, seg 0 (0.5) [0.5 on Epop[64]] -> cell 58, seg 0 (0.5) [0.5 on Epop[58]], weight: 4.1363508E-4, delay 1.5
        h("Epop[58] syn_projEE_ampa[5178] = new ampa(0.5)")
        h("Epop[64] netConn_projEE_ampa[5178] = new NetCon(&v(0.5), syn_projEE_ampa[5178], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5179: cell 64, seg 0 (0.5) [0.5 on Epop[64]] -> cell 59, seg 0 (0.5) [0.5 on Epop[59]], weight: 4.1363508E-4, delay 1.5
        h("Epop[59] syn_projEE_ampa[5179] = new ampa(0.5)")
        h("Epop[64] netConn_projEE_ampa[5179] = new NetCon(&v(0.5), syn_projEE_ampa[5179], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5180: cell 64, seg 0 (0.5) [0.5 on Epop[64]] -> cell 60, seg 0 (0.5) [0.5 on Epop[60]], weight: 4.1363508E-4, delay 1.5
        h("Epop[60] syn_projEE_ampa[5180] = new ampa(0.5)")
        h("Epop[64] netConn_projEE_ampa[5180] = new NetCon(&v(0.5), syn_projEE_ampa[5180], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5181: cell 64, seg 0 (0.5) [0.5 on Epop[64]] -> cell 61, seg 0 (0.5) [0.5 on Epop[61]], weight: 4.1363508E-4, delay 1.5
        h("Epop[61] syn_projEE_ampa[5181] = new ampa(0.5)")
        h("Epop[64] netConn_projEE_ampa[5181] = new NetCon(&v(0.5), syn_projEE_ampa[5181], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5182: cell 64, seg 0 (0.5) [0.5 on Epop[64]] -> cell 62, seg 0 (0.5) [0.5 on Epop[62]], weight: 4.1363508E-4, delay 1.5
        h("Epop[62] syn_projEE_ampa[5182] = new ampa(0.5)")
        h("Epop[64] netConn_projEE_ampa[5182] = new NetCon(&v(0.5), syn_projEE_ampa[5182], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5183: cell 64, seg 0 (0.5) [0.5 on Epop[64]] -> cell 63, seg 0 (0.5) [0.5 on Epop[63]], weight: 4.1363508E-4, delay 1.5
        h("Epop[63] syn_projEE_ampa[5183] = new ampa(0.5)")
        h("Epop[64] netConn_projEE_ampa[5183] = new NetCon(&v(0.5), syn_projEE_ampa[5183], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5184: cell 64, seg 0 (0.5) [0.5 on Epop[64]] -> cell 64, seg 0 (0.5) [0.5 on Epop[64]], weight: 4.1363508E-4, delay 1.5
        h("Epop[64] syn_projEE_ampa[5184] = new ampa(0.5)")
        h("Epop[64] netConn_projEE_ampa[5184] = new NetCon(&v(0.5), syn_projEE_ampa[5184], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5185: cell 64, seg 0 (0.5) [0.5 on Epop[64]] -> cell 65, seg 0 (0.5) [0.5 on Epop[65]], weight: 4.1363508E-4, delay 1.5
        h("Epop[65] syn_projEE_ampa[5185] = new ampa(0.5)")
        h("Epop[64] netConn_projEE_ampa[5185] = new NetCon(&v(0.5), syn_projEE_ampa[5185], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5186: cell 64, seg 0 (0.5) [0.5 on Epop[64]] -> cell 66, seg 0 (0.5) [0.5 on Epop[66]], weight: 4.1363508E-4, delay 1.5
        h("Epop[66] syn_projEE_ampa[5186] = new ampa(0.5)")
        h("Epop[64] netConn_projEE_ampa[5186] = new NetCon(&v(0.5), syn_projEE_ampa[5186], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5187: cell 64, seg 0 (0.5) [0.5 on Epop[64]] -> cell 67, seg 0 (0.5) [0.5 on Epop[67]], weight: 4.1363508E-4, delay 1.5
        h("Epop[67] syn_projEE_ampa[5187] = new ampa(0.5)")
        h("Epop[64] netConn_projEE_ampa[5187] = new NetCon(&v(0.5), syn_projEE_ampa[5187], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5188: cell 64, seg 0 (0.5) [0.5 on Epop[64]] -> cell 68, seg 0 (0.5) [0.5 on Epop[68]], weight: 4.1363508E-4, delay 1.5
        h("Epop[68] syn_projEE_ampa[5188] = new ampa(0.5)")
        h("Epop[64] netConn_projEE_ampa[5188] = new NetCon(&v(0.5), syn_projEE_ampa[5188], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5189: cell 64, seg 0 (0.5) [0.5 on Epop[64]] -> cell 69, seg 0 (0.5) [0.5 on Epop[69]], weight: 4.1363508E-4, delay 1.5
        h("Epop[69] syn_projEE_ampa[5189] = new ampa(0.5)")
        h("Epop[64] netConn_projEE_ampa[5189] = new NetCon(&v(0.5), syn_projEE_ampa[5189], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5190: cell 64, seg 0 (0.5) [0.5 on Epop[64]] -> cell 70, seg 0 (0.5) [0.5 on Epop[70]], weight: 4.1363508E-4, delay 1.5
        h("Epop[70] syn_projEE_ampa[5190] = new ampa(0.5)")
        h("Epop[64] netConn_projEE_ampa[5190] = new NetCon(&v(0.5), syn_projEE_ampa[5190], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5191: cell 64, seg 0 (0.5) [0.5 on Epop[64]] -> cell 71, seg 0 (0.5) [0.5 on Epop[71]], weight: 4.1363508E-4, delay 1.5
        h("Epop[71] syn_projEE_ampa[5191] = new ampa(0.5)")
        h("Epop[64] netConn_projEE_ampa[5191] = new NetCon(&v(0.5), syn_projEE_ampa[5191], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5192: cell 64, seg 0 (0.5) [0.5 on Epop[64]] -> cell 72, seg 0 (0.5) [0.5 on Epop[72]], weight: 4.1363508E-4, delay 1.5
        h("Epop[72] syn_projEE_ampa[5192] = new ampa(0.5)")
        h("Epop[64] netConn_projEE_ampa[5192] = new NetCon(&v(0.5), syn_projEE_ampa[5192], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5193: cell 64, seg 0 (0.5) [0.5 on Epop[64]] -> cell 73, seg 0 (0.5) [0.5 on Epop[73]], weight: 4.1363508E-4, delay 1.5
        h("Epop[73] syn_projEE_ampa[5193] = new ampa(0.5)")
        h("Epop[64] netConn_projEE_ampa[5193] = new NetCon(&v(0.5), syn_projEE_ampa[5193], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5194: cell 64, seg 0 (0.5) [0.5 on Epop[64]] -> cell 74, seg 0 (0.5) [0.5 on Epop[74]], weight: 4.1363508E-4, delay 1.5
        h("Epop[74] syn_projEE_ampa[5194] = new ampa(0.5)")
        h("Epop[64] netConn_projEE_ampa[5194] = new NetCon(&v(0.5), syn_projEE_ampa[5194], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5195: cell 64, seg 0 (0.5) [0.5 on Epop[64]] -> cell 75, seg 0 (0.5) [0.5 on Epop[75]], weight: 4.1363508E-4, delay 1.5
        h("Epop[75] syn_projEE_ampa[5195] = new ampa(0.5)")
        h("Epop[64] netConn_projEE_ampa[5195] = new NetCon(&v(0.5), syn_projEE_ampa[5195], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5196: cell 64, seg 0 (0.5) [0.5 on Epop[64]] -> cell 76, seg 0 (0.5) [0.5 on Epop[76]], weight: 4.1363508E-4, delay 1.5
        h("Epop[76] syn_projEE_ampa[5196] = new ampa(0.5)")
        h("Epop[64] netConn_projEE_ampa[5196] = new NetCon(&v(0.5), syn_projEE_ampa[5196], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5197: cell 64, seg 0 (0.5) [0.5 on Epop[64]] -> cell 77, seg 0 (0.5) [0.5 on Epop[77]], weight: 4.1363508E-4, delay 1.5
        h("Epop[77] syn_projEE_ampa[5197] = new ampa(0.5)")
        h("Epop[64] netConn_projEE_ampa[5197] = new NetCon(&v(0.5), syn_projEE_ampa[5197], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5198: cell 64, seg 0 (0.5) [0.5 on Epop[64]] -> cell 78, seg 0 (0.5) [0.5 on Epop[78]], weight: 4.1363508E-4, delay 1.5
        h("Epop[78] syn_projEE_ampa[5198] = new ampa(0.5)")
        h("Epop[64] netConn_projEE_ampa[5198] = new NetCon(&v(0.5), syn_projEE_ampa[5198], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5199: cell 64, seg 0 (0.5) [0.5 on Epop[64]] -> cell 79, seg 0 (0.5) [0.5 on Epop[79]], weight: 4.1363508E-4, delay 1.5
        h("Epop[79] syn_projEE_ampa[5199] = new ampa(0.5)")
        h("Epop[64] netConn_projEE_ampa[5199] = new NetCon(&v(0.5), syn_projEE_ampa[5199], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5200: cell 65, seg 0 (0.5) [0.5 on Epop[65]] -> cell 0, seg 0 (0.5) [0.5 on Epop[0]], weight: 4.1363508E-4, delay 1.5
        h("Epop[0] syn_projEE_ampa[5200] = new ampa(0.5)")
        h("Epop[65] netConn_projEE_ampa[5200] = new NetCon(&v(0.5), syn_projEE_ampa[5200], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5201: cell 65, seg 0 (0.5) [0.5 on Epop[65]] -> cell 1, seg 0 (0.5) [0.5 on Epop[1]], weight: 4.1363508E-4, delay 1.5
        h("Epop[1] syn_projEE_ampa[5201] = new ampa(0.5)")
        h("Epop[65] netConn_projEE_ampa[5201] = new NetCon(&v(0.5), syn_projEE_ampa[5201], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5202: cell 65, seg 0 (0.5) [0.5 on Epop[65]] -> cell 2, seg 0 (0.5) [0.5 on Epop[2]], weight: 4.1363508E-4, delay 1.5
        h("Epop[2] syn_projEE_ampa[5202] = new ampa(0.5)")
        h("Epop[65] netConn_projEE_ampa[5202] = new NetCon(&v(0.5), syn_projEE_ampa[5202], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5203: cell 65, seg 0 (0.5) [0.5 on Epop[65]] -> cell 3, seg 0 (0.5) [0.5 on Epop[3]], weight: 4.1363508E-4, delay 1.5
        h("Epop[3] syn_projEE_ampa[5203] = new ampa(0.5)")
        h("Epop[65] netConn_projEE_ampa[5203] = new NetCon(&v(0.5), syn_projEE_ampa[5203], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5204: cell 65, seg 0 (0.5) [0.5 on Epop[65]] -> cell 4, seg 0 (0.5) [0.5 on Epop[4]], weight: 4.1363508E-4, delay 1.5
        h("Epop[4] syn_projEE_ampa[5204] = new ampa(0.5)")
        h("Epop[65] netConn_projEE_ampa[5204] = new NetCon(&v(0.5), syn_projEE_ampa[5204], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5205: cell 65, seg 0 (0.5) [0.5 on Epop[65]] -> cell 5, seg 0 (0.5) [0.5 on Epop[5]], weight: 4.1363508E-4, delay 1.5
        h("Epop[5] syn_projEE_ampa[5205] = new ampa(0.5)")
        h("Epop[65] netConn_projEE_ampa[5205] = new NetCon(&v(0.5), syn_projEE_ampa[5205], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5206: cell 65, seg 0 (0.5) [0.5 on Epop[65]] -> cell 6, seg 0 (0.5) [0.5 on Epop[6]], weight: 4.1363508E-4, delay 1.5
        h("Epop[6] syn_projEE_ampa[5206] = new ampa(0.5)")
        h("Epop[65] netConn_projEE_ampa[5206] = new NetCon(&v(0.5), syn_projEE_ampa[5206], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5207: cell 65, seg 0 (0.5) [0.5 on Epop[65]] -> cell 7, seg 0 (0.5) [0.5 on Epop[7]], weight: 4.1363508E-4, delay 1.5
        h("Epop[7] syn_projEE_ampa[5207] = new ampa(0.5)")
        h("Epop[65] netConn_projEE_ampa[5207] = new NetCon(&v(0.5), syn_projEE_ampa[5207], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5208: cell 65, seg 0 (0.5) [0.5 on Epop[65]] -> cell 8, seg 0 (0.5) [0.5 on Epop[8]], weight: 4.1363508E-4, delay 1.5
        h("Epop[8] syn_projEE_ampa[5208] = new ampa(0.5)")
        h("Epop[65] netConn_projEE_ampa[5208] = new NetCon(&v(0.5), syn_projEE_ampa[5208], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5209: cell 65, seg 0 (0.5) [0.5 on Epop[65]] -> cell 9, seg 0 (0.5) [0.5 on Epop[9]], weight: 4.1363508E-4, delay 1.5
        h("Epop[9] syn_projEE_ampa[5209] = new ampa(0.5)")
        h("Epop[65] netConn_projEE_ampa[5209] = new NetCon(&v(0.5), syn_projEE_ampa[5209], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5210: cell 65, seg 0 (0.5) [0.5 on Epop[65]] -> cell 10, seg 0 (0.5) [0.5 on Epop[10]], weight: 4.1363508E-4, delay 1.5
        h("Epop[10] syn_projEE_ampa[5210] = new ampa(0.5)")
        h("Epop[65] netConn_projEE_ampa[5210] = new NetCon(&v(0.5), syn_projEE_ampa[5210], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5211: cell 65, seg 0 (0.5) [0.5 on Epop[65]] -> cell 11, seg 0 (0.5) [0.5 on Epop[11]], weight: 4.1363508E-4, delay 1.5
        h("Epop[11] syn_projEE_ampa[5211] = new ampa(0.5)")
        h("Epop[65] netConn_projEE_ampa[5211] = new NetCon(&v(0.5), syn_projEE_ampa[5211], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5212: cell 65, seg 0 (0.5) [0.5 on Epop[65]] -> cell 12, seg 0 (0.5) [0.5 on Epop[12]], weight: 4.1363508E-4, delay 1.5
        h("Epop[12] syn_projEE_ampa[5212] = new ampa(0.5)")
        h("Epop[65] netConn_projEE_ampa[5212] = new NetCon(&v(0.5), syn_projEE_ampa[5212], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5213: cell 65, seg 0 (0.5) [0.5 on Epop[65]] -> cell 13, seg 0 (0.5) [0.5 on Epop[13]], weight: 4.1363508E-4, delay 1.5
        h("Epop[13] syn_projEE_ampa[5213] = new ampa(0.5)")
        h("Epop[65] netConn_projEE_ampa[5213] = new NetCon(&v(0.5), syn_projEE_ampa[5213], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5214: cell 65, seg 0 (0.5) [0.5 on Epop[65]] -> cell 14, seg 0 (0.5) [0.5 on Epop[14]], weight: 4.1363508E-4, delay 1.5
        h("Epop[14] syn_projEE_ampa[5214] = new ampa(0.5)")
        h("Epop[65] netConn_projEE_ampa[5214] = new NetCon(&v(0.5), syn_projEE_ampa[5214], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5215: cell 65, seg 0 (0.5) [0.5 on Epop[65]] -> cell 15, seg 0 (0.5) [0.5 on Epop[15]], weight: 4.1363508E-4, delay 1.5
        h("Epop[15] syn_projEE_ampa[5215] = new ampa(0.5)")
        h("Epop[65] netConn_projEE_ampa[5215] = new NetCon(&v(0.5), syn_projEE_ampa[5215], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5216: cell 65, seg 0 (0.5) [0.5 on Epop[65]] -> cell 16, seg 0 (0.5) [0.5 on Epop[16]], weight: 4.1363508E-4, delay 1.5
        h("Epop[16] syn_projEE_ampa[5216] = new ampa(0.5)")
        h("Epop[65] netConn_projEE_ampa[5216] = new NetCon(&v(0.5), syn_projEE_ampa[5216], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5217: cell 65, seg 0 (0.5) [0.5 on Epop[65]] -> cell 17, seg 0 (0.5) [0.5 on Epop[17]], weight: 4.1363508E-4, delay 1.5
        h("Epop[17] syn_projEE_ampa[5217] = new ampa(0.5)")
        h("Epop[65] netConn_projEE_ampa[5217] = new NetCon(&v(0.5), syn_projEE_ampa[5217], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5218: cell 65, seg 0 (0.5) [0.5 on Epop[65]] -> cell 18, seg 0 (0.5) [0.5 on Epop[18]], weight: 4.1363508E-4, delay 1.5
        h("Epop[18] syn_projEE_ampa[5218] = new ampa(0.5)")
        h("Epop[65] netConn_projEE_ampa[5218] = new NetCon(&v(0.5), syn_projEE_ampa[5218], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5219: cell 65, seg 0 (0.5) [0.5 on Epop[65]] -> cell 19, seg 0 (0.5) [0.5 on Epop[19]], weight: 4.1363508E-4, delay 1.5
        h("Epop[19] syn_projEE_ampa[5219] = new ampa(0.5)")
        h("Epop[65] netConn_projEE_ampa[5219] = new NetCon(&v(0.5), syn_projEE_ampa[5219], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5220: cell 65, seg 0 (0.5) [0.5 on Epop[65]] -> cell 20, seg 0 (0.5) [0.5 on Epop[20]], weight: 4.1363508E-4, delay 1.5
        h("Epop[20] syn_projEE_ampa[5220] = new ampa(0.5)")
        h("Epop[65] netConn_projEE_ampa[5220] = new NetCon(&v(0.5), syn_projEE_ampa[5220], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5221: cell 65, seg 0 (0.5) [0.5 on Epop[65]] -> cell 21, seg 0 (0.5) [0.5 on Epop[21]], weight: 4.1363508E-4, delay 1.5
        h("Epop[21] syn_projEE_ampa[5221] = new ampa(0.5)")
        h("Epop[65] netConn_projEE_ampa[5221] = new NetCon(&v(0.5), syn_projEE_ampa[5221], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5222: cell 65, seg 0 (0.5) [0.5 on Epop[65]] -> cell 22, seg 0 (0.5) [0.5 on Epop[22]], weight: 4.1363508E-4, delay 1.5
        h("Epop[22] syn_projEE_ampa[5222] = new ampa(0.5)")
        h("Epop[65] netConn_projEE_ampa[5222] = new NetCon(&v(0.5), syn_projEE_ampa[5222], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5223: cell 65, seg 0 (0.5) [0.5 on Epop[65]] -> cell 23, seg 0 (0.5) [0.5 on Epop[23]], weight: 4.1363508E-4, delay 1.5
        h("Epop[23] syn_projEE_ampa[5223] = new ampa(0.5)")
        h("Epop[65] netConn_projEE_ampa[5223] = new NetCon(&v(0.5), syn_projEE_ampa[5223], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5224: cell 65, seg 0 (0.5) [0.5 on Epop[65]] -> cell 24, seg 0 (0.5) [0.5 on Epop[24]], weight: 4.1363508E-4, delay 1.5
        h("Epop[24] syn_projEE_ampa[5224] = new ampa(0.5)")
        h("Epop[65] netConn_projEE_ampa[5224] = new NetCon(&v(0.5), syn_projEE_ampa[5224], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5225: cell 65, seg 0 (0.5) [0.5 on Epop[65]] -> cell 25, seg 0 (0.5) [0.5 on Epop[25]], weight: 4.1363508E-4, delay 1.5
        h("Epop[25] syn_projEE_ampa[5225] = new ampa(0.5)")
        h("Epop[65] netConn_projEE_ampa[5225] = new NetCon(&v(0.5), syn_projEE_ampa[5225], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5226: cell 65, seg 0 (0.5) [0.5 on Epop[65]] -> cell 26, seg 0 (0.5) [0.5 on Epop[26]], weight: 4.1363508E-4, delay 1.5
        h("Epop[26] syn_projEE_ampa[5226] = new ampa(0.5)")
        h("Epop[65] netConn_projEE_ampa[5226] = new NetCon(&v(0.5), syn_projEE_ampa[5226], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5227: cell 65, seg 0 (0.5) [0.5 on Epop[65]] -> cell 27, seg 0 (0.5) [0.5 on Epop[27]], weight: 4.1363508E-4, delay 1.5
        h("Epop[27] syn_projEE_ampa[5227] = new ampa(0.5)")
        h("Epop[65] netConn_projEE_ampa[5227] = new NetCon(&v(0.5), syn_projEE_ampa[5227], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5228: cell 65, seg 0 (0.5) [0.5 on Epop[65]] -> cell 28, seg 0 (0.5) [0.5 on Epop[28]], weight: 4.1363508E-4, delay 1.5
        h("Epop[28] syn_projEE_ampa[5228] = new ampa(0.5)")
        h("Epop[65] netConn_projEE_ampa[5228] = new NetCon(&v(0.5), syn_projEE_ampa[5228], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5229: cell 65, seg 0 (0.5) [0.5 on Epop[65]] -> cell 29, seg 0 (0.5) [0.5 on Epop[29]], weight: 4.1363508E-4, delay 1.5
        h("Epop[29] syn_projEE_ampa[5229] = new ampa(0.5)")
        h("Epop[65] netConn_projEE_ampa[5229] = new NetCon(&v(0.5), syn_projEE_ampa[5229], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5230: cell 65, seg 0 (0.5) [0.5 on Epop[65]] -> cell 30, seg 0 (0.5) [0.5 on Epop[30]], weight: 4.1363508E-4, delay 1.5
        h("Epop[30] syn_projEE_ampa[5230] = new ampa(0.5)")
        h("Epop[65] netConn_projEE_ampa[5230] = new NetCon(&v(0.5), syn_projEE_ampa[5230], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5231: cell 65, seg 0 (0.5) [0.5 on Epop[65]] -> cell 31, seg 0 (0.5) [0.5 on Epop[31]], weight: 4.1363508E-4, delay 1.5
        h("Epop[31] syn_projEE_ampa[5231] = new ampa(0.5)")
        h("Epop[65] netConn_projEE_ampa[5231] = new NetCon(&v(0.5), syn_projEE_ampa[5231], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5232: cell 65, seg 0 (0.5) [0.5 on Epop[65]] -> cell 32, seg 0 (0.5) [0.5 on Epop[32]], weight: 4.1363508E-4, delay 1.5
        h("Epop[32] syn_projEE_ampa[5232] = new ampa(0.5)")
        h("Epop[65] netConn_projEE_ampa[5232] = new NetCon(&v(0.5), syn_projEE_ampa[5232], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5233: cell 65, seg 0 (0.5) [0.5 on Epop[65]] -> cell 33, seg 0 (0.5) [0.5 on Epop[33]], weight: 4.1363508E-4, delay 1.5
        h("Epop[33] syn_projEE_ampa[5233] = new ampa(0.5)")
        h("Epop[65] netConn_projEE_ampa[5233] = new NetCon(&v(0.5), syn_projEE_ampa[5233], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5234: cell 65, seg 0 (0.5) [0.5 on Epop[65]] -> cell 34, seg 0 (0.5) [0.5 on Epop[34]], weight: 4.1363508E-4, delay 1.5
        h("Epop[34] syn_projEE_ampa[5234] = new ampa(0.5)")
        h("Epop[65] netConn_projEE_ampa[5234] = new NetCon(&v(0.5), syn_projEE_ampa[5234], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5235: cell 65, seg 0 (0.5) [0.5 on Epop[65]] -> cell 35, seg 0 (0.5) [0.5 on Epop[35]], weight: 4.1363508E-4, delay 1.5
        h("Epop[35] syn_projEE_ampa[5235] = new ampa(0.5)")
        h("Epop[65] netConn_projEE_ampa[5235] = new NetCon(&v(0.5), syn_projEE_ampa[5235], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5236: cell 65, seg 0 (0.5) [0.5 on Epop[65]] -> cell 36, seg 0 (0.5) [0.5 on Epop[36]], weight: 4.1363508E-4, delay 1.5
        h("Epop[36] syn_projEE_ampa[5236] = new ampa(0.5)")
        h("Epop[65] netConn_projEE_ampa[5236] = new NetCon(&v(0.5), syn_projEE_ampa[5236], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5237: cell 65, seg 0 (0.5) [0.5 on Epop[65]] -> cell 37, seg 0 (0.5) [0.5 on Epop[37]], weight: 4.1363508E-4, delay 1.5
        h("Epop[37] syn_projEE_ampa[5237] = new ampa(0.5)")
        h("Epop[65] netConn_projEE_ampa[5237] = new NetCon(&v(0.5), syn_projEE_ampa[5237], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5238: cell 65, seg 0 (0.5) [0.5 on Epop[65]] -> cell 38, seg 0 (0.5) [0.5 on Epop[38]], weight: 4.1363508E-4, delay 1.5
        h("Epop[38] syn_projEE_ampa[5238] = new ampa(0.5)")
        h("Epop[65] netConn_projEE_ampa[5238] = new NetCon(&v(0.5), syn_projEE_ampa[5238], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5239: cell 65, seg 0 (0.5) [0.5 on Epop[65]] -> cell 39, seg 0 (0.5) [0.5 on Epop[39]], weight: 4.1363508E-4, delay 1.5
        h("Epop[39] syn_projEE_ampa[5239] = new ampa(0.5)")
        h("Epop[65] netConn_projEE_ampa[5239] = new NetCon(&v(0.5), syn_projEE_ampa[5239], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5240: cell 65, seg 0 (0.5) [0.5 on Epop[65]] -> cell 40, seg 0 (0.5) [0.5 on Epop[40]], weight: 4.1363508E-4, delay 1.5
        h("Epop[40] syn_projEE_ampa[5240] = new ampa(0.5)")
        h("Epop[65] netConn_projEE_ampa[5240] = new NetCon(&v(0.5), syn_projEE_ampa[5240], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5241: cell 65, seg 0 (0.5) [0.5 on Epop[65]] -> cell 41, seg 0 (0.5) [0.5 on Epop[41]], weight: 4.1363508E-4, delay 1.5
        h("Epop[41] syn_projEE_ampa[5241] = new ampa(0.5)")
        h("Epop[65] netConn_projEE_ampa[5241] = new NetCon(&v(0.5), syn_projEE_ampa[5241], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5242: cell 65, seg 0 (0.5) [0.5 on Epop[65]] -> cell 42, seg 0 (0.5) [0.5 on Epop[42]], weight: 4.1363508E-4, delay 1.5
        h("Epop[42] syn_projEE_ampa[5242] = new ampa(0.5)")
        h("Epop[65] netConn_projEE_ampa[5242] = new NetCon(&v(0.5), syn_projEE_ampa[5242], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5243: cell 65, seg 0 (0.5) [0.5 on Epop[65]] -> cell 43, seg 0 (0.5) [0.5 on Epop[43]], weight: 4.1363508E-4, delay 1.5
        h("Epop[43] syn_projEE_ampa[5243] = new ampa(0.5)")
        h("Epop[65] netConn_projEE_ampa[5243] = new NetCon(&v(0.5), syn_projEE_ampa[5243], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5244: cell 65, seg 0 (0.5) [0.5 on Epop[65]] -> cell 44, seg 0 (0.5) [0.5 on Epop[44]], weight: 4.1363508E-4, delay 1.5
        h("Epop[44] syn_projEE_ampa[5244] = new ampa(0.5)")
        h("Epop[65] netConn_projEE_ampa[5244] = new NetCon(&v(0.5), syn_projEE_ampa[5244], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5245: cell 65, seg 0 (0.5) [0.5 on Epop[65]] -> cell 45, seg 0 (0.5) [0.5 on Epop[45]], weight: 4.1363508E-4, delay 1.5
        h("Epop[45] syn_projEE_ampa[5245] = new ampa(0.5)")
        h("Epop[65] netConn_projEE_ampa[5245] = new NetCon(&v(0.5), syn_projEE_ampa[5245], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5246: cell 65, seg 0 (0.5) [0.5 on Epop[65]] -> cell 46, seg 0 (0.5) [0.5 on Epop[46]], weight: 4.1363508E-4, delay 1.5
        h("Epop[46] syn_projEE_ampa[5246] = new ampa(0.5)")
        h("Epop[65] netConn_projEE_ampa[5246] = new NetCon(&v(0.5), syn_projEE_ampa[5246], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5247: cell 65, seg 0 (0.5) [0.5 on Epop[65]] -> cell 47, seg 0 (0.5) [0.5 on Epop[47]], weight: 4.1363508E-4, delay 1.5
        h("Epop[47] syn_projEE_ampa[5247] = new ampa(0.5)")
        h("Epop[65] netConn_projEE_ampa[5247] = new NetCon(&v(0.5), syn_projEE_ampa[5247], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5248: cell 65, seg 0 (0.5) [0.5 on Epop[65]] -> cell 48, seg 0 (0.5) [0.5 on Epop[48]], weight: 4.1363508E-4, delay 1.5
        h("Epop[48] syn_projEE_ampa[5248] = new ampa(0.5)")
        h("Epop[65] netConn_projEE_ampa[5248] = new NetCon(&v(0.5), syn_projEE_ampa[5248], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5249: cell 65, seg 0 (0.5) [0.5 on Epop[65]] -> cell 49, seg 0 (0.5) [0.5 on Epop[49]], weight: 4.1363508E-4, delay 1.5
        h("Epop[49] syn_projEE_ampa[5249] = new ampa(0.5)")
        h("Epop[65] netConn_projEE_ampa[5249] = new NetCon(&v(0.5), syn_projEE_ampa[5249], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5250: cell 65, seg 0 (0.5) [0.5 on Epop[65]] -> cell 50, seg 0 (0.5) [0.5 on Epop[50]], weight: 4.1363508E-4, delay 1.5
        h("Epop[50] syn_projEE_ampa[5250] = new ampa(0.5)")
        h("Epop[65] netConn_projEE_ampa[5250] = new NetCon(&v(0.5), syn_projEE_ampa[5250], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5251: cell 65, seg 0 (0.5) [0.5 on Epop[65]] -> cell 51, seg 0 (0.5) [0.5 on Epop[51]], weight: 4.1363508E-4, delay 1.5
        h("Epop[51] syn_projEE_ampa[5251] = new ampa(0.5)")
        h("Epop[65] netConn_projEE_ampa[5251] = new NetCon(&v(0.5), syn_projEE_ampa[5251], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5252: cell 65, seg 0 (0.5) [0.5 on Epop[65]] -> cell 52, seg 0 (0.5) [0.5 on Epop[52]], weight: 4.1363508E-4, delay 1.5
        h("Epop[52] syn_projEE_ampa[5252] = new ampa(0.5)")
        h("Epop[65] netConn_projEE_ampa[5252] = new NetCon(&v(0.5), syn_projEE_ampa[5252], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5253: cell 65, seg 0 (0.5) [0.5 on Epop[65]] -> cell 53, seg 0 (0.5) [0.5 on Epop[53]], weight: 4.1363508E-4, delay 1.5
        h("Epop[53] syn_projEE_ampa[5253] = new ampa(0.5)")
        h("Epop[65] netConn_projEE_ampa[5253] = new NetCon(&v(0.5), syn_projEE_ampa[5253], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5254: cell 65, seg 0 (0.5) [0.5 on Epop[65]] -> cell 54, seg 0 (0.5) [0.5 on Epop[54]], weight: 4.1363508E-4, delay 1.5
        h("Epop[54] syn_projEE_ampa[5254] = new ampa(0.5)")
        h("Epop[65] netConn_projEE_ampa[5254] = new NetCon(&v(0.5), syn_projEE_ampa[5254], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5255: cell 65, seg 0 (0.5) [0.5 on Epop[65]] -> cell 55, seg 0 (0.5) [0.5 on Epop[55]], weight: 4.1363508E-4, delay 1.5
        h("Epop[55] syn_projEE_ampa[5255] = new ampa(0.5)")
        h("Epop[65] netConn_projEE_ampa[5255] = new NetCon(&v(0.5), syn_projEE_ampa[5255], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5256: cell 65, seg 0 (0.5) [0.5 on Epop[65]] -> cell 56, seg 0 (0.5) [0.5 on Epop[56]], weight: 4.1363508E-4, delay 1.5
        h("Epop[56] syn_projEE_ampa[5256] = new ampa(0.5)")
        h("Epop[65] netConn_projEE_ampa[5256] = new NetCon(&v(0.5), syn_projEE_ampa[5256], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5257: cell 65, seg 0 (0.5) [0.5 on Epop[65]] -> cell 57, seg 0 (0.5) [0.5 on Epop[57]], weight: 4.1363508E-4, delay 1.5
        h("Epop[57] syn_projEE_ampa[5257] = new ampa(0.5)")
        h("Epop[65] netConn_projEE_ampa[5257] = new NetCon(&v(0.5), syn_projEE_ampa[5257], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5258: cell 65, seg 0 (0.5) [0.5 on Epop[65]] -> cell 58, seg 0 (0.5) [0.5 on Epop[58]], weight: 4.1363508E-4, delay 1.5
        h("Epop[58] syn_projEE_ampa[5258] = new ampa(0.5)")
        h("Epop[65] netConn_projEE_ampa[5258] = new NetCon(&v(0.5), syn_projEE_ampa[5258], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5259: cell 65, seg 0 (0.5) [0.5 on Epop[65]] -> cell 59, seg 0 (0.5) [0.5 on Epop[59]], weight: 4.1363508E-4, delay 1.5
        h("Epop[59] syn_projEE_ampa[5259] = new ampa(0.5)")
        h("Epop[65] netConn_projEE_ampa[5259] = new NetCon(&v(0.5), syn_projEE_ampa[5259], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5260: cell 65, seg 0 (0.5) [0.5 on Epop[65]] -> cell 60, seg 0 (0.5) [0.5 on Epop[60]], weight: 4.1363508E-4, delay 1.5
        h("Epop[60] syn_projEE_ampa[5260] = new ampa(0.5)")
        h("Epop[65] netConn_projEE_ampa[5260] = new NetCon(&v(0.5), syn_projEE_ampa[5260], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5261: cell 65, seg 0 (0.5) [0.5 on Epop[65]] -> cell 61, seg 0 (0.5) [0.5 on Epop[61]], weight: 4.1363508E-4, delay 1.5
        h("Epop[61] syn_projEE_ampa[5261] = new ampa(0.5)")
        h("Epop[65] netConn_projEE_ampa[5261] = new NetCon(&v(0.5), syn_projEE_ampa[5261], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5262: cell 65, seg 0 (0.5) [0.5 on Epop[65]] -> cell 62, seg 0 (0.5) [0.5 on Epop[62]], weight: 4.1363508E-4, delay 1.5
        h("Epop[62] syn_projEE_ampa[5262] = new ampa(0.5)")
        h("Epop[65] netConn_projEE_ampa[5262] = new NetCon(&v(0.5), syn_projEE_ampa[5262], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5263: cell 65, seg 0 (0.5) [0.5 on Epop[65]] -> cell 63, seg 0 (0.5) [0.5 on Epop[63]], weight: 4.1363508E-4, delay 1.5
        h("Epop[63] syn_projEE_ampa[5263] = new ampa(0.5)")
        h("Epop[65] netConn_projEE_ampa[5263] = new NetCon(&v(0.5), syn_projEE_ampa[5263], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5264: cell 65, seg 0 (0.5) [0.5 on Epop[65]] -> cell 64, seg 0 (0.5) [0.5 on Epop[64]], weight: 4.1363508E-4, delay 1.5
        h("Epop[64] syn_projEE_ampa[5264] = new ampa(0.5)")
        h("Epop[65] netConn_projEE_ampa[5264] = new NetCon(&v(0.5), syn_projEE_ampa[5264], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5265: cell 65, seg 0 (0.5) [0.5 on Epop[65]] -> cell 65, seg 0 (0.5) [0.5 on Epop[65]], weight: 4.1363508E-4, delay 1.5
        h("Epop[65] syn_projEE_ampa[5265] = new ampa(0.5)")
        h("Epop[65] netConn_projEE_ampa[5265] = new NetCon(&v(0.5), syn_projEE_ampa[5265], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5266: cell 65, seg 0 (0.5) [0.5 on Epop[65]] -> cell 66, seg 0 (0.5) [0.5 on Epop[66]], weight: 4.1363508E-4, delay 1.5
        h("Epop[66] syn_projEE_ampa[5266] = new ampa(0.5)")
        h("Epop[65] netConn_projEE_ampa[5266] = new NetCon(&v(0.5), syn_projEE_ampa[5266], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5267: cell 65, seg 0 (0.5) [0.5 on Epop[65]] -> cell 67, seg 0 (0.5) [0.5 on Epop[67]], weight: 4.1363508E-4, delay 1.5
        h("Epop[67] syn_projEE_ampa[5267] = new ampa(0.5)")
        h("Epop[65] netConn_projEE_ampa[5267] = new NetCon(&v(0.5), syn_projEE_ampa[5267], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5268: cell 65, seg 0 (0.5) [0.5 on Epop[65]] -> cell 68, seg 0 (0.5) [0.5 on Epop[68]], weight: 4.1363508E-4, delay 1.5
        h("Epop[68] syn_projEE_ampa[5268] = new ampa(0.5)")
        h("Epop[65] netConn_projEE_ampa[5268] = new NetCon(&v(0.5), syn_projEE_ampa[5268], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5269: cell 65, seg 0 (0.5) [0.5 on Epop[65]] -> cell 69, seg 0 (0.5) [0.5 on Epop[69]], weight: 4.1363508E-4, delay 1.5
        h("Epop[69] syn_projEE_ampa[5269] = new ampa(0.5)")
        h("Epop[65] netConn_projEE_ampa[5269] = new NetCon(&v(0.5), syn_projEE_ampa[5269], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5270: cell 65, seg 0 (0.5) [0.5 on Epop[65]] -> cell 70, seg 0 (0.5) [0.5 on Epop[70]], weight: 4.1363508E-4, delay 1.5
        h("Epop[70] syn_projEE_ampa[5270] = new ampa(0.5)")
        h("Epop[65] netConn_projEE_ampa[5270] = new NetCon(&v(0.5), syn_projEE_ampa[5270], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5271: cell 65, seg 0 (0.5) [0.5 on Epop[65]] -> cell 71, seg 0 (0.5) [0.5 on Epop[71]], weight: 4.1363508E-4, delay 1.5
        h("Epop[71] syn_projEE_ampa[5271] = new ampa(0.5)")
        h("Epop[65] netConn_projEE_ampa[5271] = new NetCon(&v(0.5), syn_projEE_ampa[5271], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5272: cell 65, seg 0 (0.5) [0.5 on Epop[65]] -> cell 72, seg 0 (0.5) [0.5 on Epop[72]], weight: 4.1363508E-4, delay 1.5
        h("Epop[72] syn_projEE_ampa[5272] = new ampa(0.5)")
        h("Epop[65] netConn_projEE_ampa[5272] = new NetCon(&v(0.5), syn_projEE_ampa[5272], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5273: cell 65, seg 0 (0.5) [0.5 on Epop[65]] -> cell 73, seg 0 (0.5) [0.5 on Epop[73]], weight: 4.1363508E-4, delay 1.5
        h("Epop[73] syn_projEE_ampa[5273] = new ampa(0.5)")
        h("Epop[65] netConn_projEE_ampa[5273] = new NetCon(&v(0.5), syn_projEE_ampa[5273], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5274: cell 65, seg 0 (0.5) [0.5 on Epop[65]] -> cell 74, seg 0 (0.5) [0.5 on Epop[74]], weight: 4.1363508E-4, delay 1.5
        h("Epop[74] syn_projEE_ampa[5274] = new ampa(0.5)")
        h("Epop[65] netConn_projEE_ampa[5274] = new NetCon(&v(0.5), syn_projEE_ampa[5274], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5275: cell 65, seg 0 (0.5) [0.5 on Epop[65]] -> cell 75, seg 0 (0.5) [0.5 on Epop[75]], weight: 4.1363508E-4, delay 1.5
        h("Epop[75] syn_projEE_ampa[5275] = new ampa(0.5)")
        h("Epop[65] netConn_projEE_ampa[5275] = new NetCon(&v(0.5), syn_projEE_ampa[5275], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5276: cell 65, seg 0 (0.5) [0.5 on Epop[65]] -> cell 76, seg 0 (0.5) [0.5 on Epop[76]], weight: 4.1363508E-4, delay 1.5
        h("Epop[76] syn_projEE_ampa[5276] = new ampa(0.5)")
        h("Epop[65] netConn_projEE_ampa[5276] = new NetCon(&v(0.5), syn_projEE_ampa[5276], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5277: cell 65, seg 0 (0.5) [0.5 on Epop[65]] -> cell 77, seg 0 (0.5) [0.5 on Epop[77]], weight: 4.1363508E-4, delay 1.5
        h("Epop[77] syn_projEE_ampa[5277] = new ampa(0.5)")
        h("Epop[65] netConn_projEE_ampa[5277] = new NetCon(&v(0.5), syn_projEE_ampa[5277], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5278: cell 65, seg 0 (0.5) [0.5 on Epop[65]] -> cell 78, seg 0 (0.5) [0.5 on Epop[78]], weight: 4.1363508E-4, delay 1.5
        h("Epop[78] syn_projEE_ampa[5278] = new ampa(0.5)")
        h("Epop[65] netConn_projEE_ampa[5278] = new NetCon(&v(0.5), syn_projEE_ampa[5278], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5279: cell 65, seg 0 (0.5) [0.5 on Epop[65]] -> cell 79, seg 0 (0.5) [0.5 on Epop[79]], weight: 4.1363508E-4, delay 1.5
        h("Epop[79] syn_projEE_ampa[5279] = new ampa(0.5)")
        h("Epop[65] netConn_projEE_ampa[5279] = new NetCon(&v(0.5), syn_projEE_ampa[5279], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5280: cell 66, seg 0 (0.5) [0.5 on Epop[66]] -> cell 0, seg 0 (0.5) [0.5 on Epop[0]], weight: 4.1363508E-4, delay 1.5
        h("Epop[0] syn_projEE_ampa[5280] = new ampa(0.5)")
        h("Epop[66] netConn_projEE_ampa[5280] = new NetCon(&v(0.5), syn_projEE_ampa[5280], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5281: cell 66, seg 0 (0.5) [0.5 on Epop[66]] -> cell 1, seg 0 (0.5) [0.5 on Epop[1]], weight: 4.1363508E-4, delay 1.5
        h("Epop[1] syn_projEE_ampa[5281] = new ampa(0.5)")
        h("Epop[66] netConn_projEE_ampa[5281] = new NetCon(&v(0.5), syn_projEE_ampa[5281], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5282: cell 66, seg 0 (0.5) [0.5 on Epop[66]] -> cell 2, seg 0 (0.5) [0.5 on Epop[2]], weight: 4.1363508E-4, delay 1.5
        h("Epop[2] syn_projEE_ampa[5282] = new ampa(0.5)")
        h("Epop[66] netConn_projEE_ampa[5282] = new NetCon(&v(0.5), syn_projEE_ampa[5282], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5283: cell 66, seg 0 (0.5) [0.5 on Epop[66]] -> cell 3, seg 0 (0.5) [0.5 on Epop[3]], weight: 4.1363508E-4, delay 1.5
        h("Epop[3] syn_projEE_ampa[5283] = new ampa(0.5)")
        h("Epop[66] netConn_projEE_ampa[5283] = new NetCon(&v(0.5), syn_projEE_ampa[5283], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5284: cell 66, seg 0 (0.5) [0.5 on Epop[66]] -> cell 4, seg 0 (0.5) [0.5 on Epop[4]], weight: 4.1363508E-4, delay 1.5
        h("Epop[4] syn_projEE_ampa[5284] = new ampa(0.5)")
        h("Epop[66] netConn_projEE_ampa[5284] = new NetCon(&v(0.5), syn_projEE_ampa[5284], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5285: cell 66, seg 0 (0.5) [0.5 on Epop[66]] -> cell 5, seg 0 (0.5) [0.5 on Epop[5]], weight: 4.1363508E-4, delay 1.5
        h("Epop[5] syn_projEE_ampa[5285] = new ampa(0.5)")
        h("Epop[66] netConn_projEE_ampa[5285] = new NetCon(&v(0.5), syn_projEE_ampa[5285], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5286: cell 66, seg 0 (0.5) [0.5 on Epop[66]] -> cell 6, seg 0 (0.5) [0.5 on Epop[6]], weight: 4.1363508E-4, delay 1.5
        h("Epop[6] syn_projEE_ampa[5286] = new ampa(0.5)")
        h("Epop[66] netConn_projEE_ampa[5286] = new NetCon(&v(0.5), syn_projEE_ampa[5286], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5287: cell 66, seg 0 (0.5) [0.5 on Epop[66]] -> cell 7, seg 0 (0.5) [0.5 on Epop[7]], weight: 4.1363508E-4, delay 1.5
        h("Epop[7] syn_projEE_ampa[5287] = new ampa(0.5)")
        h("Epop[66] netConn_projEE_ampa[5287] = new NetCon(&v(0.5), syn_projEE_ampa[5287], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5288: cell 66, seg 0 (0.5) [0.5 on Epop[66]] -> cell 8, seg 0 (0.5) [0.5 on Epop[8]], weight: 4.1363508E-4, delay 1.5
        h("Epop[8] syn_projEE_ampa[5288] = new ampa(0.5)")
        h("Epop[66] netConn_projEE_ampa[5288] = new NetCon(&v(0.5), syn_projEE_ampa[5288], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5289: cell 66, seg 0 (0.5) [0.5 on Epop[66]] -> cell 9, seg 0 (0.5) [0.5 on Epop[9]], weight: 4.1363508E-4, delay 1.5
        h("Epop[9] syn_projEE_ampa[5289] = new ampa(0.5)")
        h("Epop[66] netConn_projEE_ampa[5289] = new NetCon(&v(0.5), syn_projEE_ampa[5289], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5290: cell 66, seg 0 (0.5) [0.5 on Epop[66]] -> cell 10, seg 0 (0.5) [0.5 on Epop[10]], weight: 4.1363508E-4, delay 1.5
        h("Epop[10] syn_projEE_ampa[5290] = new ampa(0.5)")
        h("Epop[66] netConn_projEE_ampa[5290] = new NetCon(&v(0.5), syn_projEE_ampa[5290], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5291: cell 66, seg 0 (0.5) [0.5 on Epop[66]] -> cell 11, seg 0 (0.5) [0.5 on Epop[11]], weight: 4.1363508E-4, delay 1.5
        h("Epop[11] syn_projEE_ampa[5291] = new ampa(0.5)")
        h("Epop[66] netConn_projEE_ampa[5291] = new NetCon(&v(0.5), syn_projEE_ampa[5291], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5292: cell 66, seg 0 (0.5) [0.5 on Epop[66]] -> cell 12, seg 0 (0.5) [0.5 on Epop[12]], weight: 4.1363508E-4, delay 1.5
        h("Epop[12] syn_projEE_ampa[5292] = new ampa(0.5)")
        h("Epop[66] netConn_projEE_ampa[5292] = new NetCon(&v(0.5), syn_projEE_ampa[5292], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5293: cell 66, seg 0 (0.5) [0.5 on Epop[66]] -> cell 13, seg 0 (0.5) [0.5 on Epop[13]], weight: 4.1363508E-4, delay 1.5
        h("Epop[13] syn_projEE_ampa[5293] = new ampa(0.5)")
        h("Epop[66] netConn_projEE_ampa[5293] = new NetCon(&v(0.5), syn_projEE_ampa[5293], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5294: cell 66, seg 0 (0.5) [0.5 on Epop[66]] -> cell 14, seg 0 (0.5) [0.5 on Epop[14]], weight: 4.1363508E-4, delay 1.5
        h("Epop[14] syn_projEE_ampa[5294] = new ampa(0.5)")
        h("Epop[66] netConn_projEE_ampa[5294] = new NetCon(&v(0.5), syn_projEE_ampa[5294], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5295: cell 66, seg 0 (0.5) [0.5 on Epop[66]] -> cell 15, seg 0 (0.5) [0.5 on Epop[15]], weight: 4.1363508E-4, delay 1.5
        h("Epop[15] syn_projEE_ampa[5295] = new ampa(0.5)")
        h("Epop[66] netConn_projEE_ampa[5295] = new NetCon(&v(0.5), syn_projEE_ampa[5295], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5296: cell 66, seg 0 (0.5) [0.5 on Epop[66]] -> cell 16, seg 0 (0.5) [0.5 on Epop[16]], weight: 4.1363508E-4, delay 1.5
        h("Epop[16] syn_projEE_ampa[5296] = new ampa(0.5)")
        h("Epop[66] netConn_projEE_ampa[5296] = new NetCon(&v(0.5), syn_projEE_ampa[5296], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5297: cell 66, seg 0 (0.5) [0.5 on Epop[66]] -> cell 17, seg 0 (0.5) [0.5 on Epop[17]], weight: 4.1363508E-4, delay 1.5
        h("Epop[17] syn_projEE_ampa[5297] = new ampa(0.5)")
        h("Epop[66] netConn_projEE_ampa[5297] = new NetCon(&v(0.5), syn_projEE_ampa[5297], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5298: cell 66, seg 0 (0.5) [0.5 on Epop[66]] -> cell 18, seg 0 (0.5) [0.5 on Epop[18]], weight: 4.1363508E-4, delay 1.5
        h("Epop[18] syn_projEE_ampa[5298] = new ampa(0.5)")
        h("Epop[66] netConn_projEE_ampa[5298] = new NetCon(&v(0.5), syn_projEE_ampa[5298], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5299: cell 66, seg 0 (0.5) [0.5 on Epop[66]] -> cell 19, seg 0 (0.5) [0.5 on Epop[19]], weight: 4.1363508E-4, delay 1.5
        h("Epop[19] syn_projEE_ampa[5299] = new ampa(0.5)")
        h("Epop[66] netConn_projEE_ampa[5299] = new NetCon(&v(0.5), syn_projEE_ampa[5299], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5300: cell 66, seg 0 (0.5) [0.5 on Epop[66]] -> cell 20, seg 0 (0.5) [0.5 on Epop[20]], weight: 4.1363508E-4, delay 1.5
        h("Epop[20] syn_projEE_ampa[5300] = new ampa(0.5)")
        h("Epop[66] netConn_projEE_ampa[5300] = new NetCon(&v(0.5), syn_projEE_ampa[5300], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5301: cell 66, seg 0 (0.5) [0.5 on Epop[66]] -> cell 21, seg 0 (0.5) [0.5 on Epop[21]], weight: 4.1363508E-4, delay 1.5
        h("Epop[21] syn_projEE_ampa[5301] = new ampa(0.5)")
        h("Epop[66] netConn_projEE_ampa[5301] = new NetCon(&v(0.5), syn_projEE_ampa[5301], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5302: cell 66, seg 0 (0.5) [0.5 on Epop[66]] -> cell 22, seg 0 (0.5) [0.5 on Epop[22]], weight: 4.1363508E-4, delay 1.5
        h("Epop[22] syn_projEE_ampa[5302] = new ampa(0.5)")
        h("Epop[66] netConn_projEE_ampa[5302] = new NetCon(&v(0.5), syn_projEE_ampa[5302], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5303: cell 66, seg 0 (0.5) [0.5 on Epop[66]] -> cell 23, seg 0 (0.5) [0.5 on Epop[23]], weight: 4.1363508E-4, delay 1.5
        h("Epop[23] syn_projEE_ampa[5303] = new ampa(0.5)")
        h("Epop[66] netConn_projEE_ampa[5303] = new NetCon(&v(0.5), syn_projEE_ampa[5303], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5304: cell 66, seg 0 (0.5) [0.5 on Epop[66]] -> cell 24, seg 0 (0.5) [0.5 on Epop[24]], weight: 4.1363508E-4, delay 1.5
        h("Epop[24] syn_projEE_ampa[5304] = new ampa(0.5)")
        h("Epop[66] netConn_projEE_ampa[5304] = new NetCon(&v(0.5), syn_projEE_ampa[5304], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5305: cell 66, seg 0 (0.5) [0.5 on Epop[66]] -> cell 25, seg 0 (0.5) [0.5 on Epop[25]], weight: 4.1363508E-4, delay 1.5
        h("Epop[25] syn_projEE_ampa[5305] = new ampa(0.5)")
        h("Epop[66] netConn_projEE_ampa[5305] = new NetCon(&v(0.5), syn_projEE_ampa[5305], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5306: cell 66, seg 0 (0.5) [0.5 on Epop[66]] -> cell 26, seg 0 (0.5) [0.5 on Epop[26]], weight: 4.1363508E-4, delay 1.5
        h("Epop[26] syn_projEE_ampa[5306] = new ampa(0.5)")
        h("Epop[66] netConn_projEE_ampa[5306] = new NetCon(&v(0.5), syn_projEE_ampa[5306], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5307: cell 66, seg 0 (0.5) [0.5 on Epop[66]] -> cell 27, seg 0 (0.5) [0.5 on Epop[27]], weight: 4.1363508E-4, delay 1.5
        h("Epop[27] syn_projEE_ampa[5307] = new ampa(0.5)")
        h("Epop[66] netConn_projEE_ampa[5307] = new NetCon(&v(0.5), syn_projEE_ampa[5307], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5308: cell 66, seg 0 (0.5) [0.5 on Epop[66]] -> cell 28, seg 0 (0.5) [0.5 on Epop[28]], weight: 4.1363508E-4, delay 1.5
        h("Epop[28] syn_projEE_ampa[5308] = new ampa(0.5)")
        h("Epop[66] netConn_projEE_ampa[5308] = new NetCon(&v(0.5), syn_projEE_ampa[5308], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5309: cell 66, seg 0 (0.5) [0.5 on Epop[66]] -> cell 29, seg 0 (0.5) [0.5 on Epop[29]], weight: 4.1363508E-4, delay 1.5
        h("Epop[29] syn_projEE_ampa[5309] = new ampa(0.5)")
        h("Epop[66] netConn_projEE_ampa[5309] = new NetCon(&v(0.5), syn_projEE_ampa[5309], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5310: cell 66, seg 0 (0.5) [0.5 on Epop[66]] -> cell 30, seg 0 (0.5) [0.5 on Epop[30]], weight: 4.1363508E-4, delay 1.5
        h("Epop[30] syn_projEE_ampa[5310] = new ampa(0.5)")
        h("Epop[66] netConn_projEE_ampa[5310] = new NetCon(&v(0.5), syn_projEE_ampa[5310], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5311: cell 66, seg 0 (0.5) [0.5 on Epop[66]] -> cell 31, seg 0 (0.5) [0.5 on Epop[31]], weight: 4.1363508E-4, delay 1.5
        h("Epop[31] syn_projEE_ampa[5311] = new ampa(0.5)")
        h("Epop[66] netConn_projEE_ampa[5311] = new NetCon(&v(0.5), syn_projEE_ampa[5311], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5312: cell 66, seg 0 (0.5) [0.5 on Epop[66]] -> cell 32, seg 0 (0.5) [0.5 on Epop[32]], weight: 4.1363508E-4, delay 1.5
        h("Epop[32] syn_projEE_ampa[5312] = new ampa(0.5)")
        h("Epop[66] netConn_projEE_ampa[5312] = new NetCon(&v(0.5), syn_projEE_ampa[5312], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5313: cell 66, seg 0 (0.5) [0.5 on Epop[66]] -> cell 33, seg 0 (0.5) [0.5 on Epop[33]], weight: 4.1363508E-4, delay 1.5
        h("Epop[33] syn_projEE_ampa[5313] = new ampa(0.5)")
        h("Epop[66] netConn_projEE_ampa[5313] = new NetCon(&v(0.5), syn_projEE_ampa[5313], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5314: cell 66, seg 0 (0.5) [0.5 on Epop[66]] -> cell 34, seg 0 (0.5) [0.5 on Epop[34]], weight: 4.1363508E-4, delay 1.5
        h("Epop[34] syn_projEE_ampa[5314] = new ampa(0.5)")
        h("Epop[66] netConn_projEE_ampa[5314] = new NetCon(&v(0.5), syn_projEE_ampa[5314], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5315: cell 66, seg 0 (0.5) [0.5 on Epop[66]] -> cell 35, seg 0 (0.5) [0.5 on Epop[35]], weight: 4.1363508E-4, delay 1.5
        h("Epop[35] syn_projEE_ampa[5315] = new ampa(0.5)")
        h("Epop[66] netConn_projEE_ampa[5315] = new NetCon(&v(0.5), syn_projEE_ampa[5315], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5316: cell 66, seg 0 (0.5) [0.5 on Epop[66]] -> cell 36, seg 0 (0.5) [0.5 on Epop[36]], weight: 4.1363508E-4, delay 1.5
        h("Epop[36] syn_projEE_ampa[5316] = new ampa(0.5)")
        h("Epop[66] netConn_projEE_ampa[5316] = new NetCon(&v(0.5), syn_projEE_ampa[5316], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5317: cell 66, seg 0 (0.5) [0.5 on Epop[66]] -> cell 37, seg 0 (0.5) [0.5 on Epop[37]], weight: 4.1363508E-4, delay 1.5
        h("Epop[37] syn_projEE_ampa[5317] = new ampa(0.5)")
        h("Epop[66] netConn_projEE_ampa[5317] = new NetCon(&v(0.5), syn_projEE_ampa[5317], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5318: cell 66, seg 0 (0.5) [0.5 on Epop[66]] -> cell 38, seg 0 (0.5) [0.5 on Epop[38]], weight: 4.1363508E-4, delay 1.5
        h("Epop[38] syn_projEE_ampa[5318] = new ampa(0.5)")
        h("Epop[66] netConn_projEE_ampa[5318] = new NetCon(&v(0.5), syn_projEE_ampa[5318], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5319: cell 66, seg 0 (0.5) [0.5 on Epop[66]] -> cell 39, seg 0 (0.5) [0.5 on Epop[39]], weight: 4.1363508E-4, delay 1.5
        h("Epop[39] syn_projEE_ampa[5319] = new ampa(0.5)")
        h("Epop[66] netConn_projEE_ampa[5319] = new NetCon(&v(0.5), syn_projEE_ampa[5319], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5320: cell 66, seg 0 (0.5) [0.5 on Epop[66]] -> cell 40, seg 0 (0.5) [0.5 on Epop[40]], weight: 4.1363508E-4, delay 1.5
        h("Epop[40] syn_projEE_ampa[5320] = new ampa(0.5)")
        h("Epop[66] netConn_projEE_ampa[5320] = new NetCon(&v(0.5), syn_projEE_ampa[5320], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5321: cell 66, seg 0 (0.5) [0.5 on Epop[66]] -> cell 41, seg 0 (0.5) [0.5 on Epop[41]], weight: 4.1363508E-4, delay 1.5
        h("Epop[41] syn_projEE_ampa[5321] = new ampa(0.5)")
        h("Epop[66] netConn_projEE_ampa[5321] = new NetCon(&v(0.5), syn_projEE_ampa[5321], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5322: cell 66, seg 0 (0.5) [0.5 on Epop[66]] -> cell 42, seg 0 (0.5) [0.5 on Epop[42]], weight: 4.1363508E-4, delay 1.5
        h("Epop[42] syn_projEE_ampa[5322] = new ampa(0.5)")
        h("Epop[66] netConn_projEE_ampa[5322] = new NetCon(&v(0.5), syn_projEE_ampa[5322], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5323: cell 66, seg 0 (0.5) [0.5 on Epop[66]] -> cell 43, seg 0 (0.5) [0.5 on Epop[43]], weight: 4.1363508E-4, delay 1.5
        h("Epop[43] syn_projEE_ampa[5323] = new ampa(0.5)")
        h("Epop[66] netConn_projEE_ampa[5323] = new NetCon(&v(0.5), syn_projEE_ampa[5323], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5324: cell 66, seg 0 (0.5) [0.5 on Epop[66]] -> cell 44, seg 0 (0.5) [0.5 on Epop[44]], weight: 4.1363508E-4, delay 1.5
        h("Epop[44] syn_projEE_ampa[5324] = new ampa(0.5)")
        h("Epop[66] netConn_projEE_ampa[5324] = new NetCon(&v(0.5), syn_projEE_ampa[5324], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5325: cell 66, seg 0 (0.5) [0.5 on Epop[66]] -> cell 45, seg 0 (0.5) [0.5 on Epop[45]], weight: 4.1363508E-4, delay 1.5
        h("Epop[45] syn_projEE_ampa[5325] = new ampa(0.5)")
        h("Epop[66] netConn_projEE_ampa[5325] = new NetCon(&v(0.5), syn_projEE_ampa[5325], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5326: cell 66, seg 0 (0.5) [0.5 on Epop[66]] -> cell 46, seg 0 (0.5) [0.5 on Epop[46]], weight: 4.1363508E-4, delay 1.5
        h("Epop[46] syn_projEE_ampa[5326] = new ampa(0.5)")
        h("Epop[66] netConn_projEE_ampa[5326] = new NetCon(&v(0.5), syn_projEE_ampa[5326], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5327: cell 66, seg 0 (0.5) [0.5 on Epop[66]] -> cell 47, seg 0 (0.5) [0.5 on Epop[47]], weight: 4.1363508E-4, delay 1.5
        h("Epop[47] syn_projEE_ampa[5327] = new ampa(0.5)")
        h("Epop[66] netConn_projEE_ampa[5327] = new NetCon(&v(0.5), syn_projEE_ampa[5327], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5328: cell 66, seg 0 (0.5) [0.5 on Epop[66]] -> cell 48, seg 0 (0.5) [0.5 on Epop[48]], weight: 4.1363508E-4, delay 1.5
        h("Epop[48] syn_projEE_ampa[5328] = new ampa(0.5)")
        h("Epop[66] netConn_projEE_ampa[5328] = new NetCon(&v(0.5), syn_projEE_ampa[5328], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5329: cell 66, seg 0 (0.5) [0.5 on Epop[66]] -> cell 49, seg 0 (0.5) [0.5 on Epop[49]], weight: 4.1363508E-4, delay 1.5
        h("Epop[49] syn_projEE_ampa[5329] = new ampa(0.5)")
        h("Epop[66] netConn_projEE_ampa[5329] = new NetCon(&v(0.5), syn_projEE_ampa[5329], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5330: cell 66, seg 0 (0.5) [0.5 on Epop[66]] -> cell 50, seg 0 (0.5) [0.5 on Epop[50]], weight: 4.1363508E-4, delay 1.5
        h("Epop[50] syn_projEE_ampa[5330] = new ampa(0.5)")
        h("Epop[66] netConn_projEE_ampa[5330] = new NetCon(&v(0.5), syn_projEE_ampa[5330], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5331: cell 66, seg 0 (0.5) [0.5 on Epop[66]] -> cell 51, seg 0 (0.5) [0.5 on Epop[51]], weight: 4.1363508E-4, delay 1.5
        h("Epop[51] syn_projEE_ampa[5331] = new ampa(0.5)")
        h("Epop[66] netConn_projEE_ampa[5331] = new NetCon(&v(0.5), syn_projEE_ampa[5331], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5332: cell 66, seg 0 (0.5) [0.5 on Epop[66]] -> cell 52, seg 0 (0.5) [0.5 on Epop[52]], weight: 4.1363508E-4, delay 1.5
        h("Epop[52] syn_projEE_ampa[5332] = new ampa(0.5)")
        h("Epop[66] netConn_projEE_ampa[5332] = new NetCon(&v(0.5), syn_projEE_ampa[5332], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5333: cell 66, seg 0 (0.5) [0.5 on Epop[66]] -> cell 53, seg 0 (0.5) [0.5 on Epop[53]], weight: 4.1363508E-4, delay 1.5
        h("Epop[53] syn_projEE_ampa[5333] = new ampa(0.5)")
        h("Epop[66] netConn_projEE_ampa[5333] = new NetCon(&v(0.5), syn_projEE_ampa[5333], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5334: cell 66, seg 0 (0.5) [0.5 on Epop[66]] -> cell 54, seg 0 (0.5) [0.5 on Epop[54]], weight: 4.1363508E-4, delay 1.5
        h("Epop[54] syn_projEE_ampa[5334] = new ampa(0.5)")
        h("Epop[66] netConn_projEE_ampa[5334] = new NetCon(&v(0.5), syn_projEE_ampa[5334], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5335: cell 66, seg 0 (0.5) [0.5 on Epop[66]] -> cell 55, seg 0 (0.5) [0.5 on Epop[55]], weight: 4.1363508E-4, delay 1.5
        h("Epop[55] syn_projEE_ampa[5335] = new ampa(0.5)")
        h("Epop[66] netConn_projEE_ampa[5335] = new NetCon(&v(0.5), syn_projEE_ampa[5335], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5336: cell 66, seg 0 (0.5) [0.5 on Epop[66]] -> cell 56, seg 0 (0.5) [0.5 on Epop[56]], weight: 4.1363508E-4, delay 1.5
        h("Epop[56] syn_projEE_ampa[5336] = new ampa(0.5)")
        h("Epop[66] netConn_projEE_ampa[5336] = new NetCon(&v(0.5), syn_projEE_ampa[5336], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5337: cell 66, seg 0 (0.5) [0.5 on Epop[66]] -> cell 57, seg 0 (0.5) [0.5 on Epop[57]], weight: 4.1363508E-4, delay 1.5
        h("Epop[57] syn_projEE_ampa[5337] = new ampa(0.5)")
        h("Epop[66] netConn_projEE_ampa[5337] = new NetCon(&v(0.5), syn_projEE_ampa[5337], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5338: cell 66, seg 0 (0.5) [0.5 on Epop[66]] -> cell 58, seg 0 (0.5) [0.5 on Epop[58]], weight: 4.1363508E-4, delay 1.5
        h("Epop[58] syn_projEE_ampa[5338] = new ampa(0.5)")
        h("Epop[66] netConn_projEE_ampa[5338] = new NetCon(&v(0.5), syn_projEE_ampa[5338], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5339: cell 66, seg 0 (0.5) [0.5 on Epop[66]] -> cell 59, seg 0 (0.5) [0.5 on Epop[59]], weight: 4.1363508E-4, delay 1.5
        h("Epop[59] syn_projEE_ampa[5339] = new ampa(0.5)")
        h("Epop[66] netConn_projEE_ampa[5339] = new NetCon(&v(0.5), syn_projEE_ampa[5339], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5340: cell 66, seg 0 (0.5) [0.5 on Epop[66]] -> cell 60, seg 0 (0.5) [0.5 on Epop[60]], weight: 4.1363508E-4, delay 1.5
        h("Epop[60] syn_projEE_ampa[5340] = new ampa(0.5)")
        h("Epop[66] netConn_projEE_ampa[5340] = new NetCon(&v(0.5), syn_projEE_ampa[5340], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5341: cell 66, seg 0 (0.5) [0.5 on Epop[66]] -> cell 61, seg 0 (0.5) [0.5 on Epop[61]], weight: 4.1363508E-4, delay 1.5
        h("Epop[61] syn_projEE_ampa[5341] = new ampa(0.5)")
        h("Epop[66] netConn_projEE_ampa[5341] = new NetCon(&v(0.5), syn_projEE_ampa[5341], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5342: cell 66, seg 0 (0.5) [0.5 on Epop[66]] -> cell 62, seg 0 (0.5) [0.5 on Epop[62]], weight: 4.1363508E-4, delay 1.5
        h("Epop[62] syn_projEE_ampa[5342] = new ampa(0.5)")
        h("Epop[66] netConn_projEE_ampa[5342] = new NetCon(&v(0.5), syn_projEE_ampa[5342], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5343: cell 66, seg 0 (0.5) [0.5 on Epop[66]] -> cell 63, seg 0 (0.5) [0.5 on Epop[63]], weight: 4.1363508E-4, delay 1.5
        h("Epop[63] syn_projEE_ampa[5343] = new ampa(0.5)")
        h("Epop[66] netConn_projEE_ampa[5343] = new NetCon(&v(0.5), syn_projEE_ampa[5343], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5344: cell 66, seg 0 (0.5) [0.5 on Epop[66]] -> cell 64, seg 0 (0.5) [0.5 on Epop[64]], weight: 4.1363508E-4, delay 1.5
        h("Epop[64] syn_projEE_ampa[5344] = new ampa(0.5)")
        h("Epop[66] netConn_projEE_ampa[5344] = new NetCon(&v(0.5), syn_projEE_ampa[5344], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5345: cell 66, seg 0 (0.5) [0.5 on Epop[66]] -> cell 65, seg 0 (0.5) [0.5 on Epop[65]], weight: 4.1363508E-4, delay 1.5
        h("Epop[65] syn_projEE_ampa[5345] = new ampa(0.5)")
        h("Epop[66] netConn_projEE_ampa[5345] = new NetCon(&v(0.5), syn_projEE_ampa[5345], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5346: cell 66, seg 0 (0.5) [0.5 on Epop[66]] -> cell 66, seg 0 (0.5) [0.5 on Epop[66]], weight: 4.1363508E-4, delay 1.5
        h("Epop[66] syn_projEE_ampa[5346] = new ampa(0.5)")
        h("Epop[66] netConn_projEE_ampa[5346] = new NetCon(&v(0.5), syn_projEE_ampa[5346], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5347: cell 66, seg 0 (0.5) [0.5 on Epop[66]] -> cell 67, seg 0 (0.5) [0.5 on Epop[67]], weight: 4.1363508E-4, delay 1.5
        h("Epop[67] syn_projEE_ampa[5347] = new ampa(0.5)")
        h("Epop[66] netConn_projEE_ampa[5347] = new NetCon(&v(0.5), syn_projEE_ampa[5347], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5348: cell 66, seg 0 (0.5) [0.5 on Epop[66]] -> cell 68, seg 0 (0.5) [0.5 on Epop[68]], weight: 4.1363508E-4, delay 1.5
        h("Epop[68] syn_projEE_ampa[5348] = new ampa(0.5)")
        h("Epop[66] netConn_projEE_ampa[5348] = new NetCon(&v(0.5), syn_projEE_ampa[5348], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5349: cell 66, seg 0 (0.5) [0.5 on Epop[66]] -> cell 69, seg 0 (0.5) [0.5 on Epop[69]], weight: 4.1363508E-4, delay 1.5
        h("Epop[69] syn_projEE_ampa[5349] = new ampa(0.5)")
        h("Epop[66] netConn_projEE_ampa[5349] = new NetCon(&v(0.5), syn_projEE_ampa[5349], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5350: cell 66, seg 0 (0.5) [0.5 on Epop[66]] -> cell 70, seg 0 (0.5) [0.5 on Epop[70]], weight: 4.1363508E-4, delay 1.5
        h("Epop[70] syn_projEE_ampa[5350] = new ampa(0.5)")
        h("Epop[66] netConn_projEE_ampa[5350] = new NetCon(&v(0.5), syn_projEE_ampa[5350], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5351: cell 66, seg 0 (0.5) [0.5 on Epop[66]] -> cell 71, seg 0 (0.5) [0.5 on Epop[71]], weight: 4.1363508E-4, delay 1.5
        h("Epop[71] syn_projEE_ampa[5351] = new ampa(0.5)")
        h("Epop[66] netConn_projEE_ampa[5351] = new NetCon(&v(0.5), syn_projEE_ampa[5351], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5352: cell 66, seg 0 (0.5) [0.5 on Epop[66]] -> cell 72, seg 0 (0.5) [0.5 on Epop[72]], weight: 4.1363508E-4, delay 1.5
        h("Epop[72] syn_projEE_ampa[5352] = new ampa(0.5)")
        h("Epop[66] netConn_projEE_ampa[5352] = new NetCon(&v(0.5), syn_projEE_ampa[5352], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5353: cell 66, seg 0 (0.5) [0.5 on Epop[66]] -> cell 73, seg 0 (0.5) [0.5 on Epop[73]], weight: 4.1363508E-4, delay 1.5
        h("Epop[73] syn_projEE_ampa[5353] = new ampa(0.5)")
        h("Epop[66] netConn_projEE_ampa[5353] = new NetCon(&v(0.5), syn_projEE_ampa[5353], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5354: cell 66, seg 0 (0.5) [0.5 on Epop[66]] -> cell 74, seg 0 (0.5) [0.5 on Epop[74]], weight: 4.1363508E-4, delay 1.5
        h("Epop[74] syn_projEE_ampa[5354] = new ampa(0.5)")
        h("Epop[66] netConn_projEE_ampa[5354] = new NetCon(&v(0.5), syn_projEE_ampa[5354], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5355: cell 66, seg 0 (0.5) [0.5 on Epop[66]] -> cell 75, seg 0 (0.5) [0.5 on Epop[75]], weight: 4.1363508E-4, delay 1.5
        h("Epop[75] syn_projEE_ampa[5355] = new ampa(0.5)")
        h("Epop[66] netConn_projEE_ampa[5355] = new NetCon(&v(0.5), syn_projEE_ampa[5355], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5356: cell 66, seg 0 (0.5) [0.5 on Epop[66]] -> cell 76, seg 0 (0.5) [0.5 on Epop[76]], weight: 4.1363508E-4, delay 1.5
        h("Epop[76] syn_projEE_ampa[5356] = new ampa(0.5)")
        h("Epop[66] netConn_projEE_ampa[5356] = new NetCon(&v(0.5), syn_projEE_ampa[5356], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5357: cell 66, seg 0 (0.5) [0.5 on Epop[66]] -> cell 77, seg 0 (0.5) [0.5 on Epop[77]], weight: 4.1363508E-4, delay 1.5
        h("Epop[77] syn_projEE_ampa[5357] = new ampa(0.5)")
        h("Epop[66] netConn_projEE_ampa[5357] = new NetCon(&v(0.5), syn_projEE_ampa[5357], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5358: cell 66, seg 0 (0.5) [0.5 on Epop[66]] -> cell 78, seg 0 (0.5) [0.5 on Epop[78]], weight: 4.1363508E-4, delay 1.5
        h("Epop[78] syn_projEE_ampa[5358] = new ampa(0.5)")
        h("Epop[66] netConn_projEE_ampa[5358] = new NetCon(&v(0.5), syn_projEE_ampa[5358], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5359: cell 66, seg 0 (0.5) [0.5 on Epop[66]] -> cell 79, seg 0 (0.5) [0.5 on Epop[79]], weight: 4.1363508E-4, delay 1.5
        h("Epop[79] syn_projEE_ampa[5359] = new ampa(0.5)")
        h("Epop[66] netConn_projEE_ampa[5359] = new NetCon(&v(0.5), syn_projEE_ampa[5359], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5360: cell 67, seg 0 (0.5) [0.5 on Epop[67]] -> cell 0, seg 0 (0.5) [0.5 on Epop[0]], weight: 4.1363508E-4, delay 1.5
        h("Epop[0] syn_projEE_ampa[5360] = new ampa(0.5)")
        h("Epop[67] netConn_projEE_ampa[5360] = new NetCon(&v(0.5), syn_projEE_ampa[5360], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5361: cell 67, seg 0 (0.5) [0.5 on Epop[67]] -> cell 1, seg 0 (0.5) [0.5 on Epop[1]], weight: 4.1363508E-4, delay 1.5
        h("Epop[1] syn_projEE_ampa[5361] = new ampa(0.5)")
        h("Epop[67] netConn_projEE_ampa[5361] = new NetCon(&v(0.5), syn_projEE_ampa[5361], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5362: cell 67, seg 0 (0.5) [0.5 on Epop[67]] -> cell 2, seg 0 (0.5) [0.5 on Epop[2]], weight: 4.1363508E-4, delay 1.5
        h("Epop[2] syn_projEE_ampa[5362] = new ampa(0.5)")
        h("Epop[67] netConn_projEE_ampa[5362] = new NetCon(&v(0.5), syn_projEE_ampa[5362], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5363: cell 67, seg 0 (0.5) [0.5 on Epop[67]] -> cell 3, seg 0 (0.5) [0.5 on Epop[3]], weight: 4.1363508E-4, delay 1.5
        h("Epop[3] syn_projEE_ampa[5363] = new ampa(0.5)")
        h("Epop[67] netConn_projEE_ampa[5363] = new NetCon(&v(0.5), syn_projEE_ampa[5363], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5364: cell 67, seg 0 (0.5) [0.5 on Epop[67]] -> cell 4, seg 0 (0.5) [0.5 on Epop[4]], weight: 4.1363508E-4, delay 1.5
        h("Epop[4] syn_projEE_ampa[5364] = new ampa(0.5)")
        h("Epop[67] netConn_projEE_ampa[5364] = new NetCon(&v(0.5), syn_projEE_ampa[5364], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5365: cell 67, seg 0 (0.5) [0.5 on Epop[67]] -> cell 5, seg 0 (0.5) [0.5 on Epop[5]], weight: 4.1363508E-4, delay 1.5
        h("Epop[5] syn_projEE_ampa[5365] = new ampa(0.5)")
        h("Epop[67] netConn_projEE_ampa[5365] = new NetCon(&v(0.5), syn_projEE_ampa[5365], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5366: cell 67, seg 0 (0.5) [0.5 on Epop[67]] -> cell 6, seg 0 (0.5) [0.5 on Epop[6]], weight: 4.1363508E-4, delay 1.5
        h("Epop[6] syn_projEE_ampa[5366] = new ampa(0.5)")
        h("Epop[67] netConn_projEE_ampa[5366] = new NetCon(&v(0.5), syn_projEE_ampa[5366], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5367: cell 67, seg 0 (0.5) [0.5 on Epop[67]] -> cell 7, seg 0 (0.5) [0.5 on Epop[7]], weight: 4.1363508E-4, delay 1.5
        h("Epop[7] syn_projEE_ampa[5367] = new ampa(0.5)")
        h("Epop[67] netConn_projEE_ampa[5367] = new NetCon(&v(0.5), syn_projEE_ampa[5367], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5368: cell 67, seg 0 (0.5) [0.5 on Epop[67]] -> cell 8, seg 0 (0.5) [0.5 on Epop[8]], weight: 4.1363508E-4, delay 1.5
        h("Epop[8] syn_projEE_ampa[5368] = new ampa(0.5)")
        h("Epop[67] netConn_projEE_ampa[5368] = new NetCon(&v(0.5), syn_projEE_ampa[5368], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5369: cell 67, seg 0 (0.5) [0.5 on Epop[67]] -> cell 9, seg 0 (0.5) [0.5 on Epop[9]], weight: 4.1363508E-4, delay 1.5
        h("Epop[9] syn_projEE_ampa[5369] = new ampa(0.5)")
        h("Epop[67] netConn_projEE_ampa[5369] = new NetCon(&v(0.5), syn_projEE_ampa[5369], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5370: cell 67, seg 0 (0.5) [0.5 on Epop[67]] -> cell 10, seg 0 (0.5) [0.5 on Epop[10]], weight: 4.1363508E-4, delay 1.5
        h("Epop[10] syn_projEE_ampa[5370] = new ampa(0.5)")
        h("Epop[67] netConn_projEE_ampa[5370] = new NetCon(&v(0.5), syn_projEE_ampa[5370], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5371: cell 67, seg 0 (0.5) [0.5 on Epop[67]] -> cell 11, seg 0 (0.5) [0.5 on Epop[11]], weight: 4.1363508E-4, delay 1.5
        h("Epop[11] syn_projEE_ampa[5371] = new ampa(0.5)")
        h("Epop[67] netConn_projEE_ampa[5371] = new NetCon(&v(0.5), syn_projEE_ampa[5371], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5372: cell 67, seg 0 (0.5) [0.5 on Epop[67]] -> cell 12, seg 0 (0.5) [0.5 on Epop[12]], weight: 4.1363508E-4, delay 1.5
        h("Epop[12] syn_projEE_ampa[5372] = new ampa(0.5)")
        h("Epop[67] netConn_projEE_ampa[5372] = new NetCon(&v(0.5), syn_projEE_ampa[5372], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5373: cell 67, seg 0 (0.5) [0.5 on Epop[67]] -> cell 13, seg 0 (0.5) [0.5 on Epop[13]], weight: 4.1363508E-4, delay 1.5
        h("Epop[13] syn_projEE_ampa[5373] = new ampa(0.5)")
        h("Epop[67] netConn_projEE_ampa[5373] = new NetCon(&v(0.5), syn_projEE_ampa[5373], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5374: cell 67, seg 0 (0.5) [0.5 on Epop[67]] -> cell 14, seg 0 (0.5) [0.5 on Epop[14]], weight: 4.1363508E-4, delay 1.5
        h("Epop[14] syn_projEE_ampa[5374] = new ampa(0.5)")
        h("Epop[67] netConn_projEE_ampa[5374] = new NetCon(&v(0.5), syn_projEE_ampa[5374], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5375: cell 67, seg 0 (0.5) [0.5 on Epop[67]] -> cell 15, seg 0 (0.5) [0.5 on Epop[15]], weight: 4.1363508E-4, delay 1.5
        h("Epop[15] syn_projEE_ampa[5375] = new ampa(0.5)")
        h("Epop[67] netConn_projEE_ampa[5375] = new NetCon(&v(0.5), syn_projEE_ampa[5375], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5376: cell 67, seg 0 (0.5) [0.5 on Epop[67]] -> cell 16, seg 0 (0.5) [0.5 on Epop[16]], weight: 4.1363508E-4, delay 1.5
        h("Epop[16] syn_projEE_ampa[5376] = new ampa(0.5)")
        h("Epop[67] netConn_projEE_ampa[5376] = new NetCon(&v(0.5), syn_projEE_ampa[5376], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5377: cell 67, seg 0 (0.5) [0.5 on Epop[67]] -> cell 17, seg 0 (0.5) [0.5 on Epop[17]], weight: 4.1363508E-4, delay 1.5
        h("Epop[17] syn_projEE_ampa[5377] = new ampa(0.5)")
        h("Epop[67] netConn_projEE_ampa[5377] = new NetCon(&v(0.5), syn_projEE_ampa[5377], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5378: cell 67, seg 0 (0.5) [0.5 on Epop[67]] -> cell 18, seg 0 (0.5) [0.5 on Epop[18]], weight: 4.1363508E-4, delay 1.5
        h("Epop[18] syn_projEE_ampa[5378] = new ampa(0.5)")
        h("Epop[67] netConn_projEE_ampa[5378] = new NetCon(&v(0.5), syn_projEE_ampa[5378], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5379: cell 67, seg 0 (0.5) [0.5 on Epop[67]] -> cell 19, seg 0 (0.5) [0.5 on Epop[19]], weight: 4.1363508E-4, delay 1.5
        h("Epop[19] syn_projEE_ampa[5379] = new ampa(0.5)")
        h("Epop[67] netConn_projEE_ampa[5379] = new NetCon(&v(0.5), syn_projEE_ampa[5379], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5380: cell 67, seg 0 (0.5) [0.5 on Epop[67]] -> cell 20, seg 0 (0.5) [0.5 on Epop[20]], weight: 4.1363508E-4, delay 1.5
        h("Epop[20] syn_projEE_ampa[5380] = new ampa(0.5)")
        h("Epop[67] netConn_projEE_ampa[5380] = new NetCon(&v(0.5), syn_projEE_ampa[5380], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5381: cell 67, seg 0 (0.5) [0.5 on Epop[67]] -> cell 21, seg 0 (0.5) [0.5 on Epop[21]], weight: 4.1363508E-4, delay 1.5
        h("Epop[21] syn_projEE_ampa[5381] = new ampa(0.5)")
        h("Epop[67] netConn_projEE_ampa[5381] = new NetCon(&v(0.5), syn_projEE_ampa[5381], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5382: cell 67, seg 0 (0.5) [0.5 on Epop[67]] -> cell 22, seg 0 (0.5) [0.5 on Epop[22]], weight: 4.1363508E-4, delay 1.5
        h("Epop[22] syn_projEE_ampa[5382] = new ampa(0.5)")
        h("Epop[67] netConn_projEE_ampa[5382] = new NetCon(&v(0.5), syn_projEE_ampa[5382], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5383: cell 67, seg 0 (0.5) [0.5 on Epop[67]] -> cell 23, seg 0 (0.5) [0.5 on Epop[23]], weight: 4.1363508E-4, delay 1.5
        h("Epop[23] syn_projEE_ampa[5383] = new ampa(0.5)")
        h("Epop[67] netConn_projEE_ampa[5383] = new NetCon(&v(0.5), syn_projEE_ampa[5383], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5384: cell 67, seg 0 (0.5) [0.5 on Epop[67]] -> cell 24, seg 0 (0.5) [0.5 on Epop[24]], weight: 4.1363508E-4, delay 1.5
        h("Epop[24] syn_projEE_ampa[5384] = new ampa(0.5)")
        h("Epop[67] netConn_projEE_ampa[5384] = new NetCon(&v(0.5), syn_projEE_ampa[5384], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5385: cell 67, seg 0 (0.5) [0.5 on Epop[67]] -> cell 25, seg 0 (0.5) [0.5 on Epop[25]], weight: 4.1363508E-4, delay 1.5
        h("Epop[25] syn_projEE_ampa[5385] = new ampa(0.5)")
        h("Epop[67] netConn_projEE_ampa[5385] = new NetCon(&v(0.5), syn_projEE_ampa[5385], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5386: cell 67, seg 0 (0.5) [0.5 on Epop[67]] -> cell 26, seg 0 (0.5) [0.5 on Epop[26]], weight: 4.1363508E-4, delay 1.5
        h("Epop[26] syn_projEE_ampa[5386] = new ampa(0.5)")
        h("Epop[67] netConn_projEE_ampa[5386] = new NetCon(&v(0.5), syn_projEE_ampa[5386], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5387: cell 67, seg 0 (0.5) [0.5 on Epop[67]] -> cell 27, seg 0 (0.5) [0.5 on Epop[27]], weight: 4.1363508E-4, delay 1.5
        h("Epop[27] syn_projEE_ampa[5387] = new ampa(0.5)")
        h("Epop[67] netConn_projEE_ampa[5387] = new NetCon(&v(0.5), syn_projEE_ampa[5387], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5388: cell 67, seg 0 (0.5) [0.5 on Epop[67]] -> cell 28, seg 0 (0.5) [0.5 on Epop[28]], weight: 4.1363508E-4, delay 1.5
        h("Epop[28] syn_projEE_ampa[5388] = new ampa(0.5)")
        h("Epop[67] netConn_projEE_ampa[5388] = new NetCon(&v(0.5), syn_projEE_ampa[5388], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5389: cell 67, seg 0 (0.5) [0.5 on Epop[67]] -> cell 29, seg 0 (0.5) [0.5 on Epop[29]], weight: 4.1363508E-4, delay 1.5
        h("Epop[29] syn_projEE_ampa[5389] = new ampa(0.5)")
        h("Epop[67] netConn_projEE_ampa[5389] = new NetCon(&v(0.5), syn_projEE_ampa[5389], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5390: cell 67, seg 0 (0.5) [0.5 on Epop[67]] -> cell 30, seg 0 (0.5) [0.5 on Epop[30]], weight: 4.1363508E-4, delay 1.5
        h("Epop[30] syn_projEE_ampa[5390] = new ampa(0.5)")
        h("Epop[67] netConn_projEE_ampa[5390] = new NetCon(&v(0.5), syn_projEE_ampa[5390], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5391: cell 67, seg 0 (0.5) [0.5 on Epop[67]] -> cell 31, seg 0 (0.5) [0.5 on Epop[31]], weight: 4.1363508E-4, delay 1.5
        h("Epop[31] syn_projEE_ampa[5391] = new ampa(0.5)")
        h("Epop[67] netConn_projEE_ampa[5391] = new NetCon(&v(0.5), syn_projEE_ampa[5391], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5392: cell 67, seg 0 (0.5) [0.5 on Epop[67]] -> cell 32, seg 0 (0.5) [0.5 on Epop[32]], weight: 4.1363508E-4, delay 1.5
        h("Epop[32] syn_projEE_ampa[5392] = new ampa(0.5)")
        h("Epop[67] netConn_projEE_ampa[5392] = new NetCon(&v(0.5), syn_projEE_ampa[5392], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5393: cell 67, seg 0 (0.5) [0.5 on Epop[67]] -> cell 33, seg 0 (0.5) [0.5 on Epop[33]], weight: 4.1363508E-4, delay 1.5
        h("Epop[33] syn_projEE_ampa[5393] = new ampa(0.5)")
        h("Epop[67] netConn_projEE_ampa[5393] = new NetCon(&v(0.5), syn_projEE_ampa[5393], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5394: cell 67, seg 0 (0.5) [0.5 on Epop[67]] -> cell 34, seg 0 (0.5) [0.5 on Epop[34]], weight: 4.1363508E-4, delay 1.5
        h("Epop[34] syn_projEE_ampa[5394] = new ampa(0.5)")
        h("Epop[67] netConn_projEE_ampa[5394] = new NetCon(&v(0.5), syn_projEE_ampa[5394], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5395: cell 67, seg 0 (0.5) [0.5 on Epop[67]] -> cell 35, seg 0 (0.5) [0.5 on Epop[35]], weight: 4.1363508E-4, delay 1.5
        h("Epop[35] syn_projEE_ampa[5395] = new ampa(0.5)")
        h("Epop[67] netConn_projEE_ampa[5395] = new NetCon(&v(0.5), syn_projEE_ampa[5395], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5396: cell 67, seg 0 (0.5) [0.5 on Epop[67]] -> cell 36, seg 0 (0.5) [0.5 on Epop[36]], weight: 4.1363508E-4, delay 1.5
        h("Epop[36] syn_projEE_ampa[5396] = new ampa(0.5)")
        h("Epop[67] netConn_projEE_ampa[5396] = new NetCon(&v(0.5), syn_projEE_ampa[5396], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5397: cell 67, seg 0 (0.5) [0.5 on Epop[67]] -> cell 37, seg 0 (0.5) [0.5 on Epop[37]], weight: 4.1363508E-4, delay 1.5
        h("Epop[37] syn_projEE_ampa[5397] = new ampa(0.5)")
        h("Epop[67] netConn_projEE_ampa[5397] = new NetCon(&v(0.5), syn_projEE_ampa[5397], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5398: cell 67, seg 0 (0.5) [0.5 on Epop[67]] -> cell 38, seg 0 (0.5) [0.5 on Epop[38]], weight: 4.1363508E-4, delay 1.5
        h("Epop[38] syn_projEE_ampa[5398] = new ampa(0.5)")
        h("Epop[67] netConn_projEE_ampa[5398] = new NetCon(&v(0.5), syn_projEE_ampa[5398], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5399: cell 67, seg 0 (0.5) [0.5 on Epop[67]] -> cell 39, seg 0 (0.5) [0.5 on Epop[39]], weight: 4.1363508E-4, delay 1.5
        h("Epop[39] syn_projEE_ampa[5399] = new ampa(0.5)")
        h("Epop[67] netConn_projEE_ampa[5399] = new NetCon(&v(0.5), syn_projEE_ampa[5399], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5400: cell 67, seg 0 (0.5) [0.5 on Epop[67]] -> cell 40, seg 0 (0.5) [0.5 on Epop[40]], weight: 4.1363508E-4, delay 1.5
        h("Epop[40] syn_projEE_ampa[5400] = new ampa(0.5)")
        h("Epop[67] netConn_projEE_ampa[5400] = new NetCon(&v(0.5), syn_projEE_ampa[5400], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5401: cell 67, seg 0 (0.5) [0.5 on Epop[67]] -> cell 41, seg 0 (0.5) [0.5 on Epop[41]], weight: 4.1363508E-4, delay 1.5
        h("Epop[41] syn_projEE_ampa[5401] = new ampa(0.5)")
        h("Epop[67] netConn_projEE_ampa[5401] = new NetCon(&v(0.5), syn_projEE_ampa[5401], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5402: cell 67, seg 0 (0.5) [0.5 on Epop[67]] -> cell 42, seg 0 (0.5) [0.5 on Epop[42]], weight: 4.1363508E-4, delay 1.5
        h("Epop[42] syn_projEE_ampa[5402] = new ampa(0.5)")
        h("Epop[67] netConn_projEE_ampa[5402] = new NetCon(&v(0.5), syn_projEE_ampa[5402], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5403: cell 67, seg 0 (0.5) [0.5 on Epop[67]] -> cell 43, seg 0 (0.5) [0.5 on Epop[43]], weight: 4.1363508E-4, delay 1.5
        h("Epop[43] syn_projEE_ampa[5403] = new ampa(0.5)")
        h("Epop[67] netConn_projEE_ampa[5403] = new NetCon(&v(0.5), syn_projEE_ampa[5403], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5404: cell 67, seg 0 (0.5) [0.5 on Epop[67]] -> cell 44, seg 0 (0.5) [0.5 on Epop[44]], weight: 4.1363508E-4, delay 1.5
        h("Epop[44] syn_projEE_ampa[5404] = new ampa(0.5)")
        h("Epop[67] netConn_projEE_ampa[5404] = new NetCon(&v(0.5), syn_projEE_ampa[5404], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5405: cell 67, seg 0 (0.5) [0.5 on Epop[67]] -> cell 45, seg 0 (0.5) [0.5 on Epop[45]], weight: 4.1363508E-4, delay 1.5
        h("Epop[45] syn_projEE_ampa[5405] = new ampa(0.5)")
        h("Epop[67] netConn_projEE_ampa[5405] = new NetCon(&v(0.5), syn_projEE_ampa[5405], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5406: cell 67, seg 0 (0.5) [0.5 on Epop[67]] -> cell 46, seg 0 (0.5) [0.5 on Epop[46]], weight: 4.1363508E-4, delay 1.5
        h("Epop[46] syn_projEE_ampa[5406] = new ampa(0.5)")
        h("Epop[67] netConn_projEE_ampa[5406] = new NetCon(&v(0.5), syn_projEE_ampa[5406], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5407: cell 67, seg 0 (0.5) [0.5 on Epop[67]] -> cell 47, seg 0 (0.5) [0.5 on Epop[47]], weight: 4.1363508E-4, delay 1.5
        h("Epop[47] syn_projEE_ampa[5407] = new ampa(0.5)")
        h("Epop[67] netConn_projEE_ampa[5407] = new NetCon(&v(0.5), syn_projEE_ampa[5407], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5408: cell 67, seg 0 (0.5) [0.5 on Epop[67]] -> cell 48, seg 0 (0.5) [0.5 on Epop[48]], weight: 4.1363508E-4, delay 1.5
        h("Epop[48] syn_projEE_ampa[5408] = new ampa(0.5)")
        h("Epop[67] netConn_projEE_ampa[5408] = new NetCon(&v(0.5), syn_projEE_ampa[5408], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5409: cell 67, seg 0 (0.5) [0.5 on Epop[67]] -> cell 49, seg 0 (0.5) [0.5 on Epop[49]], weight: 4.1363508E-4, delay 1.5
        h("Epop[49] syn_projEE_ampa[5409] = new ampa(0.5)")
        h("Epop[67] netConn_projEE_ampa[5409] = new NetCon(&v(0.5), syn_projEE_ampa[5409], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5410: cell 67, seg 0 (0.5) [0.5 on Epop[67]] -> cell 50, seg 0 (0.5) [0.5 on Epop[50]], weight: 4.1363508E-4, delay 1.5
        h("Epop[50] syn_projEE_ampa[5410] = new ampa(0.5)")
        h("Epop[67] netConn_projEE_ampa[5410] = new NetCon(&v(0.5), syn_projEE_ampa[5410], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5411: cell 67, seg 0 (0.5) [0.5 on Epop[67]] -> cell 51, seg 0 (0.5) [0.5 on Epop[51]], weight: 4.1363508E-4, delay 1.5
        h("Epop[51] syn_projEE_ampa[5411] = new ampa(0.5)")
        h("Epop[67] netConn_projEE_ampa[5411] = new NetCon(&v(0.5), syn_projEE_ampa[5411], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5412: cell 67, seg 0 (0.5) [0.5 on Epop[67]] -> cell 52, seg 0 (0.5) [0.5 on Epop[52]], weight: 4.1363508E-4, delay 1.5
        h("Epop[52] syn_projEE_ampa[5412] = new ampa(0.5)")
        h("Epop[67] netConn_projEE_ampa[5412] = new NetCon(&v(0.5), syn_projEE_ampa[5412], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5413: cell 67, seg 0 (0.5) [0.5 on Epop[67]] -> cell 53, seg 0 (0.5) [0.5 on Epop[53]], weight: 4.1363508E-4, delay 1.5
        h("Epop[53] syn_projEE_ampa[5413] = new ampa(0.5)")
        h("Epop[67] netConn_projEE_ampa[5413] = new NetCon(&v(0.5), syn_projEE_ampa[5413], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5414: cell 67, seg 0 (0.5) [0.5 on Epop[67]] -> cell 54, seg 0 (0.5) [0.5 on Epop[54]], weight: 4.1363508E-4, delay 1.5
        h("Epop[54] syn_projEE_ampa[5414] = new ampa(0.5)")
        h("Epop[67] netConn_projEE_ampa[5414] = new NetCon(&v(0.5), syn_projEE_ampa[5414], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5415: cell 67, seg 0 (0.5) [0.5 on Epop[67]] -> cell 55, seg 0 (0.5) [0.5 on Epop[55]], weight: 4.1363508E-4, delay 1.5
        h("Epop[55] syn_projEE_ampa[5415] = new ampa(0.5)")
        h("Epop[67] netConn_projEE_ampa[5415] = new NetCon(&v(0.5), syn_projEE_ampa[5415], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5416: cell 67, seg 0 (0.5) [0.5 on Epop[67]] -> cell 56, seg 0 (0.5) [0.5 on Epop[56]], weight: 4.1363508E-4, delay 1.5
        h("Epop[56] syn_projEE_ampa[5416] = new ampa(0.5)")
        h("Epop[67] netConn_projEE_ampa[5416] = new NetCon(&v(0.5), syn_projEE_ampa[5416], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5417: cell 67, seg 0 (0.5) [0.5 on Epop[67]] -> cell 57, seg 0 (0.5) [0.5 on Epop[57]], weight: 4.1363508E-4, delay 1.5
        h("Epop[57] syn_projEE_ampa[5417] = new ampa(0.5)")
        h("Epop[67] netConn_projEE_ampa[5417] = new NetCon(&v(0.5), syn_projEE_ampa[5417], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5418: cell 67, seg 0 (0.5) [0.5 on Epop[67]] -> cell 58, seg 0 (0.5) [0.5 on Epop[58]], weight: 4.1363508E-4, delay 1.5
        h("Epop[58] syn_projEE_ampa[5418] = new ampa(0.5)")
        h("Epop[67] netConn_projEE_ampa[5418] = new NetCon(&v(0.5), syn_projEE_ampa[5418], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5419: cell 67, seg 0 (0.5) [0.5 on Epop[67]] -> cell 59, seg 0 (0.5) [0.5 on Epop[59]], weight: 4.1363508E-4, delay 1.5
        h("Epop[59] syn_projEE_ampa[5419] = new ampa(0.5)")
        h("Epop[67] netConn_projEE_ampa[5419] = new NetCon(&v(0.5), syn_projEE_ampa[5419], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5420: cell 67, seg 0 (0.5) [0.5 on Epop[67]] -> cell 60, seg 0 (0.5) [0.5 on Epop[60]], weight: 4.1363508E-4, delay 1.5
        h("Epop[60] syn_projEE_ampa[5420] = new ampa(0.5)")
        h("Epop[67] netConn_projEE_ampa[5420] = new NetCon(&v(0.5), syn_projEE_ampa[5420], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5421: cell 67, seg 0 (0.5) [0.5 on Epop[67]] -> cell 61, seg 0 (0.5) [0.5 on Epop[61]], weight: 4.1363508E-4, delay 1.5
        h("Epop[61] syn_projEE_ampa[5421] = new ampa(0.5)")
        h("Epop[67] netConn_projEE_ampa[5421] = new NetCon(&v(0.5), syn_projEE_ampa[5421], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5422: cell 67, seg 0 (0.5) [0.5 on Epop[67]] -> cell 62, seg 0 (0.5) [0.5 on Epop[62]], weight: 4.1363508E-4, delay 1.5
        h("Epop[62] syn_projEE_ampa[5422] = new ampa(0.5)")
        h("Epop[67] netConn_projEE_ampa[5422] = new NetCon(&v(0.5), syn_projEE_ampa[5422], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5423: cell 67, seg 0 (0.5) [0.5 on Epop[67]] -> cell 63, seg 0 (0.5) [0.5 on Epop[63]], weight: 4.1363508E-4, delay 1.5
        h("Epop[63] syn_projEE_ampa[5423] = new ampa(0.5)")
        h("Epop[67] netConn_projEE_ampa[5423] = new NetCon(&v(0.5), syn_projEE_ampa[5423], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5424: cell 67, seg 0 (0.5) [0.5 on Epop[67]] -> cell 64, seg 0 (0.5) [0.5 on Epop[64]], weight: 4.1363508E-4, delay 1.5
        h("Epop[64] syn_projEE_ampa[5424] = new ampa(0.5)")
        h("Epop[67] netConn_projEE_ampa[5424] = new NetCon(&v(0.5), syn_projEE_ampa[5424], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5425: cell 67, seg 0 (0.5) [0.5 on Epop[67]] -> cell 65, seg 0 (0.5) [0.5 on Epop[65]], weight: 4.1363508E-4, delay 1.5
        h("Epop[65] syn_projEE_ampa[5425] = new ampa(0.5)")
        h("Epop[67] netConn_projEE_ampa[5425] = new NetCon(&v(0.5), syn_projEE_ampa[5425], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5426: cell 67, seg 0 (0.5) [0.5 on Epop[67]] -> cell 66, seg 0 (0.5) [0.5 on Epop[66]], weight: 4.1363508E-4, delay 1.5
        h("Epop[66] syn_projEE_ampa[5426] = new ampa(0.5)")
        h("Epop[67] netConn_projEE_ampa[5426] = new NetCon(&v(0.5), syn_projEE_ampa[5426], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5427: cell 67, seg 0 (0.5) [0.5 on Epop[67]] -> cell 67, seg 0 (0.5) [0.5 on Epop[67]], weight: 4.1363508E-4, delay 1.5
        h("Epop[67] syn_projEE_ampa[5427] = new ampa(0.5)")
        h("Epop[67] netConn_projEE_ampa[5427] = new NetCon(&v(0.5), syn_projEE_ampa[5427], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5428: cell 67, seg 0 (0.5) [0.5 on Epop[67]] -> cell 68, seg 0 (0.5) [0.5 on Epop[68]], weight: 4.1363508E-4, delay 1.5
        h("Epop[68] syn_projEE_ampa[5428] = new ampa(0.5)")
        h("Epop[67] netConn_projEE_ampa[5428] = new NetCon(&v(0.5), syn_projEE_ampa[5428], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5429: cell 67, seg 0 (0.5) [0.5 on Epop[67]] -> cell 69, seg 0 (0.5) [0.5 on Epop[69]], weight: 4.1363508E-4, delay 1.5
        h("Epop[69] syn_projEE_ampa[5429] = new ampa(0.5)")
        h("Epop[67] netConn_projEE_ampa[5429] = new NetCon(&v(0.5), syn_projEE_ampa[5429], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5430: cell 67, seg 0 (0.5) [0.5 on Epop[67]] -> cell 70, seg 0 (0.5) [0.5 on Epop[70]], weight: 4.1363508E-4, delay 1.5
        h("Epop[70] syn_projEE_ampa[5430] = new ampa(0.5)")
        h("Epop[67] netConn_projEE_ampa[5430] = new NetCon(&v(0.5), syn_projEE_ampa[5430], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5431: cell 67, seg 0 (0.5) [0.5 on Epop[67]] -> cell 71, seg 0 (0.5) [0.5 on Epop[71]], weight: 4.1363508E-4, delay 1.5
        h("Epop[71] syn_projEE_ampa[5431] = new ampa(0.5)")
        h("Epop[67] netConn_projEE_ampa[5431] = new NetCon(&v(0.5), syn_projEE_ampa[5431], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5432: cell 67, seg 0 (0.5) [0.5 on Epop[67]] -> cell 72, seg 0 (0.5) [0.5 on Epop[72]], weight: 4.1363508E-4, delay 1.5
        h("Epop[72] syn_projEE_ampa[5432] = new ampa(0.5)")
        h("Epop[67] netConn_projEE_ampa[5432] = new NetCon(&v(0.5), syn_projEE_ampa[5432], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5433: cell 67, seg 0 (0.5) [0.5 on Epop[67]] -> cell 73, seg 0 (0.5) [0.5 on Epop[73]], weight: 4.1363508E-4, delay 1.5
        h("Epop[73] syn_projEE_ampa[5433] = new ampa(0.5)")
        h("Epop[67] netConn_projEE_ampa[5433] = new NetCon(&v(0.5), syn_projEE_ampa[5433], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5434: cell 67, seg 0 (0.5) [0.5 on Epop[67]] -> cell 74, seg 0 (0.5) [0.5 on Epop[74]], weight: 4.1363508E-4, delay 1.5
        h("Epop[74] syn_projEE_ampa[5434] = new ampa(0.5)")
        h("Epop[67] netConn_projEE_ampa[5434] = new NetCon(&v(0.5), syn_projEE_ampa[5434], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5435: cell 67, seg 0 (0.5) [0.5 on Epop[67]] -> cell 75, seg 0 (0.5) [0.5 on Epop[75]], weight: 4.1363508E-4, delay 1.5
        h("Epop[75] syn_projEE_ampa[5435] = new ampa(0.5)")
        h("Epop[67] netConn_projEE_ampa[5435] = new NetCon(&v(0.5), syn_projEE_ampa[5435], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5436: cell 67, seg 0 (0.5) [0.5 on Epop[67]] -> cell 76, seg 0 (0.5) [0.5 on Epop[76]], weight: 4.1363508E-4, delay 1.5
        h("Epop[76] syn_projEE_ampa[5436] = new ampa(0.5)")
        h("Epop[67] netConn_projEE_ampa[5436] = new NetCon(&v(0.5), syn_projEE_ampa[5436], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5437: cell 67, seg 0 (0.5) [0.5 on Epop[67]] -> cell 77, seg 0 (0.5) [0.5 on Epop[77]], weight: 4.1363508E-4, delay 1.5
        h("Epop[77] syn_projEE_ampa[5437] = new ampa(0.5)")
        h("Epop[67] netConn_projEE_ampa[5437] = new NetCon(&v(0.5), syn_projEE_ampa[5437], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5438: cell 67, seg 0 (0.5) [0.5 on Epop[67]] -> cell 78, seg 0 (0.5) [0.5 on Epop[78]], weight: 4.1363508E-4, delay 1.5
        h("Epop[78] syn_projEE_ampa[5438] = new ampa(0.5)")
        h("Epop[67] netConn_projEE_ampa[5438] = new NetCon(&v(0.5), syn_projEE_ampa[5438], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5439: cell 67, seg 0 (0.5) [0.5 on Epop[67]] -> cell 79, seg 0 (0.5) [0.5 on Epop[79]], weight: 4.1363508E-4, delay 1.5
        h("Epop[79] syn_projEE_ampa[5439] = new ampa(0.5)")
        h("Epop[67] netConn_projEE_ampa[5439] = new NetCon(&v(0.5), syn_projEE_ampa[5439], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5440: cell 68, seg 0 (0.5) [0.5 on Epop[68]] -> cell 0, seg 0 (0.5) [0.5 on Epop[0]], weight: 4.1363508E-4, delay 1.5
        h("Epop[0] syn_projEE_ampa[5440] = new ampa(0.5)")
        h("Epop[68] netConn_projEE_ampa[5440] = new NetCon(&v(0.5), syn_projEE_ampa[5440], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5441: cell 68, seg 0 (0.5) [0.5 on Epop[68]] -> cell 1, seg 0 (0.5) [0.5 on Epop[1]], weight: 4.1363508E-4, delay 1.5
        h("Epop[1] syn_projEE_ampa[5441] = new ampa(0.5)")
        h("Epop[68] netConn_projEE_ampa[5441] = new NetCon(&v(0.5), syn_projEE_ampa[5441], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5442: cell 68, seg 0 (0.5) [0.5 on Epop[68]] -> cell 2, seg 0 (0.5) [0.5 on Epop[2]], weight: 4.1363508E-4, delay 1.5
        h("Epop[2] syn_projEE_ampa[5442] = new ampa(0.5)")
        h("Epop[68] netConn_projEE_ampa[5442] = new NetCon(&v(0.5), syn_projEE_ampa[5442], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5443: cell 68, seg 0 (0.5) [0.5 on Epop[68]] -> cell 3, seg 0 (0.5) [0.5 on Epop[3]], weight: 4.1363508E-4, delay 1.5
        h("Epop[3] syn_projEE_ampa[5443] = new ampa(0.5)")
        h("Epop[68] netConn_projEE_ampa[5443] = new NetCon(&v(0.5), syn_projEE_ampa[5443], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5444: cell 68, seg 0 (0.5) [0.5 on Epop[68]] -> cell 4, seg 0 (0.5) [0.5 on Epop[4]], weight: 4.1363508E-4, delay 1.5
        h("Epop[4] syn_projEE_ampa[5444] = new ampa(0.5)")
        h("Epop[68] netConn_projEE_ampa[5444] = new NetCon(&v(0.5), syn_projEE_ampa[5444], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5445: cell 68, seg 0 (0.5) [0.5 on Epop[68]] -> cell 5, seg 0 (0.5) [0.5 on Epop[5]], weight: 4.1363508E-4, delay 1.5
        h("Epop[5] syn_projEE_ampa[5445] = new ampa(0.5)")
        h("Epop[68] netConn_projEE_ampa[5445] = new NetCon(&v(0.5), syn_projEE_ampa[5445], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5446: cell 68, seg 0 (0.5) [0.5 on Epop[68]] -> cell 6, seg 0 (0.5) [0.5 on Epop[6]], weight: 4.1363508E-4, delay 1.5
        h("Epop[6] syn_projEE_ampa[5446] = new ampa(0.5)")
        h("Epop[68] netConn_projEE_ampa[5446] = new NetCon(&v(0.5), syn_projEE_ampa[5446], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5447: cell 68, seg 0 (0.5) [0.5 on Epop[68]] -> cell 7, seg 0 (0.5) [0.5 on Epop[7]], weight: 4.1363508E-4, delay 1.5
        h("Epop[7] syn_projEE_ampa[5447] = new ampa(0.5)")
        h("Epop[68] netConn_projEE_ampa[5447] = new NetCon(&v(0.5), syn_projEE_ampa[5447], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5448: cell 68, seg 0 (0.5) [0.5 on Epop[68]] -> cell 8, seg 0 (0.5) [0.5 on Epop[8]], weight: 4.1363508E-4, delay 1.5
        h("Epop[8] syn_projEE_ampa[5448] = new ampa(0.5)")
        h("Epop[68] netConn_projEE_ampa[5448] = new NetCon(&v(0.5), syn_projEE_ampa[5448], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5449: cell 68, seg 0 (0.5) [0.5 on Epop[68]] -> cell 9, seg 0 (0.5) [0.5 on Epop[9]], weight: 4.1363508E-4, delay 1.5
        h("Epop[9] syn_projEE_ampa[5449] = new ampa(0.5)")
        h("Epop[68] netConn_projEE_ampa[5449] = new NetCon(&v(0.5), syn_projEE_ampa[5449], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5450: cell 68, seg 0 (0.5) [0.5 on Epop[68]] -> cell 10, seg 0 (0.5) [0.5 on Epop[10]], weight: 4.1363508E-4, delay 1.5
        h("Epop[10] syn_projEE_ampa[5450] = new ampa(0.5)")
        h("Epop[68] netConn_projEE_ampa[5450] = new NetCon(&v(0.5), syn_projEE_ampa[5450], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5451: cell 68, seg 0 (0.5) [0.5 on Epop[68]] -> cell 11, seg 0 (0.5) [0.5 on Epop[11]], weight: 4.1363508E-4, delay 1.5
        h("Epop[11] syn_projEE_ampa[5451] = new ampa(0.5)")
        h("Epop[68] netConn_projEE_ampa[5451] = new NetCon(&v(0.5), syn_projEE_ampa[5451], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5452: cell 68, seg 0 (0.5) [0.5 on Epop[68]] -> cell 12, seg 0 (0.5) [0.5 on Epop[12]], weight: 4.1363508E-4, delay 1.5
        h("Epop[12] syn_projEE_ampa[5452] = new ampa(0.5)")
        h("Epop[68] netConn_projEE_ampa[5452] = new NetCon(&v(0.5), syn_projEE_ampa[5452], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5453: cell 68, seg 0 (0.5) [0.5 on Epop[68]] -> cell 13, seg 0 (0.5) [0.5 on Epop[13]], weight: 4.1363508E-4, delay 1.5
        h("Epop[13] syn_projEE_ampa[5453] = new ampa(0.5)")
        h("Epop[68] netConn_projEE_ampa[5453] = new NetCon(&v(0.5), syn_projEE_ampa[5453], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5454: cell 68, seg 0 (0.5) [0.5 on Epop[68]] -> cell 14, seg 0 (0.5) [0.5 on Epop[14]], weight: 4.1363508E-4, delay 1.5
        h("Epop[14] syn_projEE_ampa[5454] = new ampa(0.5)")
        h("Epop[68] netConn_projEE_ampa[5454] = new NetCon(&v(0.5), syn_projEE_ampa[5454], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5455: cell 68, seg 0 (0.5) [0.5 on Epop[68]] -> cell 15, seg 0 (0.5) [0.5 on Epop[15]], weight: 4.1363508E-4, delay 1.5
        h("Epop[15] syn_projEE_ampa[5455] = new ampa(0.5)")
        h("Epop[68] netConn_projEE_ampa[5455] = new NetCon(&v(0.5), syn_projEE_ampa[5455], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5456: cell 68, seg 0 (0.5) [0.5 on Epop[68]] -> cell 16, seg 0 (0.5) [0.5 on Epop[16]], weight: 4.1363508E-4, delay 1.5
        h("Epop[16] syn_projEE_ampa[5456] = new ampa(0.5)")
        h("Epop[68] netConn_projEE_ampa[5456] = new NetCon(&v(0.5), syn_projEE_ampa[5456], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5457: cell 68, seg 0 (0.5) [0.5 on Epop[68]] -> cell 17, seg 0 (0.5) [0.5 on Epop[17]], weight: 4.1363508E-4, delay 1.5
        h("Epop[17] syn_projEE_ampa[5457] = new ampa(0.5)")
        h("Epop[68] netConn_projEE_ampa[5457] = new NetCon(&v(0.5), syn_projEE_ampa[5457], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5458: cell 68, seg 0 (0.5) [0.5 on Epop[68]] -> cell 18, seg 0 (0.5) [0.5 on Epop[18]], weight: 4.1363508E-4, delay 1.5
        h("Epop[18] syn_projEE_ampa[5458] = new ampa(0.5)")
        h("Epop[68] netConn_projEE_ampa[5458] = new NetCon(&v(0.5), syn_projEE_ampa[5458], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5459: cell 68, seg 0 (0.5) [0.5 on Epop[68]] -> cell 19, seg 0 (0.5) [0.5 on Epop[19]], weight: 4.1363508E-4, delay 1.5
        h("Epop[19] syn_projEE_ampa[5459] = new ampa(0.5)")
        h("Epop[68] netConn_projEE_ampa[5459] = new NetCon(&v(0.5), syn_projEE_ampa[5459], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5460: cell 68, seg 0 (0.5) [0.5 on Epop[68]] -> cell 20, seg 0 (0.5) [0.5 on Epop[20]], weight: 4.1363508E-4, delay 1.5
        h("Epop[20] syn_projEE_ampa[5460] = new ampa(0.5)")
        h("Epop[68] netConn_projEE_ampa[5460] = new NetCon(&v(0.5), syn_projEE_ampa[5460], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5461: cell 68, seg 0 (0.5) [0.5 on Epop[68]] -> cell 21, seg 0 (0.5) [0.5 on Epop[21]], weight: 4.1363508E-4, delay 1.5
        h("Epop[21] syn_projEE_ampa[5461] = new ampa(0.5)")
        h("Epop[68] netConn_projEE_ampa[5461] = new NetCon(&v(0.5), syn_projEE_ampa[5461], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5462: cell 68, seg 0 (0.5) [0.5 on Epop[68]] -> cell 22, seg 0 (0.5) [0.5 on Epop[22]], weight: 4.1363508E-4, delay 1.5
        h("Epop[22] syn_projEE_ampa[5462] = new ampa(0.5)")
        h("Epop[68] netConn_projEE_ampa[5462] = new NetCon(&v(0.5), syn_projEE_ampa[5462], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5463: cell 68, seg 0 (0.5) [0.5 on Epop[68]] -> cell 23, seg 0 (0.5) [0.5 on Epop[23]], weight: 4.1363508E-4, delay 1.5
        h("Epop[23] syn_projEE_ampa[5463] = new ampa(0.5)")
        h("Epop[68] netConn_projEE_ampa[5463] = new NetCon(&v(0.5), syn_projEE_ampa[5463], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5464: cell 68, seg 0 (0.5) [0.5 on Epop[68]] -> cell 24, seg 0 (0.5) [0.5 on Epop[24]], weight: 4.1363508E-4, delay 1.5
        h("Epop[24] syn_projEE_ampa[5464] = new ampa(0.5)")
        h("Epop[68] netConn_projEE_ampa[5464] = new NetCon(&v(0.5), syn_projEE_ampa[5464], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5465: cell 68, seg 0 (0.5) [0.5 on Epop[68]] -> cell 25, seg 0 (0.5) [0.5 on Epop[25]], weight: 4.1363508E-4, delay 1.5
        h("Epop[25] syn_projEE_ampa[5465] = new ampa(0.5)")
        h("Epop[68] netConn_projEE_ampa[5465] = new NetCon(&v(0.5), syn_projEE_ampa[5465], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5466: cell 68, seg 0 (0.5) [0.5 on Epop[68]] -> cell 26, seg 0 (0.5) [0.5 on Epop[26]], weight: 4.1363508E-4, delay 1.5
        h("Epop[26] syn_projEE_ampa[5466] = new ampa(0.5)")
        h("Epop[68] netConn_projEE_ampa[5466] = new NetCon(&v(0.5), syn_projEE_ampa[5466], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5467: cell 68, seg 0 (0.5) [0.5 on Epop[68]] -> cell 27, seg 0 (0.5) [0.5 on Epop[27]], weight: 4.1363508E-4, delay 1.5
        h("Epop[27] syn_projEE_ampa[5467] = new ampa(0.5)")
        h("Epop[68] netConn_projEE_ampa[5467] = new NetCon(&v(0.5), syn_projEE_ampa[5467], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5468: cell 68, seg 0 (0.5) [0.5 on Epop[68]] -> cell 28, seg 0 (0.5) [0.5 on Epop[28]], weight: 4.1363508E-4, delay 1.5
        h("Epop[28] syn_projEE_ampa[5468] = new ampa(0.5)")
        h("Epop[68] netConn_projEE_ampa[5468] = new NetCon(&v(0.5), syn_projEE_ampa[5468], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5469: cell 68, seg 0 (0.5) [0.5 on Epop[68]] -> cell 29, seg 0 (0.5) [0.5 on Epop[29]], weight: 4.1363508E-4, delay 1.5
        h("Epop[29] syn_projEE_ampa[5469] = new ampa(0.5)")
        h("Epop[68] netConn_projEE_ampa[5469] = new NetCon(&v(0.5), syn_projEE_ampa[5469], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5470: cell 68, seg 0 (0.5) [0.5 on Epop[68]] -> cell 30, seg 0 (0.5) [0.5 on Epop[30]], weight: 4.1363508E-4, delay 1.5
        h("Epop[30] syn_projEE_ampa[5470] = new ampa(0.5)")
        h("Epop[68] netConn_projEE_ampa[5470] = new NetCon(&v(0.5), syn_projEE_ampa[5470], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5471: cell 68, seg 0 (0.5) [0.5 on Epop[68]] -> cell 31, seg 0 (0.5) [0.5 on Epop[31]], weight: 4.1363508E-4, delay 1.5
        h("Epop[31] syn_projEE_ampa[5471] = new ampa(0.5)")
        h("Epop[68] netConn_projEE_ampa[5471] = new NetCon(&v(0.5), syn_projEE_ampa[5471], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5472: cell 68, seg 0 (0.5) [0.5 on Epop[68]] -> cell 32, seg 0 (0.5) [0.5 on Epop[32]], weight: 4.1363508E-4, delay 1.5
        h("Epop[32] syn_projEE_ampa[5472] = new ampa(0.5)")
        h("Epop[68] netConn_projEE_ampa[5472] = new NetCon(&v(0.5), syn_projEE_ampa[5472], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5473: cell 68, seg 0 (0.5) [0.5 on Epop[68]] -> cell 33, seg 0 (0.5) [0.5 on Epop[33]], weight: 4.1363508E-4, delay 1.5
        h("Epop[33] syn_projEE_ampa[5473] = new ampa(0.5)")
        h("Epop[68] netConn_projEE_ampa[5473] = new NetCon(&v(0.5), syn_projEE_ampa[5473], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5474: cell 68, seg 0 (0.5) [0.5 on Epop[68]] -> cell 34, seg 0 (0.5) [0.5 on Epop[34]], weight: 4.1363508E-4, delay 1.5
        h("Epop[34] syn_projEE_ampa[5474] = new ampa(0.5)")
        h("Epop[68] netConn_projEE_ampa[5474] = new NetCon(&v(0.5), syn_projEE_ampa[5474], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5475: cell 68, seg 0 (0.5) [0.5 on Epop[68]] -> cell 35, seg 0 (0.5) [0.5 on Epop[35]], weight: 4.1363508E-4, delay 1.5
        h("Epop[35] syn_projEE_ampa[5475] = new ampa(0.5)")
        h("Epop[68] netConn_projEE_ampa[5475] = new NetCon(&v(0.5), syn_projEE_ampa[5475], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5476: cell 68, seg 0 (0.5) [0.5 on Epop[68]] -> cell 36, seg 0 (0.5) [0.5 on Epop[36]], weight: 4.1363508E-4, delay 1.5
        h("Epop[36] syn_projEE_ampa[5476] = new ampa(0.5)")
        h("Epop[68] netConn_projEE_ampa[5476] = new NetCon(&v(0.5), syn_projEE_ampa[5476], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5477: cell 68, seg 0 (0.5) [0.5 on Epop[68]] -> cell 37, seg 0 (0.5) [0.5 on Epop[37]], weight: 4.1363508E-4, delay 1.5
        h("Epop[37] syn_projEE_ampa[5477] = new ampa(0.5)")
        h("Epop[68] netConn_projEE_ampa[5477] = new NetCon(&v(0.5), syn_projEE_ampa[5477], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5478: cell 68, seg 0 (0.5) [0.5 on Epop[68]] -> cell 38, seg 0 (0.5) [0.5 on Epop[38]], weight: 4.1363508E-4, delay 1.5
        h("Epop[38] syn_projEE_ampa[5478] = new ampa(0.5)")
        h("Epop[68] netConn_projEE_ampa[5478] = new NetCon(&v(0.5), syn_projEE_ampa[5478], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5479: cell 68, seg 0 (0.5) [0.5 on Epop[68]] -> cell 39, seg 0 (0.5) [0.5 on Epop[39]], weight: 4.1363508E-4, delay 1.5
        h("Epop[39] syn_projEE_ampa[5479] = new ampa(0.5)")
        h("Epop[68] netConn_projEE_ampa[5479] = new NetCon(&v(0.5), syn_projEE_ampa[5479], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5480: cell 68, seg 0 (0.5) [0.5 on Epop[68]] -> cell 40, seg 0 (0.5) [0.5 on Epop[40]], weight: 4.1363508E-4, delay 1.5
        h("Epop[40] syn_projEE_ampa[5480] = new ampa(0.5)")
        h("Epop[68] netConn_projEE_ampa[5480] = new NetCon(&v(0.5), syn_projEE_ampa[5480], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5481: cell 68, seg 0 (0.5) [0.5 on Epop[68]] -> cell 41, seg 0 (0.5) [0.5 on Epop[41]], weight: 4.1363508E-4, delay 1.5
        h("Epop[41] syn_projEE_ampa[5481] = new ampa(0.5)")
        h("Epop[68] netConn_projEE_ampa[5481] = new NetCon(&v(0.5), syn_projEE_ampa[5481], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5482: cell 68, seg 0 (0.5) [0.5 on Epop[68]] -> cell 42, seg 0 (0.5) [0.5 on Epop[42]], weight: 4.1363508E-4, delay 1.5
        h("Epop[42] syn_projEE_ampa[5482] = new ampa(0.5)")
        h("Epop[68] netConn_projEE_ampa[5482] = new NetCon(&v(0.5), syn_projEE_ampa[5482], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5483: cell 68, seg 0 (0.5) [0.5 on Epop[68]] -> cell 43, seg 0 (0.5) [0.5 on Epop[43]], weight: 4.1363508E-4, delay 1.5
        h("Epop[43] syn_projEE_ampa[5483] = new ampa(0.5)")
        h("Epop[68] netConn_projEE_ampa[5483] = new NetCon(&v(0.5), syn_projEE_ampa[5483], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5484: cell 68, seg 0 (0.5) [0.5 on Epop[68]] -> cell 44, seg 0 (0.5) [0.5 on Epop[44]], weight: 4.1363508E-4, delay 1.5
        h("Epop[44] syn_projEE_ampa[5484] = new ampa(0.5)")
        h("Epop[68] netConn_projEE_ampa[5484] = new NetCon(&v(0.5), syn_projEE_ampa[5484], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5485: cell 68, seg 0 (0.5) [0.5 on Epop[68]] -> cell 45, seg 0 (0.5) [0.5 on Epop[45]], weight: 4.1363508E-4, delay 1.5
        h("Epop[45] syn_projEE_ampa[5485] = new ampa(0.5)")
        h("Epop[68] netConn_projEE_ampa[5485] = new NetCon(&v(0.5), syn_projEE_ampa[5485], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5486: cell 68, seg 0 (0.5) [0.5 on Epop[68]] -> cell 46, seg 0 (0.5) [0.5 on Epop[46]], weight: 4.1363508E-4, delay 1.5
        h("Epop[46] syn_projEE_ampa[5486] = new ampa(0.5)")
        h("Epop[68] netConn_projEE_ampa[5486] = new NetCon(&v(0.5), syn_projEE_ampa[5486], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5487: cell 68, seg 0 (0.5) [0.5 on Epop[68]] -> cell 47, seg 0 (0.5) [0.5 on Epop[47]], weight: 4.1363508E-4, delay 1.5
        h("Epop[47] syn_projEE_ampa[5487] = new ampa(0.5)")
        h("Epop[68] netConn_projEE_ampa[5487] = new NetCon(&v(0.5), syn_projEE_ampa[5487], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5488: cell 68, seg 0 (0.5) [0.5 on Epop[68]] -> cell 48, seg 0 (0.5) [0.5 on Epop[48]], weight: 4.1363508E-4, delay 1.5
        h("Epop[48] syn_projEE_ampa[5488] = new ampa(0.5)")
        h("Epop[68] netConn_projEE_ampa[5488] = new NetCon(&v(0.5), syn_projEE_ampa[5488], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5489: cell 68, seg 0 (0.5) [0.5 on Epop[68]] -> cell 49, seg 0 (0.5) [0.5 on Epop[49]], weight: 4.1363508E-4, delay 1.5
        h("Epop[49] syn_projEE_ampa[5489] = new ampa(0.5)")
        h("Epop[68] netConn_projEE_ampa[5489] = new NetCon(&v(0.5), syn_projEE_ampa[5489], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5490: cell 68, seg 0 (0.5) [0.5 on Epop[68]] -> cell 50, seg 0 (0.5) [0.5 on Epop[50]], weight: 4.1363508E-4, delay 1.5
        h("Epop[50] syn_projEE_ampa[5490] = new ampa(0.5)")
        h("Epop[68] netConn_projEE_ampa[5490] = new NetCon(&v(0.5), syn_projEE_ampa[5490], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5491: cell 68, seg 0 (0.5) [0.5 on Epop[68]] -> cell 51, seg 0 (0.5) [0.5 on Epop[51]], weight: 4.1363508E-4, delay 1.5
        h("Epop[51] syn_projEE_ampa[5491] = new ampa(0.5)")
        h("Epop[68] netConn_projEE_ampa[5491] = new NetCon(&v(0.5), syn_projEE_ampa[5491], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5492: cell 68, seg 0 (0.5) [0.5 on Epop[68]] -> cell 52, seg 0 (0.5) [0.5 on Epop[52]], weight: 4.1363508E-4, delay 1.5
        h("Epop[52] syn_projEE_ampa[5492] = new ampa(0.5)")
        h("Epop[68] netConn_projEE_ampa[5492] = new NetCon(&v(0.5), syn_projEE_ampa[5492], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5493: cell 68, seg 0 (0.5) [0.5 on Epop[68]] -> cell 53, seg 0 (0.5) [0.5 on Epop[53]], weight: 4.1363508E-4, delay 1.5
        h("Epop[53] syn_projEE_ampa[5493] = new ampa(0.5)")
        h("Epop[68] netConn_projEE_ampa[5493] = new NetCon(&v(0.5), syn_projEE_ampa[5493], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5494: cell 68, seg 0 (0.5) [0.5 on Epop[68]] -> cell 54, seg 0 (0.5) [0.5 on Epop[54]], weight: 4.1363508E-4, delay 1.5
        h("Epop[54] syn_projEE_ampa[5494] = new ampa(0.5)")
        h("Epop[68] netConn_projEE_ampa[5494] = new NetCon(&v(0.5), syn_projEE_ampa[5494], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5495: cell 68, seg 0 (0.5) [0.5 on Epop[68]] -> cell 55, seg 0 (0.5) [0.5 on Epop[55]], weight: 4.1363508E-4, delay 1.5
        h("Epop[55] syn_projEE_ampa[5495] = new ampa(0.5)")
        h("Epop[68] netConn_projEE_ampa[5495] = new NetCon(&v(0.5), syn_projEE_ampa[5495], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5496: cell 68, seg 0 (0.5) [0.5 on Epop[68]] -> cell 56, seg 0 (0.5) [0.5 on Epop[56]], weight: 4.1363508E-4, delay 1.5
        h("Epop[56] syn_projEE_ampa[5496] = new ampa(0.5)")
        h("Epop[68] netConn_projEE_ampa[5496] = new NetCon(&v(0.5), syn_projEE_ampa[5496], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5497: cell 68, seg 0 (0.5) [0.5 on Epop[68]] -> cell 57, seg 0 (0.5) [0.5 on Epop[57]], weight: 4.1363508E-4, delay 1.5
        h("Epop[57] syn_projEE_ampa[5497] = new ampa(0.5)")
        h("Epop[68] netConn_projEE_ampa[5497] = new NetCon(&v(0.5), syn_projEE_ampa[5497], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5498: cell 68, seg 0 (0.5) [0.5 on Epop[68]] -> cell 58, seg 0 (0.5) [0.5 on Epop[58]], weight: 4.1363508E-4, delay 1.5
        h("Epop[58] syn_projEE_ampa[5498] = new ampa(0.5)")
        h("Epop[68] netConn_projEE_ampa[5498] = new NetCon(&v(0.5), syn_projEE_ampa[5498], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5499: cell 68, seg 0 (0.5) [0.5 on Epop[68]] -> cell 59, seg 0 (0.5) [0.5 on Epop[59]], weight: 4.1363508E-4, delay 1.5
        h("Epop[59] syn_projEE_ampa[5499] = new ampa(0.5)")
        h("Epop[68] netConn_projEE_ampa[5499] = new NetCon(&v(0.5), syn_projEE_ampa[5499], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5500: cell 68, seg 0 (0.5) [0.5 on Epop[68]] -> cell 60, seg 0 (0.5) [0.5 on Epop[60]], weight: 4.1363508E-4, delay 1.5
        h("Epop[60] syn_projEE_ampa[5500] = new ampa(0.5)")
        h("Epop[68] netConn_projEE_ampa[5500] = new NetCon(&v(0.5), syn_projEE_ampa[5500], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5501: cell 68, seg 0 (0.5) [0.5 on Epop[68]] -> cell 61, seg 0 (0.5) [0.5 on Epop[61]], weight: 4.1363508E-4, delay 1.5
        h("Epop[61] syn_projEE_ampa[5501] = new ampa(0.5)")
        h("Epop[68] netConn_projEE_ampa[5501] = new NetCon(&v(0.5), syn_projEE_ampa[5501], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5502: cell 68, seg 0 (0.5) [0.5 on Epop[68]] -> cell 62, seg 0 (0.5) [0.5 on Epop[62]], weight: 4.1363508E-4, delay 1.5
        h("Epop[62] syn_projEE_ampa[5502] = new ampa(0.5)")
        h("Epop[68] netConn_projEE_ampa[5502] = new NetCon(&v(0.5), syn_projEE_ampa[5502], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5503: cell 68, seg 0 (0.5) [0.5 on Epop[68]] -> cell 63, seg 0 (0.5) [0.5 on Epop[63]], weight: 4.1363508E-4, delay 1.5
        h("Epop[63] syn_projEE_ampa[5503] = new ampa(0.5)")
        h("Epop[68] netConn_projEE_ampa[5503] = new NetCon(&v(0.5), syn_projEE_ampa[5503], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5504: cell 68, seg 0 (0.5) [0.5 on Epop[68]] -> cell 64, seg 0 (0.5) [0.5 on Epop[64]], weight: 4.1363508E-4, delay 1.5
        h("Epop[64] syn_projEE_ampa[5504] = new ampa(0.5)")
        h("Epop[68] netConn_projEE_ampa[5504] = new NetCon(&v(0.5), syn_projEE_ampa[5504], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5505: cell 68, seg 0 (0.5) [0.5 on Epop[68]] -> cell 65, seg 0 (0.5) [0.5 on Epop[65]], weight: 4.1363508E-4, delay 1.5
        h("Epop[65] syn_projEE_ampa[5505] = new ampa(0.5)")
        h("Epop[68] netConn_projEE_ampa[5505] = new NetCon(&v(0.5), syn_projEE_ampa[5505], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5506: cell 68, seg 0 (0.5) [0.5 on Epop[68]] -> cell 66, seg 0 (0.5) [0.5 on Epop[66]], weight: 4.1363508E-4, delay 1.5
        h("Epop[66] syn_projEE_ampa[5506] = new ampa(0.5)")
        h("Epop[68] netConn_projEE_ampa[5506] = new NetCon(&v(0.5), syn_projEE_ampa[5506], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5507: cell 68, seg 0 (0.5) [0.5 on Epop[68]] -> cell 67, seg 0 (0.5) [0.5 on Epop[67]], weight: 4.1363508E-4, delay 1.5
        h("Epop[67] syn_projEE_ampa[5507] = new ampa(0.5)")
        h("Epop[68] netConn_projEE_ampa[5507] = new NetCon(&v(0.5), syn_projEE_ampa[5507], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5508: cell 68, seg 0 (0.5) [0.5 on Epop[68]] -> cell 68, seg 0 (0.5) [0.5 on Epop[68]], weight: 4.1363508E-4, delay 1.5
        h("Epop[68] syn_projEE_ampa[5508] = new ampa(0.5)")
        h("Epop[68] netConn_projEE_ampa[5508] = new NetCon(&v(0.5), syn_projEE_ampa[5508], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5509: cell 68, seg 0 (0.5) [0.5 on Epop[68]] -> cell 69, seg 0 (0.5) [0.5 on Epop[69]], weight: 4.1363508E-4, delay 1.5
        h("Epop[69] syn_projEE_ampa[5509] = new ampa(0.5)")
        h("Epop[68] netConn_projEE_ampa[5509] = new NetCon(&v(0.5), syn_projEE_ampa[5509], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5510: cell 68, seg 0 (0.5) [0.5 on Epop[68]] -> cell 70, seg 0 (0.5) [0.5 on Epop[70]], weight: 4.1363508E-4, delay 1.5
        h("Epop[70] syn_projEE_ampa[5510] = new ampa(0.5)")
        h("Epop[68] netConn_projEE_ampa[5510] = new NetCon(&v(0.5), syn_projEE_ampa[5510], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5511: cell 68, seg 0 (0.5) [0.5 on Epop[68]] -> cell 71, seg 0 (0.5) [0.5 on Epop[71]], weight: 4.1363508E-4, delay 1.5
        h("Epop[71] syn_projEE_ampa[5511] = new ampa(0.5)")
        h("Epop[68] netConn_projEE_ampa[5511] = new NetCon(&v(0.5), syn_projEE_ampa[5511], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5512: cell 68, seg 0 (0.5) [0.5 on Epop[68]] -> cell 72, seg 0 (0.5) [0.5 on Epop[72]], weight: 4.1363508E-4, delay 1.5
        h("Epop[72] syn_projEE_ampa[5512] = new ampa(0.5)")
        h("Epop[68] netConn_projEE_ampa[5512] = new NetCon(&v(0.5), syn_projEE_ampa[5512], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5513: cell 68, seg 0 (0.5) [0.5 on Epop[68]] -> cell 73, seg 0 (0.5) [0.5 on Epop[73]], weight: 4.1363508E-4, delay 1.5
        h("Epop[73] syn_projEE_ampa[5513] = new ampa(0.5)")
        h("Epop[68] netConn_projEE_ampa[5513] = new NetCon(&v(0.5), syn_projEE_ampa[5513], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5514: cell 68, seg 0 (0.5) [0.5 on Epop[68]] -> cell 74, seg 0 (0.5) [0.5 on Epop[74]], weight: 4.1363508E-4, delay 1.5
        h("Epop[74] syn_projEE_ampa[5514] = new ampa(0.5)")
        h("Epop[68] netConn_projEE_ampa[5514] = new NetCon(&v(0.5), syn_projEE_ampa[5514], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5515: cell 68, seg 0 (0.5) [0.5 on Epop[68]] -> cell 75, seg 0 (0.5) [0.5 on Epop[75]], weight: 4.1363508E-4, delay 1.5
        h("Epop[75] syn_projEE_ampa[5515] = new ampa(0.5)")
        h("Epop[68] netConn_projEE_ampa[5515] = new NetCon(&v(0.5), syn_projEE_ampa[5515], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5516: cell 68, seg 0 (0.5) [0.5 on Epop[68]] -> cell 76, seg 0 (0.5) [0.5 on Epop[76]], weight: 4.1363508E-4, delay 1.5
        h("Epop[76] syn_projEE_ampa[5516] = new ampa(0.5)")
        h("Epop[68] netConn_projEE_ampa[5516] = new NetCon(&v(0.5), syn_projEE_ampa[5516], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5517: cell 68, seg 0 (0.5) [0.5 on Epop[68]] -> cell 77, seg 0 (0.5) [0.5 on Epop[77]], weight: 4.1363508E-4, delay 1.5
        h("Epop[77] syn_projEE_ampa[5517] = new ampa(0.5)")
        h("Epop[68] netConn_projEE_ampa[5517] = new NetCon(&v(0.5), syn_projEE_ampa[5517], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5518: cell 68, seg 0 (0.5) [0.5 on Epop[68]] -> cell 78, seg 0 (0.5) [0.5 on Epop[78]], weight: 4.1363508E-4, delay 1.5
        h("Epop[78] syn_projEE_ampa[5518] = new ampa(0.5)")
        h("Epop[68] netConn_projEE_ampa[5518] = new NetCon(&v(0.5), syn_projEE_ampa[5518], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5519: cell 68, seg 0 (0.5) [0.5 on Epop[68]] -> cell 79, seg 0 (0.5) [0.5 on Epop[79]], weight: 4.1363508E-4, delay 1.5
        h("Epop[79] syn_projEE_ampa[5519] = new ampa(0.5)")
        h("Epop[68] netConn_projEE_ampa[5519] = new NetCon(&v(0.5), syn_projEE_ampa[5519], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5520: cell 69, seg 0 (0.5) [0.5 on Epop[69]] -> cell 0, seg 0 (0.5) [0.5 on Epop[0]], weight: 4.1363508E-4, delay 1.5
        h("Epop[0] syn_projEE_ampa[5520] = new ampa(0.5)")
        h("Epop[69] netConn_projEE_ampa[5520] = new NetCon(&v(0.5), syn_projEE_ampa[5520], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5521: cell 69, seg 0 (0.5) [0.5 on Epop[69]] -> cell 1, seg 0 (0.5) [0.5 on Epop[1]], weight: 4.1363508E-4, delay 1.5
        h("Epop[1] syn_projEE_ampa[5521] = new ampa(0.5)")
        h("Epop[69] netConn_projEE_ampa[5521] = new NetCon(&v(0.5), syn_projEE_ampa[5521], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5522: cell 69, seg 0 (0.5) [0.5 on Epop[69]] -> cell 2, seg 0 (0.5) [0.5 on Epop[2]], weight: 4.1363508E-4, delay 1.5
        h("Epop[2] syn_projEE_ampa[5522] = new ampa(0.5)")
        h("Epop[69] netConn_projEE_ampa[5522] = new NetCon(&v(0.5), syn_projEE_ampa[5522], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5523: cell 69, seg 0 (0.5) [0.5 on Epop[69]] -> cell 3, seg 0 (0.5) [0.5 on Epop[3]], weight: 4.1363508E-4, delay 1.5
        h("Epop[3] syn_projEE_ampa[5523] = new ampa(0.5)")
        h("Epop[69] netConn_projEE_ampa[5523] = new NetCon(&v(0.5), syn_projEE_ampa[5523], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5524: cell 69, seg 0 (0.5) [0.5 on Epop[69]] -> cell 4, seg 0 (0.5) [0.5 on Epop[4]], weight: 4.1363508E-4, delay 1.5
        h("Epop[4] syn_projEE_ampa[5524] = new ampa(0.5)")
        h("Epop[69] netConn_projEE_ampa[5524] = new NetCon(&v(0.5), syn_projEE_ampa[5524], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5525: cell 69, seg 0 (0.5) [0.5 on Epop[69]] -> cell 5, seg 0 (0.5) [0.5 on Epop[5]], weight: 4.1363508E-4, delay 1.5
        h("Epop[5] syn_projEE_ampa[5525] = new ampa(0.5)")
        h("Epop[69] netConn_projEE_ampa[5525] = new NetCon(&v(0.5), syn_projEE_ampa[5525], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5526: cell 69, seg 0 (0.5) [0.5 on Epop[69]] -> cell 6, seg 0 (0.5) [0.5 on Epop[6]], weight: 4.1363508E-4, delay 1.5
        h("Epop[6] syn_projEE_ampa[5526] = new ampa(0.5)")
        h("Epop[69] netConn_projEE_ampa[5526] = new NetCon(&v(0.5), syn_projEE_ampa[5526], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5527: cell 69, seg 0 (0.5) [0.5 on Epop[69]] -> cell 7, seg 0 (0.5) [0.5 on Epop[7]], weight: 4.1363508E-4, delay 1.5
        h("Epop[7] syn_projEE_ampa[5527] = new ampa(0.5)")
        h("Epop[69] netConn_projEE_ampa[5527] = new NetCon(&v(0.5), syn_projEE_ampa[5527], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5528: cell 69, seg 0 (0.5) [0.5 on Epop[69]] -> cell 8, seg 0 (0.5) [0.5 on Epop[8]], weight: 4.1363508E-4, delay 1.5
        h("Epop[8] syn_projEE_ampa[5528] = new ampa(0.5)")
        h("Epop[69] netConn_projEE_ampa[5528] = new NetCon(&v(0.5), syn_projEE_ampa[5528], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5529: cell 69, seg 0 (0.5) [0.5 on Epop[69]] -> cell 9, seg 0 (0.5) [0.5 on Epop[9]], weight: 4.1363508E-4, delay 1.5
        h("Epop[9] syn_projEE_ampa[5529] = new ampa(0.5)")
        h("Epop[69] netConn_projEE_ampa[5529] = new NetCon(&v(0.5), syn_projEE_ampa[5529], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5530: cell 69, seg 0 (0.5) [0.5 on Epop[69]] -> cell 10, seg 0 (0.5) [0.5 on Epop[10]], weight: 4.1363508E-4, delay 1.5
        h("Epop[10] syn_projEE_ampa[5530] = new ampa(0.5)")
        h("Epop[69] netConn_projEE_ampa[5530] = new NetCon(&v(0.5), syn_projEE_ampa[5530], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5531: cell 69, seg 0 (0.5) [0.5 on Epop[69]] -> cell 11, seg 0 (0.5) [0.5 on Epop[11]], weight: 4.1363508E-4, delay 1.5
        h("Epop[11] syn_projEE_ampa[5531] = new ampa(0.5)")
        h("Epop[69] netConn_projEE_ampa[5531] = new NetCon(&v(0.5), syn_projEE_ampa[5531], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5532: cell 69, seg 0 (0.5) [0.5 on Epop[69]] -> cell 12, seg 0 (0.5) [0.5 on Epop[12]], weight: 4.1363508E-4, delay 1.5
        h("Epop[12] syn_projEE_ampa[5532] = new ampa(0.5)")
        h("Epop[69] netConn_projEE_ampa[5532] = new NetCon(&v(0.5), syn_projEE_ampa[5532], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5533: cell 69, seg 0 (0.5) [0.5 on Epop[69]] -> cell 13, seg 0 (0.5) [0.5 on Epop[13]], weight: 4.1363508E-4, delay 1.5
        h("Epop[13] syn_projEE_ampa[5533] = new ampa(0.5)")
        h("Epop[69] netConn_projEE_ampa[5533] = new NetCon(&v(0.5), syn_projEE_ampa[5533], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5534: cell 69, seg 0 (0.5) [0.5 on Epop[69]] -> cell 14, seg 0 (0.5) [0.5 on Epop[14]], weight: 4.1363508E-4, delay 1.5
        h("Epop[14] syn_projEE_ampa[5534] = new ampa(0.5)")
        h("Epop[69] netConn_projEE_ampa[5534] = new NetCon(&v(0.5), syn_projEE_ampa[5534], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5535: cell 69, seg 0 (0.5) [0.5 on Epop[69]] -> cell 15, seg 0 (0.5) [0.5 on Epop[15]], weight: 4.1363508E-4, delay 1.5
        h("Epop[15] syn_projEE_ampa[5535] = new ampa(0.5)")
        h("Epop[69] netConn_projEE_ampa[5535] = new NetCon(&v(0.5), syn_projEE_ampa[5535], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5536: cell 69, seg 0 (0.5) [0.5 on Epop[69]] -> cell 16, seg 0 (0.5) [0.5 on Epop[16]], weight: 4.1363508E-4, delay 1.5
        h("Epop[16] syn_projEE_ampa[5536] = new ampa(0.5)")
        h("Epop[69] netConn_projEE_ampa[5536] = new NetCon(&v(0.5), syn_projEE_ampa[5536], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5537: cell 69, seg 0 (0.5) [0.5 on Epop[69]] -> cell 17, seg 0 (0.5) [0.5 on Epop[17]], weight: 4.1363508E-4, delay 1.5
        h("Epop[17] syn_projEE_ampa[5537] = new ampa(0.5)")
        h("Epop[69] netConn_projEE_ampa[5537] = new NetCon(&v(0.5), syn_projEE_ampa[5537], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5538: cell 69, seg 0 (0.5) [0.5 on Epop[69]] -> cell 18, seg 0 (0.5) [0.5 on Epop[18]], weight: 4.1363508E-4, delay 1.5
        h("Epop[18] syn_projEE_ampa[5538] = new ampa(0.5)")
        h("Epop[69] netConn_projEE_ampa[5538] = new NetCon(&v(0.5), syn_projEE_ampa[5538], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5539: cell 69, seg 0 (0.5) [0.5 on Epop[69]] -> cell 19, seg 0 (0.5) [0.5 on Epop[19]], weight: 4.1363508E-4, delay 1.5
        h("Epop[19] syn_projEE_ampa[5539] = new ampa(0.5)")
        h("Epop[69] netConn_projEE_ampa[5539] = new NetCon(&v(0.5), syn_projEE_ampa[5539], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5540: cell 69, seg 0 (0.5) [0.5 on Epop[69]] -> cell 20, seg 0 (0.5) [0.5 on Epop[20]], weight: 4.1363508E-4, delay 1.5
        h("Epop[20] syn_projEE_ampa[5540] = new ampa(0.5)")
        h("Epop[69] netConn_projEE_ampa[5540] = new NetCon(&v(0.5), syn_projEE_ampa[5540], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5541: cell 69, seg 0 (0.5) [0.5 on Epop[69]] -> cell 21, seg 0 (0.5) [0.5 on Epop[21]], weight: 4.1363508E-4, delay 1.5
        h("Epop[21] syn_projEE_ampa[5541] = new ampa(0.5)")
        h("Epop[69] netConn_projEE_ampa[5541] = new NetCon(&v(0.5), syn_projEE_ampa[5541], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5542: cell 69, seg 0 (0.5) [0.5 on Epop[69]] -> cell 22, seg 0 (0.5) [0.5 on Epop[22]], weight: 4.1363508E-4, delay 1.5
        h("Epop[22] syn_projEE_ampa[5542] = new ampa(0.5)")
        h("Epop[69] netConn_projEE_ampa[5542] = new NetCon(&v(0.5), syn_projEE_ampa[5542], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5543: cell 69, seg 0 (0.5) [0.5 on Epop[69]] -> cell 23, seg 0 (0.5) [0.5 on Epop[23]], weight: 4.1363508E-4, delay 1.5
        h("Epop[23] syn_projEE_ampa[5543] = new ampa(0.5)")
        h("Epop[69] netConn_projEE_ampa[5543] = new NetCon(&v(0.5), syn_projEE_ampa[5543], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5544: cell 69, seg 0 (0.5) [0.5 on Epop[69]] -> cell 24, seg 0 (0.5) [0.5 on Epop[24]], weight: 4.1363508E-4, delay 1.5
        h("Epop[24] syn_projEE_ampa[5544] = new ampa(0.5)")
        h("Epop[69] netConn_projEE_ampa[5544] = new NetCon(&v(0.5), syn_projEE_ampa[5544], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5545: cell 69, seg 0 (0.5) [0.5 on Epop[69]] -> cell 25, seg 0 (0.5) [0.5 on Epop[25]], weight: 4.1363508E-4, delay 1.5
        h("Epop[25] syn_projEE_ampa[5545] = new ampa(0.5)")
        h("Epop[69] netConn_projEE_ampa[5545] = new NetCon(&v(0.5), syn_projEE_ampa[5545], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5546: cell 69, seg 0 (0.5) [0.5 on Epop[69]] -> cell 26, seg 0 (0.5) [0.5 on Epop[26]], weight: 4.1363508E-4, delay 1.5
        h("Epop[26] syn_projEE_ampa[5546] = new ampa(0.5)")
        h("Epop[69] netConn_projEE_ampa[5546] = new NetCon(&v(0.5), syn_projEE_ampa[5546], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5547: cell 69, seg 0 (0.5) [0.5 on Epop[69]] -> cell 27, seg 0 (0.5) [0.5 on Epop[27]], weight: 4.1363508E-4, delay 1.5
        h("Epop[27] syn_projEE_ampa[5547] = new ampa(0.5)")
        h("Epop[69] netConn_projEE_ampa[5547] = new NetCon(&v(0.5), syn_projEE_ampa[5547], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5548: cell 69, seg 0 (0.5) [0.5 on Epop[69]] -> cell 28, seg 0 (0.5) [0.5 on Epop[28]], weight: 4.1363508E-4, delay 1.5
        h("Epop[28] syn_projEE_ampa[5548] = new ampa(0.5)")
        h("Epop[69] netConn_projEE_ampa[5548] = new NetCon(&v(0.5), syn_projEE_ampa[5548], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5549: cell 69, seg 0 (0.5) [0.5 on Epop[69]] -> cell 29, seg 0 (0.5) [0.5 on Epop[29]], weight: 4.1363508E-4, delay 1.5
        h("Epop[29] syn_projEE_ampa[5549] = new ampa(0.5)")
        h("Epop[69] netConn_projEE_ampa[5549] = new NetCon(&v(0.5), syn_projEE_ampa[5549], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5550: cell 69, seg 0 (0.5) [0.5 on Epop[69]] -> cell 30, seg 0 (0.5) [0.5 on Epop[30]], weight: 4.1363508E-4, delay 1.5
        h("Epop[30] syn_projEE_ampa[5550] = new ampa(0.5)")
        h("Epop[69] netConn_projEE_ampa[5550] = new NetCon(&v(0.5), syn_projEE_ampa[5550], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5551: cell 69, seg 0 (0.5) [0.5 on Epop[69]] -> cell 31, seg 0 (0.5) [0.5 on Epop[31]], weight: 4.1363508E-4, delay 1.5
        h("Epop[31] syn_projEE_ampa[5551] = new ampa(0.5)")
        h("Epop[69] netConn_projEE_ampa[5551] = new NetCon(&v(0.5), syn_projEE_ampa[5551], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5552: cell 69, seg 0 (0.5) [0.5 on Epop[69]] -> cell 32, seg 0 (0.5) [0.5 on Epop[32]], weight: 4.1363508E-4, delay 1.5
        h("Epop[32] syn_projEE_ampa[5552] = new ampa(0.5)")
        h("Epop[69] netConn_projEE_ampa[5552] = new NetCon(&v(0.5), syn_projEE_ampa[5552], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5553: cell 69, seg 0 (0.5) [0.5 on Epop[69]] -> cell 33, seg 0 (0.5) [0.5 on Epop[33]], weight: 4.1363508E-4, delay 1.5
        h("Epop[33] syn_projEE_ampa[5553] = new ampa(0.5)")
        h("Epop[69] netConn_projEE_ampa[5553] = new NetCon(&v(0.5), syn_projEE_ampa[5553], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5554: cell 69, seg 0 (0.5) [0.5 on Epop[69]] -> cell 34, seg 0 (0.5) [0.5 on Epop[34]], weight: 4.1363508E-4, delay 1.5
        h("Epop[34] syn_projEE_ampa[5554] = new ampa(0.5)")
        h("Epop[69] netConn_projEE_ampa[5554] = new NetCon(&v(0.5), syn_projEE_ampa[5554], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5555: cell 69, seg 0 (0.5) [0.5 on Epop[69]] -> cell 35, seg 0 (0.5) [0.5 on Epop[35]], weight: 4.1363508E-4, delay 1.5
        h("Epop[35] syn_projEE_ampa[5555] = new ampa(0.5)")
        h("Epop[69] netConn_projEE_ampa[5555] = new NetCon(&v(0.5), syn_projEE_ampa[5555], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5556: cell 69, seg 0 (0.5) [0.5 on Epop[69]] -> cell 36, seg 0 (0.5) [0.5 on Epop[36]], weight: 4.1363508E-4, delay 1.5
        h("Epop[36] syn_projEE_ampa[5556] = new ampa(0.5)")
        h("Epop[69] netConn_projEE_ampa[5556] = new NetCon(&v(0.5), syn_projEE_ampa[5556], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5557: cell 69, seg 0 (0.5) [0.5 on Epop[69]] -> cell 37, seg 0 (0.5) [0.5 on Epop[37]], weight: 4.1363508E-4, delay 1.5
        h("Epop[37] syn_projEE_ampa[5557] = new ampa(0.5)")
        h("Epop[69] netConn_projEE_ampa[5557] = new NetCon(&v(0.5), syn_projEE_ampa[5557], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5558: cell 69, seg 0 (0.5) [0.5 on Epop[69]] -> cell 38, seg 0 (0.5) [0.5 on Epop[38]], weight: 4.1363508E-4, delay 1.5
        h("Epop[38] syn_projEE_ampa[5558] = new ampa(0.5)")
        h("Epop[69] netConn_projEE_ampa[5558] = new NetCon(&v(0.5), syn_projEE_ampa[5558], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5559: cell 69, seg 0 (0.5) [0.5 on Epop[69]] -> cell 39, seg 0 (0.5) [0.5 on Epop[39]], weight: 4.1363508E-4, delay 1.5
        h("Epop[39] syn_projEE_ampa[5559] = new ampa(0.5)")
        h("Epop[69] netConn_projEE_ampa[5559] = new NetCon(&v(0.5), syn_projEE_ampa[5559], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5560: cell 69, seg 0 (0.5) [0.5 on Epop[69]] -> cell 40, seg 0 (0.5) [0.5 on Epop[40]], weight: 4.1363508E-4, delay 1.5
        h("Epop[40] syn_projEE_ampa[5560] = new ampa(0.5)")
        h("Epop[69] netConn_projEE_ampa[5560] = new NetCon(&v(0.5), syn_projEE_ampa[5560], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5561: cell 69, seg 0 (0.5) [0.5 on Epop[69]] -> cell 41, seg 0 (0.5) [0.5 on Epop[41]], weight: 4.1363508E-4, delay 1.5
        h("Epop[41] syn_projEE_ampa[5561] = new ampa(0.5)")
        h("Epop[69] netConn_projEE_ampa[5561] = new NetCon(&v(0.5), syn_projEE_ampa[5561], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5562: cell 69, seg 0 (0.5) [0.5 on Epop[69]] -> cell 42, seg 0 (0.5) [0.5 on Epop[42]], weight: 4.1363508E-4, delay 1.5
        h("Epop[42] syn_projEE_ampa[5562] = new ampa(0.5)")
        h("Epop[69] netConn_projEE_ampa[5562] = new NetCon(&v(0.5), syn_projEE_ampa[5562], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5563: cell 69, seg 0 (0.5) [0.5 on Epop[69]] -> cell 43, seg 0 (0.5) [0.5 on Epop[43]], weight: 4.1363508E-4, delay 1.5
        h("Epop[43] syn_projEE_ampa[5563] = new ampa(0.5)")
        h("Epop[69] netConn_projEE_ampa[5563] = new NetCon(&v(0.5), syn_projEE_ampa[5563], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5564: cell 69, seg 0 (0.5) [0.5 on Epop[69]] -> cell 44, seg 0 (0.5) [0.5 on Epop[44]], weight: 4.1363508E-4, delay 1.5
        h("Epop[44] syn_projEE_ampa[5564] = new ampa(0.5)")
        h("Epop[69] netConn_projEE_ampa[5564] = new NetCon(&v(0.5), syn_projEE_ampa[5564], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5565: cell 69, seg 0 (0.5) [0.5 on Epop[69]] -> cell 45, seg 0 (0.5) [0.5 on Epop[45]], weight: 4.1363508E-4, delay 1.5
        h("Epop[45] syn_projEE_ampa[5565] = new ampa(0.5)")
        h("Epop[69] netConn_projEE_ampa[5565] = new NetCon(&v(0.5), syn_projEE_ampa[5565], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5566: cell 69, seg 0 (0.5) [0.5 on Epop[69]] -> cell 46, seg 0 (0.5) [0.5 on Epop[46]], weight: 4.1363508E-4, delay 1.5
        h("Epop[46] syn_projEE_ampa[5566] = new ampa(0.5)")
        h("Epop[69] netConn_projEE_ampa[5566] = new NetCon(&v(0.5), syn_projEE_ampa[5566], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5567: cell 69, seg 0 (0.5) [0.5 on Epop[69]] -> cell 47, seg 0 (0.5) [0.5 on Epop[47]], weight: 4.1363508E-4, delay 1.5
        h("Epop[47] syn_projEE_ampa[5567] = new ampa(0.5)")
        h("Epop[69] netConn_projEE_ampa[5567] = new NetCon(&v(0.5), syn_projEE_ampa[5567], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5568: cell 69, seg 0 (0.5) [0.5 on Epop[69]] -> cell 48, seg 0 (0.5) [0.5 on Epop[48]], weight: 4.1363508E-4, delay 1.5
        h("Epop[48] syn_projEE_ampa[5568] = new ampa(0.5)")
        h("Epop[69] netConn_projEE_ampa[5568] = new NetCon(&v(0.5), syn_projEE_ampa[5568], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5569: cell 69, seg 0 (0.5) [0.5 on Epop[69]] -> cell 49, seg 0 (0.5) [0.5 on Epop[49]], weight: 4.1363508E-4, delay 1.5
        h("Epop[49] syn_projEE_ampa[5569] = new ampa(0.5)")
        h("Epop[69] netConn_projEE_ampa[5569] = new NetCon(&v(0.5), syn_projEE_ampa[5569], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5570: cell 69, seg 0 (0.5) [0.5 on Epop[69]] -> cell 50, seg 0 (0.5) [0.5 on Epop[50]], weight: 4.1363508E-4, delay 1.5
        h("Epop[50] syn_projEE_ampa[5570] = new ampa(0.5)")
        h("Epop[69] netConn_projEE_ampa[5570] = new NetCon(&v(0.5), syn_projEE_ampa[5570], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5571: cell 69, seg 0 (0.5) [0.5 on Epop[69]] -> cell 51, seg 0 (0.5) [0.5 on Epop[51]], weight: 4.1363508E-4, delay 1.5
        h("Epop[51] syn_projEE_ampa[5571] = new ampa(0.5)")
        h("Epop[69] netConn_projEE_ampa[5571] = new NetCon(&v(0.5), syn_projEE_ampa[5571], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5572: cell 69, seg 0 (0.5) [0.5 on Epop[69]] -> cell 52, seg 0 (0.5) [0.5 on Epop[52]], weight: 4.1363508E-4, delay 1.5
        h("Epop[52] syn_projEE_ampa[5572] = new ampa(0.5)")
        h("Epop[69] netConn_projEE_ampa[5572] = new NetCon(&v(0.5), syn_projEE_ampa[5572], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5573: cell 69, seg 0 (0.5) [0.5 on Epop[69]] -> cell 53, seg 0 (0.5) [0.5 on Epop[53]], weight: 4.1363508E-4, delay 1.5
        h("Epop[53] syn_projEE_ampa[5573] = new ampa(0.5)")
        h("Epop[69] netConn_projEE_ampa[5573] = new NetCon(&v(0.5), syn_projEE_ampa[5573], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5574: cell 69, seg 0 (0.5) [0.5 on Epop[69]] -> cell 54, seg 0 (0.5) [0.5 on Epop[54]], weight: 4.1363508E-4, delay 1.5
        h("Epop[54] syn_projEE_ampa[5574] = new ampa(0.5)")
        h("Epop[69] netConn_projEE_ampa[5574] = new NetCon(&v(0.5), syn_projEE_ampa[5574], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5575: cell 69, seg 0 (0.5) [0.5 on Epop[69]] -> cell 55, seg 0 (0.5) [0.5 on Epop[55]], weight: 4.1363508E-4, delay 1.5
        h("Epop[55] syn_projEE_ampa[5575] = new ampa(0.5)")
        h("Epop[69] netConn_projEE_ampa[5575] = new NetCon(&v(0.5), syn_projEE_ampa[5575], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5576: cell 69, seg 0 (0.5) [0.5 on Epop[69]] -> cell 56, seg 0 (0.5) [0.5 on Epop[56]], weight: 4.1363508E-4, delay 1.5
        h("Epop[56] syn_projEE_ampa[5576] = new ampa(0.5)")
        h("Epop[69] netConn_projEE_ampa[5576] = new NetCon(&v(0.5), syn_projEE_ampa[5576], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5577: cell 69, seg 0 (0.5) [0.5 on Epop[69]] -> cell 57, seg 0 (0.5) [0.5 on Epop[57]], weight: 4.1363508E-4, delay 1.5
        h("Epop[57] syn_projEE_ampa[5577] = new ampa(0.5)")
        h("Epop[69] netConn_projEE_ampa[5577] = new NetCon(&v(0.5), syn_projEE_ampa[5577], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5578: cell 69, seg 0 (0.5) [0.5 on Epop[69]] -> cell 58, seg 0 (0.5) [0.5 on Epop[58]], weight: 4.1363508E-4, delay 1.5
        h("Epop[58] syn_projEE_ampa[5578] = new ampa(0.5)")
        h("Epop[69] netConn_projEE_ampa[5578] = new NetCon(&v(0.5), syn_projEE_ampa[5578], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5579: cell 69, seg 0 (0.5) [0.5 on Epop[69]] -> cell 59, seg 0 (0.5) [0.5 on Epop[59]], weight: 4.1363508E-4, delay 1.5
        h("Epop[59] syn_projEE_ampa[5579] = new ampa(0.5)")
        h("Epop[69] netConn_projEE_ampa[5579] = new NetCon(&v(0.5), syn_projEE_ampa[5579], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5580: cell 69, seg 0 (0.5) [0.5 on Epop[69]] -> cell 60, seg 0 (0.5) [0.5 on Epop[60]], weight: 4.1363508E-4, delay 1.5
        h("Epop[60] syn_projEE_ampa[5580] = new ampa(0.5)")
        h("Epop[69] netConn_projEE_ampa[5580] = new NetCon(&v(0.5), syn_projEE_ampa[5580], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5581: cell 69, seg 0 (0.5) [0.5 on Epop[69]] -> cell 61, seg 0 (0.5) [0.5 on Epop[61]], weight: 4.1363508E-4, delay 1.5
        h("Epop[61] syn_projEE_ampa[5581] = new ampa(0.5)")
        h("Epop[69] netConn_projEE_ampa[5581] = new NetCon(&v(0.5), syn_projEE_ampa[5581], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5582: cell 69, seg 0 (0.5) [0.5 on Epop[69]] -> cell 62, seg 0 (0.5) [0.5 on Epop[62]], weight: 4.1363508E-4, delay 1.5
        h("Epop[62] syn_projEE_ampa[5582] = new ampa(0.5)")
        h("Epop[69] netConn_projEE_ampa[5582] = new NetCon(&v(0.5), syn_projEE_ampa[5582], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5583: cell 69, seg 0 (0.5) [0.5 on Epop[69]] -> cell 63, seg 0 (0.5) [0.5 on Epop[63]], weight: 4.1363508E-4, delay 1.5
        h("Epop[63] syn_projEE_ampa[5583] = new ampa(0.5)")
        h("Epop[69] netConn_projEE_ampa[5583] = new NetCon(&v(0.5), syn_projEE_ampa[5583], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5584: cell 69, seg 0 (0.5) [0.5 on Epop[69]] -> cell 64, seg 0 (0.5) [0.5 on Epop[64]], weight: 4.1363508E-4, delay 1.5
        h("Epop[64] syn_projEE_ampa[5584] = new ampa(0.5)")
        h("Epop[69] netConn_projEE_ampa[5584] = new NetCon(&v(0.5), syn_projEE_ampa[5584], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5585: cell 69, seg 0 (0.5) [0.5 on Epop[69]] -> cell 65, seg 0 (0.5) [0.5 on Epop[65]], weight: 4.1363508E-4, delay 1.5
        h("Epop[65] syn_projEE_ampa[5585] = new ampa(0.5)")
        h("Epop[69] netConn_projEE_ampa[5585] = new NetCon(&v(0.5), syn_projEE_ampa[5585], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5586: cell 69, seg 0 (0.5) [0.5 on Epop[69]] -> cell 66, seg 0 (0.5) [0.5 on Epop[66]], weight: 4.1363508E-4, delay 1.5
        h("Epop[66] syn_projEE_ampa[5586] = new ampa(0.5)")
        h("Epop[69] netConn_projEE_ampa[5586] = new NetCon(&v(0.5), syn_projEE_ampa[5586], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5587: cell 69, seg 0 (0.5) [0.5 on Epop[69]] -> cell 67, seg 0 (0.5) [0.5 on Epop[67]], weight: 4.1363508E-4, delay 1.5
        h("Epop[67] syn_projEE_ampa[5587] = new ampa(0.5)")
        h("Epop[69] netConn_projEE_ampa[5587] = new NetCon(&v(0.5), syn_projEE_ampa[5587], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5588: cell 69, seg 0 (0.5) [0.5 on Epop[69]] -> cell 68, seg 0 (0.5) [0.5 on Epop[68]], weight: 4.1363508E-4, delay 1.5
        h("Epop[68] syn_projEE_ampa[5588] = new ampa(0.5)")
        h("Epop[69] netConn_projEE_ampa[5588] = new NetCon(&v(0.5), syn_projEE_ampa[5588], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5589: cell 69, seg 0 (0.5) [0.5 on Epop[69]] -> cell 69, seg 0 (0.5) [0.5 on Epop[69]], weight: 4.1363508E-4, delay 1.5
        h("Epop[69] syn_projEE_ampa[5589] = new ampa(0.5)")
        h("Epop[69] netConn_projEE_ampa[5589] = new NetCon(&v(0.5), syn_projEE_ampa[5589], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5590: cell 69, seg 0 (0.5) [0.5 on Epop[69]] -> cell 70, seg 0 (0.5) [0.5 on Epop[70]], weight: 4.1363508E-4, delay 1.5
        h("Epop[70] syn_projEE_ampa[5590] = new ampa(0.5)")
        h("Epop[69] netConn_projEE_ampa[5590] = new NetCon(&v(0.5), syn_projEE_ampa[5590], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5591: cell 69, seg 0 (0.5) [0.5 on Epop[69]] -> cell 71, seg 0 (0.5) [0.5 on Epop[71]], weight: 4.1363508E-4, delay 1.5
        h("Epop[71] syn_projEE_ampa[5591] = new ampa(0.5)")
        h("Epop[69] netConn_projEE_ampa[5591] = new NetCon(&v(0.5), syn_projEE_ampa[5591], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5592: cell 69, seg 0 (0.5) [0.5 on Epop[69]] -> cell 72, seg 0 (0.5) [0.5 on Epop[72]], weight: 4.1363508E-4, delay 1.5
        h("Epop[72] syn_projEE_ampa[5592] = new ampa(0.5)")
        h("Epop[69] netConn_projEE_ampa[5592] = new NetCon(&v(0.5), syn_projEE_ampa[5592], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5593: cell 69, seg 0 (0.5) [0.5 on Epop[69]] -> cell 73, seg 0 (0.5) [0.5 on Epop[73]], weight: 4.1363508E-4, delay 1.5
        h("Epop[73] syn_projEE_ampa[5593] = new ampa(0.5)")
        h("Epop[69] netConn_projEE_ampa[5593] = new NetCon(&v(0.5), syn_projEE_ampa[5593], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5594: cell 69, seg 0 (0.5) [0.5 on Epop[69]] -> cell 74, seg 0 (0.5) [0.5 on Epop[74]], weight: 4.1363508E-4, delay 1.5
        h("Epop[74] syn_projEE_ampa[5594] = new ampa(0.5)")
        h("Epop[69] netConn_projEE_ampa[5594] = new NetCon(&v(0.5), syn_projEE_ampa[5594], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5595: cell 69, seg 0 (0.5) [0.5 on Epop[69]] -> cell 75, seg 0 (0.5) [0.5 on Epop[75]], weight: 4.1363508E-4, delay 1.5
        h("Epop[75] syn_projEE_ampa[5595] = new ampa(0.5)")
        h("Epop[69] netConn_projEE_ampa[5595] = new NetCon(&v(0.5), syn_projEE_ampa[5595], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5596: cell 69, seg 0 (0.5) [0.5 on Epop[69]] -> cell 76, seg 0 (0.5) [0.5 on Epop[76]], weight: 4.1363508E-4, delay 1.5
        h("Epop[76] syn_projEE_ampa[5596] = new ampa(0.5)")
        h("Epop[69] netConn_projEE_ampa[5596] = new NetCon(&v(0.5), syn_projEE_ampa[5596], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5597: cell 69, seg 0 (0.5) [0.5 on Epop[69]] -> cell 77, seg 0 (0.5) [0.5 on Epop[77]], weight: 4.1363508E-4, delay 1.5
        h("Epop[77] syn_projEE_ampa[5597] = new ampa(0.5)")
        h("Epop[69] netConn_projEE_ampa[5597] = new NetCon(&v(0.5), syn_projEE_ampa[5597], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5598: cell 69, seg 0 (0.5) [0.5 on Epop[69]] -> cell 78, seg 0 (0.5) [0.5 on Epop[78]], weight: 4.1363508E-4, delay 1.5
        h("Epop[78] syn_projEE_ampa[5598] = new ampa(0.5)")
        h("Epop[69] netConn_projEE_ampa[5598] = new NetCon(&v(0.5), syn_projEE_ampa[5598], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5599: cell 69, seg 0 (0.5) [0.5 on Epop[69]] -> cell 79, seg 0 (0.5) [0.5 on Epop[79]], weight: 4.1363508E-4, delay 1.5
        h("Epop[79] syn_projEE_ampa[5599] = new ampa(0.5)")
        h("Epop[69] netConn_projEE_ampa[5599] = new NetCon(&v(0.5), syn_projEE_ampa[5599], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5600: cell 70, seg 0 (0.5) [0.5 on Epop[70]] -> cell 0, seg 0 (0.5) [0.5 on Epop[0]], weight: 4.1363508E-4, delay 1.5
        h("Epop[0] syn_projEE_ampa[5600] = new ampa(0.5)")
        h("Epop[70] netConn_projEE_ampa[5600] = new NetCon(&v(0.5), syn_projEE_ampa[5600], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5601: cell 70, seg 0 (0.5) [0.5 on Epop[70]] -> cell 1, seg 0 (0.5) [0.5 on Epop[1]], weight: 4.1363508E-4, delay 1.5
        h("Epop[1] syn_projEE_ampa[5601] = new ampa(0.5)")
        h("Epop[70] netConn_projEE_ampa[5601] = new NetCon(&v(0.5), syn_projEE_ampa[5601], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5602: cell 70, seg 0 (0.5) [0.5 on Epop[70]] -> cell 2, seg 0 (0.5) [0.5 on Epop[2]], weight: 4.1363508E-4, delay 1.5
        h("Epop[2] syn_projEE_ampa[5602] = new ampa(0.5)")
        h("Epop[70] netConn_projEE_ampa[5602] = new NetCon(&v(0.5), syn_projEE_ampa[5602], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5603: cell 70, seg 0 (0.5) [0.5 on Epop[70]] -> cell 3, seg 0 (0.5) [0.5 on Epop[3]], weight: 4.1363508E-4, delay 1.5
        h("Epop[3] syn_projEE_ampa[5603] = new ampa(0.5)")
        h("Epop[70] netConn_projEE_ampa[5603] = new NetCon(&v(0.5), syn_projEE_ampa[5603], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5604: cell 70, seg 0 (0.5) [0.5 on Epop[70]] -> cell 4, seg 0 (0.5) [0.5 on Epop[4]], weight: 4.1363508E-4, delay 1.5
        h("Epop[4] syn_projEE_ampa[5604] = new ampa(0.5)")
        h("Epop[70] netConn_projEE_ampa[5604] = new NetCon(&v(0.5), syn_projEE_ampa[5604], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5605: cell 70, seg 0 (0.5) [0.5 on Epop[70]] -> cell 5, seg 0 (0.5) [0.5 on Epop[5]], weight: 4.1363508E-4, delay 1.5
        h("Epop[5] syn_projEE_ampa[5605] = new ampa(0.5)")
        h("Epop[70] netConn_projEE_ampa[5605] = new NetCon(&v(0.5), syn_projEE_ampa[5605], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5606: cell 70, seg 0 (0.5) [0.5 on Epop[70]] -> cell 6, seg 0 (0.5) [0.5 on Epop[6]], weight: 4.1363508E-4, delay 1.5
        h("Epop[6] syn_projEE_ampa[5606] = new ampa(0.5)")
        h("Epop[70] netConn_projEE_ampa[5606] = new NetCon(&v(0.5), syn_projEE_ampa[5606], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5607: cell 70, seg 0 (0.5) [0.5 on Epop[70]] -> cell 7, seg 0 (0.5) [0.5 on Epop[7]], weight: 4.1363508E-4, delay 1.5
        h("Epop[7] syn_projEE_ampa[5607] = new ampa(0.5)")
        h("Epop[70] netConn_projEE_ampa[5607] = new NetCon(&v(0.5), syn_projEE_ampa[5607], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5608: cell 70, seg 0 (0.5) [0.5 on Epop[70]] -> cell 8, seg 0 (0.5) [0.5 on Epop[8]], weight: 4.1363508E-4, delay 1.5
        h("Epop[8] syn_projEE_ampa[5608] = new ampa(0.5)")
        h("Epop[70] netConn_projEE_ampa[5608] = new NetCon(&v(0.5), syn_projEE_ampa[5608], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5609: cell 70, seg 0 (0.5) [0.5 on Epop[70]] -> cell 9, seg 0 (0.5) [0.5 on Epop[9]], weight: 4.1363508E-4, delay 1.5
        h("Epop[9] syn_projEE_ampa[5609] = new ampa(0.5)")
        h("Epop[70] netConn_projEE_ampa[5609] = new NetCon(&v(0.5), syn_projEE_ampa[5609], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5610: cell 70, seg 0 (0.5) [0.5 on Epop[70]] -> cell 10, seg 0 (0.5) [0.5 on Epop[10]], weight: 4.1363508E-4, delay 1.5
        h("Epop[10] syn_projEE_ampa[5610] = new ampa(0.5)")
        h("Epop[70] netConn_projEE_ampa[5610] = new NetCon(&v(0.5), syn_projEE_ampa[5610], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5611: cell 70, seg 0 (0.5) [0.5 on Epop[70]] -> cell 11, seg 0 (0.5) [0.5 on Epop[11]], weight: 4.1363508E-4, delay 1.5
        h("Epop[11] syn_projEE_ampa[5611] = new ampa(0.5)")
        h("Epop[70] netConn_projEE_ampa[5611] = new NetCon(&v(0.5), syn_projEE_ampa[5611], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5612: cell 70, seg 0 (0.5) [0.5 on Epop[70]] -> cell 12, seg 0 (0.5) [0.5 on Epop[12]], weight: 4.1363508E-4, delay 1.5
        h("Epop[12] syn_projEE_ampa[5612] = new ampa(0.5)")
        h("Epop[70] netConn_projEE_ampa[5612] = new NetCon(&v(0.5), syn_projEE_ampa[5612], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5613: cell 70, seg 0 (0.5) [0.5 on Epop[70]] -> cell 13, seg 0 (0.5) [0.5 on Epop[13]], weight: 4.1363508E-4, delay 1.5
        h("Epop[13] syn_projEE_ampa[5613] = new ampa(0.5)")
        h("Epop[70] netConn_projEE_ampa[5613] = new NetCon(&v(0.5), syn_projEE_ampa[5613], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5614: cell 70, seg 0 (0.5) [0.5 on Epop[70]] -> cell 14, seg 0 (0.5) [0.5 on Epop[14]], weight: 4.1363508E-4, delay 1.5
        h("Epop[14] syn_projEE_ampa[5614] = new ampa(0.5)")
        h("Epop[70] netConn_projEE_ampa[5614] = new NetCon(&v(0.5), syn_projEE_ampa[5614], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5615: cell 70, seg 0 (0.5) [0.5 on Epop[70]] -> cell 15, seg 0 (0.5) [0.5 on Epop[15]], weight: 4.1363508E-4, delay 1.5
        h("Epop[15] syn_projEE_ampa[5615] = new ampa(0.5)")
        h("Epop[70] netConn_projEE_ampa[5615] = new NetCon(&v(0.5), syn_projEE_ampa[5615], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5616: cell 70, seg 0 (0.5) [0.5 on Epop[70]] -> cell 16, seg 0 (0.5) [0.5 on Epop[16]], weight: 4.1363508E-4, delay 1.5
        h("Epop[16] syn_projEE_ampa[5616] = new ampa(0.5)")
        h("Epop[70] netConn_projEE_ampa[5616] = new NetCon(&v(0.5), syn_projEE_ampa[5616], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5617: cell 70, seg 0 (0.5) [0.5 on Epop[70]] -> cell 17, seg 0 (0.5) [0.5 on Epop[17]], weight: 4.1363508E-4, delay 1.5
        h("Epop[17] syn_projEE_ampa[5617] = new ampa(0.5)")
        h("Epop[70] netConn_projEE_ampa[5617] = new NetCon(&v(0.5), syn_projEE_ampa[5617], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5618: cell 70, seg 0 (0.5) [0.5 on Epop[70]] -> cell 18, seg 0 (0.5) [0.5 on Epop[18]], weight: 4.1363508E-4, delay 1.5
        h("Epop[18] syn_projEE_ampa[5618] = new ampa(0.5)")
        h("Epop[70] netConn_projEE_ampa[5618] = new NetCon(&v(0.5), syn_projEE_ampa[5618], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5619: cell 70, seg 0 (0.5) [0.5 on Epop[70]] -> cell 19, seg 0 (0.5) [0.5 on Epop[19]], weight: 4.1363508E-4, delay 1.5
        h("Epop[19] syn_projEE_ampa[5619] = new ampa(0.5)")
        h("Epop[70] netConn_projEE_ampa[5619] = new NetCon(&v(0.5), syn_projEE_ampa[5619], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5620: cell 70, seg 0 (0.5) [0.5 on Epop[70]] -> cell 20, seg 0 (0.5) [0.5 on Epop[20]], weight: 4.1363508E-4, delay 1.5
        h("Epop[20] syn_projEE_ampa[5620] = new ampa(0.5)")
        h("Epop[70] netConn_projEE_ampa[5620] = new NetCon(&v(0.5), syn_projEE_ampa[5620], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5621: cell 70, seg 0 (0.5) [0.5 on Epop[70]] -> cell 21, seg 0 (0.5) [0.5 on Epop[21]], weight: 4.1363508E-4, delay 1.5
        h("Epop[21] syn_projEE_ampa[5621] = new ampa(0.5)")
        h("Epop[70] netConn_projEE_ampa[5621] = new NetCon(&v(0.5), syn_projEE_ampa[5621], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5622: cell 70, seg 0 (0.5) [0.5 on Epop[70]] -> cell 22, seg 0 (0.5) [0.5 on Epop[22]], weight: 4.1363508E-4, delay 1.5
        h("Epop[22] syn_projEE_ampa[5622] = new ampa(0.5)")
        h("Epop[70] netConn_projEE_ampa[5622] = new NetCon(&v(0.5), syn_projEE_ampa[5622], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5623: cell 70, seg 0 (0.5) [0.5 on Epop[70]] -> cell 23, seg 0 (0.5) [0.5 on Epop[23]], weight: 4.1363508E-4, delay 1.5
        h("Epop[23] syn_projEE_ampa[5623] = new ampa(0.5)")
        h("Epop[70] netConn_projEE_ampa[5623] = new NetCon(&v(0.5), syn_projEE_ampa[5623], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5624: cell 70, seg 0 (0.5) [0.5 on Epop[70]] -> cell 24, seg 0 (0.5) [0.5 on Epop[24]], weight: 4.1363508E-4, delay 1.5
        h("Epop[24] syn_projEE_ampa[5624] = new ampa(0.5)")
        h("Epop[70] netConn_projEE_ampa[5624] = new NetCon(&v(0.5), syn_projEE_ampa[5624], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5625: cell 70, seg 0 (0.5) [0.5 on Epop[70]] -> cell 25, seg 0 (0.5) [0.5 on Epop[25]], weight: 4.1363508E-4, delay 1.5
        h("Epop[25] syn_projEE_ampa[5625] = new ampa(0.5)")
        h("Epop[70] netConn_projEE_ampa[5625] = new NetCon(&v(0.5), syn_projEE_ampa[5625], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5626: cell 70, seg 0 (0.5) [0.5 on Epop[70]] -> cell 26, seg 0 (0.5) [0.5 on Epop[26]], weight: 4.1363508E-4, delay 1.5
        h("Epop[26] syn_projEE_ampa[5626] = new ampa(0.5)")
        h("Epop[70] netConn_projEE_ampa[5626] = new NetCon(&v(0.5), syn_projEE_ampa[5626], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5627: cell 70, seg 0 (0.5) [0.5 on Epop[70]] -> cell 27, seg 0 (0.5) [0.5 on Epop[27]], weight: 4.1363508E-4, delay 1.5
        h("Epop[27] syn_projEE_ampa[5627] = new ampa(0.5)")
        h("Epop[70] netConn_projEE_ampa[5627] = new NetCon(&v(0.5), syn_projEE_ampa[5627], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5628: cell 70, seg 0 (0.5) [0.5 on Epop[70]] -> cell 28, seg 0 (0.5) [0.5 on Epop[28]], weight: 4.1363508E-4, delay 1.5
        h("Epop[28] syn_projEE_ampa[5628] = new ampa(0.5)")
        h("Epop[70] netConn_projEE_ampa[5628] = new NetCon(&v(0.5), syn_projEE_ampa[5628], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5629: cell 70, seg 0 (0.5) [0.5 on Epop[70]] -> cell 29, seg 0 (0.5) [0.5 on Epop[29]], weight: 4.1363508E-4, delay 1.5
        h("Epop[29] syn_projEE_ampa[5629] = new ampa(0.5)")
        h("Epop[70] netConn_projEE_ampa[5629] = new NetCon(&v(0.5), syn_projEE_ampa[5629], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5630: cell 70, seg 0 (0.5) [0.5 on Epop[70]] -> cell 30, seg 0 (0.5) [0.5 on Epop[30]], weight: 4.1363508E-4, delay 1.5
        h("Epop[30] syn_projEE_ampa[5630] = new ampa(0.5)")
        h("Epop[70] netConn_projEE_ampa[5630] = new NetCon(&v(0.5), syn_projEE_ampa[5630], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5631: cell 70, seg 0 (0.5) [0.5 on Epop[70]] -> cell 31, seg 0 (0.5) [0.5 on Epop[31]], weight: 4.1363508E-4, delay 1.5
        h("Epop[31] syn_projEE_ampa[5631] = new ampa(0.5)")
        h("Epop[70] netConn_projEE_ampa[5631] = new NetCon(&v(0.5), syn_projEE_ampa[5631], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5632: cell 70, seg 0 (0.5) [0.5 on Epop[70]] -> cell 32, seg 0 (0.5) [0.5 on Epop[32]], weight: 4.1363508E-4, delay 1.5
        h("Epop[32] syn_projEE_ampa[5632] = new ampa(0.5)")
        h("Epop[70] netConn_projEE_ampa[5632] = new NetCon(&v(0.5), syn_projEE_ampa[5632], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5633: cell 70, seg 0 (0.5) [0.5 on Epop[70]] -> cell 33, seg 0 (0.5) [0.5 on Epop[33]], weight: 4.1363508E-4, delay 1.5
        h("Epop[33] syn_projEE_ampa[5633] = new ampa(0.5)")
        h("Epop[70] netConn_projEE_ampa[5633] = new NetCon(&v(0.5), syn_projEE_ampa[5633], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5634: cell 70, seg 0 (0.5) [0.5 on Epop[70]] -> cell 34, seg 0 (0.5) [0.5 on Epop[34]], weight: 4.1363508E-4, delay 1.5
        h("Epop[34] syn_projEE_ampa[5634] = new ampa(0.5)")
        h("Epop[70] netConn_projEE_ampa[5634] = new NetCon(&v(0.5), syn_projEE_ampa[5634], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5635: cell 70, seg 0 (0.5) [0.5 on Epop[70]] -> cell 35, seg 0 (0.5) [0.5 on Epop[35]], weight: 4.1363508E-4, delay 1.5
        h("Epop[35] syn_projEE_ampa[5635] = new ampa(0.5)")
        h("Epop[70] netConn_projEE_ampa[5635] = new NetCon(&v(0.5), syn_projEE_ampa[5635], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5636: cell 70, seg 0 (0.5) [0.5 on Epop[70]] -> cell 36, seg 0 (0.5) [0.5 on Epop[36]], weight: 4.1363508E-4, delay 1.5
        h("Epop[36] syn_projEE_ampa[5636] = new ampa(0.5)")
        h("Epop[70] netConn_projEE_ampa[5636] = new NetCon(&v(0.5), syn_projEE_ampa[5636], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5637: cell 70, seg 0 (0.5) [0.5 on Epop[70]] -> cell 37, seg 0 (0.5) [0.5 on Epop[37]], weight: 4.1363508E-4, delay 1.5
        h("Epop[37] syn_projEE_ampa[5637] = new ampa(0.5)")
        h("Epop[70] netConn_projEE_ampa[5637] = new NetCon(&v(0.5), syn_projEE_ampa[5637], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5638: cell 70, seg 0 (0.5) [0.5 on Epop[70]] -> cell 38, seg 0 (0.5) [0.5 on Epop[38]], weight: 4.1363508E-4, delay 1.5
        h("Epop[38] syn_projEE_ampa[5638] = new ampa(0.5)")
        h("Epop[70] netConn_projEE_ampa[5638] = new NetCon(&v(0.5), syn_projEE_ampa[5638], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5639: cell 70, seg 0 (0.5) [0.5 on Epop[70]] -> cell 39, seg 0 (0.5) [0.5 on Epop[39]], weight: 4.1363508E-4, delay 1.5
        h("Epop[39] syn_projEE_ampa[5639] = new ampa(0.5)")
        h("Epop[70] netConn_projEE_ampa[5639] = new NetCon(&v(0.5), syn_projEE_ampa[5639], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5640: cell 70, seg 0 (0.5) [0.5 on Epop[70]] -> cell 40, seg 0 (0.5) [0.5 on Epop[40]], weight: 4.1363508E-4, delay 1.5
        h("Epop[40] syn_projEE_ampa[5640] = new ampa(0.5)")
        h("Epop[70] netConn_projEE_ampa[5640] = new NetCon(&v(0.5), syn_projEE_ampa[5640], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5641: cell 70, seg 0 (0.5) [0.5 on Epop[70]] -> cell 41, seg 0 (0.5) [0.5 on Epop[41]], weight: 4.1363508E-4, delay 1.5
        h("Epop[41] syn_projEE_ampa[5641] = new ampa(0.5)")
        h("Epop[70] netConn_projEE_ampa[5641] = new NetCon(&v(0.5), syn_projEE_ampa[5641], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5642: cell 70, seg 0 (0.5) [0.5 on Epop[70]] -> cell 42, seg 0 (0.5) [0.5 on Epop[42]], weight: 4.1363508E-4, delay 1.5
        h("Epop[42] syn_projEE_ampa[5642] = new ampa(0.5)")
        h("Epop[70] netConn_projEE_ampa[5642] = new NetCon(&v(0.5), syn_projEE_ampa[5642], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5643: cell 70, seg 0 (0.5) [0.5 on Epop[70]] -> cell 43, seg 0 (0.5) [0.5 on Epop[43]], weight: 4.1363508E-4, delay 1.5
        h("Epop[43] syn_projEE_ampa[5643] = new ampa(0.5)")
        h("Epop[70] netConn_projEE_ampa[5643] = new NetCon(&v(0.5), syn_projEE_ampa[5643], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5644: cell 70, seg 0 (0.5) [0.5 on Epop[70]] -> cell 44, seg 0 (0.5) [0.5 on Epop[44]], weight: 4.1363508E-4, delay 1.5
        h("Epop[44] syn_projEE_ampa[5644] = new ampa(0.5)")
        h("Epop[70] netConn_projEE_ampa[5644] = new NetCon(&v(0.5), syn_projEE_ampa[5644], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5645: cell 70, seg 0 (0.5) [0.5 on Epop[70]] -> cell 45, seg 0 (0.5) [0.5 on Epop[45]], weight: 4.1363508E-4, delay 1.5
        h("Epop[45] syn_projEE_ampa[5645] = new ampa(0.5)")
        h("Epop[70] netConn_projEE_ampa[5645] = new NetCon(&v(0.5), syn_projEE_ampa[5645], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5646: cell 70, seg 0 (0.5) [0.5 on Epop[70]] -> cell 46, seg 0 (0.5) [0.5 on Epop[46]], weight: 4.1363508E-4, delay 1.5
        h("Epop[46] syn_projEE_ampa[5646] = new ampa(0.5)")
        h("Epop[70] netConn_projEE_ampa[5646] = new NetCon(&v(0.5), syn_projEE_ampa[5646], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5647: cell 70, seg 0 (0.5) [0.5 on Epop[70]] -> cell 47, seg 0 (0.5) [0.5 on Epop[47]], weight: 4.1363508E-4, delay 1.5
        h("Epop[47] syn_projEE_ampa[5647] = new ampa(0.5)")
        h("Epop[70] netConn_projEE_ampa[5647] = new NetCon(&v(0.5), syn_projEE_ampa[5647], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5648: cell 70, seg 0 (0.5) [0.5 on Epop[70]] -> cell 48, seg 0 (0.5) [0.5 on Epop[48]], weight: 4.1363508E-4, delay 1.5
        h("Epop[48] syn_projEE_ampa[5648] = new ampa(0.5)")
        h("Epop[70] netConn_projEE_ampa[5648] = new NetCon(&v(0.5), syn_projEE_ampa[5648], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5649: cell 70, seg 0 (0.5) [0.5 on Epop[70]] -> cell 49, seg 0 (0.5) [0.5 on Epop[49]], weight: 4.1363508E-4, delay 1.5
        h("Epop[49] syn_projEE_ampa[5649] = new ampa(0.5)")
        h("Epop[70] netConn_projEE_ampa[5649] = new NetCon(&v(0.5), syn_projEE_ampa[5649], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5650: cell 70, seg 0 (0.5) [0.5 on Epop[70]] -> cell 50, seg 0 (0.5) [0.5 on Epop[50]], weight: 4.1363508E-4, delay 1.5
        h("Epop[50] syn_projEE_ampa[5650] = new ampa(0.5)")
        h("Epop[70] netConn_projEE_ampa[5650] = new NetCon(&v(0.5), syn_projEE_ampa[5650], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5651: cell 70, seg 0 (0.5) [0.5 on Epop[70]] -> cell 51, seg 0 (0.5) [0.5 on Epop[51]], weight: 4.1363508E-4, delay 1.5
        h("Epop[51] syn_projEE_ampa[5651] = new ampa(0.5)")
        h("Epop[70] netConn_projEE_ampa[5651] = new NetCon(&v(0.5), syn_projEE_ampa[5651], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5652: cell 70, seg 0 (0.5) [0.5 on Epop[70]] -> cell 52, seg 0 (0.5) [0.5 on Epop[52]], weight: 4.1363508E-4, delay 1.5
        h("Epop[52] syn_projEE_ampa[5652] = new ampa(0.5)")
        h("Epop[70] netConn_projEE_ampa[5652] = new NetCon(&v(0.5), syn_projEE_ampa[5652], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5653: cell 70, seg 0 (0.5) [0.5 on Epop[70]] -> cell 53, seg 0 (0.5) [0.5 on Epop[53]], weight: 4.1363508E-4, delay 1.5
        h("Epop[53] syn_projEE_ampa[5653] = new ampa(0.5)")
        h("Epop[70] netConn_projEE_ampa[5653] = new NetCon(&v(0.5), syn_projEE_ampa[5653], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5654: cell 70, seg 0 (0.5) [0.5 on Epop[70]] -> cell 54, seg 0 (0.5) [0.5 on Epop[54]], weight: 4.1363508E-4, delay 1.5
        h("Epop[54] syn_projEE_ampa[5654] = new ampa(0.5)")
        h("Epop[70] netConn_projEE_ampa[5654] = new NetCon(&v(0.5), syn_projEE_ampa[5654], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5655: cell 70, seg 0 (0.5) [0.5 on Epop[70]] -> cell 55, seg 0 (0.5) [0.5 on Epop[55]], weight: 4.1363508E-4, delay 1.5
        h("Epop[55] syn_projEE_ampa[5655] = new ampa(0.5)")
        h("Epop[70] netConn_projEE_ampa[5655] = new NetCon(&v(0.5), syn_projEE_ampa[5655], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5656: cell 70, seg 0 (0.5) [0.5 on Epop[70]] -> cell 56, seg 0 (0.5) [0.5 on Epop[56]], weight: 4.1363508E-4, delay 1.5
        h("Epop[56] syn_projEE_ampa[5656] = new ampa(0.5)")
        h("Epop[70] netConn_projEE_ampa[5656] = new NetCon(&v(0.5), syn_projEE_ampa[5656], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5657: cell 70, seg 0 (0.5) [0.5 on Epop[70]] -> cell 57, seg 0 (0.5) [0.5 on Epop[57]], weight: 4.1363508E-4, delay 1.5
        h("Epop[57] syn_projEE_ampa[5657] = new ampa(0.5)")
        h("Epop[70] netConn_projEE_ampa[5657] = new NetCon(&v(0.5), syn_projEE_ampa[5657], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5658: cell 70, seg 0 (0.5) [0.5 on Epop[70]] -> cell 58, seg 0 (0.5) [0.5 on Epop[58]], weight: 4.1363508E-4, delay 1.5
        h("Epop[58] syn_projEE_ampa[5658] = new ampa(0.5)")
        h("Epop[70] netConn_projEE_ampa[5658] = new NetCon(&v(0.5), syn_projEE_ampa[5658], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5659: cell 70, seg 0 (0.5) [0.5 on Epop[70]] -> cell 59, seg 0 (0.5) [0.5 on Epop[59]], weight: 4.1363508E-4, delay 1.5
        h("Epop[59] syn_projEE_ampa[5659] = new ampa(0.5)")
        h("Epop[70] netConn_projEE_ampa[5659] = new NetCon(&v(0.5), syn_projEE_ampa[5659], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5660: cell 70, seg 0 (0.5) [0.5 on Epop[70]] -> cell 60, seg 0 (0.5) [0.5 on Epop[60]], weight: 4.1363508E-4, delay 1.5
        h("Epop[60] syn_projEE_ampa[5660] = new ampa(0.5)")
        h("Epop[70] netConn_projEE_ampa[5660] = new NetCon(&v(0.5), syn_projEE_ampa[5660], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5661: cell 70, seg 0 (0.5) [0.5 on Epop[70]] -> cell 61, seg 0 (0.5) [0.5 on Epop[61]], weight: 4.1363508E-4, delay 1.5
        h("Epop[61] syn_projEE_ampa[5661] = new ampa(0.5)")
        h("Epop[70] netConn_projEE_ampa[5661] = new NetCon(&v(0.5), syn_projEE_ampa[5661], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5662: cell 70, seg 0 (0.5) [0.5 on Epop[70]] -> cell 62, seg 0 (0.5) [0.5 on Epop[62]], weight: 4.1363508E-4, delay 1.5
        h("Epop[62] syn_projEE_ampa[5662] = new ampa(0.5)")
        h("Epop[70] netConn_projEE_ampa[5662] = new NetCon(&v(0.5), syn_projEE_ampa[5662], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5663: cell 70, seg 0 (0.5) [0.5 on Epop[70]] -> cell 63, seg 0 (0.5) [0.5 on Epop[63]], weight: 4.1363508E-4, delay 1.5
        h("Epop[63] syn_projEE_ampa[5663] = new ampa(0.5)")
        h("Epop[70] netConn_projEE_ampa[5663] = new NetCon(&v(0.5), syn_projEE_ampa[5663], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5664: cell 70, seg 0 (0.5) [0.5 on Epop[70]] -> cell 64, seg 0 (0.5) [0.5 on Epop[64]], weight: 4.1363508E-4, delay 1.5
        h("Epop[64] syn_projEE_ampa[5664] = new ampa(0.5)")
        h("Epop[70] netConn_projEE_ampa[5664] = new NetCon(&v(0.5), syn_projEE_ampa[5664], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5665: cell 70, seg 0 (0.5) [0.5 on Epop[70]] -> cell 65, seg 0 (0.5) [0.5 on Epop[65]], weight: 4.1363508E-4, delay 1.5
        h("Epop[65] syn_projEE_ampa[5665] = new ampa(0.5)")
        h("Epop[70] netConn_projEE_ampa[5665] = new NetCon(&v(0.5), syn_projEE_ampa[5665], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5666: cell 70, seg 0 (0.5) [0.5 on Epop[70]] -> cell 66, seg 0 (0.5) [0.5 on Epop[66]], weight: 4.1363508E-4, delay 1.5
        h("Epop[66] syn_projEE_ampa[5666] = new ampa(0.5)")
        h("Epop[70] netConn_projEE_ampa[5666] = new NetCon(&v(0.5), syn_projEE_ampa[5666], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5667: cell 70, seg 0 (0.5) [0.5 on Epop[70]] -> cell 67, seg 0 (0.5) [0.5 on Epop[67]], weight: 4.1363508E-4, delay 1.5
        h("Epop[67] syn_projEE_ampa[5667] = new ampa(0.5)")
        h("Epop[70] netConn_projEE_ampa[5667] = new NetCon(&v(0.5), syn_projEE_ampa[5667], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5668: cell 70, seg 0 (0.5) [0.5 on Epop[70]] -> cell 68, seg 0 (0.5) [0.5 on Epop[68]], weight: 4.1363508E-4, delay 1.5
        h("Epop[68] syn_projEE_ampa[5668] = new ampa(0.5)")
        h("Epop[70] netConn_projEE_ampa[5668] = new NetCon(&v(0.5), syn_projEE_ampa[5668], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5669: cell 70, seg 0 (0.5) [0.5 on Epop[70]] -> cell 69, seg 0 (0.5) [0.5 on Epop[69]], weight: 4.1363508E-4, delay 1.5
        h("Epop[69] syn_projEE_ampa[5669] = new ampa(0.5)")
        h("Epop[70] netConn_projEE_ampa[5669] = new NetCon(&v(0.5), syn_projEE_ampa[5669], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5670: cell 70, seg 0 (0.5) [0.5 on Epop[70]] -> cell 70, seg 0 (0.5) [0.5 on Epop[70]], weight: 4.1363508E-4, delay 1.5
        h("Epop[70] syn_projEE_ampa[5670] = new ampa(0.5)")
        h("Epop[70] netConn_projEE_ampa[5670] = new NetCon(&v(0.5), syn_projEE_ampa[5670], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5671: cell 70, seg 0 (0.5) [0.5 on Epop[70]] -> cell 71, seg 0 (0.5) [0.5 on Epop[71]], weight: 4.1363508E-4, delay 1.5
        h("Epop[71] syn_projEE_ampa[5671] = new ampa(0.5)")
        h("Epop[70] netConn_projEE_ampa[5671] = new NetCon(&v(0.5), syn_projEE_ampa[5671], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5672: cell 70, seg 0 (0.5) [0.5 on Epop[70]] -> cell 72, seg 0 (0.5) [0.5 on Epop[72]], weight: 4.1363508E-4, delay 1.5
        h("Epop[72] syn_projEE_ampa[5672] = new ampa(0.5)")
        h("Epop[70] netConn_projEE_ampa[5672] = new NetCon(&v(0.5), syn_projEE_ampa[5672], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5673: cell 70, seg 0 (0.5) [0.5 on Epop[70]] -> cell 73, seg 0 (0.5) [0.5 on Epop[73]], weight: 4.1363508E-4, delay 1.5
        h("Epop[73] syn_projEE_ampa[5673] = new ampa(0.5)")
        h("Epop[70] netConn_projEE_ampa[5673] = new NetCon(&v(0.5), syn_projEE_ampa[5673], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5674: cell 70, seg 0 (0.5) [0.5 on Epop[70]] -> cell 74, seg 0 (0.5) [0.5 on Epop[74]], weight: 4.1363508E-4, delay 1.5
        h("Epop[74] syn_projEE_ampa[5674] = new ampa(0.5)")
        h("Epop[70] netConn_projEE_ampa[5674] = new NetCon(&v(0.5), syn_projEE_ampa[5674], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5675: cell 70, seg 0 (0.5) [0.5 on Epop[70]] -> cell 75, seg 0 (0.5) [0.5 on Epop[75]], weight: 4.1363508E-4, delay 1.5
        h("Epop[75] syn_projEE_ampa[5675] = new ampa(0.5)")
        h("Epop[70] netConn_projEE_ampa[5675] = new NetCon(&v(0.5), syn_projEE_ampa[5675], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5676: cell 70, seg 0 (0.5) [0.5 on Epop[70]] -> cell 76, seg 0 (0.5) [0.5 on Epop[76]], weight: 4.1363508E-4, delay 1.5
        h("Epop[76] syn_projEE_ampa[5676] = new ampa(0.5)")
        h("Epop[70] netConn_projEE_ampa[5676] = new NetCon(&v(0.5), syn_projEE_ampa[5676], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5677: cell 70, seg 0 (0.5) [0.5 on Epop[70]] -> cell 77, seg 0 (0.5) [0.5 on Epop[77]], weight: 4.1363508E-4, delay 1.5
        h("Epop[77] syn_projEE_ampa[5677] = new ampa(0.5)")
        h("Epop[70] netConn_projEE_ampa[5677] = new NetCon(&v(0.5), syn_projEE_ampa[5677], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5678: cell 70, seg 0 (0.5) [0.5 on Epop[70]] -> cell 78, seg 0 (0.5) [0.5 on Epop[78]], weight: 4.1363508E-4, delay 1.5
        h("Epop[78] syn_projEE_ampa[5678] = new ampa(0.5)")
        h("Epop[70] netConn_projEE_ampa[5678] = new NetCon(&v(0.5), syn_projEE_ampa[5678], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5679: cell 70, seg 0 (0.5) [0.5 on Epop[70]] -> cell 79, seg 0 (0.5) [0.5 on Epop[79]], weight: 4.1363508E-4, delay 1.5
        h("Epop[79] syn_projEE_ampa[5679] = new ampa(0.5)")
        h("Epop[70] netConn_projEE_ampa[5679] = new NetCon(&v(0.5), syn_projEE_ampa[5679], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5680: cell 71, seg 0 (0.5) [0.5 on Epop[71]] -> cell 0, seg 0 (0.5) [0.5 on Epop[0]], weight: 4.1363508E-4, delay 1.5
        h("Epop[0] syn_projEE_ampa[5680] = new ampa(0.5)")
        h("Epop[71] netConn_projEE_ampa[5680] = new NetCon(&v(0.5), syn_projEE_ampa[5680], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5681: cell 71, seg 0 (0.5) [0.5 on Epop[71]] -> cell 1, seg 0 (0.5) [0.5 on Epop[1]], weight: 4.1363508E-4, delay 1.5
        h("Epop[1] syn_projEE_ampa[5681] = new ampa(0.5)")
        h("Epop[71] netConn_projEE_ampa[5681] = new NetCon(&v(0.5), syn_projEE_ampa[5681], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5682: cell 71, seg 0 (0.5) [0.5 on Epop[71]] -> cell 2, seg 0 (0.5) [0.5 on Epop[2]], weight: 4.1363508E-4, delay 1.5
        h("Epop[2] syn_projEE_ampa[5682] = new ampa(0.5)")
        h("Epop[71] netConn_projEE_ampa[5682] = new NetCon(&v(0.5), syn_projEE_ampa[5682], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5683: cell 71, seg 0 (0.5) [0.5 on Epop[71]] -> cell 3, seg 0 (0.5) [0.5 on Epop[3]], weight: 4.1363508E-4, delay 1.5
        h("Epop[3] syn_projEE_ampa[5683] = new ampa(0.5)")
        h("Epop[71] netConn_projEE_ampa[5683] = new NetCon(&v(0.5), syn_projEE_ampa[5683], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5684: cell 71, seg 0 (0.5) [0.5 on Epop[71]] -> cell 4, seg 0 (0.5) [0.5 on Epop[4]], weight: 4.1363508E-4, delay 1.5
        h("Epop[4] syn_projEE_ampa[5684] = new ampa(0.5)")
        h("Epop[71] netConn_projEE_ampa[5684] = new NetCon(&v(0.5), syn_projEE_ampa[5684], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5685: cell 71, seg 0 (0.5) [0.5 on Epop[71]] -> cell 5, seg 0 (0.5) [0.5 on Epop[5]], weight: 4.1363508E-4, delay 1.5
        h("Epop[5] syn_projEE_ampa[5685] = new ampa(0.5)")
        h("Epop[71] netConn_projEE_ampa[5685] = new NetCon(&v(0.5), syn_projEE_ampa[5685], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5686: cell 71, seg 0 (0.5) [0.5 on Epop[71]] -> cell 6, seg 0 (0.5) [0.5 on Epop[6]], weight: 4.1363508E-4, delay 1.5
        h("Epop[6] syn_projEE_ampa[5686] = new ampa(0.5)")
        h("Epop[71] netConn_projEE_ampa[5686] = new NetCon(&v(0.5), syn_projEE_ampa[5686], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5687: cell 71, seg 0 (0.5) [0.5 on Epop[71]] -> cell 7, seg 0 (0.5) [0.5 on Epop[7]], weight: 4.1363508E-4, delay 1.5
        h("Epop[7] syn_projEE_ampa[5687] = new ampa(0.5)")
        h("Epop[71] netConn_projEE_ampa[5687] = new NetCon(&v(0.5), syn_projEE_ampa[5687], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5688: cell 71, seg 0 (0.5) [0.5 on Epop[71]] -> cell 8, seg 0 (0.5) [0.5 on Epop[8]], weight: 4.1363508E-4, delay 1.5
        h("Epop[8] syn_projEE_ampa[5688] = new ampa(0.5)")
        h("Epop[71] netConn_projEE_ampa[5688] = new NetCon(&v(0.5), syn_projEE_ampa[5688], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5689: cell 71, seg 0 (0.5) [0.5 on Epop[71]] -> cell 9, seg 0 (0.5) [0.5 on Epop[9]], weight: 4.1363508E-4, delay 1.5
        h("Epop[9] syn_projEE_ampa[5689] = new ampa(0.5)")
        h("Epop[71] netConn_projEE_ampa[5689] = new NetCon(&v(0.5), syn_projEE_ampa[5689], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5690: cell 71, seg 0 (0.5) [0.5 on Epop[71]] -> cell 10, seg 0 (0.5) [0.5 on Epop[10]], weight: 4.1363508E-4, delay 1.5
        h("Epop[10] syn_projEE_ampa[5690] = new ampa(0.5)")
        h("Epop[71] netConn_projEE_ampa[5690] = new NetCon(&v(0.5), syn_projEE_ampa[5690], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5691: cell 71, seg 0 (0.5) [0.5 on Epop[71]] -> cell 11, seg 0 (0.5) [0.5 on Epop[11]], weight: 4.1363508E-4, delay 1.5
        h("Epop[11] syn_projEE_ampa[5691] = new ampa(0.5)")
        h("Epop[71] netConn_projEE_ampa[5691] = new NetCon(&v(0.5), syn_projEE_ampa[5691], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5692: cell 71, seg 0 (0.5) [0.5 on Epop[71]] -> cell 12, seg 0 (0.5) [0.5 on Epop[12]], weight: 4.1363508E-4, delay 1.5
        h("Epop[12] syn_projEE_ampa[5692] = new ampa(0.5)")
        h("Epop[71] netConn_projEE_ampa[5692] = new NetCon(&v(0.5), syn_projEE_ampa[5692], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5693: cell 71, seg 0 (0.5) [0.5 on Epop[71]] -> cell 13, seg 0 (0.5) [0.5 on Epop[13]], weight: 4.1363508E-4, delay 1.5
        h("Epop[13] syn_projEE_ampa[5693] = new ampa(0.5)")
        h("Epop[71] netConn_projEE_ampa[5693] = new NetCon(&v(0.5), syn_projEE_ampa[5693], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5694: cell 71, seg 0 (0.5) [0.5 on Epop[71]] -> cell 14, seg 0 (0.5) [0.5 on Epop[14]], weight: 4.1363508E-4, delay 1.5
        h("Epop[14] syn_projEE_ampa[5694] = new ampa(0.5)")
        h("Epop[71] netConn_projEE_ampa[5694] = new NetCon(&v(0.5), syn_projEE_ampa[5694], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5695: cell 71, seg 0 (0.5) [0.5 on Epop[71]] -> cell 15, seg 0 (0.5) [0.5 on Epop[15]], weight: 4.1363508E-4, delay 1.5
        h("Epop[15] syn_projEE_ampa[5695] = new ampa(0.5)")
        h("Epop[71] netConn_projEE_ampa[5695] = new NetCon(&v(0.5), syn_projEE_ampa[5695], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5696: cell 71, seg 0 (0.5) [0.5 on Epop[71]] -> cell 16, seg 0 (0.5) [0.5 on Epop[16]], weight: 4.1363508E-4, delay 1.5
        h("Epop[16] syn_projEE_ampa[5696] = new ampa(0.5)")
        h("Epop[71] netConn_projEE_ampa[5696] = new NetCon(&v(0.5), syn_projEE_ampa[5696], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5697: cell 71, seg 0 (0.5) [0.5 on Epop[71]] -> cell 17, seg 0 (0.5) [0.5 on Epop[17]], weight: 4.1363508E-4, delay 1.5
        h("Epop[17] syn_projEE_ampa[5697] = new ampa(0.5)")
        h("Epop[71] netConn_projEE_ampa[5697] = new NetCon(&v(0.5), syn_projEE_ampa[5697], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5698: cell 71, seg 0 (0.5) [0.5 on Epop[71]] -> cell 18, seg 0 (0.5) [0.5 on Epop[18]], weight: 4.1363508E-4, delay 1.5
        h("Epop[18] syn_projEE_ampa[5698] = new ampa(0.5)")
        h("Epop[71] netConn_projEE_ampa[5698] = new NetCon(&v(0.5), syn_projEE_ampa[5698], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5699: cell 71, seg 0 (0.5) [0.5 on Epop[71]] -> cell 19, seg 0 (0.5) [0.5 on Epop[19]], weight: 4.1363508E-4, delay 1.5
        h("Epop[19] syn_projEE_ampa[5699] = new ampa(0.5)")
        h("Epop[71] netConn_projEE_ampa[5699] = new NetCon(&v(0.5), syn_projEE_ampa[5699], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5700: cell 71, seg 0 (0.5) [0.5 on Epop[71]] -> cell 20, seg 0 (0.5) [0.5 on Epop[20]], weight: 4.1363508E-4, delay 1.5
        h("Epop[20] syn_projEE_ampa[5700] = new ampa(0.5)")
        h("Epop[71] netConn_projEE_ampa[5700] = new NetCon(&v(0.5), syn_projEE_ampa[5700], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5701: cell 71, seg 0 (0.5) [0.5 on Epop[71]] -> cell 21, seg 0 (0.5) [0.5 on Epop[21]], weight: 4.1363508E-4, delay 1.5
        h("Epop[21] syn_projEE_ampa[5701] = new ampa(0.5)")
        h("Epop[71] netConn_projEE_ampa[5701] = new NetCon(&v(0.5), syn_projEE_ampa[5701], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5702: cell 71, seg 0 (0.5) [0.5 on Epop[71]] -> cell 22, seg 0 (0.5) [0.5 on Epop[22]], weight: 4.1363508E-4, delay 1.5
        h("Epop[22] syn_projEE_ampa[5702] = new ampa(0.5)")
        h("Epop[71] netConn_projEE_ampa[5702] = new NetCon(&v(0.5), syn_projEE_ampa[5702], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5703: cell 71, seg 0 (0.5) [0.5 on Epop[71]] -> cell 23, seg 0 (0.5) [0.5 on Epop[23]], weight: 4.1363508E-4, delay 1.5
        h("Epop[23] syn_projEE_ampa[5703] = new ampa(0.5)")
        h("Epop[71] netConn_projEE_ampa[5703] = new NetCon(&v(0.5), syn_projEE_ampa[5703], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5704: cell 71, seg 0 (0.5) [0.5 on Epop[71]] -> cell 24, seg 0 (0.5) [0.5 on Epop[24]], weight: 4.1363508E-4, delay 1.5
        h("Epop[24] syn_projEE_ampa[5704] = new ampa(0.5)")
        h("Epop[71] netConn_projEE_ampa[5704] = new NetCon(&v(0.5), syn_projEE_ampa[5704], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5705: cell 71, seg 0 (0.5) [0.5 on Epop[71]] -> cell 25, seg 0 (0.5) [0.5 on Epop[25]], weight: 4.1363508E-4, delay 1.5
        h("Epop[25] syn_projEE_ampa[5705] = new ampa(0.5)")
        h("Epop[71] netConn_projEE_ampa[5705] = new NetCon(&v(0.5), syn_projEE_ampa[5705], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5706: cell 71, seg 0 (0.5) [0.5 on Epop[71]] -> cell 26, seg 0 (0.5) [0.5 on Epop[26]], weight: 4.1363508E-4, delay 1.5
        h("Epop[26] syn_projEE_ampa[5706] = new ampa(0.5)")
        h("Epop[71] netConn_projEE_ampa[5706] = new NetCon(&v(0.5), syn_projEE_ampa[5706], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5707: cell 71, seg 0 (0.5) [0.5 on Epop[71]] -> cell 27, seg 0 (0.5) [0.5 on Epop[27]], weight: 4.1363508E-4, delay 1.5
        h("Epop[27] syn_projEE_ampa[5707] = new ampa(0.5)")
        h("Epop[71] netConn_projEE_ampa[5707] = new NetCon(&v(0.5), syn_projEE_ampa[5707], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5708: cell 71, seg 0 (0.5) [0.5 on Epop[71]] -> cell 28, seg 0 (0.5) [0.5 on Epop[28]], weight: 4.1363508E-4, delay 1.5
        h("Epop[28] syn_projEE_ampa[5708] = new ampa(0.5)")
        h("Epop[71] netConn_projEE_ampa[5708] = new NetCon(&v(0.5), syn_projEE_ampa[5708], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5709: cell 71, seg 0 (0.5) [0.5 on Epop[71]] -> cell 29, seg 0 (0.5) [0.5 on Epop[29]], weight: 4.1363508E-4, delay 1.5
        h("Epop[29] syn_projEE_ampa[5709] = new ampa(0.5)")
        h("Epop[71] netConn_projEE_ampa[5709] = new NetCon(&v(0.5), syn_projEE_ampa[5709], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5710: cell 71, seg 0 (0.5) [0.5 on Epop[71]] -> cell 30, seg 0 (0.5) [0.5 on Epop[30]], weight: 4.1363508E-4, delay 1.5
        h("Epop[30] syn_projEE_ampa[5710] = new ampa(0.5)")
        h("Epop[71] netConn_projEE_ampa[5710] = new NetCon(&v(0.5), syn_projEE_ampa[5710], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5711: cell 71, seg 0 (0.5) [0.5 on Epop[71]] -> cell 31, seg 0 (0.5) [0.5 on Epop[31]], weight: 4.1363508E-4, delay 1.5
        h("Epop[31] syn_projEE_ampa[5711] = new ampa(0.5)")
        h("Epop[71] netConn_projEE_ampa[5711] = new NetCon(&v(0.5), syn_projEE_ampa[5711], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5712: cell 71, seg 0 (0.5) [0.5 on Epop[71]] -> cell 32, seg 0 (0.5) [0.5 on Epop[32]], weight: 4.1363508E-4, delay 1.5
        h("Epop[32] syn_projEE_ampa[5712] = new ampa(0.5)")
        h("Epop[71] netConn_projEE_ampa[5712] = new NetCon(&v(0.5), syn_projEE_ampa[5712], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5713: cell 71, seg 0 (0.5) [0.5 on Epop[71]] -> cell 33, seg 0 (0.5) [0.5 on Epop[33]], weight: 4.1363508E-4, delay 1.5
        h("Epop[33] syn_projEE_ampa[5713] = new ampa(0.5)")
        h("Epop[71] netConn_projEE_ampa[5713] = new NetCon(&v(0.5), syn_projEE_ampa[5713], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5714: cell 71, seg 0 (0.5) [0.5 on Epop[71]] -> cell 34, seg 0 (0.5) [0.5 on Epop[34]], weight: 4.1363508E-4, delay 1.5
        h("Epop[34] syn_projEE_ampa[5714] = new ampa(0.5)")
        h("Epop[71] netConn_projEE_ampa[5714] = new NetCon(&v(0.5), syn_projEE_ampa[5714], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5715: cell 71, seg 0 (0.5) [0.5 on Epop[71]] -> cell 35, seg 0 (0.5) [0.5 on Epop[35]], weight: 4.1363508E-4, delay 1.5
        h("Epop[35] syn_projEE_ampa[5715] = new ampa(0.5)")
        h("Epop[71] netConn_projEE_ampa[5715] = new NetCon(&v(0.5), syn_projEE_ampa[5715], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5716: cell 71, seg 0 (0.5) [0.5 on Epop[71]] -> cell 36, seg 0 (0.5) [0.5 on Epop[36]], weight: 4.1363508E-4, delay 1.5
        h("Epop[36] syn_projEE_ampa[5716] = new ampa(0.5)")
        h("Epop[71] netConn_projEE_ampa[5716] = new NetCon(&v(0.5), syn_projEE_ampa[5716], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5717: cell 71, seg 0 (0.5) [0.5 on Epop[71]] -> cell 37, seg 0 (0.5) [0.5 on Epop[37]], weight: 4.1363508E-4, delay 1.5
        h("Epop[37] syn_projEE_ampa[5717] = new ampa(0.5)")
        h("Epop[71] netConn_projEE_ampa[5717] = new NetCon(&v(0.5), syn_projEE_ampa[5717], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5718: cell 71, seg 0 (0.5) [0.5 on Epop[71]] -> cell 38, seg 0 (0.5) [0.5 on Epop[38]], weight: 4.1363508E-4, delay 1.5
        h("Epop[38] syn_projEE_ampa[5718] = new ampa(0.5)")
        h("Epop[71] netConn_projEE_ampa[5718] = new NetCon(&v(0.5), syn_projEE_ampa[5718], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5719: cell 71, seg 0 (0.5) [0.5 on Epop[71]] -> cell 39, seg 0 (0.5) [0.5 on Epop[39]], weight: 4.1363508E-4, delay 1.5
        h("Epop[39] syn_projEE_ampa[5719] = new ampa(0.5)")
        h("Epop[71] netConn_projEE_ampa[5719] = new NetCon(&v(0.5), syn_projEE_ampa[5719], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5720: cell 71, seg 0 (0.5) [0.5 on Epop[71]] -> cell 40, seg 0 (0.5) [0.5 on Epop[40]], weight: 4.1363508E-4, delay 1.5
        h("Epop[40] syn_projEE_ampa[5720] = new ampa(0.5)")
        h("Epop[71] netConn_projEE_ampa[5720] = new NetCon(&v(0.5), syn_projEE_ampa[5720], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5721: cell 71, seg 0 (0.5) [0.5 on Epop[71]] -> cell 41, seg 0 (0.5) [0.5 on Epop[41]], weight: 4.1363508E-4, delay 1.5
        h("Epop[41] syn_projEE_ampa[5721] = new ampa(0.5)")
        h("Epop[71] netConn_projEE_ampa[5721] = new NetCon(&v(0.5), syn_projEE_ampa[5721], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5722: cell 71, seg 0 (0.5) [0.5 on Epop[71]] -> cell 42, seg 0 (0.5) [0.5 on Epop[42]], weight: 4.1363508E-4, delay 1.5
        h("Epop[42] syn_projEE_ampa[5722] = new ampa(0.5)")
        h("Epop[71] netConn_projEE_ampa[5722] = new NetCon(&v(0.5), syn_projEE_ampa[5722], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5723: cell 71, seg 0 (0.5) [0.5 on Epop[71]] -> cell 43, seg 0 (0.5) [0.5 on Epop[43]], weight: 4.1363508E-4, delay 1.5
        h("Epop[43] syn_projEE_ampa[5723] = new ampa(0.5)")
        h("Epop[71] netConn_projEE_ampa[5723] = new NetCon(&v(0.5), syn_projEE_ampa[5723], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5724: cell 71, seg 0 (0.5) [0.5 on Epop[71]] -> cell 44, seg 0 (0.5) [0.5 on Epop[44]], weight: 4.1363508E-4, delay 1.5
        h("Epop[44] syn_projEE_ampa[5724] = new ampa(0.5)")
        h("Epop[71] netConn_projEE_ampa[5724] = new NetCon(&v(0.5), syn_projEE_ampa[5724], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5725: cell 71, seg 0 (0.5) [0.5 on Epop[71]] -> cell 45, seg 0 (0.5) [0.5 on Epop[45]], weight: 4.1363508E-4, delay 1.5
        h("Epop[45] syn_projEE_ampa[5725] = new ampa(0.5)")
        h("Epop[71] netConn_projEE_ampa[5725] = new NetCon(&v(0.5), syn_projEE_ampa[5725], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5726: cell 71, seg 0 (0.5) [0.5 on Epop[71]] -> cell 46, seg 0 (0.5) [0.5 on Epop[46]], weight: 4.1363508E-4, delay 1.5
        h("Epop[46] syn_projEE_ampa[5726] = new ampa(0.5)")
        h("Epop[71] netConn_projEE_ampa[5726] = new NetCon(&v(0.5), syn_projEE_ampa[5726], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5727: cell 71, seg 0 (0.5) [0.5 on Epop[71]] -> cell 47, seg 0 (0.5) [0.5 on Epop[47]], weight: 4.1363508E-4, delay 1.5
        h("Epop[47] syn_projEE_ampa[5727] = new ampa(0.5)")
        h("Epop[71] netConn_projEE_ampa[5727] = new NetCon(&v(0.5), syn_projEE_ampa[5727], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5728: cell 71, seg 0 (0.5) [0.5 on Epop[71]] -> cell 48, seg 0 (0.5) [0.5 on Epop[48]], weight: 4.1363508E-4, delay 1.5
        h("Epop[48] syn_projEE_ampa[5728] = new ampa(0.5)")
        h("Epop[71] netConn_projEE_ampa[5728] = new NetCon(&v(0.5), syn_projEE_ampa[5728], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5729: cell 71, seg 0 (0.5) [0.5 on Epop[71]] -> cell 49, seg 0 (0.5) [0.5 on Epop[49]], weight: 4.1363508E-4, delay 1.5
        h("Epop[49] syn_projEE_ampa[5729] = new ampa(0.5)")
        h("Epop[71] netConn_projEE_ampa[5729] = new NetCon(&v(0.5), syn_projEE_ampa[5729], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5730: cell 71, seg 0 (0.5) [0.5 on Epop[71]] -> cell 50, seg 0 (0.5) [0.5 on Epop[50]], weight: 4.1363508E-4, delay 1.5
        h("Epop[50] syn_projEE_ampa[5730] = new ampa(0.5)")
        h("Epop[71] netConn_projEE_ampa[5730] = new NetCon(&v(0.5), syn_projEE_ampa[5730], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5731: cell 71, seg 0 (0.5) [0.5 on Epop[71]] -> cell 51, seg 0 (0.5) [0.5 on Epop[51]], weight: 4.1363508E-4, delay 1.5
        h("Epop[51] syn_projEE_ampa[5731] = new ampa(0.5)")
        h("Epop[71] netConn_projEE_ampa[5731] = new NetCon(&v(0.5), syn_projEE_ampa[5731], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5732: cell 71, seg 0 (0.5) [0.5 on Epop[71]] -> cell 52, seg 0 (0.5) [0.5 on Epop[52]], weight: 4.1363508E-4, delay 1.5
        h("Epop[52] syn_projEE_ampa[5732] = new ampa(0.5)")
        h("Epop[71] netConn_projEE_ampa[5732] = new NetCon(&v(0.5), syn_projEE_ampa[5732], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5733: cell 71, seg 0 (0.5) [0.5 on Epop[71]] -> cell 53, seg 0 (0.5) [0.5 on Epop[53]], weight: 4.1363508E-4, delay 1.5
        h("Epop[53] syn_projEE_ampa[5733] = new ampa(0.5)")
        h("Epop[71] netConn_projEE_ampa[5733] = new NetCon(&v(0.5), syn_projEE_ampa[5733], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5734: cell 71, seg 0 (0.5) [0.5 on Epop[71]] -> cell 54, seg 0 (0.5) [0.5 on Epop[54]], weight: 4.1363508E-4, delay 1.5
        h("Epop[54] syn_projEE_ampa[5734] = new ampa(0.5)")
        h("Epop[71] netConn_projEE_ampa[5734] = new NetCon(&v(0.5), syn_projEE_ampa[5734], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5735: cell 71, seg 0 (0.5) [0.5 on Epop[71]] -> cell 55, seg 0 (0.5) [0.5 on Epop[55]], weight: 4.1363508E-4, delay 1.5
        h("Epop[55] syn_projEE_ampa[5735] = new ampa(0.5)")
        h("Epop[71] netConn_projEE_ampa[5735] = new NetCon(&v(0.5), syn_projEE_ampa[5735], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5736: cell 71, seg 0 (0.5) [0.5 on Epop[71]] -> cell 56, seg 0 (0.5) [0.5 on Epop[56]], weight: 4.1363508E-4, delay 1.5
        h("Epop[56] syn_projEE_ampa[5736] = new ampa(0.5)")
        h("Epop[71] netConn_projEE_ampa[5736] = new NetCon(&v(0.5), syn_projEE_ampa[5736], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5737: cell 71, seg 0 (0.5) [0.5 on Epop[71]] -> cell 57, seg 0 (0.5) [0.5 on Epop[57]], weight: 4.1363508E-4, delay 1.5
        h("Epop[57] syn_projEE_ampa[5737] = new ampa(0.5)")
        h("Epop[71] netConn_projEE_ampa[5737] = new NetCon(&v(0.5), syn_projEE_ampa[5737], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5738: cell 71, seg 0 (0.5) [0.5 on Epop[71]] -> cell 58, seg 0 (0.5) [0.5 on Epop[58]], weight: 4.1363508E-4, delay 1.5
        h("Epop[58] syn_projEE_ampa[5738] = new ampa(0.5)")
        h("Epop[71] netConn_projEE_ampa[5738] = new NetCon(&v(0.5), syn_projEE_ampa[5738], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5739: cell 71, seg 0 (0.5) [0.5 on Epop[71]] -> cell 59, seg 0 (0.5) [0.5 on Epop[59]], weight: 4.1363508E-4, delay 1.5
        h("Epop[59] syn_projEE_ampa[5739] = new ampa(0.5)")
        h("Epop[71] netConn_projEE_ampa[5739] = new NetCon(&v(0.5), syn_projEE_ampa[5739], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5740: cell 71, seg 0 (0.5) [0.5 on Epop[71]] -> cell 60, seg 0 (0.5) [0.5 on Epop[60]], weight: 4.1363508E-4, delay 1.5
        h("Epop[60] syn_projEE_ampa[5740] = new ampa(0.5)")
        h("Epop[71] netConn_projEE_ampa[5740] = new NetCon(&v(0.5), syn_projEE_ampa[5740], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5741: cell 71, seg 0 (0.5) [0.5 on Epop[71]] -> cell 61, seg 0 (0.5) [0.5 on Epop[61]], weight: 4.1363508E-4, delay 1.5
        h("Epop[61] syn_projEE_ampa[5741] = new ampa(0.5)")
        h("Epop[71] netConn_projEE_ampa[5741] = new NetCon(&v(0.5), syn_projEE_ampa[5741], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5742: cell 71, seg 0 (0.5) [0.5 on Epop[71]] -> cell 62, seg 0 (0.5) [0.5 on Epop[62]], weight: 4.1363508E-4, delay 1.5
        h("Epop[62] syn_projEE_ampa[5742] = new ampa(0.5)")
        h("Epop[71] netConn_projEE_ampa[5742] = new NetCon(&v(0.5), syn_projEE_ampa[5742], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5743: cell 71, seg 0 (0.5) [0.5 on Epop[71]] -> cell 63, seg 0 (0.5) [0.5 on Epop[63]], weight: 4.1363508E-4, delay 1.5
        h("Epop[63] syn_projEE_ampa[5743] = new ampa(0.5)")
        h("Epop[71] netConn_projEE_ampa[5743] = new NetCon(&v(0.5), syn_projEE_ampa[5743], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5744: cell 71, seg 0 (0.5) [0.5 on Epop[71]] -> cell 64, seg 0 (0.5) [0.5 on Epop[64]], weight: 4.1363508E-4, delay 1.5
        h("Epop[64] syn_projEE_ampa[5744] = new ampa(0.5)")
        h("Epop[71] netConn_projEE_ampa[5744] = new NetCon(&v(0.5), syn_projEE_ampa[5744], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5745: cell 71, seg 0 (0.5) [0.5 on Epop[71]] -> cell 65, seg 0 (0.5) [0.5 on Epop[65]], weight: 4.1363508E-4, delay 1.5
        h("Epop[65] syn_projEE_ampa[5745] = new ampa(0.5)")
        h("Epop[71] netConn_projEE_ampa[5745] = new NetCon(&v(0.5), syn_projEE_ampa[5745], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5746: cell 71, seg 0 (0.5) [0.5 on Epop[71]] -> cell 66, seg 0 (0.5) [0.5 on Epop[66]], weight: 4.1363508E-4, delay 1.5
        h("Epop[66] syn_projEE_ampa[5746] = new ampa(0.5)")
        h("Epop[71] netConn_projEE_ampa[5746] = new NetCon(&v(0.5), syn_projEE_ampa[5746], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5747: cell 71, seg 0 (0.5) [0.5 on Epop[71]] -> cell 67, seg 0 (0.5) [0.5 on Epop[67]], weight: 4.1363508E-4, delay 1.5
        h("Epop[67] syn_projEE_ampa[5747] = new ampa(0.5)")
        h("Epop[71] netConn_projEE_ampa[5747] = new NetCon(&v(0.5), syn_projEE_ampa[5747], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5748: cell 71, seg 0 (0.5) [0.5 on Epop[71]] -> cell 68, seg 0 (0.5) [0.5 on Epop[68]], weight: 4.1363508E-4, delay 1.5
        h("Epop[68] syn_projEE_ampa[5748] = new ampa(0.5)")
        h("Epop[71] netConn_projEE_ampa[5748] = new NetCon(&v(0.5), syn_projEE_ampa[5748], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5749: cell 71, seg 0 (0.5) [0.5 on Epop[71]] -> cell 69, seg 0 (0.5) [0.5 on Epop[69]], weight: 4.1363508E-4, delay 1.5
        h("Epop[69] syn_projEE_ampa[5749] = new ampa(0.5)")
        h("Epop[71] netConn_projEE_ampa[5749] = new NetCon(&v(0.5), syn_projEE_ampa[5749], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5750: cell 71, seg 0 (0.5) [0.5 on Epop[71]] -> cell 70, seg 0 (0.5) [0.5 on Epop[70]], weight: 4.1363508E-4, delay 1.5
        h("Epop[70] syn_projEE_ampa[5750] = new ampa(0.5)")
        h("Epop[71] netConn_projEE_ampa[5750] = new NetCon(&v(0.5), syn_projEE_ampa[5750], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5751: cell 71, seg 0 (0.5) [0.5 on Epop[71]] -> cell 71, seg 0 (0.5) [0.5 on Epop[71]], weight: 4.1363508E-4, delay 1.5
        h("Epop[71] syn_projEE_ampa[5751] = new ampa(0.5)")
        h("Epop[71] netConn_projEE_ampa[5751] = new NetCon(&v(0.5), syn_projEE_ampa[5751], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5752: cell 71, seg 0 (0.5) [0.5 on Epop[71]] -> cell 72, seg 0 (0.5) [0.5 on Epop[72]], weight: 4.1363508E-4, delay 1.5
        h("Epop[72] syn_projEE_ampa[5752] = new ampa(0.5)")
        h("Epop[71] netConn_projEE_ampa[5752] = new NetCon(&v(0.5), syn_projEE_ampa[5752], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5753: cell 71, seg 0 (0.5) [0.5 on Epop[71]] -> cell 73, seg 0 (0.5) [0.5 on Epop[73]], weight: 4.1363508E-4, delay 1.5
        h("Epop[73] syn_projEE_ampa[5753] = new ampa(0.5)")
        h("Epop[71] netConn_projEE_ampa[5753] = new NetCon(&v(0.5), syn_projEE_ampa[5753], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5754: cell 71, seg 0 (0.5) [0.5 on Epop[71]] -> cell 74, seg 0 (0.5) [0.5 on Epop[74]], weight: 4.1363508E-4, delay 1.5
        h("Epop[74] syn_projEE_ampa[5754] = new ampa(0.5)")
        h("Epop[71] netConn_projEE_ampa[5754] = new NetCon(&v(0.5), syn_projEE_ampa[5754], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5755: cell 71, seg 0 (0.5) [0.5 on Epop[71]] -> cell 75, seg 0 (0.5) [0.5 on Epop[75]], weight: 4.1363508E-4, delay 1.5
        h("Epop[75] syn_projEE_ampa[5755] = new ampa(0.5)")
        h("Epop[71] netConn_projEE_ampa[5755] = new NetCon(&v(0.5), syn_projEE_ampa[5755], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5756: cell 71, seg 0 (0.5) [0.5 on Epop[71]] -> cell 76, seg 0 (0.5) [0.5 on Epop[76]], weight: 4.1363508E-4, delay 1.5
        h("Epop[76] syn_projEE_ampa[5756] = new ampa(0.5)")
        h("Epop[71] netConn_projEE_ampa[5756] = new NetCon(&v(0.5), syn_projEE_ampa[5756], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5757: cell 71, seg 0 (0.5) [0.5 on Epop[71]] -> cell 77, seg 0 (0.5) [0.5 on Epop[77]], weight: 4.1363508E-4, delay 1.5
        h("Epop[77] syn_projEE_ampa[5757] = new ampa(0.5)")
        h("Epop[71] netConn_projEE_ampa[5757] = new NetCon(&v(0.5), syn_projEE_ampa[5757], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5758: cell 71, seg 0 (0.5) [0.5 on Epop[71]] -> cell 78, seg 0 (0.5) [0.5 on Epop[78]], weight: 4.1363508E-4, delay 1.5
        h("Epop[78] syn_projEE_ampa[5758] = new ampa(0.5)")
        h("Epop[71] netConn_projEE_ampa[5758] = new NetCon(&v(0.5), syn_projEE_ampa[5758], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5759: cell 71, seg 0 (0.5) [0.5 on Epop[71]] -> cell 79, seg 0 (0.5) [0.5 on Epop[79]], weight: 4.1363508E-4, delay 1.5
        h("Epop[79] syn_projEE_ampa[5759] = new ampa(0.5)")
        h("Epop[71] netConn_projEE_ampa[5759] = new NetCon(&v(0.5), syn_projEE_ampa[5759], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5760: cell 72, seg 0 (0.5) [0.5 on Epop[72]] -> cell 0, seg 0 (0.5) [0.5 on Epop[0]], weight: 4.1363508E-4, delay 1.5
        h("Epop[0] syn_projEE_ampa[5760] = new ampa(0.5)")
        h("Epop[72] netConn_projEE_ampa[5760] = new NetCon(&v(0.5), syn_projEE_ampa[5760], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5761: cell 72, seg 0 (0.5) [0.5 on Epop[72]] -> cell 1, seg 0 (0.5) [0.5 on Epop[1]], weight: 4.1363508E-4, delay 1.5
        h("Epop[1] syn_projEE_ampa[5761] = new ampa(0.5)")
        h("Epop[72] netConn_projEE_ampa[5761] = new NetCon(&v(0.5), syn_projEE_ampa[5761], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5762: cell 72, seg 0 (0.5) [0.5 on Epop[72]] -> cell 2, seg 0 (0.5) [0.5 on Epop[2]], weight: 4.1363508E-4, delay 1.5
        h("Epop[2] syn_projEE_ampa[5762] = new ampa(0.5)")
        h("Epop[72] netConn_projEE_ampa[5762] = new NetCon(&v(0.5), syn_projEE_ampa[5762], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5763: cell 72, seg 0 (0.5) [0.5 on Epop[72]] -> cell 3, seg 0 (0.5) [0.5 on Epop[3]], weight: 4.1363508E-4, delay 1.5
        h("Epop[3] syn_projEE_ampa[5763] = new ampa(0.5)")
        h("Epop[72] netConn_projEE_ampa[5763] = new NetCon(&v(0.5), syn_projEE_ampa[5763], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5764: cell 72, seg 0 (0.5) [0.5 on Epop[72]] -> cell 4, seg 0 (0.5) [0.5 on Epop[4]], weight: 4.1363508E-4, delay 1.5
        h("Epop[4] syn_projEE_ampa[5764] = new ampa(0.5)")
        h("Epop[72] netConn_projEE_ampa[5764] = new NetCon(&v(0.5), syn_projEE_ampa[5764], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5765: cell 72, seg 0 (0.5) [0.5 on Epop[72]] -> cell 5, seg 0 (0.5) [0.5 on Epop[5]], weight: 4.1363508E-4, delay 1.5
        h("Epop[5] syn_projEE_ampa[5765] = new ampa(0.5)")
        h("Epop[72] netConn_projEE_ampa[5765] = new NetCon(&v(0.5), syn_projEE_ampa[5765], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5766: cell 72, seg 0 (0.5) [0.5 on Epop[72]] -> cell 6, seg 0 (0.5) [0.5 on Epop[6]], weight: 4.1363508E-4, delay 1.5
        h("Epop[6] syn_projEE_ampa[5766] = new ampa(0.5)")
        h("Epop[72] netConn_projEE_ampa[5766] = new NetCon(&v(0.5), syn_projEE_ampa[5766], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5767: cell 72, seg 0 (0.5) [0.5 on Epop[72]] -> cell 7, seg 0 (0.5) [0.5 on Epop[7]], weight: 4.1363508E-4, delay 1.5
        h("Epop[7] syn_projEE_ampa[5767] = new ampa(0.5)")
        h("Epop[72] netConn_projEE_ampa[5767] = new NetCon(&v(0.5), syn_projEE_ampa[5767], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5768: cell 72, seg 0 (0.5) [0.5 on Epop[72]] -> cell 8, seg 0 (0.5) [0.5 on Epop[8]], weight: 4.1363508E-4, delay 1.5
        h("Epop[8] syn_projEE_ampa[5768] = new ampa(0.5)")
        h("Epop[72] netConn_projEE_ampa[5768] = new NetCon(&v(0.5), syn_projEE_ampa[5768], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5769: cell 72, seg 0 (0.5) [0.5 on Epop[72]] -> cell 9, seg 0 (0.5) [0.5 on Epop[9]], weight: 4.1363508E-4, delay 1.5
        h("Epop[9] syn_projEE_ampa[5769] = new ampa(0.5)")
        h("Epop[72] netConn_projEE_ampa[5769] = new NetCon(&v(0.5), syn_projEE_ampa[5769], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5770: cell 72, seg 0 (0.5) [0.5 on Epop[72]] -> cell 10, seg 0 (0.5) [0.5 on Epop[10]], weight: 4.1363508E-4, delay 1.5
        h("Epop[10] syn_projEE_ampa[5770] = new ampa(0.5)")
        h("Epop[72] netConn_projEE_ampa[5770] = new NetCon(&v(0.5), syn_projEE_ampa[5770], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5771: cell 72, seg 0 (0.5) [0.5 on Epop[72]] -> cell 11, seg 0 (0.5) [0.5 on Epop[11]], weight: 4.1363508E-4, delay 1.5
        h("Epop[11] syn_projEE_ampa[5771] = new ampa(0.5)")
        h("Epop[72] netConn_projEE_ampa[5771] = new NetCon(&v(0.5), syn_projEE_ampa[5771], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5772: cell 72, seg 0 (0.5) [0.5 on Epop[72]] -> cell 12, seg 0 (0.5) [0.5 on Epop[12]], weight: 4.1363508E-4, delay 1.5
        h("Epop[12] syn_projEE_ampa[5772] = new ampa(0.5)")
        h("Epop[72] netConn_projEE_ampa[5772] = new NetCon(&v(0.5), syn_projEE_ampa[5772], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5773: cell 72, seg 0 (0.5) [0.5 on Epop[72]] -> cell 13, seg 0 (0.5) [0.5 on Epop[13]], weight: 4.1363508E-4, delay 1.5
        h("Epop[13] syn_projEE_ampa[5773] = new ampa(0.5)")
        h("Epop[72] netConn_projEE_ampa[5773] = new NetCon(&v(0.5), syn_projEE_ampa[5773], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5774: cell 72, seg 0 (0.5) [0.5 on Epop[72]] -> cell 14, seg 0 (0.5) [0.5 on Epop[14]], weight: 4.1363508E-4, delay 1.5
        h("Epop[14] syn_projEE_ampa[5774] = new ampa(0.5)")
        h("Epop[72] netConn_projEE_ampa[5774] = new NetCon(&v(0.5), syn_projEE_ampa[5774], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5775: cell 72, seg 0 (0.5) [0.5 on Epop[72]] -> cell 15, seg 0 (0.5) [0.5 on Epop[15]], weight: 4.1363508E-4, delay 1.5
        h("Epop[15] syn_projEE_ampa[5775] = new ampa(0.5)")
        h("Epop[72] netConn_projEE_ampa[5775] = new NetCon(&v(0.5), syn_projEE_ampa[5775], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5776: cell 72, seg 0 (0.5) [0.5 on Epop[72]] -> cell 16, seg 0 (0.5) [0.5 on Epop[16]], weight: 4.1363508E-4, delay 1.5
        h("Epop[16] syn_projEE_ampa[5776] = new ampa(0.5)")
        h("Epop[72] netConn_projEE_ampa[5776] = new NetCon(&v(0.5), syn_projEE_ampa[5776], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5777: cell 72, seg 0 (0.5) [0.5 on Epop[72]] -> cell 17, seg 0 (0.5) [0.5 on Epop[17]], weight: 4.1363508E-4, delay 1.5
        h("Epop[17] syn_projEE_ampa[5777] = new ampa(0.5)")
        h("Epop[72] netConn_projEE_ampa[5777] = new NetCon(&v(0.5), syn_projEE_ampa[5777], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5778: cell 72, seg 0 (0.5) [0.5 on Epop[72]] -> cell 18, seg 0 (0.5) [0.5 on Epop[18]], weight: 4.1363508E-4, delay 1.5
        h("Epop[18] syn_projEE_ampa[5778] = new ampa(0.5)")
        h("Epop[72] netConn_projEE_ampa[5778] = new NetCon(&v(0.5), syn_projEE_ampa[5778], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5779: cell 72, seg 0 (0.5) [0.5 on Epop[72]] -> cell 19, seg 0 (0.5) [0.5 on Epop[19]], weight: 4.1363508E-4, delay 1.5
        h("Epop[19] syn_projEE_ampa[5779] = new ampa(0.5)")
        h("Epop[72] netConn_projEE_ampa[5779] = new NetCon(&v(0.5), syn_projEE_ampa[5779], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5780: cell 72, seg 0 (0.5) [0.5 on Epop[72]] -> cell 20, seg 0 (0.5) [0.5 on Epop[20]], weight: 4.1363508E-4, delay 1.5
        h("Epop[20] syn_projEE_ampa[5780] = new ampa(0.5)")
        h("Epop[72] netConn_projEE_ampa[5780] = new NetCon(&v(0.5), syn_projEE_ampa[5780], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5781: cell 72, seg 0 (0.5) [0.5 on Epop[72]] -> cell 21, seg 0 (0.5) [0.5 on Epop[21]], weight: 4.1363508E-4, delay 1.5
        h("Epop[21] syn_projEE_ampa[5781] = new ampa(0.5)")
        h("Epop[72] netConn_projEE_ampa[5781] = new NetCon(&v(0.5), syn_projEE_ampa[5781], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5782: cell 72, seg 0 (0.5) [0.5 on Epop[72]] -> cell 22, seg 0 (0.5) [0.5 on Epop[22]], weight: 4.1363508E-4, delay 1.5
        h("Epop[22] syn_projEE_ampa[5782] = new ampa(0.5)")
        h("Epop[72] netConn_projEE_ampa[5782] = new NetCon(&v(0.5), syn_projEE_ampa[5782], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5783: cell 72, seg 0 (0.5) [0.5 on Epop[72]] -> cell 23, seg 0 (0.5) [0.5 on Epop[23]], weight: 4.1363508E-4, delay 1.5
        h("Epop[23] syn_projEE_ampa[5783] = new ampa(0.5)")
        h("Epop[72] netConn_projEE_ampa[5783] = new NetCon(&v(0.5), syn_projEE_ampa[5783], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5784: cell 72, seg 0 (0.5) [0.5 on Epop[72]] -> cell 24, seg 0 (0.5) [0.5 on Epop[24]], weight: 4.1363508E-4, delay 1.5
        h("Epop[24] syn_projEE_ampa[5784] = new ampa(0.5)")
        h("Epop[72] netConn_projEE_ampa[5784] = new NetCon(&v(0.5), syn_projEE_ampa[5784], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5785: cell 72, seg 0 (0.5) [0.5 on Epop[72]] -> cell 25, seg 0 (0.5) [0.5 on Epop[25]], weight: 4.1363508E-4, delay 1.5
        h("Epop[25] syn_projEE_ampa[5785] = new ampa(0.5)")
        h("Epop[72] netConn_projEE_ampa[5785] = new NetCon(&v(0.5), syn_projEE_ampa[5785], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5786: cell 72, seg 0 (0.5) [0.5 on Epop[72]] -> cell 26, seg 0 (0.5) [0.5 on Epop[26]], weight: 4.1363508E-4, delay 1.5
        h("Epop[26] syn_projEE_ampa[5786] = new ampa(0.5)")
        h("Epop[72] netConn_projEE_ampa[5786] = new NetCon(&v(0.5), syn_projEE_ampa[5786], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5787: cell 72, seg 0 (0.5) [0.5 on Epop[72]] -> cell 27, seg 0 (0.5) [0.5 on Epop[27]], weight: 4.1363508E-4, delay 1.5
        h("Epop[27] syn_projEE_ampa[5787] = new ampa(0.5)")
        h("Epop[72] netConn_projEE_ampa[5787] = new NetCon(&v(0.5), syn_projEE_ampa[5787], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5788: cell 72, seg 0 (0.5) [0.5 on Epop[72]] -> cell 28, seg 0 (0.5) [0.5 on Epop[28]], weight: 4.1363508E-4, delay 1.5
        h("Epop[28] syn_projEE_ampa[5788] = new ampa(0.5)")
        h("Epop[72] netConn_projEE_ampa[5788] = new NetCon(&v(0.5), syn_projEE_ampa[5788], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5789: cell 72, seg 0 (0.5) [0.5 on Epop[72]] -> cell 29, seg 0 (0.5) [0.5 on Epop[29]], weight: 4.1363508E-4, delay 1.5
        h("Epop[29] syn_projEE_ampa[5789] = new ampa(0.5)")
        h("Epop[72] netConn_projEE_ampa[5789] = new NetCon(&v(0.5), syn_projEE_ampa[5789], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5790: cell 72, seg 0 (0.5) [0.5 on Epop[72]] -> cell 30, seg 0 (0.5) [0.5 on Epop[30]], weight: 4.1363508E-4, delay 1.5
        h("Epop[30] syn_projEE_ampa[5790] = new ampa(0.5)")
        h("Epop[72] netConn_projEE_ampa[5790] = new NetCon(&v(0.5), syn_projEE_ampa[5790], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5791: cell 72, seg 0 (0.5) [0.5 on Epop[72]] -> cell 31, seg 0 (0.5) [0.5 on Epop[31]], weight: 4.1363508E-4, delay 1.5
        h("Epop[31] syn_projEE_ampa[5791] = new ampa(0.5)")
        h("Epop[72] netConn_projEE_ampa[5791] = new NetCon(&v(0.5), syn_projEE_ampa[5791], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5792: cell 72, seg 0 (0.5) [0.5 on Epop[72]] -> cell 32, seg 0 (0.5) [0.5 on Epop[32]], weight: 4.1363508E-4, delay 1.5
        h("Epop[32] syn_projEE_ampa[5792] = new ampa(0.5)")
        h("Epop[72] netConn_projEE_ampa[5792] = new NetCon(&v(0.5), syn_projEE_ampa[5792], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5793: cell 72, seg 0 (0.5) [0.5 on Epop[72]] -> cell 33, seg 0 (0.5) [0.5 on Epop[33]], weight: 4.1363508E-4, delay 1.5
        h("Epop[33] syn_projEE_ampa[5793] = new ampa(0.5)")
        h("Epop[72] netConn_projEE_ampa[5793] = new NetCon(&v(0.5), syn_projEE_ampa[5793], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5794: cell 72, seg 0 (0.5) [0.5 on Epop[72]] -> cell 34, seg 0 (0.5) [0.5 on Epop[34]], weight: 4.1363508E-4, delay 1.5
        h("Epop[34] syn_projEE_ampa[5794] = new ampa(0.5)")
        h("Epop[72] netConn_projEE_ampa[5794] = new NetCon(&v(0.5), syn_projEE_ampa[5794], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5795: cell 72, seg 0 (0.5) [0.5 on Epop[72]] -> cell 35, seg 0 (0.5) [0.5 on Epop[35]], weight: 4.1363508E-4, delay 1.5
        h("Epop[35] syn_projEE_ampa[5795] = new ampa(0.5)")
        h("Epop[72] netConn_projEE_ampa[5795] = new NetCon(&v(0.5), syn_projEE_ampa[5795], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5796: cell 72, seg 0 (0.5) [0.5 on Epop[72]] -> cell 36, seg 0 (0.5) [0.5 on Epop[36]], weight: 4.1363508E-4, delay 1.5
        h("Epop[36] syn_projEE_ampa[5796] = new ampa(0.5)")
        h("Epop[72] netConn_projEE_ampa[5796] = new NetCon(&v(0.5), syn_projEE_ampa[5796], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5797: cell 72, seg 0 (0.5) [0.5 on Epop[72]] -> cell 37, seg 0 (0.5) [0.5 on Epop[37]], weight: 4.1363508E-4, delay 1.5
        h("Epop[37] syn_projEE_ampa[5797] = new ampa(0.5)")
        h("Epop[72] netConn_projEE_ampa[5797] = new NetCon(&v(0.5), syn_projEE_ampa[5797], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5798: cell 72, seg 0 (0.5) [0.5 on Epop[72]] -> cell 38, seg 0 (0.5) [0.5 on Epop[38]], weight: 4.1363508E-4, delay 1.5
        h("Epop[38] syn_projEE_ampa[5798] = new ampa(0.5)")
        h("Epop[72] netConn_projEE_ampa[5798] = new NetCon(&v(0.5), syn_projEE_ampa[5798], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5799: cell 72, seg 0 (0.5) [0.5 on Epop[72]] -> cell 39, seg 0 (0.5) [0.5 on Epop[39]], weight: 4.1363508E-4, delay 1.5
        h("Epop[39] syn_projEE_ampa[5799] = new ampa(0.5)")
        h("Epop[72] netConn_projEE_ampa[5799] = new NetCon(&v(0.5), syn_projEE_ampa[5799], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5800: cell 72, seg 0 (0.5) [0.5 on Epop[72]] -> cell 40, seg 0 (0.5) [0.5 on Epop[40]], weight: 4.1363508E-4, delay 1.5
        h("Epop[40] syn_projEE_ampa[5800] = new ampa(0.5)")
        h("Epop[72] netConn_projEE_ampa[5800] = new NetCon(&v(0.5), syn_projEE_ampa[5800], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5801: cell 72, seg 0 (0.5) [0.5 on Epop[72]] -> cell 41, seg 0 (0.5) [0.5 on Epop[41]], weight: 4.1363508E-4, delay 1.5
        h("Epop[41] syn_projEE_ampa[5801] = new ampa(0.5)")
        h("Epop[72] netConn_projEE_ampa[5801] = new NetCon(&v(0.5), syn_projEE_ampa[5801], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5802: cell 72, seg 0 (0.5) [0.5 on Epop[72]] -> cell 42, seg 0 (0.5) [0.5 on Epop[42]], weight: 4.1363508E-4, delay 1.5
        h("Epop[42] syn_projEE_ampa[5802] = new ampa(0.5)")
        h("Epop[72] netConn_projEE_ampa[5802] = new NetCon(&v(0.5), syn_projEE_ampa[5802], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5803: cell 72, seg 0 (0.5) [0.5 on Epop[72]] -> cell 43, seg 0 (0.5) [0.5 on Epop[43]], weight: 4.1363508E-4, delay 1.5
        h("Epop[43] syn_projEE_ampa[5803] = new ampa(0.5)")
        h("Epop[72] netConn_projEE_ampa[5803] = new NetCon(&v(0.5), syn_projEE_ampa[5803], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5804: cell 72, seg 0 (0.5) [0.5 on Epop[72]] -> cell 44, seg 0 (0.5) [0.5 on Epop[44]], weight: 4.1363508E-4, delay 1.5
        h("Epop[44] syn_projEE_ampa[5804] = new ampa(0.5)")
        h("Epop[72] netConn_projEE_ampa[5804] = new NetCon(&v(0.5), syn_projEE_ampa[5804], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5805: cell 72, seg 0 (0.5) [0.5 on Epop[72]] -> cell 45, seg 0 (0.5) [0.5 on Epop[45]], weight: 4.1363508E-4, delay 1.5
        h("Epop[45] syn_projEE_ampa[5805] = new ampa(0.5)")
        h("Epop[72] netConn_projEE_ampa[5805] = new NetCon(&v(0.5), syn_projEE_ampa[5805], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5806: cell 72, seg 0 (0.5) [0.5 on Epop[72]] -> cell 46, seg 0 (0.5) [0.5 on Epop[46]], weight: 4.1363508E-4, delay 1.5
        h("Epop[46] syn_projEE_ampa[5806] = new ampa(0.5)")
        h("Epop[72] netConn_projEE_ampa[5806] = new NetCon(&v(0.5), syn_projEE_ampa[5806], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5807: cell 72, seg 0 (0.5) [0.5 on Epop[72]] -> cell 47, seg 0 (0.5) [0.5 on Epop[47]], weight: 4.1363508E-4, delay 1.5
        h("Epop[47] syn_projEE_ampa[5807] = new ampa(0.5)")
        h("Epop[72] netConn_projEE_ampa[5807] = new NetCon(&v(0.5), syn_projEE_ampa[5807], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5808: cell 72, seg 0 (0.5) [0.5 on Epop[72]] -> cell 48, seg 0 (0.5) [0.5 on Epop[48]], weight: 4.1363508E-4, delay 1.5
        h("Epop[48] syn_projEE_ampa[5808] = new ampa(0.5)")
        h("Epop[72] netConn_projEE_ampa[5808] = new NetCon(&v(0.5), syn_projEE_ampa[5808], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5809: cell 72, seg 0 (0.5) [0.5 on Epop[72]] -> cell 49, seg 0 (0.5) [0.5 on Epop[49]], weight: 4.1363508E-4, delay 1.5
        h("Epop[49] syn_projEE_ampa[5809] = new ampa(0.5)")
        h("Epop[72] netConn_projEE_ampa[5809] = new NetCon(&v(0.5), syn_projEE_ampa[5809], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5810: cell 72, seg 0 (0.5) [0.5 on Epop[72]] -> cell 50, seg 0 (0.5) [0.5 on Epop[50]], weight: 4.1363508E-4, delay 1.5
        h("Epop[50] syn_projEE_ampa[5810] = new ampa(0.5)")
        h("Epop[72] netConn_projEE_ampa[5810] = new NetCon(&v(0.5), syn_projEE_ampa[5810], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5811: cell 72, seg 0 (0.5) [0.5 on Epop[72]] -> cell 51, seg 0 (0.5) [0.5 on Epop[51]], weight: 4.1363508E-4, delay 1.5
        h("Epop[51] syn_projEE_ampa[5811] = new ampa(0.5)")
        h("Epop[72] netConn_projEE_ampa[5811] = new NetCon(&v(0.5), syn_projEE_ampa[5811], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5812: cell 72, seg 0 (0.5) [0.5 on Epop[72]] -> cell 52, seg 0 (0.5) [0.5 on Epop[52]], weight: 4.1363508E-4, delay 1.5
        h("Epop[52] syn_projEE_ampa[5812] = new ampa(0.5)")
        h("Epop[72] netConn_projEE_ampa[5812] = new NetCon(&v(0.5), syn_projEE_ampa[5812], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5813: cell 72, seg 0 (0.5) [0.5 on Epop[72]] -> cell 53, seg 0 (0.5) [0.5 on Epop[53]], weight: 4.1363508E-4, delay 1.5
        h("Epop[53] syn_projEE_ampa[5813] = new ampa(0.5)")
        h("Epop[72] netConn_projEE_ampa[5813] = new NetCon(&v(0.5), syn_projEE_ampa[5813], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5814: cell 72, seg 0 (0.5) [0.5 on Epop[72]] -> cell 54, seg 0 (0.5) [0.5 on Epop[54]], weight: 4.1363508E-4, delay 1.5
        h("Epop[54] syn_projEE_ampa[5814] = new ampa(0.5)")
        h("Epop[72] netConn_projEE_ampa[5814] = new NetCon(&v(0.5), syn_projEE_ampa[5814], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5815: cell 72, seg 0 (0.5) [0.5 on Epop[72]] -> cell 55, seg 0 (0.5) [0.5 on Epop[55]], weight: 4.1363508E-4, delay 1.5
        h("Epop[55] syn_projEE_ampa[5815] = new ampa(0.5)")
        h("Epop[72] netConn_projEE_ampa[5815] = new NetCon(&v(0.5), syn_projEE_ampa[5815], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5816: cell 72, seg 0 (0.5) [0.5 on Epop[72]] -> cell 56, seg 0 (0.5) [0.5 on Epop[56]], weight: 4.1363508E-4, delay 1.5
        h("Epop[56] syn_projEE_ampa[5816] = new ampa(0.5)")
        h("Epop[72] netConn_projEE_ampa[5816] = new NetCon(&v(0.5), syn_projEE_ampa[5816], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5817: cell 72, seg 0 (0.5) [0.5 on Epop[72]] -> cell 57, seg 0 (0.5) [0.5 on Epop[57]], weight: 4.1363508E-4, delay 1.5
        h("Epop[57] syn_projEE_ampa[5817] = new ampa(0.5)")
        h("Epop[72] netConn_projEE_ampa[5817] = new NetCon(&v(0.5), syn_projEE_ampa[5817], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5818: cell 72, seg 0 (0.5) [0.5 on Epop[72]] -> cell 58, seg 0 (0.5) [0.5 on Epop[58]], weight: 4.1363508E-4, delay 1.5
        h("Epop[58] syn_projEE_ampa[5818] = new ampa(0.5)")
        h("Epop[72] netConn_projEE_ampa[5818] = new NetCon(&v(0.5), syn_projEE_ampa[5818], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5819: cell 72, seg 0 (0.5) [0.5 on Epop[72]] -> cell 59, seg 0 (0.5) [0.5 on Epop[59]], weight: 4.1363508E-4, delay 1.5
        h("Epop[59] syn_projEE_ampa[5819] = new ampa(0.5)")
        h("Epop[72] netConn_projEE_ampa[5819] = new NetCon(&v(0.5), syn_projEE_ampa[5819], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5820: cell 72, seg 0 (0.5) [0.5 on Epop[72]] -> cell 60, seg 0 (0.5) [0.5 on Epop[60]], weight: 4.1363508E-4, delay 1.5
        h("Epop[60] syn_projEE_ampa[5820] = new ampa(0.5)")
        h("Epop[72] netConn_projEE_ampa[5820] = new NetCon(&v(0.5), syn_projEE_ampa[5820], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5821: cell 72, seg 0 (0.5) [0.5 on Epop[72]] -> cell 61, seg 0 (0.5) [0.5 on Epop[61]], weight: 4.1363508E-4, delay 1.5
        h("Epop[61] syn_projEE_ampa[5821] = new ampa(0.5)")
        h("Epop[72] netConn_projEE_ampa[5821] = new NetCon(&v(0.5), syn_projEE_ampa[5821], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5822: cell 72, seg 0 (0.5) [0.5 on Epop[72]] -> cell 62, seg 0 (0.5) [0.5 on Epop[62]], weight: 4.1363508E-4, delay 1.5
        h("Epop[62] syn_projEE_ampa[5822] = new ampa(0.5)")
        h("Epop[72] netConn_projEE_ampa[5822] = new NetCon(&v(0.5), syn_projEE_ampa[5822], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5823: cell 72, seg 0 (0.5) [0.5 on Epop[72]] -> cell 63, seg 0 (0.5) [0.5 on Epop[63]], weight: 4.1363508E-4, delay 1.5
        h("Epop[63] syn_projEE_ampa[5823] = new ampa(0.5)")
        h("Epop[72] netConn_projEE_ampa[5823] = new NetCon(&v(0.5), syn_projEE_ampa[5823], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5824: cell 72, seg 0 (0.5) [0.5 on Epop[72]] -> cell 64, seg 0 (0.5) [0.5 on Epop[64]], weight: 4.1363508E-4, delay 1.5
        h("Epop[64] syn_projEE_ampa[5824] = new ampa(0.5)")
        h("Epop[72] netConn_projEE_ampa[5824] = new NetCon(&v(0.5), syn_projEE_ampa[5824], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5825: cell 72, seg 0 (0.5) [0.5 on Epop[72]] -> cell 65, seg 0 (0.5) [0.5 on Epop[65]], weight: 4.1363508E-4, delay 1.5
        h("Epop[65] syn_projEE_ampa[5825] = new ampa(0.5)")
        h("Epop[72] netConn_projEE_ampa[5825] = new NetCon(&v(0.5), syn_projEE_ampa[5825], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5826: cell 72, seg 0 (0.5) [0.5 on Epop[72]] -> cell 66, seg 0 (0.5) [0.5 on Epop[66]], weight: 4.1363508E-4, delay 1.5
        h("Epop[66] syn_projEE_ampa[5826] = new ampa(0.5)")
        h("Epop[72] netConn_projEE_ampa[5826] = new NetCon(&v(0.5), syn_projEE_ampa[5826], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5827: cell 72, seg 0 (0.5) [0.5 on Epop[72]] -> cell 67, seg 0 (0.5) [0.5 on Epop[67]], weight: 4.1363508E-4, delay 1.5
        h("Epop[67] syn_projEE_ampa[5827] = new ampa(0.5)")
        h("Epop[72] netConn_projEE_ampa[5827] = new NetCon(&v(0.5), syn_projEE_ampa[5827], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5828: cell 72, seg 0 (0.5) [0.5 on Epop[72]] -> cell 68, seg 0 (0.5) [0.5 on Epop[68]], weight: 4.1363508E-4, delay 1.5
        h("Epop[68] syn_projEE_ampa[5828] = new ampa(0.5)")
        h("Epop[72] netConn_projEE_ampa[5828] = new NetCon(&v(0.5), syn_projEE_ampa[5828], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5829: cell 72, seg 0 (0.5) [0.5 on Epop[72]] -> cell 69, seg 0 (0.5) [0.5 on Epop[69]], weight: 4.1363508E-4, delay 1.5
        h("Epop[69] syn_projEE_ampa[5829] = new ampa(0.5)")
        h("Epop[72] netConn_projEE_ampa[5829] = new NetCon(&v(0.5), syn_projEE_ampa[5829], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5830: cell 72, seg 0 (0.5) [0.5 on Epop[72]] -> cell 70, seg 0 (0.5) [0.5 on Epop[70]], weight: 4.1363508E-4, delay 1.5
        h("Epop[70] syn_projEE_ampa[5830] = new ampa(0.5)")
        h("Epop[72] netConn_projEE_ampa[5830] = new NetCon(&v(0.5), syn_projEE_ampa[5830], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5831: cell 72, seg 0 (0.5) [0.5 on Epop[72]] -> cell 71, seg 0 (0.5) [0.5 on Epop[71]], weight: 4.1363508E-4, delay 1.5
        h("Epop[71] syn_projEE_ampa[5831] = new ampa(0.5)")
        h("Epop[72] netConn_projEE_ampa[5831] = new NetCon(&v(0.5), syn_projEE_ampa[5831], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5832: cell 72, seg 0 (0.5) [0.5 on Epop[72]] -> cell 72, seg 0 (0.5) [0.5 on Epop[72]], weight: 4.1363508E-4, delay 1.5
        h("Epop[72] syn_projEE_ampa[5832] = new ampa(0.5)")
        h("Epop[72] netConn_projEE_ampa[5832] = new NetCon(&v(0.5), syn_projEE_ampa[5832], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5833: cell 72, seg 0 (0.5) [0.5 on Epop[72]] -> cell 73, seg 0 (0.5) [0.5 on Epop[73]], weight: 4.1363508E-4, delay 1.5
        h("Epop[73] syn_projEE_ampa[5833] = new ampa(0.5)")
        h("Epop[72] netConn_projEE_ampa[5833] = new NetCon(&v(0.5), syn_projEE_ampa[5833], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5834: cell 72, seg 0 (0.5) [0.5 on Epop[72]] -> cell 74, seg 0 (0.5) [0.5 on Epop[74]], weight: 4.1363508E-4, delay 1.5
        h("Epop[74] syn_projEE_ampa[5834] = new ampa(0.5)")
        h("Epop[72] netConn_projEE_ampa[5834] = new NetCon(&v(0.5), syn_projEE_ampa[5834], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5835: cell 72, seg 0 (0.5) [0.5 on Epop[72]] -> cell 75, seg 0 (0.5) [0.5 on Epop[75]], weight: 4.1363508E-4, delay 1.5
        h("Epop[75] syn_projEE_ampa[5835] = new ampa(0.5)")
        h("Epop[72] netConn_projEE_ampa[5835] = new NetCon(&v(0.5), syn_projEE_ampa[5835], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5836: cell 72, seg 0 (0.5) [0.5 on Epop[72]] -> cell 76, seg 0 (0.5) [0.5 on Epop[76]], weight: 4.1363508E-4, delay 1.5
        h("Epop[76] syn_projEE_ampa[5836] = new ampa(0.5)")
        h("Epop[72] netConn_projEE_ampa[5836] = new NetCon(&v(0.5), syn_projEE_ampa[5836], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5837: cell 72, seg 0 (0.5) [0.5 on Epop[72]] -> cell 77, seg 0 (0.5) [0.5 on Epop[77]], weight: 4.1363508E-4, delay 1.5
        h("Epop[77] syn_projEE_ampa[5837] = new ampa(0.5)")
        h("Epop[72] netConn_projEE_ampa[5837] = new NetCon(&v(0.5), syn_projEE_ampa[5837], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5838: cell 72, seg 0 (0.5) [0.5 on Epop[72]] -> cell 78, seg 0 (0.5) [0.5 on Epop[78]], weight: 4.1363508E-4, delay 1.5
        h("Epop[78] syn_projEE_ampa[5838] = new ampa(0.5)")
        h("Epop[72] netConn_projEE_ampa[5838] = new NetCon(&v(0.5), syn_projEE_ampa[5838], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5839: cell 72, seg 0 (0.5) [0.5 on Epop[72]] -> cell 79, seg 0 (0.5) [0.5 on Epop[79]], weight: 4.1363508E-4, delay 1.5
        h("Epop[79] syn_projEE_ampa[5839] = new ampa(0.5)")
        h("Epop[72] netConn_projEE_ampa[5839] = new NetCon(&v(0.5), syn_projEE_ampa[5839], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5840: cell 73, seg 0 (0.5) [0.5 on Epop[73]] -> cell 0, seg 0 (0.5) [0.5 on Epop[0]], weight: 4.1363508E-4, delay 1.5
        h("Epop[0] syn_projEE_ampa[5840] = new ampa(0.5)")
        h("Epop[73] netConn_projEE_ampa[5840] = new NetCon(&v(0.5), syn_projEE_ampa[5840], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5841: cell 73, seg 0 (0.5) [0.5 on Epop[73]] -> cell 1, seg 0 (0.5) [0.5 on Epop[1]], weight: 4.1363508E-4, delay 1.5
        h("Epop[1] syn_projEE_ampa[5841] = new ampa(0.5)")
        h("Epop[73] netConn_projEE_ampa[5841] = new NetCon(&v(0.5), syn_projEE_ampa[5841], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5842: cell 73, seg 0 (0.5) [0.5 on Epop[73]] -> cell 2, seg 0 (0.5) [0.5 on Epop[2]], weight: 4.1363508E-4, delay 1.5
        h("Epop[2] syn_projEE_ampa[5842] = new ampa(0.5)")
        h("Epop[73] netConn_projEE_ampa[5842] = new NetCon(&v(0.5), syn_projEE_ampa[5842], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5843: cell 73, seg 0 (0.5) [0.5 on Epop[73]] -> cell 3, seg 0 (0.5) [0.5 on Epop[3]], weight: 4.1363508E-4, delay 1.5
        h("Epop[3] syn_projEE_ampa[5843] = new ampa(0.5)")
        h("Epop[73] netConn_projEE_ampa[5843] = new NetCon(&v(0.5), syn_projEE_ampa[5843], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5844: cell 73, seg 0 (0.5) [0.5 on Epop[73]] -> cell 4, seg 0 (0.5) [0.5 on Epop[4]], weight: 4.1363508E-4, delay 1.5
        h("Epop[4] syn_projEE_ampa[5844] = new ampa(0.5)")
        h("Epop[73] netConn_projEE_ampa[5844] = new NetCon(&v(0.5), syn_projEE_ampa[5844], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5845: cell 73, seg 0 (0.5) [0.5 on Epop[73]] -> cell 5, seg 0 (0.5) [0.5 on Epop[5]], weight: 4.1363508E-4, delay 1.5
        h("Epop[5] syn_projEE_ampa[5845] = new ampa(0.5)")
        h("Epop[73] netConn_projEE_ampa[5845] = new NetCon(&v(0.5), syn_projEE_ampa[5845], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5846: cell 73, seg 0 (0.5) [0.5 on Epop[73]] -> cell 6, seg 0 (0.5) [0.5 on Epop[6]], weight: 4.1363508E-4, delay 1.5
        h("Epop[6] syn_projEE_ampa[5846] = new ampa(0.5)")
        h("Epop[73] netConn_projEE_ampa[5846] = new NetCon(&v(0.5), syn_projEE_ampa[5846], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5847: cell 73, seg 0 (0.5) [0.5 on Epop[73]] -> cell 7, seg 0 (0.5) [0.5 on Epop[7]], weight: 4.1363508E-4, delay 1.5
        h("Epop[7] syn_projEE_ampa[5847] = new ampa(0.5)")
        h("Epop[73] netConn_projEE_ampa[5847] = new NetCon(&v(0.5), syn_projEE_ampa[5847], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5848: cell 73, seg 0 (0.5) [0.5 on Epop[73]] -> cell 8, seg 0 (0.5) [0.5 on Epop[8]], weight: 4.1363508E-4, delay 1.5
        h("Epop[8] syn_projEE_ampa[5848] = new ampa(0.5)")
        h("Epop[73] netConn_projEE_ampa[5848] = new NetCon(&v(0.5), syn_projEE_ampa[5848], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5849: cell 73, seg 0 (0.5) [0.5 on Epop[73]] -> cell 9, seg 0 (0.5) [0.5 on Epop[9]], weight: 4.1363508E-4, delay 1.5
        h("Epop[9] syn_projEE_ampa[5849] = new ampa(0.5)")
        h("Epop[73] netConn_projEE_ampa[5849] = new NetCon(&v(0.5), syn_projEE_ampa[5849], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5850: cell 73, seg 0 (0.5) [0.5 on Epop[73]] -> cell 10, seg 0 (0.5) [0.5 on Epop[10]], weight: 4.1363508E-4, delay 1.5
        h("Epop[10] syn_projEE_ampa[5850] = new ampa(0.5)")
        h("Epop[73] netConn_projEE_ampa[5850] = new NetCon(&v(0.5), syn_projEE_ampa[5850], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5851: cell 73, seg 0 (0.5) [0.5 on Epop[73]] -> cell 11, seg 0 (0.5) [0.5 on Epop[11]], weight: 4.1363508E-4, delay 1.5
        h("Epop[11] syn_projEE_ampa[5851] = new ampa(0.5)")
        h("Epop[73] netConn_projEE_ampa[5851] = new NetCon(&v(0.5), syn_projEE_ampa[5851], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5852: cell 73, seg 0 (0.5) [0.5 on Epop[73]] -> cell 12, seg 0 (0.5) [0.5 on Epop[12]], weight: 4.1363508E-4, delay 1.5
        h("Epop[12] syn_projEE_ampa[5852] = new ampa(0.5)")
        h("Epop[73] netConn_projEE_ampa[5852] = new NetCon(&v(0.5), syn_projEE_ampa[5852], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5853: cell 73, seg 0 (0.5) [0.5 on Epop[73]] -> cell 13, seg 0 (0.5) [0.5 on Epop[13]], weight: 4.1363508E-4, delay 1.5
        h("Epop[13] syn_projEE_ampa[5853] = new ampa(0.5)")
        h("Epop[73] netConn_projEE_ampa[5853] = new NetCon(&v(0.5), syn_projEE_ampa[5853], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5854: cell 73, seg 0 (0.5) [0.5 on Epop[73]] -> cell 14, seg 0 (0.5) [0.5 on Epop[14]], weight: 4.1363508E-4, delay 1.5
        h("Epop[14] syn_projEE_ampa[5854] = new ampa(0.5)")
        h("Epop[73] netConn_projEE_ampa[5854] = new NetCon(&v(0.5), syn_projEE_ampa[5854], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5855: cell 73, seg 0 (0.5) [0.5 on Epop[73]] -> cell 15, seg 0 (0.5) [0.5 on Epop[15]], weight: 4.1363508E-4, delay 1.5
        h("Epop[15] syn_projEE_ampa[5855] = new ampa(0.5)")
        h("Epop[73] netConn_projEE_ampa[5855] = new NetCon(&v(0.5), syn_projEE_ampa[5855], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5856: cell 73, seg 0 (0.5) [0.5 on Epop[73]] -> cell 16, seg 0 (0.5) [0.5 on Epop[16]], weight: 4.1363508E-4, delay 1.5
        h("Epop[16] syn_projEE_ampa[5856] = new ampa(0.5)")
        h("Epop[73] netConn_projEE_ampa[5856] = new NetCon(&v(0.5), syn_projEE_ampa[5856], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5857: cell 73, seg 0 (0.5) [0.5 on Epop[73]] -> cell 17, seg 0 (0.5) [0.5 on Epop[17]], weight: 4.1363508E-4, delay 1.5
        h("Epop[17] syn_projEE_ampa[5857] = new ampa(0.5)")
        h("Epop[73] netConn_projEE_ampa[5857] = new NetCon(&v(0.5), syn_projEE_ampa[5857], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5858: cell 73, seg 0 (0.5) [0.5 on Epop[73]] -> cell 18, seg 0 (0.5) [0.5 on Epop[18]], weight: 4.1363508E-4, delay 1.5
        h("Epop[18] syn_projEE_ampa[5858] = new ampa(0.5)")
        h("Epop[73] netConn_projEE_ampa[5858] = new NetCon(&v(0.5), syn_projEE_ampa[5858], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5859: cell 73, seg 0 (0.5) [0.5 on Epop[73]] -> cell 19, seg 0 (0.5) [0.5 on Epop[19]], weight: 4.1363508E-4, delay 1.5
        h("Epop[19] syn_projEE_ampa[5859] = new ampa(0.5)")
        h("Epop[73] netConn_projEE_ampa[5859] = new NetCon(&v(0.5), syn_projEE_ampa[5859], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5860: cell 73, seg 0 (0.5) [0.5 on Epop[73]] -> cell 20, seg 0 (0.5) [0.5 on Epop[20]], weight: 4.1363508E-4, delay 1.5
        h("Epop[20] syn_projEE_ampa[5860] = new ampa(0.5)")
        h("Epop[73] netConn_projEE_ampa[5860] = new NetCon(&v(0.5), syn_projEE_ampa[5860], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5861: cell 73, seg 0 (0.5) [0.5 on Epop[73]] -> cell 21, seg 0 (0.5) [0.5 on Epop[21]], weight: 4.1363508E-4, delay 1.5
        h("Epop[21] syn_projEE_ampa[5861] = new ampa(0.5)")
        h("Epop[73] netConn_projEE_ampa[5861] = new NetCon(&v(0.5), syn_projEE_ampa[5861], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5862: cell 73, seg 0 (0.5) [0.5 on Epop[73]] -> cell 22, seg 0 (0.5) [0.5 on Epop[22]], weight: 4.1363508E-4, delay 1.5
        h("Epop[22] syn_projEE_ampa[5862] = new ampa(0.5)")
        h("Epop[73] netConn_projEE_ampa[5862] = new NetCon(&v(0.5), syn_projEE_ampa[5862], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5863: cell 73, seg 0 (0.5) [0.5 on Epop[73]] -> cell 23, seg 0 (0.5) [0.5 on Epop[23]], weight: 4.1363508E-4, delay 1.5
        h("Epop[23] syn_projEE_ampa[5863] = new ampa(0.5)")
        h("Epop[73] netConn_projEE_ampa[5863] = new NetCon(&v(0.5), syn_projEE_ampa[5863], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5864: cell 73, seg 0 (0.5) [0.5 on Epop[73]] -> cell 24, seg 0 (0.5) [0.5 on Epop[24]], weight: 4.1363508E-4, delay 1.5
        h("Epop[24] syn_projEE_ampa[5864] = new ampa(0.5)")
        h("Epop[73] netConn_projEE_ampa[5864] = new NetCon(&v(0.5), syn_projEE_ampa[5864], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5865: cell 73, seg 0 (0.5) [0.5 on Epop[73]] -> cell 25, seg 0 (0.5) [0.5 on Epop[25]], weight: 4.1363508E-4, delay 1.5
        h("Epop[25] syn_projEE_ampa[5865] = new ampa(0.5)")
        h("Epop[73] netConn_projEE_ampa[5865] = new NetCon(&v(0.5), syn_projEE_ampa[5865], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5866: cell 73, seg 0 (0.5) [0.5 on Epop[73]] -> cell 26, seg 0 (0.5) [0.5 on Epop[26]], weight: 4.1363508E-4, delay 1.5
        h("Epop[26] syn_projEE_ampa[5866] = new ampa(0.5)")
        h("Epop[73] netConn_projEE_ampa[5866] = new NetCon(&v(0.5), syn_projEE_ampa[5866], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5867: cell 73, seg 0 (0.5) [0.5 on Epop[73]] -> cell 27, seg 0 (0.5) [0.5 on Epop[27]], weight: 4.1363508E-4, delay 1.5
        h("Epop[27] syn_projEE_ampa[5867] = new ampa(0.5)")
        h("Epop[73] netConn_projEE_ampa[5867] = new NetCon(&v(0.5), syn_projEE_ampa[5867], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5868: cell 73, seg 0 (0.5) [0.5 on Epop[73]] -> cell 28, seg 0 (0.5) [0.5 on Epop[28]], weight: 4.1363508E-4, delay 1.5
        h("Epop[28] syn_projEE_ampa[5868] = new ampa(0.5)")
        h("Epop[73] netConn_projEE_ampa[5868] = new NetCon(&v(0.5), syn_projEE_ampa[5868], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5869: cell 73, seg 0 (0.5) [0.5 on Epop[73]] -> cell 29, seg 0 (0.5) [0.5 on Epop[29]], weight: 4.1363508E-4, delay 1.5
        h("Epop[29] syn_projEE_ampa[5869] = new ampa(0.5)")
        h("Epop[73] netConn_projEE_ampa[5869] = new NetCon(&v(0.5), syn_projEE_ampa[5869], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5870: cell 73, seg 0 (0.5) [0.5 on Epop[73]] -> cell 30, seg 0 (0.5) [0.5 on Epop[30]], weight: 4.1363508E-4, delay 1.5
        h("Epop[30] syn_projEE_ampa[5870] = new ampa(0.5)")
        h("Epop[73] netConn_projEE_ampa[5870] = new NetCon(&v(0.5), syn_projEE_ampa[5870], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5871: cell 73, seg 0 (0.5) [0.5 on Epop[73]] -> cell 31, seg 0 (0.5) [0.5 on Epop[31]], weight: 4.1363508E-4, delay 1.5
        h("Epop[31] syn_projEE_ampa[5871] = new ampa(0.5)")
        h("Epop[73] netConn_projEE_ampa[5871] = new NetCon(&v(0.5), syn_projEE_ampa[5871], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5872: cell 73, seg 0 (0.5) [0.5 on Epop[73]] -> cell 32, seg 0 (0.5) [0.5 on Epop[32]], weight: 4.1363508E-4, delay 1.5
        h("Epop[32] syn_projEE_ampa[5872] = new ampa(0.5)")
        h("Epop[73] netConn_projEE_ampa[5872] = new NetCon(&v(0.5), syn_projEE_ampa[5872], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5873: cell 73, seg 0 (0.5) [0.5 on Epop[73]] -> cell 33, seg 0 (0.5) [0.5 on Epop[33]], weight: 4.1363508E-4, delay 1.5
        h("Epop[33] syn_projEE_ampa[5873] = new ampa(0.5)")
        h("Epop[73] netConn_projEE_ampa[5873] = new NetCon(&v(0.5), syn_projEE_ampa[5873], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5874: cell 73, seg 0 (0.5) [0.5 on Epop[73]] -> cell 34, seg 0 (0.5) [0.5 on Epop[34]], weight: 4.1363508E-4, delay 1.5
        h("Epop[34] syn_projEE_ampa[5874] = new ampa(0.5)")
        h("Epop[73] netConn_projEE_ampa[5874] = new NetCon(&v(0.5), syn_projEE_ampa[5874], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5875: cell 73, seg 0 (0.5) [0.5 on Epop[73]] -> cell 35, seg 0 (0.5) [0.5 on Epop[35]], weight: 4.1363508E-4, delay 1.5
        h("Epop[35] syn_projEE_ampa[5875] = new ampa(0.5)")
        h("Epop[73] netConn_projEE_ampa[5875] = new NetCon(&v(0.5), syn_projEE_ampa[5875], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5876: cell 73, seg 0 (0.5) [0.5 on Epop[73]] -> cell 36, seg 0 (0.5) [0.5 on Epop[36]], weight: 4.1363508E-4, delay 1.5
        h("Epop[36] syn_projEE_ampa[5876] = new ampa(0.5)")
        h("Epop[73] netConn_projEE_ampa[5876] = new NetCon(&v(0.5), syn_projEE_ampa[5876], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5877: cell 73, seg 0 (0.5) [0.5 on Epop[73]] -> cell 37, seg 0 (0.5) [0.5 on Epop[37]], weight: 4.1363508E-4, delay 1.5
        h("Epop[37] syn_projEE_ampa[5877] = new ampa(0.5)")
        h("Epop[73] netConn_projEE_ampa[5877] = new NetCon(&v(0.5), syn_projEE_ampa[5877], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5878: cell 73, seg 0 (0.5) [0.5 on Epop[73]] -> cell 38, seg 0 (0.5) [0.5 on Epop[38]], weight: 4.1363508E-4, delay 1.5
        h("Epop[38] syn_projEE_ampa[5878] = new ampa(0.5)")
        h("Epop[73] netConn_projEE_ampa[5878] = new NetCon(&v(0.5), syn_projEE_ampa[5878], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5879: cell 73, seg 0 (0.5) [0.5 on Epop[73]] -> cell 39, seg 0 (0.5) [0.5 on Epop[39]], weight: 4.1363508E-4, delay 1.5
        h("Epop[39] syn_projEE_ampa[5879] = new ampa(0.5)")
        h("Epop[73] netConn_projEE_ampa[5879] = new NetCon(&v(0.5), syn_projEE_ampa[5879], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5880: cell 73, seg 0 (0.5) [0.5 on Epop[73]] -> cell 40, seg 0 (0.5) [0.5 on Epop[40]], weight: 4.1363508E-4, delay 1.5
        h("Epop[40] syn_projEE_ampa[5880] = new ampa(0.5)")
        h("Epop[73] netConn_projEE_ampa[5880] = new NetCon(&v(0.5), syn_projEE_ampa[5880], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5881: cell 73, seg 0 (0.5) [0.5 on Epop[73]] -> cell 41, seg 0 (0.5) [0.5 on Epop[41]], weight: 4.1363508E-4, delay 1.5
        h("Epop[41] syn_projEE_ampa[5881] = new ampa(0.5)")
        h("Epop[73] netConn_projEE_ampa[5881] = new NetCon(&v(0.5), syn_projEE_ampa[5881], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5882: cell 73, seg 0 (0.5) [0.5 on Epop[73]] -> cell 42, seg 0 (0.5) [0.5 on Epop[42]], weight: 4.1363508E-4, delay 1.5
        h("Epop[42] syn_projEE_ampa[5882] = new ampa(0.5)")
        h("Epop[73] netConn_projEE_ampa[5882] = new NetCon(&v(0.5), syn_projEE_ampa[5882], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5883: cell 73, seg 0 (0.5) [0.5 on Epop[73]] -> cell 43, seg 0 (0.5) [0.5 on Epop[43]], weight: 4.1363508E-4, delay 1.5
        h("Epop[43] syn_projEE_ampa[5883] = new ampa(0.5)")
        h("Epop[73] netConn_projEE_ampa[5883] = new NetCon(&v(0.5), syn_projEE_ampa[5883], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5884: cell 73, seg 0 (0.5) [0.5 on Epop[73]] -> cell 44, seg 0 (0.5) [0.5 on Epop[44]], weight: 4.1363508E-4, delay 1.5
        h("Epop[44] syn_projEE_ampa[5884] = new ampa(0.5)")
        h("Epop[73] netConn_projEE_ampa[5884] = new NetCon(&v(0.5), syn_projEE_ampa[5884], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5885: cell 73, seg 0 (0.5) [0.5 on Epop[73]] -> cell 45, seg 0 (0.5) [0.5 on Epop[45]], weight: 4.1363508E-4, delay 1.5
        h("Epop[45] syn_projEE_ampa[5885] = new ampa(0.5)")
        h("Epop[73] netConn_projEE_ampa[5885] = new NetCon(&v(0.5), syn_projEE_ampa[5885], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5886: cell 73, seg 0 (0.5) [0.5 on Epop[73]] -> cell 46, seg 0 (0.5) [0.5 on Epop[46]], weight: 4.1363508E-4, delay 1.5
        h("Epop[46] syn_projEE_ampa[5886] = new ampa(0.5)")
        h("Epop[73] netConn_projEE_ampa[5886] = new NetCon(&v(0.5), syn_projEE_ampa[5886], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5887: cell 73, seg 0 (0.5) [0.5 on Epop[73]] -> cell 47, seg 0 (0.5) [0.5 on Epop[47]], weight: 4.1363508E-4, delay 1.5
        h("Epop[47] syn_projEE_ampa[5887] = new ampa(0.5)")
        h("Epop[73] netConn_projEE_ampa[5887] = new NetCon(&v(0.5), syn_projEE_ampa[5887], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5888: cell 73, seg 0 (0.5) [0.5 on Epop[73]] -> cell 48, seg 0 (0.5) [0.5 on Epop[48]], weight: 4.1363508E-4, delay 1.5
        h("Epop[48] syn_projEE_ampa[5888] = new ampa(0.5)")
        h("Epop[73] netConn_projEE_ampa[5888] = new NetCon(&v(0.5), syn_projEE_ampa[5888], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5889: cell 73, seg 0 (0.5) [0.5 on Epop[73]] -> cell 49, seg 0 (0.5) [0.5 on Epop[49]], weight: 4.1363508E-4, delay 1.5
        h("Epop[49] syn_projEE_ampa[5889] = new ampa(0.5)")
        h("Epop[73] netConn_projEE_ampa[5889] = new NetCon(&v(0.5), syn_projEE_ampa[5889], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5890: cell 73, seg 0 (0.5) [0.5 on Epop[73]] -> cell 50, seg 0 (0.5) [0.5 on Epop[50]], weight: 4.1363508E-4, delay 1.5
        h("Epop[50] syn_projEE_ampa[5890] = new ampa(0.5)")
        h("Epop[73] netConn_projEE_ampa[5890] = new NetCon(&v(0.5), syn_projEE_ampa[5890], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5891: cell 73, seg 0 (0.5) [0.5 on Epop[73]] -> cell 51, seg 0 (0.5) [0.5 on Epop[51]], weight: 4.1363508E-4, delay 1.5
        h("Epop[51] syn_projEE_ampa[5891] = new ampa(0.5)")
        h("Epop[73] netConn_projEE_ampa[5891] = new NetCon(&v(0.5), syn_projEE_ampa[5891], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5892: cell 73, seg 0 (0.5) [0.5 on Epop[73]] -> cell 52, seg 0 (0.5) [0.5 on Epop[52]], weight: 4.1363508E-4, delay 1.5
        h("Epop[52] syn_projEE_ampa[5892] = new ampa(0.5)")
        h("Epop[73] netConn_projEE_ampa[5892] = new NetCon(&v(0.5), syn_projEE_ampa[5892], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5893: cell 73, seg 0 (0.5) [0.5 on Epop[73]] -> cell 53, seg 0 (0.5) [0.5 on Epop[53]], weight: 4.1363508E-4, delay 1.5
        h("Epop[53] syn_projEE_ampa[5893] = new ampa(0.5)")
        h("Epop[73] netConn_projEE_ampa[5893] = new NetCon(&v(0.5), syn_projEE_ampa[5893], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5894: cell 73, seg 0 (0.5) [0.5 on Epop[73]] -> cell 54, seg 0 (0.5) [0.5 on Epop[54]], weight: 4.1363508E-4, delay 1.5
        h("Epop[54] syn_projEE_ampa[5894] = new ampa(0.5)")
        h("Epop[73] netConn_projEE_ampa[5894] = new NetCon(&v(0.5), syn_projEE_ampa[5894], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5895: cell 73, seg 0 (0.5) [0.5 on Epop[73]] -> cell 55, seg 0 (0.5) [0.5 on Epop[55]], weight: 4.1363508E-4, delay 1.5
        h("Epop[55] syn_projEE_ampa[5895] = new ampa(0.5)")
        h("Epop[73] netConn_projEE_ampa[5895] = new NetCon(&v(0.5), syn_projEE_ampa[5895], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5896: cell 73, seg 0 (0.5) [0.5 on Epop[73]] -> cell 56, seg 0 (0.5) [0.5 on Epop[56]], weight: 4.1363508E-4, delay 1.5
        h("Epop[56] syn_projEE_ampa[5896] = new ampa(0.5)")
        h("Epop[73] netConn_projEE_ampa[5896] = new NetCon(&v(0.5), syn_projEE_ampa[5896], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5897: cell 73, seg 0 (0.5) [0.5 on Epop[73]] -> cell 57, seg 0 (0.5) [0.5 on Epop[57]], weight: 4.1363508E-4, delay 1.5
        h("Epop[57] syn_projEE_ampa[5897] = new ampa(0.5)")
        h("Epop[73] netConn_projEE_ampa[5897] = new NetCon(&v(0.5), syn_projEE_ampa[5897], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5898: cell 73, seg 0 (0.5) [0.5 on Epop[73]] -> cell 58, seg 0 (0.5) [0.5 on Epop[58]], weight: 4.1363508E-4, delay 1.5
        h("Epop[58] syn_projEE_ampa[5898] = new ampa(0.5)")
        h("Epop[73] netConn_projEE_ampa[5898] = new NetCon(&v(0.5), syn_projEE_ampa[5898], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5899: cell 73, seg 0 (0.5) [0.5 on Epop[73]] -> cell 59, seg 0 (0.5) [0.5 on Epop[59]], weight: 4.1363508E-4, delay 1.5
        h("Epop[59] syn_projEE_ampa[5899] = new ampa(0.5)")
        h("Epop[73] netConn_projEE_ampa[5899] = new NetCon(&v(0.5), syn_projEE_ampa[5899], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5900: cell 73, seg 0 (0.5) [0.5 on Epop[73]] -> cell 60, seg 0 (0.5) [0.5 on Epop[60]], weight: 4.1363508E-4, delay 1.5
        h("Epop[60] syn_projEE_ampa[5900] = new ampa(0.5)")
        h("Epop[73] netConn_projEE_ampa[5900] = new NetCon(&v(0.5), syn_projEE_ampa[5900], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5901: cell 73, seg 0 (0.5) [0.5 on Epop[73]] -> cell 61, seg 0 (0.5) [0.5 on Epop[61]], weight: 4.1363508E-4, delay 1.5
        h("Epop[61] syn_projEE_ampa[5901] = new ampa(0.5)")
        h("Epop[73] netConn_projEE_ampa[5901] = new NetCon(&v(0.5), syn_projEE_ampa[5901], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5902: cell 73, seg 0 (0.5) [0.5 on Epop[73]] -> cell 62, seg 0 (0.5) [0.5 on Epop[62]], weight: 4.1363508E-4, delay 1.5
        h("Epop[62] syn_projEE_ampa[5902] = new ampa(0.5)")
        h("Epop[73] netConn_projEE_ampa[5902] = new NetCon(&v(0.5), syn_projEE_ampa[5902], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5903: cell 73, seg 0 (0.5) [0.5 on Epop[73]] -> cell 63, seg 0 (0.5) [0.5 on Epop[63]], weight: 4.1363508E-4, delay 1.5
        h("Epop[63] syn_projEE_ampa[5903] = new ampa(0.5)")
        h("Epop[73] netConn_projEE_ampa[5903] = new NetCon(&v(0.5), syn_projEE_ampa[5903], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5904: cell 73, seg 0 (0.5) [0.5 on Epop[73]] -> cell 64, seg 0 (0.5) [0.5 on Epop[64]], weight: 4.1363508E-4, delay 1.5
        h("Epop[64] syn_projEE_ampa[5904] = new ampa(0.5)")
        h("Epop[73] netConn_projEE_ampa[5904] = new NetCon(&v(0.5), syn_projEE_ampa[5904], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5905: cell 73, seg 0 (0.5) [0.5 on Epop[73]] -> cell 65, seg 0 (0.5) [0.5 on Epop[65]], weight: 4.1363508E-4, delay 1.5
        h("Epop[65] syn_projEE_ampa[5905] = new ampa(0.5)")
        h("Epop[73] netConn_projEE_ampa[5905] = new NetCon(&v(0.5), syn_projEE_ampa[5905], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5906: cell 73, seg 0 (0.5) [0.5 on Epop[73]] -> cell 66, seg 0 (0.5) [0.5 on Epop[66]], weight: 4.1363508E-4, delay 1.5
        h("Epop[66] syn_projEE_ampa[5906] = new ampa(0.5)")
        h("Epop[73] netConn_projEE_ampa[5906] = new NetCon(&v(0.5), syn_projEE_ampa[5906], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5907: cell 73, seg 0 (0.5) [0.5 on Epop[73]] -> cell 67, seg 0 (0.5) [0.5 on Epop[67]], weight: 4.1363508E-4, delay 1.5
        h("Epop[67] syn_projEE_ampa[5907] = new ampa(0.5)")
        h("Epop[73] netConn_projEE_ampa[5907] = new NetCon(&v(0.5), syn_projEE_ampa[5907], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5908: cell 73, seg 0 (0.5) [0.5 on Epop[73]] -> cell 68, seg 0 (0.5) [0.5 on Epop[68]], weight: 4.1363508E-4, delay 1.5
        h("Epop[68] syn_projEE_ampa[5908] = new ampa(0.5)")
        h("Epop[73] netConn_projEE_ampa[5908] = new NetCon(&v(0.5), syn_projEE_ampa[5908], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5909: cell 73, seg 0 (0.5) [0.5 on Epop[73]] -> cell 69, seg 0 (0.5) [0.5 on Epop[69]], weight: 4.1363508E-4, delay 1.5
        h("Epop[69] syn_projEE_ampa[5909] = new ampa(0.5)")
        h("Epop[73] netConn_projEE_ampa[5909] = new NetCon(&v(0.5), syn_projEE_ampa[5909], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5910: cell 73, seg 0 (0.5) [0.5 on Epop[73]] -> cell 70, seg 0 (0.5) [0.5 on Epop[70]], weight: 4.1363508E-4, delay 1.5
        h("Epop[70] syn_projEE_ampa[5910] = new ampa(0.5)")
        h("Epop[73] netConn_projEE_ampa[5910] = new NetCon(&v(0.5), syn_projEE_ampa[5910], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5911: cell 73, seg 0 (0.5) [0.5 on Epop[73]] -> cell 71, seg 0 (0.5) [0.5 on Epop[71]], weight: 4.1363508E-4, delay 1.5
        h("Epop[71] syn_projEE_ampa[5911] = new ampa(0.5)")
        h("Epop[73] netConn_projEE_ampa[5911] = new NetCon(&v(0.5), syn_projEE_ampa[5911], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5912: cell 73, seg 0 (0.5) [0.5 on Epop[73]] -> cell 72, seg 0 (0.5) [0.5 on Epop[72]], weight: 4.1363508E-4, delay 1.5
        h("Epop[72] syn_projEE_ampa[5912] = new ampa(0.5)")
        h("Epop[73] netConn_projEE_ampa[5912] = new NetCon(&v(0.5), syn_projEE_ampa[5912], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5913: cell 73, seg 0 (0.5) [0.5 on Epop[73]] -> cell 73, seg 0 (0.5) [0.5 on Epop[73]], weight: 4.1363508E-4, delay 1.5
        h("Epop[73] syn_projEE_ampa[5913] = new ampa(0.5)")
        h("Epop[73] netConn_projEE_ampa[5913] = new NetCon(&v(0.5), syn_projEE_ampa[5913], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5914: cell 73, seg 0 (0.5) [0.5 on Epop[73]] -> cell 74, seg 0 (0.5) [0.5 on Epop[74]], weight: 4.1363508E-4, delay 1.5
        h("Epop[74] syn_projEE_ampa[5914] = new ampa(0.5)")
        h("Epop[73] netConn_projEE_ampa[5914] = new NetCon(&v(0.5), syn_projEE_ampa[5914], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5915: cell 73, seg 0 (0.5) [0.5 on Epop[73]] -> cell 75, seg 0 (0.5) [0.5 on Epop[75]], weight: 4.1363508E-4, delay 1.5
        h("Epop[75] syn_projEE_ampa[5915] = new ampa(0.5)")
        h("Epop[73] netConn_projEE_ampa[5915] = new NetCon(&v(0.5), syn_projEE_ampa[5915], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5916: cell 73, seg 0 (0.5) [0.5 on Epop[73]] -> cell 76, seg 0 (0.5) [0.5 on Epop[76]], weight: 4.1363508E-4, delay 1.5
        h("Epop[76] syn_projEE_ampa[5916] = new ampa(0.5)")
        h("Epop[73] netConn_projEE_ampa[5916] = new NetCon(&v(0.5), syn_projEE_ampa[5916], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5917: cell 73, seg 0 (0.5) [0.5 on Epop[73]] -> cell 77, seg 0 (0.5) [0.5 on Epop[77]], weight: 4.1363508E-4, delay 1.5
        h("Epop[77] syn_projEE_ampa[5917] = new ampa(0.5)")
        h("Epop[73] netConn_projEE_ampa[5917] = new NetCon(&v(0.5), syn_projEE_ampa[5917], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5918: cell 73, seg 0 (0.5) [0.5 on Epop[73]] -> cell 78, seg 0 (0.5) [0.5 on Epop[78]], weight: 4.1363508E-4, delay 1.5
        h("Epop[78] syn_projEE_ampa[5918] = new ampa(0.5)")
        h("Epop[73] netConn_projEE_ampa[5918] = new NetCon(&v(0.5), syn_projEE_ampa[5918], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5919: cell 73, seg 0 (0.5) [0.5 on Epop[73]] -> cell 79, seg 0 (0.5) [0.5 on Epop[79]], weight: 4.1363508E-4, delay 1.5
        h("Epop[79] syn_projEE_ampa[5919] = new ampa(0.5)")
        h("Epop[73] netConn_projEE_ampa[5919] = new NetCon(&v(0.5), syn_projEE_ampa[5919], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5920: cell 74, seg 0 (0.5) [0.5 on Epop[74]] -> cell 0, seg 0 (0.5) [0.5 on Epop[0]], weight: 4.1363508E-4, delay 1.5
        h("Epop[0] syn_projEE_ampa[5920] = new ampa(0.5)")
        h("Epop[74] netConn_projEE_ampa[5920] = new NetCon(&v(0.5), syn_projEE_ampa[5920], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5921: cell 74, seg 0 (0.5) [0.5 on Epop[74]] -> cell 1, seg 0 (0.5) [0.5 on Epop[1]], weight: 4.1363508E-4, delay 1.5
        h("Epop[1] syn_projEE_ampa[5921] = new ampa(0.5)")
        h("Epop[74] netConn_projEE_ampa[5921] = new NetCon(&v(0.5), syn_projEE_ampa[5921], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5922: cell 74, seg 0 (0.5) [0.5 on Epop[74]] -> cell 2, seg 0 (0.5) [0.5 on Epop[2]], weight: 4.1363508E-4, delay 1.5
        h("Epop[2] syn_projEE_ampa[5922] = new ampa(0.5)")
        h("Epop[74] netConn_projEE_ampa[5922] = new NetCon(&v(0.5), syn_projEE_ampa[5922], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5923: cell 74, seg 0 (0.5) [0.5 on Epop[74]] -> cell 3, seg 0 (0.5) [0.5 on Epop[3]], weight: 4.1363508E-4, delay 1.5
        h("Epop[3] syn_projEE_ampa[5923] = new ampa(0.5)")
        h("Epop[74] netConn_projEE_ampa[5923] = new NetCon(&v(0.5), syn_projEE_ampa[5923], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5924: cell 74, seg 0 (0.5) [0.5 on Epop[74]] -> cell 4, seg 0 (0.5) [0.5 on Epop[4]], weight: 4.1363508E-4, delay 1.5
        h("Epop[4] syn_projEE_ampa[5924] = new ampa(0.5)")
        h("Epop[74] netConn_projEE_ampa[5924] = new NetCon(&v(0.5), syn_projEE_ampa[5924], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5925: cell 74, seg 0 (0.5) [0.5 on Epop[74]] -> cell 5, seg 0 (0.5) [0.5 on Epop[5]], weight: 4.1363508E-4, delay 1.5
        h("Epop[5] syn_projEE_ampa[5925] = new ampa(0.5)")
        h("Epop[74] netConn_projEE_ampa[5925] = new NetCon(&v(0.5), syn_projEE_ampa[5925], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5926: cell 74, seg 0 (0.5) [0.5 on Epop[74]] -> cell 6, seg 0 (0.5) [0.5 on Epop[6]], weight: 4.1363508E-4, delay 1.5
        h("Epop[6] syn_projEE_ampa[5926] = new ampa(0.5)")
        h("Epop[74] netConn_projEE_ampa[5926] = new NetCon(&v(0.5), syn_projEE_ampa[5926], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5927: cell 74, seg 0 (0.5) [0.5 on Epop[74]] -> cell 7, seg 0 (0.5) [0.5 on Epop[7]], weight: 4.1363508E-4, delay 1.5
        h("Epop[7] syn_projEE_ampa[5927] = new ampa(0.5)")
        h("Epop[74] netConn_projEE_ampa[5927] = new NetCon(&v(0.5), syn_projEE_ampa[5927], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5928: cell 74, seg 0 (0.5) [0.5 on Epop[74]] -> cell 8, seg 0 (0.5) [0.5 on Epop[8]], weight: 4.1363508E-4, delay 1.5
        h("Epop[8] syn_projEE_ampa[5928] = new ampa(0.5)")
        h("Epop[74] netConn_projEE_ampa[5928] = new NetCon(&v(0.5), syn_projEE_ampa[5928], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5929: cell 74, seg 0 (0.5) [0.5 on Epop[74]] -> cell 9, seg 0 (0.5) [0.5 on Epop[9]], weight: 4.1363508E-4, delay 1.5
        h("Epop[9] syn_projEE_ampa[5929] = new ampa(0.5)")
        h("Epop[74] netConn_projEE_ampa[5929] = new NetCon(&v(0.5), syn_projEE_ampa[5929], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5930: cell 74, seg 0 (0.5) [0.5 on Epop[74]] -> cell 10, seg 0 (0.5) [0.5 on Epop[10]], weight: 4.1363508E-4, delay 1.5
        h("Epop[10] syn_projEE_ampa[5930] = new ampa(0.5)")
        h("Epop[74] netConn_projEE_ampa[5930] = new NetCon(&v(0.5), syn_projEE_ampa[5930], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5931: cell 74, seg 0 (0.5) [0.5 on Epop[74]] -> cell 11, seg 0 (0.5) [0.5 on Epop[11]], weight: 4.1363508E-4, delay 1.5
        h("Epop[11] syn_projEE_ampa[5931] = new ampa(0.5)")
        h("Epop[74] netConn_projEE_ampa[5931] = new NetCon(&v(0.5), syn_projEE_ampa[5931], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5932: cell 74, seg 0 (0.5) [0.5 on Epop[74]] -> cell 12, seg 0 (0.5) [0.5 on Epop[12]], weight: 4.1363508E-4, delay 1.5
        h("Epop[12] syn_projEE_ampa[5932] = new ampa(0.5)")
        h("Epop[74] netConn_projEE_ampa[5932] = new NetCon(&v(0.5), syn_projEE_ampa[5932], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5933: cell 74, seg 0 (0.5) [0.5 on Epop[74]] -> cell 13, seg 0 (0.5) [0.5 on Epop[13]], weight: 4.1363508E-4, delay 1.5
        h("Epop[13] syn_projEE_ampa[5933] = new ampa(0.5)")
        h("Epop[74] netConn_projEE_ampa[5933] = new NetCon(&v(0.5), syn_projEE_ampa[5933], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5934: cell 74, seg 0 (0.5) [0.5 on Epop[74]] -> cell 14, seg 0 (0.5) [0.5 on Epop[14]], weight: 4.1363508E-4, delay 1.5
        h("Epop[14] syn_projEE_ampa[5934] = new ampa(0.5)")
        h("Epop[74] netConn_projEE_ampa[5934] = new NetCon(&v(0.5), syn_projEE_ampa[5934], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5935: cell 74, seg 0 (0.5) [0.5 on Epop[74]] -> cell 15, seg 0 (0.5) [0.5 on Epop[15]], weight: 4.1363508E-4, delay 1.5
        h("Epop[15] syn_projEE_ampa[5935] = new ampa(0.5)")
        h("Epop[74] netConn_projEE_ampa[5935] = new NetCon(&v(0.5), syn_projEE_ampa[5935], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5936: cell 74, seg 0 (0.5) [0.5 on Epop[74]] -> cell 16, seg 0 (0.5) [0.5 on Epop[16]], weight: 4.1363508E-4, delay 1.5
        h("Epop[16] syn_projEE_ampa[5936] = new ampa(0.5)")
        h("Epop[74] netConn_projEE_ampa[5936] = new NetCon(&v(0.5), syn_projEE_ampa[5936], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5937: cell 74, seg 0 (0.5) [0.5 on Epop[74]] -> cell 17, seg 0 (0.5) [0.5 on Epop[17]], weight: 4.1363508E-4, delay 1.5
        h("Epop[17] syn_projEE_ampa[5937] = new ampa(0.5)")
        h("Epop[74] netConn_projEE_ampa[5937] = new NetCon(&v(0.5), syn_projEE_ampa[5937], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5938: cell 74, seg 0 (0.5) [0.5 on Epop[74]] -> cell 18, seg 0 (0.5) [0.5 on Epop[18]], weight: 4.1363508E-4, delay 1.5
        h("Epop[18] syn_projEE_ampa[5938] = new ampa(0.5)")
        h("Epop[74] netConn_projEE_ampa[5938] = new NetCon(&v(0.5), syn_projEE_ampa[5938], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5939: cell 74, seg 0 (0.5) [0.5 on Epop[74]] -> cell 19, seg 0 (0.5) [0.5 on Epop[19]], weight: 4.1363508E-4, delay 1.5
        h("Epop[19] syn_projEE_ampa[5939] = new ampa(0.5)")
        h("Epop[74] netConn_projEE_ampa[5939] = new NetCon(&v(0.5), syn_projEE_ampa[5939], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5940: cell 74, seg 0 (0.5) [0.5 on Epop[74]] -> cell 20, seg 0 (0.5) [0.5 on Epop[20]], weight: 4.1363508E-4, delay 1.5
        h("Epop[20] syn_projEE_ampa[5940] = new ampa(0.5)")
        h("Epop[74] netConn_projEE_ampa[5940] = new NetCon(&v(0.5), syn_projEE_ampa[5940], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5941: cell 74, seg 0 (0.5) [0.5 on Epop[74]] -> cell 21, seg 0 (0.5) [0.5 on Epop[21]], weight: 4.1363508E-4, delay 1.5
        h("Epop[21] syn_projEE_ampa[5941] = new ampa(0.5)")
        h("Epop[74] netConn_projEE_ampa[5941] = new NetCon(&v(0.5), syn_projEE_ampa[5941], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5942: cell 74, seg 0 (0.5) [0.5 on Epop[74]] -> cell 22, seg 0 (0.5) [0.5 on Epop[22]], weight: 4.1363508E-4, delay 1.5
        h("Epop[22] syn_projEE_ampa[5942] = new ampa(0.5)")
        h("Epop[74] netConn_projEE_ampa[5942] = new NetCon(&v(0.5), syn_projEE_ampa[5942], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5943: cell 74, seg 0 (0.5) [0.5 on Epop[74]] -> cell 23, seg 0 (0.5) [0.5 on Epop[23]], weight: 4.1363508E-4, delay 1.5
        h("Epop[23] syn_projEE_ampa[5943] = new ampa(0.5)")
        h("Epop[74] netConn_projEE_ampa[5943] = new NetCon(&v(0.5), syn_projEE_ampa[5943], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5944: cell 74, seg 0 (0.5) [0.5 on Epop[74]] -> cell 24, seg 0 (0.5) [0.5 on Epop[24]], weight: 4.1363508E-4, delay 1.5
        h("Epop[24] syn_projEE_ampa[5944] = new ampa(0.5)")
        h("Epop[74] netConn_projEE_ampa[5944] = new NetCon(&v(0.5), syn_projEE_ampa[5944], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5945: cell 74, seg 0 (0.5) [0.5 on Epop[74]] -> cell 25, seg 0 (0.5) [0.5 on Epop[25]], weight: 4.1363508E-4, delay 1.5
        h("Epop[25] syn_projEE_ampa[5945] = new ampa(0.5)")
        h("Epop[74] netConn_projEE_ampa[5945] = new NetCon(&v(0.5), syn_projEE_ampa[5945], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5946: cell 74, seg 0 (0.5) [0.5 on Epop[74]] -> cell 26, seg 0 (0.5) [0.5 on Epop[26]], weight: 4.1363508E-4, delay 1.5
        h("Epop[26] syn_projEE_ampa[5946] = new ampa(0.5)")
        h("Epop[74] netConn_projEE_ampa[5946] = new NetCon(&v(0.5), syn_projEE_ampa[5946], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5947: cell 74, seg 0 (0.5) [0.5 on Epop[74]] -> cell 27, seg 0 (0.5) [0.5 on Epop[27]], weight: 4.1363508E-4, delay 1.5
        h("Epop[27] syn_projEE_ampa[5947] = new ampa(0.5)")
        h("Epop[74] netConn_projEE_ampa[5947] = new NetCon(&v(0.5), syn_projEE_ampa[5947], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5948: cell 74, seg 0 (0.5) [0.5 on Epop[74]] -> cell 28, seg 0 (0.5) [0.5 on Epop[28]], weight: 4.1363508E-4, delay 1.5
        h("Epop[28] syn_projEE_ampa[5948] = new ampa(0.5)")
        h("Epop[74] netConn_projEE_ampa[5948] = new NetCon(&v(0.5), syn_projEE_ampa[5948], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5949: cell 74, seg 0 (0.5) [0.5 on Epop[74]] -> cell 29, seg 0 (0.5) [0.5 on Epop[29]], weight: 4.1363508E-4, delay 1.5
        h("Epop[29] syn_projEE_ampa[5949] = new ampa(0.5)")
        h("Epop[74] netConn_projEE_ampa[5949] = new NetCon(&v(0.5), syn_projEE_ampa[5949], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5950: cell 74, seg 0 (0.5) [0.5 on Epop[74]] -> cell 30, seg 0 (0.5) [0.5 on Epop[30]], weight: 4.1363508E-4, delay 1.5
        h("Epop[30] syn_projEE_ampa[5950] = new ampa(0.5)")
        h("Epop[74] netConn_projEE_ampa[5950] = new NetCon(&v(0.5), syn_projEE_ampa[5950], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5951: cell 74, seg 0 (0.5) [0.5 on Epop[74]] -> cell 31, seg 0 (0.5) [0.5 on Epop[31]], weight: 4.1363508E-4, delay 1.5
        h("Epop[31] syn_projEE_ampa[5951] = new ampa(0.5)")
        h("Epop[74] netConn_projEE_ampa[5951] = new NetCon(&v(0.5), syn_projEE_ampa[5951], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5952: cell 74, seg 0 (0.5) [0.5 on Epop[74]] -> cell 32, seg 0 (0.5) [0.5 on Epop[32]], weight: 4.1363508E-4, delay 1.5
        h("Epop[32] syn_projEE_ampa[5952] = new ampa(0.5)")
        h("Epop[74] netConn_projEE_ampa[5952] = new NetCon(&v(0.5), syn_projEE_ampa[5952], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5953: cell 74, seg 0 (0.5) [0.5 on Epop[74]] -> cell 33, seg 0 (0.5) [0.5 on Epop[33]], weight: 4.1363508E-4, delay 1.5
        h("Epop[33] syn_projEE_ampa[5953] = new ampa(0.5)")
        h("Epop[74] netConn_projEE_ampa[5953] = new NetCon(&v(0.5), syn_projEE_ampa[5953], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5954: cell 74, seg 0 (0.5) [0.5 on Epop[74]] -> cell 34, seg 0 (0.5) [0.5 on Epop[34]], weight: 4.1363508E-4, delay 1.5
        h("Epop[34] syn_projEE_ampa[5954] = new ampa(0.5)")
        h("Epop[74] netConn_projEE_ampa[5954] = new NetCon(&v(0.5), syn_projEE_ampa[5954], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5955: cell 74, seg 0 (0.5) [0.5 on Epop[74]] -> cell 35, seg 0 (0.5) [0.5 on Epop[35]], weight: 4.1363508E-4, delay 1.5
        h("Epop[35] syn_projEE_ampa[5955] = new ampa(0.5)")
        h("Epop[74] netConn_projEE_ampa[5955] = new NetCon(&v(0.5), syn_projEE_ampa[5955], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5956: cell 74, seg 0 (0.5) [0.5 on Epop[74]] -> cell 36, seg 0 (0.5) [0.5 on Epop[36]], weight: 4.1363508E-4, delay 1.5
        h("Epop[36] syn_projEE_ampa[5956] = new ampa(0.5)")
        h("Epop[74] netConn_projEE_ampa[5956] = new NetCon(&v(0.5), syn_projEE_ampa[5956], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5957: cell 74, seg 0 (0.5) [0.5 on Epop[74]] -> cell 37, seg 0 (0.5) [0.5 on Epop[37]], weight: 4.1363508E-4, delay 1.5
        h("Epop[37] syn_projEE_ampa[5957] = new ampa(0.5)")
        h("Epop[74] netConn_projEE_ampa[5957] = new NetCon(&v(0.5), syn_projEE_ampa[5957], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5958: cell 74, seg 0 (0.5) [0.5 on Epop[74]] -> cell 38, seg 0 (0.5) [0.5 on Epop[38]], weight: 4.1363508E-4, delay 1.5
        h("Epop[38] syn_projEE_ampa[5958] = new ampa(0.5)")
        h("Epop[74] netConn_projEE_ampa[5958] = new NetCon(&v(0.5), syn_projEE_ampa[5958], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5959: cell 74, seg 0 (0.5) [0.5 on Epop[74]] -> cell 39, seg 0 (0.5) [0.5 on Epop[39]], weight: 4.1363508E-4, delay 1.5
        h("Epop[39] syn_projEE_ampa[5959] = new ampa(0.5)")
        h("Epop[74] netConn_projEE_ampa[5959] = new NetCon(&v(0.5), syn_projEE_ampa[5959], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5960: cell 74, seg 0 (0.5) [0.5 on Epop[74]] -> cell 40, seg 0 (0.5) [0.5 on Epop[40]], weight: 4.1363508E-4, delay 1.5
        h("Epop[40] syn_projEE_ampa[5960] = new ampa(0.5)")
        h("Epop[74] netConn_projEE_ampa[5960] = new NetCon(&v(0.5), syn_projEE_ampa[5960], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5961: cell 74, seg 0 (0.5) [0.5 on Epop[74]] -> cell 41, seg 0 (0.5) [0.5 on Epop[41]], weight: 4.1363508E-4, delay 1.5
        h("Epop[41] syn_projEE_ampa[5961] = new ampa(0.5)")
        h("Epop[74] netConn_projEE_ampa[5961] = new NetCon(&v(0.5), syn_projEE_ampa[5961], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5962: cell 74, seg 0 (0.5) [0.5 on Epop[74]] -> cell 42, seg 0 (0.5) [0.5 on Epop[42]], weight: 4.1363508E-4, delay 1.5
        h("Epop[42] syn_projEE_ampa[5962] = new ampa(0.5)")
        h("Epop[74] netConn_projEE_ampa[5962] = new NetCon(&v(0.5), syn_projEE_ampa[5962], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5963: cell 74, seg 0 (0.5) [0.5 on Epop[74]] -> cell 43, seg 0 (0.5) [0.5 on Epop[43]], weight: 4.1363508E-4, delay 1.5
        h("Epop[43] syn_projEE_ampa[5963] = new ampa(0.5)")
        h("Epop[74] netConn_projEE_ampa[5963] = new NetCon(&v(0.5), syn_projEE_ampa[5963], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5964: cell 74, seg 0 (0.5) [0.5 on Epop[74]] -> cell 44, seg 0 (0.5) [0.5 on Epop[44]], weight: 4.1363508E-4, delay 1.5
        h("Epop[44] syn_projEE_ampa[5964] = new ampa(0.5)")
        h("Epop[74] netConn_projEE_ampa[5964] = new NetCon(&v(0.5), syn_projEE_ampa[5964], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5965: cell 74, seg 0 (0.5) [0.5 on Epop[74]] -> cell 45, seg 0 (0.5) [0.5 on Epop[45]], weight: 4.1363508E-4, delay 1.5
        h("Epop[45] syn_projEE_ampa[5965] = new ampa(0.5)")
        h("Epop[74] netConn_projEE_ampa[5965] = new NetCon(&v(0.5), syn_projEE_ampa[5965], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5966: cell 74, seg 0 (0.5) [0.5 on Epop[74]] -> cell 46, seg 0 (0.5) [0.5 on Epop[46]], weight: 4.1363508E-4, delay 1.5
        h("Epop[46] syn_projEE_ampa[5966] = new ampa(0.5)")
        h("Epop[74] netConn_projEE_ampa[5966] = new NetCon(&v(0.5), syn_projEE_ampa[5966], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5967: cell 74, seg 0 (0.5) [0.5 on Epop[74]] -> cell 47, seg 0 (0.5) [0.5 on Epop[47]], weight: 4.1363508E-4, delay 1.5
        h("Epop[47] syn_projEE_ampa[5967] = new ampa(0.5)")
        h("Epop[74] netConn_projEE_ampa[5967] = new NetCon(&v(0.5), syn_projEE_ampa[5967], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5968: cell 74, seg 0 (0.5) [0.5 on Epop[74]] -> cell 48, seg 0 (0.5) [0.5 on Epop[48]], weight: 4.1363508E-4, delay 1.5
        h("Epop[48] syn_projEE_ampa[5968] = new ampa(0.5)")
        h("Epop[74] netConn_projEE_ampa[5968] = new NetCon(&v(0.5), syn_projEE_ampa[5968], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5969: cell 74, seg 0 (0.5) [0.5 on Epop[74]] -> cell 49, seg 0 (0.5) [0.5 on Epop[49]], weight: 4.1363508E-4, delay 1.5
        h("Epop[49] syn_projEE_ampa[5969] = new ampa(0.5)")
        h("Epop[74] netConn_projEE_ampa[5969] = new NetCon(&v(0.5), syn_projEE_ampa[5969], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5970: cell 74, seg 0 (0.5) [0.5 on Epop[74]] -> cell 50, seg 0 (0.5) [0.5 on Epop[50]], weight: 4.1363508E-4, delay 1.5
        h("Epop[50] syn_projEE_ampa[5970] = new ampa(0.5)")
        h("Epop[74] netConn_projEE_ampa[5970] = new NetCon(&v(0.5), syn_projEE_ampa[5970], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5971: cell 74, seg 0 (0.5) [0.5 on Epop[74]] -> cell 51, seg 0 (0.5) [0.5 on Epop[51]], weight: 4.1363508E-4, delay 1.5
        h("Epop[51] syn_projEE_ampa[5971] = new ampa(0.5)")
        h("Epop[74] netConn_projEE_ampa[5971] = new NetCon(&v(0.5), syn_projEE_ampa[5971], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5972: cell 74, seg 0 (0.5) [0.5 on Epop[74]] -> cell 52, seg 0 (0.5) [0.5 on Epop[52]], weight: 4.1363508E-4, delay 1.5
        h("Epop[52] syn_projEE_ampa[5972] = new ampa(0.5)")
        h("Epop[74] netConn_projEE_ampa[5972] = new NetCon(&v(0.5), syn_projEE_ampa[5972], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5973: cell 74, seg 0 (0.5) [0.5 on Epop[74]] -> cell 53, seg 0 (0.5) [0.5 on Epop[53]], weight: 4.1363508E-4, delay 1.5
        h("Epop[53] syn_projEE_ampa[5973] = new ampa(0.5)")
        h("Epop[74] netConn_projEE_ampa[5973] = new NetCon(&v(0.5), syn_projEE_ampa[5973], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5974: cell 74, seg 0 (0.5) [0.5 on Epop[74]] -> cell 54, seg 0 (0.5) [0.5 on Epop[54]], weight: 4.1363508E-4, delay 1.5
        h("Epop[54] syn_projEE_ampa[5974] = new ampa(0.5)")
        h("Epop[74] netConn_projEE_ampa[5974] = new NetCon(&v(0.5), syn_projEE_ampa[5974], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5975: cell 74, seg 0 (0.5) [0.5 on Epop[74]] -> cell 55, seg 0 (0.5) [0.5 on Epop[55]], weight: 4.1363508E-4, delay 1.5
        h("Epop[55] syn_projEE_ampa[5975] = new ampa(0.5)")
        h("Epop[74] netConn_projEE_ampa[5975] = new NetCon(&v(0.5), syn_projEE_ampa[5975], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5976: cell 74, seg 0 (0.5) [0.5 on Epop[74]] -> cell 56, seg 0 (0.5) [0.5 on Epop[56]], weight: 4.1363508E-4, delay 1.5
        h("Epop[56] syn_projEE_ampa[5976] = new ampa(0.5)")
        h("Epop[74] netConn_projEE_ampa[5976] = new NetCon(&v(0.5), syn_projEE_ampa[5976], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5977: cell 74, seg 0 (0.5) [0.5 on Epop[74]] -> cell 57, seg 0 (0.5) [0.5 on Epop[57]], weight: 4.1363508E-4, delay 1.5
        h("Epop[57] syn_projEE_ampa[5977] = new ampa(0.5)")
        h("Epop[74] netConn_projEE_ampa[5977] = new NetCon(&v(0.5), syn_projEE_ampa[5977], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5978: cell 74, seg 0 (0.5) [0.5 on Epop[74]] -> cell 58, seg 0 (0.5) [0.5 on Epop[58]], weight: 4.1363508E-4, delay 1.5
        h("Epop[58] syn_projEE_ampa[5978] = new ampa(0.5)")
        h("Epop[74] netConn_projEE_ampa[5978] = new NetCon(&v(0.5), syn_projEE_ampa[5978], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5979: cell 74, seg 0 (0.5) [0.5 on Epop[74]] -> cell 59, seg 0 (0.5) [0.5 on Epop[59]], weight: 4.1363508E-4, delay 1.5
        h("Epop[59] syn_projEE_ampa[5979] = new ampa(0.5)")
        h("Epop[74] netConn_projEE_ampa[5979] = new NetCon(&v(0.5), syn_projEE_ampa[5979], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5980: cell 74, seg 0 (0.5) [0.5 on Epop[74]] -> cell 60, seg 0 (0.5) [0.5 on Epop[60]], weight: 4.1363508E-4, delay 1.5
        h("Epop[60] syn_projEE_ampa[5980] = new ampa(0.5)")
        h("Epop[74] netConn_projEE_ampa[5980] = new NetCon(&v(0.5), syn_projEE_ampa[5980], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5981: cell 74, seg 0 (0.5) [0.5 on Epop[74]] -> cell 61, seg 0 (0.5) [0.5 on Epop[61]], weight: 4.1363508E-4, delay 1.5
        h("Epop[61] syn_projEE_ampa[5981] = new ampa(0.5)")
        h("Epop[74] netConn_projEE_ampa[5981] = new NetCon(&v(0.5), syn_projEE_ampa[5981], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5982: cell 74, seg 0 (0.5) [0.5 on Epop[74]] -> cell 62, seg 0 (0.5) [0.5 on Epop[62]], weight: 4.1363508E-4, delay 1.5
        h("Epop[62] syn_projEE_ampa[5982] = new ampa(0.5)")
        h("Epop[74] netConn_projEE_ampa[5982] = new NetCon(&v(0.5), syn_projEE_ampa[5982], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5983: cell 74, seg 0 (0.5) [0.5 on Epop[74]] -> cell 63, seg 0 (0.5) [0.5 on Epop[63]], weight: 4.1363508E-4, delay 1.5
        h("Epop[63] syn_projEE_ampa[5983] = new ampa(0.5)")
        h("Epop[74] netConn_projEE_ampa[5983] = new NetCon(&v(0.5), syn_projEE_ampa[5983], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5984: cell 74, seg 0 (0.5) [0.5 on Epop[74]] -> cell 64, seg 0 (0.5) [0.5 on Epop[64]], weight: 4.1363508E-4, delay 1.5
        h("Epop[64] syn_projEE_ampa[5984] = new ampa(0.5)")
        h("Epop[74] netConn_projEE_ampa[5984] = new NetCon(&v(0.5), syn_projEE_ampa[5984], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5985: cell 74, seg 0 (0.5) [0.5 on Epop[74]] -> cell 65, seg 0 (0.5) [0.5 on Epop[65]], weight: 4.1363508E-4, delay 1.5
        h("Epop[65] syn_projEE_ampa[5985] = new ampa(0.5)")
        h("Epop[74] netConn_projEE_ampa[5985] = new NetCon(&v(0.5), syn_projEE_ampa[5985], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5986: cell 74, seg 0 (0.5) [0.5 on Epop[74]] -> cell 66, seg 0 (0.5) [0.5 on Epop[66]], weight: 4.1363508E-4, delay 1.5
        h("Epop[66] syn_projEE_ampa[5986] = new ampa(0.5)")
        h("Epop[74] netConn_projEE_ampa[5986] = new NetCon(&v(0.5), syn_projEE_ampa[5986], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5987: cell 74, seg 0 (0.5) [0.5 on Epop[74]] -> cell 67, seg 0 (0.5) [0.5 on Epop[67]], weight: 4.1363508E-4, delay 1.5
        h("Epop[67] syn_projEE_ampa[5987] = new ampa(0.5)")
        h("Epop[74] netConn_projEE_ampa[5987] = new NetCon(&v(0.5), syn_projEE_ampa[5987], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5988: cell 74, seg 0 (0.5) [0.5 on Epop[74]] -> cell 68, seg 0 (0.5) [0.5 on Epop[68]], weight: 4.1363508E-4, delay 1.5
        h("Epop[68] syn_projEE_ampa[5988] = new ampa(0.5)")
        h("Epop[74] netConn_projEE_ampa[5988] = new NetCon(&v(0.5), syn_projEE_ampa[5988], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5989: cell 74, seg 0 (0.5) [0.5 on Epop[74]] -> cell 69, seg 0 (0.5) [0.5 on Epop[69]], weight: 4.1363508E-4, delay 1.5
        h("Epop[69] syn_projEE_ampa[5989] = new ampa(0.5)")
        h("Epop[74] netConn_projEE_ampa[5989] = new NetCon(&v(0.5), syn_projEE_ampa[5989], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5990: cell 74, seg 0 (0.5) [0.5 on Epop[74]] -> cell 70, seg 0 (0.5) [0.5 on Epop[70]], weight: 4.1363508E-4, delay 1.5
        h("Epop[70] syn_projEE_ampa[5990] = new ampa(0.5)")
        h("Epop[74] netConn_projEE_ampa[5990] = new NetCon(&v(0.5), syn_projEE_ampa[5990], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5991: cell 74, seg 0 (0.5) [0.5 on Epop[74]] -> cell 71, seg 0 (0.5) [0.5 on Epop[71]], weight: 4.1363508E-4, delay 1.5
        h("Epop[71] syn_projEE_ampa[5991] = new ampa(0.5)")
        h("Epop[74] netConn_projEE_ampa[5991] = new NetCon(&v(0.5), syn_projEE_ampa[5991], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5992: cell 74, seg 0 (0.5) [0.5 on Epop[74]] -> cell 72, seg 0 (0.5) [0.5 on Epop[72]], weight: 4.1363508E-4, delay 1.5
        h("Epop[72] syn_projEE_ampa[5992] = new ampa(0.5)")
        h("Epop[74] netConn_projEE_ampa[5992] = new NetCon(&v(0.5), syn_projEE_ampa[5992], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5993: cell 74, seg 0 (0.5) [0.5 on Epop[74]] -> cell 73, seg 0 (0.5) [0.5 on Epop[73]], weight: 4.1363508E-4, delay 1.5
        h("Epop[73] syn_projEE_ampa[5993] = new ampa(0.5)")
        h("Epop[74] netConn_projEE_ampa[5993] = new NetCon(&v(0.5), syn_projEE_ampa[5993], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5994: cell 74, seg 0 (0.5) [0.5 on Epop[74]] -> cell 74, seg 0 (0.5) [0.5 on Epop[74]], weight: 4.1363508E-4, delay 1.5
        h("Epop[74] syn_projEE_ampa[5994] = new ampa(0.5)")
        h("Epop[74] netConn_projEE_ampa[5994] = new NetCon(&v(0.5), syn_projEE_ampa[5994], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5995: cell 74, seg 0 (0.5) [0.5 on Epop[74]] -> cell 75, seg 0 (0.5) [0.5 on Epop[75]], weight: 4.1363508E-4, delay 1.5
        h("Epop[75] syn_projEE_ampa[5995] = new ampa(0.5)")
        h("Epop[74] netConn_projEE_ampa[5995] = new NetCon(&v(0.5), syn_projEE_ampa[5995], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5996: cell 74, seg 0 (0.5) [0.5 on Epop[74]] -> cell 76, seg 0 (0.5) [0.5 on Epop[76]], weight: 4.1363508E-4, delay 1.5
        h("Epop[76] syn_projEE_ampa[5996] = new ampa(0.5)")
        h("Epop[74] netConn_projEE_ampa[5996] = new NetCon(&v(0.5), syn_projEE_ampa[5996], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5997: cell 74, seg 0 (0.5) [0.5 on Epop[74]] -> cell 77, seg 0 (0.5) [0.5 on Epop[77]], weight: 4.1363508E-4, delay 1.5
        h("Epop[77] syn_projEE_ampa[5997] = new ampa(0.5)")
        h("Epop[74] netConn_projEE_ampa[5997] = new NetCon(&v(0.5), syn_projEE_ampa[5997], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5998: cell 74, seg 0 (0.5) [0.5 on Epop[74]] -> cell 78, seg 0 (0.5) [0.5 on Epop[78]], weight: 4.1363508E-4, delay 1.5
        h("Epop[78] syn_projEE_ampa[5998] = new ampa(0.5)")
        h("Epop[74] netConn_projEE_ampa[5998] = new NetCon(&v(0.5), syn_projEE_ampa[5998], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5999: cell 74, seg 0 (0.5) [0.5 on Epop[74]] -> cell 79, seg 0 (0.5) [0.5 on Epop[79]], weight: 4.1363508E-4, delay 1.5
        h("Epop[79] syn_projEE_ampa[5999] = new ampa(0.5)")
        h("Epop[74] netConn_projEE_ampa[5999] = new NetCon(&v(0.5), syn_projEE_ampa[5999], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6000: cell 75, seg 0 (0.5) [0.5 on Epop[75]] -> cell 0, seg 0 (0.5) [0.5 on Epop[0]], weight: 4.1363508E-4, delay 1.5
        h("Epop[0] syn_projEE_ampa[6000] = new ampa(0.5)")
        h("Epop[75] netConn_projEE_ampa[6000] = new NetCon(&v(0.5), syn_projEE_ampa[6000], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6001: cell 75, seg 0 (0.5) [0.5 on Epop[75]] -> cell 1, seg 0 (0.5) [0.5 on Epop[1]], weight: 4.1363508E-4, delay 1.5
        h("Epop[1] syn_projEE_ampa[6001] = new ampa(0.5)")
        h("Epop[75] netConn_projEE_ampa[6001] = new NetCon(&v(0.5), syn_projEE_ampa[6001], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6002: cell 75, seg 0 (0.5) [0.5 on Epop[75]] -> cell 2, seg 0 (0.5) [0.5 on Epop[2]], weight: 4.1363508E-4, delay 1.5
        h("Epop[2] syn_projEE_ampa[6002] = new ampa(0.5)")
        h("Epop[75] netConn_projEE_ampa[6002] = new NetCon(&v(0.5), syn_projEE_ampa[6002], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6003: cell 75, seg 0 (0.5) [0.5 on Epop[75]] -> cell 3, seg 0 (0.5) [0.5 on Epop[3]], weight: 4.1363508E-4, delay 1.5
        h("Epop[3] syn_projEE_ampa[6003] = new ampa(0.5)")
        h("Epop[75] netConn_projEE_ampa[6003] = new NetCon(&v(0.5), syn_projEE_ampa[6003], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6004: cell 75, seg 0 (0.5) [0.5 on Epop[75]] -> cell 4, seg 0 (0.5) [0.5 on Epop[4]], weight: 4.1363508E-4, delay 1.5
        h("Epop[4] syn_projEE_ampa[6004] = new ampa(0.5)")
        h("Epop[75] netConn_projEE_ampa[6004] = new NetCon(&v(0.5), syn_projEE_ampa[6004], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6005: cell 75, seg 0 (0.5) [0.5 on Epop[75]] -> cell 5, seg 0 (0.5) [0.5 on Epop[5]], weight: 4.1363508E-4, delay 1.5
        h("Epop[5] syn_projEE_ampa[6005] = new ampa(0.5)")
        h("Epop[75] netConn_projEE_ampa[6005] = new NetCon(&v(0.5), syn_projEE_ampa[6005], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6006: cell 75, seg 0 (0.5) [0.5 on Epop[75]] -> cell 6, seg 0 (0.5) [0.5 on Epop[6]], weight: 4.1363508E-4, delay 1.5
        h("Epop[6] syn_projEE_ampa[6006] = new ampa(0.5)")
        h("Epop[75] netConn_projEE_ampa[6006] = new NetCon(&v(0.5), syn_projEE_ampa[6006], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6007: cell 75, seg 0 (0.5) [0.5 on Epop[75]] -> cell 7, seg 0 (0.5) [0.5 on Epop[7]], weight: 4.1363508E-4, delay 1.5
        h("Epop[7] syn_projEE_ampa[6007] = new ampa(0.5)")
        h("Epop[75] netConn_projEE_ampa[6007] = new NetCon(&v(0.5), syn_projEE_ampa[6007], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6008: cell 75, seg 0 (0.5) [0.5 on Epop[75]] -> cell 8, seg 0 (0.5) [0.5 on Epop[8]], weight: 4.1363508E-4, delay 1.5
        h("Epop[8] syn_projEE_ampa[6008] = new ampa(0.5)")
        h("Epop[75] netConn_projEE_ampa[6008] = new NetCon(&v(0.5), syn_projEE_ampa[6008], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6009: cell 75, seg 0 (0.5) [0.5 on Epop[75]] -> cell 9, seg 0 (0.5) [0.5 on Epop[9]], weight: 4.1363508E-4, delay 1.5
        h("Epop[9] syn_projEE_ampa[6009] = new ampa(0.5)")
        h("Epop[75] netConn_projEE_ampa[6009] = new NetCon(&v(0.5), syn_projEE_ampa[6009], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6010: cell 75, seg 0 (0.5) [0.5 on Epop[75]] -> cell 10, seg 0 (0.5) [0.5 on Epop[10]], weight: 4.1363508E-4, delay 1.5
        h("Epop[10] syn_projEE_ampa[6010] = new ampa(0.5)")
        h("Epop[75] netConn_projEE_ampa[6010] = new NetCon(&v(0.5), syn_projEE_ampa[6010], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6011: cell 75, seg 0 (0.5) [0.5 on Epop[75]] -> cell 11, seg 0 (0.5) [0.5 on Epop[11]], weight: 4.1363508E-4, delay 1.5
        h("Epop[11] syn_projEE_ampa[6011] = new ampa(0.5)")
        h("Epop[75] netConn_projEE_ampa[6011] = new NetCon(&v(0.5), syn_projEE_ampa[6011], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6012: cell 75, seg 0 (0.5) [0.5 on Epop[75]] -> cell 12, seg 0 (0.5) [0.5 on Epop[12]], weight: 4.1363508E-4, delay 1.5
        h("Epop[12] syn_projEE_ampa[6012] = new ampa(0.5)")
        h("Epop[75] netConn_projEE_ampa[6012] = new NetCon(&v(0.5), syn_projEE_ampa[6012], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6013: cell 75, seg 0 (0.5) [0.5 on Epop[75]] -> cell 13, seg 0 (0.5) [0.5 on Epop[13]], weight: 4.1363508E-4, delay 1.5
        h("Epop[13] syn_projEE_ampa[6013] = new ampa(0.5)")
        h("Epop[75] netConn_projEE_ampa[6013] = new NetCon(&v(0.5), syn_projEE_ampa[6013], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6014: cell 75, seg 0 (0.5) [0.5 on Epop[75]] -> cell 14, seg 0 (0.5) [0.5 on Epop[14]], weight: 4.1363508E-4, delay 1.5
        h("Epop[14] syn_projEE_ampa[6014] = new ampa(0.5)")
        h("Epop[75] netConn_projEE_ampa[6014] = new NetCon(&v(0.5), syn_projEE_ampa[6014], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6015: cell 75, seg 0 (0.5) [0.5 on Epop[75]] -> cell 15, seg 0 (0.5) [0.5 on Epop[15]], weight: 4.1363508E-4, delay 1.5
        h("Epop[15] syn_projEE_ampa[6015] = new ampa(0.5)")
        h("Epop[75] netConn_projEE_ampa[6015] = new NetCon(&v(0.5), syn_projEE_ampa[6015], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6016: cell 75, seg 0 (0.5) [0.5 on Epop[75]] -> cell 16, seg 0 (0.5) [0.5 on Epop[16]], weight: 4.1363508E-4, delay 1.5
        h("Epop[16] syn_projEE_ampa[6016] = new ampa(0.5)")
        h("Epop[75] netConn_projEE_ampa[6016] = new NetCon(&v(0.5), syn_projEE_ampa[6016], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6017: cell 75, seg 0 (0.5) [0.5 on Epop[75]] -> cell 17, seg 0 (0.5) [0.5 on Epop[17]], weight: 4.1363508E-4, delay 1.5
        h("Epop[17] syn_projEE_ampa[6017] = new ampa(0.5)")
        h("Epop[75] netConn_projEE_ampa[6017] = new NetCon(&v(0.5), syn_projEE_ampa[6017], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6018: cell 75, seg 0 (0.5) [0.5 on Epop[75]] -> cell 18, seg 0 (0.5) [0.5 on Epop[18]], weight: 4.1363508E-4, delay 1.5
        h("Epop[18] syn_projEE_ampa[6018] = new ampa(0.5)")
        h("Epop[75] netConn_projEE_ampa[6018] = new NetCon(&v(0.5), syn_projEE_ampa[6018], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6019: cell 75, seg 0 (0.5) [0.5 on Epop[75]] -> cell 19, seg 0 (0.5) [0.5 on Epop[19]], weight: 4.1363508E-4, delay 1.5
        h("Epop[19] syn_projEE_ampa[6019] = new ampa(0.5)")
        h("Epop[75] netConn_projEE_ampa[6019] = new NetCon(&v(0.5), syn_projEE_ampa[6019], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6020: cell 75, seg 0 (0.5) [0.5 on Epop[75]] -> cell 20, seg 0 (0.5) [0.5 on Epop[20]], weight: 4.1363508E-4, delay 1.5
        h("Epop[20] syn_projEE_ampa[6020] = new ampa(0.5)")
        h("Epop[75] netConn_projEE_ampa[6020] = new NetCon(&v(0.5), syn_projEE_ampa[6020], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6021: cell 75, seg 0 (0.5) [0.5 on Epop[75]] -> cell 21, seg 0 (0.5) [0.5 on Epop[21]], weight: 4.1363508E-4, delay 1.5
        h("Epop[21] syn_projEE_ampa[6021] = new ampa(0.5)")
        h("Epop[75] netConn_projEE_ampa[6021] = new NetCon(&v(0.5), syn_projEE_ampa[6021], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6022: cell 75, seg 0 (0.5) [0.5 on Epop[75]] -> cell 22, seg 0 (0.5) [0.5 on Epop[22]], weight: 4.1363508E-4, delay 1.5
        h("Epop[22] syn_projEE_ampa[6022] = new ampa(0.5)")
        h("Epop[75] netConn_projEE_ampa[6022] = new NetCon(&v(0.5), syn_projEE_ampa[6022], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6023: cell 75, seg 0 (0.5) [0.5 on Epop[75]] -> cell 23, seg 0 (0.5) [0.5 on Epop[23]], weight: 4.1363508E-4, delay 1.5
        h("Epop[23] syn_projEE_ampa[6023] = new ampa(0.5)")
        h("Epop[75] netConn_projEE_ampa[6023] = new NetCon(&v(0.5), syn_projEE_ampa[6023], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6024: cell 75, seg 0 (0.5) [0.5 on Epop[75]] -> cell 24, seg 0 (0.5) [0.5 on Epop[24]], weight: 4.1363508E-4, delay 1.5
        h("Epop[24] syn_projEE_ampa[6024] = new ampa(0.5)")
        h("Epop[75] netConn_projEE_ampa[6024] = new NetCon(&v(0.5), syn_projEE_ampa[6024], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6025: cell 75, seg 0 (0.5) [0.5 on Epop[75]] -> cell 25, seg 0 (0.5) [0.5 on Epop[25]], weight: 4.1363508E-4, delay 1.5
        h("Epop[25] syn_projEE_ampa[6025] = new ampa(0.5)")
        h("Epop[75] netConn_projEE_ampa[6025] = new NetCon(&v(0.5), syn_projEE_ampa[6025], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6026: cell 75, seg 0 (0.5) [0.5 on Epop[75]] -> cell 26, seg 0 (0.5) [0.5 on Epop[26]], weight: 4.1363508E-4, delay 1.5
        h("Epop[26] syn_projEE_ampa[6026] = new ampa(0.5)")
        h("Epop[75] netConn_projEE_ampa[6026] = new NetCon(&v(0.5), syn_projEE_ampa[6026], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6027: cell 75, seg 0 (0.5) [0.5 on Epop[75]] -> cell 27, seg 0 (0.5) [0.5 on Epop[27]], weight: 4.1363508E-4, delay 1.5
        h("Epop[27] syn_projEE_ampa[6027] = new ampa(0.5)")
        h("Epop[75] netConn_projEE_ampa[6027] = new NetCon(&v(0.5), syn_projEE_ampa[6027], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6028: cell 75, seg 0 (0.5) [0.5 on Epop[75]] -> cell 28, seg 0 (0.5) [0.5 on Epop[28]], weight: 4.1363508E-4, delay 1.5
        h("Epop[28] syn_projEE_ampa[6028] = new ampa(0.5)")
        h("Epop[75] netConn_projEE_ampa[6028] = new NetCon(&v(0.5), syn_projEE_ampa[6028], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6029: cell 75, seg 0 (0.5) [0.5 on Epop[75]] -> cell 29, seg 0 (0.5) [0.5 on Epop[29]], weight: 4.1363508E-4, delay 1.5
        h("Epop[29] syn_projEE_ampa[6029] = new ampa(0.5)")
        h("Epop[75] netConn_projEE_ampa[6029] = new NetCon(&v(0.5), syn_projEE_ampa[6029], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6030: cell 75, seg 0 (0.5) [0.5 on Epop[75]] -> cell 30, seg 0 (0.5) [0.5 on Epop[30]], weight: 4.1363508E-4, delay 1.5
        h("Epop[30] syn_projEE_ampa[6030] = new ampa(0.5)")
        h("Epop[75] netConn_projEE_ampa[6030] = new NetCon(&v(0.5), syn_projEE_ampa[6030], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6031: cell 75, seg 0 (0.5) [0.5 on Epop[75]] -> cell 31, seg 0 (0.5) [0.5 on Epop[31]], weight: 4.1363508E-4, delay 1.5
        h("Epop[31] syn_projEE_ampa[6031] = new ampa(0.5)")
        h("Epop[75] netConn_projEE_ampa[6031] = new NetCon(&v(0.5), syn_projEE_ampa[6031], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6032: cell 75, seg 0 (0.5) [0.5 on Epop[75]] -> cell 32, seg 0 (0.5) [0.5 on Epop[32]], weight: 4.1363508E-4, delay 1.5
        h("Epop[32] syn_projEE_ampa[6032] = new ampa(0.5)")
        h("Epop[75] netConn_projEE_ampa[6032] = new NetCon(&v(0.5), syn_projEE_ampa[6032], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6033: cell 75, seg 0 (0.5) [0.5 on Epop[75]] -> cell 33, seg 0 (0.5) [0.5 on Epop[33]], weight: 4.1363508E-4, delay 1.5
        h("Epop[33] syn_projEE_ampa[6033] = new ampa(0.5)")
        h("Epop[75] netConn_projEE_ampa[6033] = new NetCon(&v(0.5), syn_projEE_ampa[6033], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6034: cell 75, seg 0 (0.5) [0.5 on Epop[75]] -> cell 34, seg 0 (0.5) [0.5 on Epop[34]], weight: 4.1363508E-4, delay 1.5
        h("Epop[34] syn_projEE_ampa[6034] = new ampa(0.5)")
        h("Epop[75] netConn_projEE_ampa[6034] = new NetCon(&v(0.5), syn_projEE_ampa[6034], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6035: cell 75, seg 0 (0.5) [0.5 on Epop[75]] -> cell 35, seg 0 (0.5) [0.5 on Epop[35]], weight: 4.1363508E-4, delay 1.5
        h("Epop[35] syn_projEE_ampa[6035] = new ampa(0.5)")
        h("Epop[75] netConn_projEE_ampa[6035] = new NetCon(&v(0.5), syn_projEE_ampa[6035], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6036: cell 75, seg 0 (0.5) [0.5 on Epop[75]] -> cell 36, seg 0 (0.5) [0.5 on Epop[36]], weight: 4.1363508E-4, delay 1.5
        h("Epop[36] syn_projEE_ampa[6036] = new ampa(0.5)")
        h("Epop[75] netConn_projEE_ampa[6036] = new NetCon(&v(0.5), syn_projEE_ampa[6036], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6037: cell 75, seg 0 (0.5) [0.5 on Epop[75]] -> cell 37, seg 0 (0.5) [0.5 on Epop[37]], weight: 4.1363508E-4, delay 1.5
        h("Epop[37] syn_projEE_ampa[6037] = new ampa(0.5)")
        h("Epop[75] netConn_projEE_ampa[6037] = new NetCon(&v(0.5), syn_projEE_ampa[6037], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6038: cell 75, seg 0 (0.5) [0.5 on Epop[75]] -> cell 38, seg 0 (0.5) [0.5 on Epop[38]], weight: 4.1363508E-4, delay 1.5
        h("Epop[38] syn_projEE_ampa[6038] = new ampa(0.5)")
        h("Epop[75] netConn_projEE_ampa[6038] = new NetCon(&v(0.5), syn_projEE_ampa[6038], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6039: cell 75, seg 0 (0.5) [0.5 on Epop[75]] -> cell 39, seg 0 (0.5) [0.5 on Epop[39]], weight: 4.1363508E-4, delay 1.5
        h("Epop[39] syn_projEE_ampa[6039] = new ampa(0.5)")
        h("Epop[75] netConn_projEE_ampa[6039] = new NetCon(&v(0.5), syn_projEE_ampa[6039], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6040: cell 75, seg 0 (0.5) [0.5 on Epop[75]] -> cell 40, seg 0 (0.5) [0.5 on Epop[40]], weight: 4.1363508E-4, delay 1.5
        h("Epop[40] syn_projEE_ampa[6040] = new ampa(0.5)")
        h("Epop[75] netConn_projEE_ampa[6040] = new NetCon(&v(0.5), syn_projEE_ampa[6040], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6041: cell 75, seg 0 (0.5) [0.5 on Epop[75]] -> cell 41, seg 0 (0.5) [0.5 on Epop[41]], weight: 4.1363508E-4, delay 1.5
        h("Epop[41] syn_projEE_ampa[6041] = new ampa(0.5)")
        h("Epop[75] netConn_projEE_ampa[6041] = new NetCon(&v(0.5), syn_projEE_ampa[6041], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6042: cell 75, seg 0 (0.5) [0.5 on Epop[75]] -> cell 42, seg 0 (0.5) [0.5 on Epop[42]], weight: 4.1363508E-4, delay 1.5
        h("Epop[42] syn_projEE_ampa[6042] = new ampa(0.5)")
        h("Epop[75] netConn_projEE_ampa[6042] = new NetCon(&v(0.5), syn_projEE_ampa[6042], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6043: cell 75, seg 0 (0.5) [0.5 on Epop[75]] -> cell 43, seg 0 (0.5) [0.5 on Epop[43]], weight: 4.1363508E-4, delay 1.5
        h("Epop[43] syn_projEE_ampa[6043] = new ampa(0.5)")
        h("Epop[75] netConn_projEE_ampa[6043] = new NetCon(&v(0.5), syn_projEE_ampa[6043], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6044: cell 75, seg 0 (0.5) [0.5 on Epop[75]] -> cell 44, seg 0 (0.5) [0.5 on Epop[44]], weight: 4.1363508E-4, delay 1.5
        h("Epop[44] syn_projEE_ampa[6044] = new ampa(0.5)")
        h("Epop[75] netConn_projEE_ampa[6044] = new NetCon(&v(0.5), syn_projEE_ampa[6044], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6045: cell 75, seg 0 (0.5) [0.5 on Epop[75]] -> cell 45, seg 0 (0.5) [0.5 on Epop[45]], weight: 4.1363508E-4, delay 1.5
        h("Epop[45] syn_projEE_ampa[6045] = new ampa(0.5)")
        h("Epop[75] netConn_projEE_ampa[6045] = new NetCon(&v(0.5), syn_projEE_ampa[6045], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6046: cell 75, seg 0 (0.5) [0.5 on Epop[75]] -> cell 46, seg 0 (0.5) [0.5 on Epop[46]], weight: 4.1363508E-4, delay 1.5
        h("Epop[46] syn_projEE_ampa[6046] = new ampa(0.5)")
        h("Epop[75] netConn_projEE_ampa[6046] = new NetCon(&v(0.5), syn_projEE_ampa[6046], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6047: cell 75, seg 0 (0.5) [0.5 on Epop[75]] -> cell 47, seg 0 (0.5) [0.5 on Epop[47]], weight: 4.1363508E-4, delay 1.5
        h("Epop[47] syn_projEE_ampa[6047] = new ampa(0.5)")
        h("Epop[75] netConn_projEE_ampa[6047] = new NetCon(&v(0.5), syn_projEE_ampa[6047], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6048: cell 75, seg 0 (0.5) [0.5 on Epop[75]] -> cell 48, seg 0 (0.5) [0.5 on Epop[48]], weight: 4.1363508E-4, delay 1.5
        h("Epop[48] syn_projEE_ampa[6048] = new ampa(0.5)")
        h("Epop[75] netConn_projEE_ampa[6048] = new NetCon(&v(0.5), syn_projEE_ampa[6048], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6049: cell 75, seg 0 (0.5) [0.5 on Epop[75]] -> cell 49, seg 0 (0.5) [0.5 on Epop[49]], weight: 4.1363508E-4, delay 1.5
        h("Epop[49] syn_projEE_ampa[6049] = new ampa(0.5)")
        h("Epop[75] netConn_projEE_ampa[6049] = new NetCon(&v(0.5), syn_projEE_ampa[6049], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6050: cell 75, seg 0 (0.5) [0.5 on Epop[75]] -> cell 50, seg 0 (0.5) [0.5 on Epop[50]], weight: 4.1363508E-4, delay 1.5
        h("Epop[50] syn_projEE_ampa[6050] = new ampa(0.5)")
        h("Epop[75] netConn_projEE_ampa[6050] = new NetCon(&v(0.5), syn_projEE_ampa[6050], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6051: cell 75, seg 0 (0.5) [0.5 on Epop[75]] -> cell 51, seg 0 (0.5) [0.5 on Epop[51]], weight: 4.1363508E-4, delay 1.5
        h("Epop[51] syn_projEE_ampa[6051] = new ampa(0.5)")
        h("Epop[75] netConn_projEE_ampa[6051] = new NetCon(&v(0.5), syn_projEE_ampa[6051], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6052: cell 75, seg 0 (0.5) [0.5 on Epop[75]] -> cell 52, seg 0 (0.5) [0.5 on Epop[52]], weight: 4.1363508E-4, delay 1.5
        h("Epop[52] syn_projEE_ampa[6052] = new ampa(0.5)")
        h("Epop[75] netConn_projEE_ampa[6052] = new NetCon(&v(0.5), syn_projEE_ampa[6052], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6053: cell 75, seg 0 (0.5) [0.5 on Epop[75]] -> cell 53, seg 0 (0.5) [0.5 on Epop[53]], weight: 4.1363508E-4, delay 1.5
        h("Epop[53] syn_projEE_ampa[6053] = new ampa(0.5)")
        h("Epop[75] netConn_projEE_ampa[6053] = new NetCon(&v(0.5), syn_projEE_ampa[6053], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6054: cell 75, seg 0 (0.5) [0.5 on Epop[75]] -> cell 54, seg 0 (0.5) [0.5 on Epop[54]], weight: 4.1363508E-4, delay 1.5
        h("Epop[54] syn_projEE_ampa[6054] = new ampa(0.5)")
        h("Epop[75] netConn_projEE_ampa[6054] = new NetCon(&v(0.5), syn_projEE_ampa[6054], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6055: cell 75, seg 0 (0.5) [0.5 on Epop[75]] -> cell 55, seg 0 (0.5) [0.5 on Epop[55]], weight: 4.1363508E-4, delay 1.5
        h("Epop[55] syn_projEE_ampa[6055] = new ampa(0.5)")
        h("Epop[75] netConn_projEE_ampa[6055] = new NetCon(&v(0.5), syn_projEE_ampa[6055], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6056: cell 75, seg 0 (0.5) [0.5 on Epop[75]] -> cell 56, seg 0 (0.5) [0.5 on Epop[56]], weight: 4.1363508E-4, delay 1.5
        h("Epop[56] syn_projEE_ampa[6056] = new ampa(0.5)")
        h("Epop[75] netConn_projEE_ampa[6056] = new NetCon(&v(0.5), syn_projEE_ampa[6056], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6057: cell 75, seg 0 (0.5) [0.5 on Epop[75]] -> cell 57, seg 0 (0.5) [0.5 on Epop[57]], weight: 4.1363508E-4, delay 1.5
        h("Epop[57] syn_projEE_ampa[6057] = new ampa(0.5)")
        h("Epop[75] netConn_projEE_ampa[6057] = new NetCon(&v(0.5), syn_projEE_ampa[6057], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6058: cell 75, seg 0 (0.5) [0.5 on Epop[75]] -> cell 58, seg 0 (0.5) [0.5 on Epop[58]], weight: 4.1363508E-4, delay 1.5
        h("Epop[58] syn_projEE_ampa[6058] = new ampa(0.5)")
        h("Epop[75] netConn_projEE_ampa[6058] = new NetCon(&v(0.5), syn_projEE_ampa[6058], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6059: cell 75, seg 0 (0.5) [0.5 on Epop[75]] -> cell 59, seg 0 (0.5) [0.5 on Epop[59]], weight: 4.1363508E-4, delay 1.5
        h("Epop[59] syn_projEE_ampa[6059] = new ampa(0.5)")
        h("Epop[75] netConn_projEE_ampa[6059] = new NetCon(&v(0.5), syn_projEE_ampa[6059], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6060: cell 75, seg 0 (0.5) [0.5 on Epop[75]] -> cell 60, seg 0 (0.5) [0.5 on Epop[60]], weight: 4.1363508E-4, delay 1.5
        h("Epop[60] syn_projEE_ampa[6060] = new ampa(0.5)")
        h("Epop[75] netConn_projEE_ampa[6060] = new NetCon(&v(0.5), syn_projEE_ampa[6060], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6061: cell 75, seg 0 (0.5) [0.5 on Epop[75]] -> cell 61, seg 0 (0.5) [0.5 on Epop[61]], weight: 4.1363508E-4, delay 1.5
        h("Epop[61] syn_projEE_ampa[6061] = new ampa(0.5)")
        h("Epop[75] netConn_projEE_ampa[6061] = new NetCon(&v(0.5), syn_projEE_ampa[6061], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6062: cell 75, seg 0 (0.5) [0.5 on Epop[75]] -> cell 62, seg 0 (0.5) [0.5 on Epop[62]], weight: 4.1363508E-4, delay 1.5
        h("Epop[62] syn_projEE_ampa[6062] = new ampa(0.5)")
        h("Epop[75] netConn_projEE_ampa[6062] = new NetCon(&v(0.5), syn_projEE_ampa[6062], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6063: cell 75, seg 0 (0.5) [0.5 on Epop[75]] -> cell 63, seg 0 (0.5) [0.5 on Epop[63]], weight: 4.1363508E-4, delay 1.5
        h("Epop[63] syn_projEE_ampa[6063] = new ampa(0.5)")
        h("Epop[75] netConn_projEE_ampa[6063] = new NetCon(&v(0.5), syn_projEE_ampa[6063], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6064: cell 75, seg 0 (0.5) [0.5 on Epop[75]] -> cell 64, seg 0 (0.5) [0.5 on Epop[64]], weight: 4.1363508E-4, delay 1.5
        h("Epop[64] syn_projEE_ampa[6064] = new ampa(0.5)")
        h("Epop[75] netConn_projEE_ampa[6064] = new NetCon(&v(0.5), syn_projEE_ampa[6064], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6065: cell 75, seg 0 (0.5) [0.5 on Epop[75]] -> cell 65, seg 0 (0.5) [0.5 on Epop[65]], weight: 4.1363508E-4, delay 1.5
        h("Epop[65] syn_projEE_ampa[6065] = new ampa(0.5)")
        h("Epop[75] netConn_projEE_ampa[6065] = new NetCon(&v(0.5), syn_projEE_ampa[6065], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6066: cell 75, seg 0 (0.5) [0.5 on Epop[75]] -> cell 66, seg 0 (0.5) [0.5 on Epop[66]], weight: 4.1363508E-4, delay 1.5
        h("Epop[66] syn_projEE_ampa[6066] = new ampa(0.5)")
        h("Epop[75] netConn_projEE_ampa[6066] = new NetCon(&v(0.5), syn_projEE_ampa[6066], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6067: cell 75, seg 0 (0.5) [0.5 on Epop[75]] -> cell 67, seg 0 (0.5) [0.5 on Epop[67]], weight: 4.1363508E-4, delay 1.5
        h("Epop[67] syn_projEE_ampa[6067] = new ampa(0.5)")
        h("Epop[75] netConn_projEE_ampa[6067] = new NetCon(&v(0.5), syn_projEE_ampa[6067], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6068: cell 75, seg 0 (0.5) [0.5 on Epop[75]] -> cell 68, seg 0 (0.5) [0.5 on Epop[68]], weight: 4.1363508E-4, delay 1.5
        h("Epop[68] syn_projEE_ampa[6068] = new ampa(0.5)")
        h("Epop[75] netConn_projEE_ampa[6068] = new NetCon(&v(0.5), syn_projEE_ampa[6068], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6069: cell 75, seg 0 (0.5) [0.5 on Epop[75]] -> cell 69, seg 0 (0.5) [0.5 on Epop[69]], weight: 4.1363508E-4, delay 1.5
        h("Epop[69] syn_projEE_ampa[6069] = new ampa(0.5)")
        h("Epop[75] netConn_projEE_ampa[6069] = new NetCon(&v(0.5), syn_projEE_ampa[6069], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6070: cell 75, seg 0 (0.5) [0.5 on Epop[75]] -> cell 70, seg 0 (0.5) [0.5 on Epop[70]], weight: 4.1363508E-4, delay 1.5
        h("Epop[70] syn_projEE_ampa[6070] = new ampa(0.5)")
        h("Epop[75] netConn_projEE_ampa[6070] = new NetCon(&v(0.5), syn_projEE_ampa[6070], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6071: cell 75, seg 0 (0.5) [0.5 on Epop[75]] -> cell 71, seg 0 (0.5) [0.5 on Epop[71]], weight: 4.1363508E-4, delay 1.5
        h("Epop[71] syn_projEE_ampa[6071] = new ampa(0.5)")
        h("Epop[75] netConn_projEE_ampa[6071] = new NetCon(&v(0.5), syn_projEE_ampa[6071], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6072: cell 75, seg 0 (0.5) [0.5 on Epop[75]] -> cell 72, seg 0 (0.5) [0.5 on Epop[72]], weight: 4.1363508E-4, delay 1.5
        h("Epop[72] syn_projEE_ampa[6072] = new ampa(0.5)")
        h("Epop[75] netConn_projEE_ampa[6072] = new NetCon(&v(0.5), syn_projEE_ampa[6072], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6073: cell 75, seg 0 (0.5) [0.5 on Epop[75]] -> cell 73, seg 0 (0.5) [0.5 on Epop[73]], weight: 4.1363508E-4, delay 1.5
        h("Epop[73] syn_projEE_ampa[6073] = new ampa(0.5)")
        h("Epop[75] netConn_projEE_ampa[6073] = new NetCon(&v(0.5), syn_projEE_ampa[6073], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6074: cell 75, seg 0 (0.5) [0.5 on Epop[75]] -> cell 74, seg 0 (0.5) [0.5 on Epop[74]], weight: 4.1363508E-4, delay 1.5
        h("Epop[74] syn_projEE_ampa[6074] = new ampa(0.5)")
        h("Epop[75] netConn_projEE_ampa[6074] = new NetCon(&v(0.5), syn_projEE_ampa[6074], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6075: cell 75, seg 0 (0.5) [0.5 on Epop[75]] -> cell 75, seg 0 (0.5) [0.5 on Epop[75]], weight: 4.1363508E-4, delay 1.5
        h("Epop[75] syn_projEE_ampa[6075] = new ampa(0.5)")
        h("Epop[75] netConn_projEE_ampa[6075] = new NetCon(&v(0.5), syn_projEE_ampa[6075], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6076: cell 75, seg 0 (0.5) [0.5 on Epop[75]] -> cell 76, seg 0 (0.5) [0.5 on Epop[76]], weight: 4.1363508E-4, delay 1.5
        h("Epop[76] syn_projEE_ampa[6076] = new ampa(0.5)")
        h("Epop[75] netConn_projEE_ampa[6076] = new NetCon(&v(0.5), syn_projEE_ampa[6076], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6077: cell 75, seg 0 (0.5) [0.5 on Epop[75]] -> cell 77, seg 0 (0.5) [0.5 on Epop[77]], weight: 4.1363508E-4, delay 1.5
        h("Epop[77] syn_projEE_ampa[6077] = new ampa(0.5)")
        h("Epop[75] netConn_projEE_ampa[6077] = new NetCon(&v(0.5), syn_projEE_ampa[6077], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6078: cell 75, seg 0 (0.5) [0.5 on Epop[75]] -> cell 78, seg 0 (0.5) [0.5 on Epop[78]], weight: 4.1363508E-4, delay 1.5
        h("Epop[78] syn_projEE_ampa[6078] = new ampa(0.5)")
        h("Epop[75] netConn_projEE_ampa[6078] = new NetCon(&v(0.5), syn_projEE_ampa[6078], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6079: cell 75, seg 0 (0.5) [0.5 on Epop[75]] -> cell 79, seg 0 (0.5) [0.5 on Epop[79]], weight: 4.1363508E-4, delay 1.5
        h("Epop[79] syn_projEE_ampa[6079] = new ampa(0.5)")
        h("Epop[75] netConn_projEE_ampa[6079] = new NetCon(&v(0.5), syn_projEE_ampa[6079], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6080: cell 76, seg 0 (0.5) [0.5 on Epop[76]] -> cell 0, seg 0 (0.5) [0.5 on Epop[0]], weight: 4.1363508E-4, delay 1.5
        h("Epop[0] syn_projEE_ampa[6080] = new ampa(0.5)")
        h("Epop[76] netConn_projEE_ampa[6080] = new NetCon(&v(0.5), syn_projEE_ampa[6080], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6081: cell 76, seg 0 (0.5) [0.5 on Epop[76]] -> cell 1, seg 0 (0.5) [0.5 on Epop[1]], weight: 4.1363508E-4, delay 1.5
        h("Epop[1] syn_projEE_ampa[6081] = new ampa(0.5)")
        h("Epop[76] netConn_projEE_ampa[6081] = new NetCon(&v(0.5), syn_projEE_ampa[6081], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6082: cell 76, seg 0 (0.5) [0.5 on Epop[76]] -> cell 2, seg 0 (0.5) [0.5 on Epop[2]], weight: 4.1363508E-4, delay 1.5
        h("Epop[2] syn_projEE_ampa[6082] = new ampa(0.5)")
        h("Epop[76] netConn_projEE_ampa[6082] = new NetCon(&v(0.5), syn_projEE_ampa[6082], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6083: cell 76, seg 0 (0.5) [0.5 on Epop[76]] -> cell 3, seg 0 (0.5) [0.5 on Epop[3]], weight: 4.1363508E-4, delay 1.5
        h("Epop[3] syn_projEE_ampa[6083] = new ampa(0.5)")
        h("Epop[76] netConn_projEE_ampa[6083] = new NetCon(&v(0.5), syn_projEE_ampa[6083], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6084: cell 76, seg 0 (0.5) [0.5 on Epop[76]] -> cell 4, seg 0 (0.5) [0.5 on Epop[4]], weight: 4.1363508E-4, delay 1.5
        h("Epop[4] syn_projEE_ampa[6084] = new ampa(0.5)")
        h("Epop[76] netConn_projEE_ampa[6084] = new NetCon(&v(0.5), syn_projEE_ampa[6084], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6085: cell 76, seg 0 (0.5) [0.5 on Epop[76]] -> cell 5, seg 0 (0.5) [0.5 on Epop[5]], weight: 4.1363508E-4, delay 1.5
        h("Epop[5] syn_projEE_ampa[6085] = new ampa(0.5)")
        h("Epop[76] netConn_projEE_ampa[6085] = new NetCon(&v(0.5), syn_projEE_ampa[6085], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6086: cell 76, seg 0 (0.5) [0.5 on Epop[76]] -> cell 6, seg 0 (0.5) [0.5 on Epop[6]], weight: 4.1363508E-4, delay 1.5
        h("Epop[6] syn_projEE_ampa[6086] = new ampa(0.5)")
        h("Epop[76] netConn_projEE_ampa[6086] = new NetCon(&v(0.5), syn_projEE_ampa[6086], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6087: cell 76, seg 0 (0.5) [0.5 on Epop[76]] -> cell 7, seg 0 (0.5) [0.5 on Epop[7]], weight: 4.1363508E-4, delay 1.5
        h("Epop[7] syn_projEE_ampa[6087] = new ampa(0.5)")
        h("Epop[76] netConn_projEE_ampa[6087] = new NetCon(&v(0.5), syn_projEE_ampa[6087], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6088: cell 76, seg 0 (0.5) [0.5 on Epop[76]] -> cell 8, seg 0 (0.5) [0.5 on Epop[8]], weight: 4.1363508E-4, delay 1.5
        h("Epop[8] syn_projEE_ampa[6088] = new ampa(0.5)")
        h("Epop[76] netConn_projEE_ampa[6088] = new NetCon(&v(0.5), syn_projEE_ampa[6088], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6089: cell 76, seg 0 (0.5) [0.5 on Epop[76]] -> cell 9, seg 0 (0.5) [0.5 on Epop[9]], weight: 4.1363508E-4, delay 1.5
        h("Epop[9] syn_projEE_ampa[6089] = new ampa(0.5)")
        h("Epop[76] netConn_projEE_ampa[6089] = new NetCon(&v(0.5), syn_projEE_ampa[6089], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6090: cell 76, seg 0 (0.5) [0.5 on Epop[76]] -> cell 10, seg 0 (0.5) [0.5 on Epop[10]], weight: 4.1363508E-4, delay 1.5
        h("Epop[10] syn_projEE_ampa[6090] = new ampa(0.5)")
        h("Epop[76] netConn_projEE_ampa[6090] = new NetCon(&v(0.5), syn_projEE_ampa[6090], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6091: cell 76, seg 0 (0.5) [0.5 on Epop[76]] -> cell 11, seg 0 (0.5) [0.5 on Epop[11]], weight: 4.1363508E-4, delay 1.5
        h("Epop[11] syn_projEE_ampa[6091] = new ampa(0.5)")
        h("Epop[76] netConn_projEE_ampa[6091] = new NetCon(&v(0.5), syn_projEE_ampa[6091], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6092: cell 76, seg 0 (0.5) [0.5 on Epop[76]] -> cell 12, seg 0 (0.5) [0.5 on Epop[12]], weight: 4.1363508E-4, delay 1.5
        h("Epop[12] syn_projEE_ampa[6092] = new ampa(0.5)")
        h("Epop[76] netConn_projEE_ampa[6092] = new NetCon(&v(0.5), syn_projEE_ampa[6092], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6093: cell 76, seg 0 (0.5) [0.5 on Epop[76]] -> cell 13, seg 0 (0.5) [0.5 on Epop[13]], weight: 4.1363508E-4, delay 1.5
        h("Epop[13] syn_projEE_ampa[6093] = new ampa(0.5)")
        h("Epop[76] netConn_projEE_ampa[6093] = new NetCon(&v(0.5), syn_projEE_ampa[6093], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6094: cell 76, seg 0 (0.5) [0.5 on Epop[76]] -> cell 14, seg 0 (0.5) [0.5 on Epop[14]], weight: 4.1363508E-4, delay 1.5
        h("Epop[14] syn_projEE_ampa[6094] = new ampa(0.5)")
        h("Epop[76] netConn_projEE_ampa[6094] = new NetCon(&v(0.5), syn_projEE_ampa[6094], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6095: cell 76, seg 0 (0.5) [0.5 on Epop[76]] -> cell 15, seg 0 (0.5) [0.5 on Epop[15]], weight: 4.1363508E-4, delay 1.5
        h("Epop[15] syn_projEE_ampa[6095] = new ampa(0.5)")
        h("Epop[76] netConn_projEE_ampa[6095] = new NetCon(&v(0.5), syn_projEE_ampa[6095], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6096: cell 76, seg 0 (0.5) [0.5 on Epop[76]] -> cell 16, seg 0 (0.5) [0.5 on Epop[16]], weight: 4.1363508E-4, delay 1.5
        h("Epop[16] syn_projEE_ampa[6096] = new ampa(0.5)")
        h("Epop[76] netConn_projEE_ampa[6096] = new NetCon(&v(0.5), syn_projEE_ampa[6096], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6097: cell 76, seg 0 (0.5) [0.5 on Epop[76]] -> cell 17, seg 0 (0.5) [0.5 on Epop[17]], weight: 4.1363508E-4, delay 1.5
        h("Epop[17] syn_projEE_ampa[6097] = new ampa(0.5)")
        h("Epop[76] netConn_projEE_ampa[6097] = new NetCon(&v(0.5), syn_projEE_ampa[6097], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6098: cell 76, seg 0 (0.5) [0.5 on Epop[76]] -> cell 18, seg 0 (0.5) [0.5 on Epop[18]], weight: 4.1363508E-4, delay 1.5
        h("Epop[18] syn_projEE_ampa[6098] = new ampa(0.5)")
        h("Epop[76] netConn_projEE_ampa[6098] = new NetCon(&v(0.5), syn_projEE_ampa[6098], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6099: cell 76, seg 0 (0.5) [0.5 on Epop[76]] -> cell 19, seg 0 (0.5) [0.5 on Epop[19]], weight: 4.1363508E-4, delay 1.5
        h("Epop[19] syn_projEE_ampa[6099] = new ampa(0.5)")
        h("Epop[76] netConn_projEE_ampa[6099] = new NetCon(&v(0.5), syn_projEE_ampa[6099], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6100: cell 76, seg 0 (0.5) [0.5 on Epop[76]] -> cell 20, seg 0 (0.5) [0.5 on Epop[20]], weight: 4.1363508E-4, delay 1.5
        h("Epop[20] syn_projEE_ampa[6100] = new ampa(0.5)")
        h("Epop[76] netConn_projEE_ampa[6100] = new NetCon(&v(0.5), syn_projEE_ampa[6100], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6101: cell 76, seg 0 (0.5) [0.5 on Epop[76]] -> cell 21, seg 0 (0.5) [0.5 on Epop[21]], weight: 4.1363508E-4, delay 1.5
        h("Epop[21] syn_projEE_ampa[6101] = new ampa(0.5)")
        h("Epop[76] netConn_projEE_ampa[6101] = new NetCon(&v(0.5), syn_projEE_ampa[6101], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6102: cell 76, seg 0 (0.5) [0.5 on Epop[76]] -> cell 22, seg 0 (0.5) [0.5 on Epop[22]], weight: 4.1363508E-4, delay 1.5
        h("Epop[22] syn_projEE_ampa[6102] = new ampa(0.5)")
        h("Epop[76] netConn_projEE_ampa[6102] = new NetCon(&v(0.5), syn_projEE_ampa[6102], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6103: cell 76, seg 0 (0.5) [0.5 on Epop[76]] -> cell 23, seg 0 (0.5) [0.5 on Epop[23]], weight: 4.1363508E-4, delay 1.5
        h("Epop[23] syn_projEE_ampa[6103] = new ampa(0.5)")
        h("Epop[76] netConn_projEE_ampa[6103] = new NetCon(&v(0.5), syn_projEE_ampa[6103], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6104: cell 76, seg 0 (0.5) [0.5 on Epop[76]] -> cell 24, seg 0 (0.5) [0.5 on Epop[24]], weight: 4.1363508E-4, delay 1.5
        h("Epop[24] syn_projEE_ampa[6104] = new ampa(0.5)")
        h("Epop[76] netConn_projEE_ampa[6104] = new NetCon(&v(0.5), syn_projEE_ampa[6104], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6105: cell 76, seg 0 (0.5) [0.5 on Epop[76]] -> cell 25, seg 0 (0.5) [0.5 on Epop[25]], weight: 4.1363508E-4, delay 1.5
        h("Epop[25] syn_projEE_ampa[6105] = new ampa(0.5)")
        h("Epop[76] netConn_projEE_ampa[6105] = new NetCon(&v(0.5), syn_projEE_ampa[6105], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6106: cell 76, seg 0 (0.5) [0.5 on Epop[76]] -> cell 26, seg 0 (0.5) [0.5 on Epop[26]], weight: 4.1363508E-4, delay 1.5
        h("Epop[26] syn_projEE_ampa[6106] = new ampa(0.5)")
        h("Epop[76] netConn_projEE_ampa[6106] = new NetCon(&v(0.5), syn_projEE_ampa[6106], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6107: cell 76, seg 0 (0.5) [0.5 on Epop[76]] -> cell 27, seg 0 (0.5) [0.5 on Epop[27]], weight: 4.1363508E-4, delay 1.5
        h("Epop[27] syn_projEE_ampa[6107] = new ampa(0.5)")
        h("Epop[76] netConn_projEE_ampa[6107] = new NetCon(&v(0.5), syn_projEE_ampa[6107], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6108: cell 76, seg 0 (0.5) [0.5 on Epop[76]] -> cell 28, seg 0 (0.5) [0.5 on Epop[28]], weight: 4.1363508E-4, delay 1.5
        h("Epop[28] syn_projEE_ampa[6108] = new ampa(0.5)")
        h("Epop[76] netConn_projEE_ampa[6108] = new NetCon(&v(0.5), syn_projEE_ampa[6108], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6109: cell 76, seg 0 (0.5) [0.5 on Epop[76]] -> cell 29, seg 0 (0.5) [0.5 on Epop[29]], weight: 4.1363508E-4, delay 1.5
        h("Epop[29] syn_projEE_ampa[6109] = new ampa(0.5)")
        h("Epop[76] netConn_projEE_ampa[6109] = new NetCon(&v(0.5), syn_projEE_ampa[6109], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6110: cell 76, seg 0 (0.5) [0.5 on Epop[76]] -> cell 30, seg 0 (0.5) [0.5 on Epop[30]], weight: 4.1363508E-4, delay 1.5
        h("Epop[30] syn_projEE_ampa[6110] = new ampa(0.5)")
        h("Epop[76] netConn_projEE_ampa[6110] = new NetCon(&v(0.5), syn_projEE_ampa[6110], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6111: cell 76, seg 0 (0.5) [0.5 on Epop[76]] -> cell 31, seg 0 (0.5) [0.5 on Epop[31]], weight: 4.1363508E-4, delay 1.5
        h("Epop[31] syn_projEE_ampa[6111] = new ampa(0.5)")
        h("Epop[76] netConn_projEE_ampa[6111] = new NetCon(&v(0.5), syn_projEE_ampa[6111], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6112: cell 76, seg 0 (0.5) [0.5 on Epop[76]] -> cell 32, seg 0 (0.5) [0.5 on Epop[32]], weight: 4.1363508E-4, delay 1.5
        h("Epop[32] syn_projEE_ampa[6112] = new ampa(0.5)")
        h("Epop[76] netConn_projEE_ampa[6112] = new NetCon(&v(0.5), syn_projEE_ampa[6112], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6113: cell 76, seg 0 (0.5) [0.5 on Epop[76]] -> cell 33, seg 0 (0.5) [0.5 on Epop[33]], weight: 4.1363508E-4, delay 1.5
        h("Epop[33] syn_projEE_ampa[6113] = new ampa(0.5)")
        h("Epop[76] netConn_projEE_ampa[6113] = new NetCon(&v(0.5), syn_projEE_ampa[6113], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6114: cell 76, seg 0 (0.5) [0.5 on Epop[76]] -> cell 34, seg 0 (0.5) [0.5 on Epop[34]], weight: 4.1363508E-4, delay 1.5
        h("Epop[34] syn_projEE_ampa[6114] = new ampa(0.5)")
        h("Epop[76] netConn_projEE_ampa[6114] = new NetCon(&v(0.5), syn_projEE_ampa[6114], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6115: cell 76, seg 0 (0.5) [0.5 on Epop[76]] -> cell 35, seg 0 (0.5) [0.5 on Epop[35]], weight: 4.1363508E-4, delay 1.5
        h("Epop[35] syn_projEE_ampa[6115] = new ampa(0.5)")
        h("Epop[76] netConn_projEE_ampa[6115] = new NetCon(&v(0.5), syn_projEE_ampa[6115], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6116: cell 76, seg 0 (0.5) [0.5 on Epop[76]] -> cell 36, seg 0 (0.5) [0.5 on Epop[36]], weight: 4.1363508E-4, delay 1.5
        h("Epop[36] syn_projEE_ampa[6116] = new ampa(0.5)")
        h("Epop[76] netConn_projEE_ampa[6116] = new NetCon(&v(0.5), syn_projEE_ampa[6116], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6117: cell 76, seg 0 (0.5) [0.5 on Epop[76]] -> cell 37, seg 0 (0.5) [0.5 on Epop[37]], weight: 4.1363508E-4, delay 1.5
        h("Epop[37] syn_projEE_ampa[6117] = new ampa(0.5)")
        h("Epop[76] netConn_projEE_ampa[6117] = new NetCon(&v(0.5), syn_projEE_ampa[6117], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6118: cell 76, seg 0 (0.5) [0.5 on Epop[76]] -> cell 38, seg 0 (0.5) [0.5 on Epop[38]], weight: 4.1363508E-4, delay 1.5
        h("Epop[38] syn_projEE_ampa[6118] = new ampa(0.5)")
        h("Epop[76] netConn_projEE_ampa[6118] = new NetCon(&v(0.5), syn_projEE_ampa[6118], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6119: cell 76, seg 0 (0.5) [0.5 on Epop[76]] -> cell 39, seg 0 (0.5) [0.5 on Epop[39]], weight: 4.1363508E-4, delay 1.5
        h("Epop[39] syn_projEE_ampa[6119] = new ampa(0.5)")
        h("Epop[76] netConn_projEE_ampa[6119] = new NetCon(&v(0.5), syn_projEE_ampa[6119], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6120: cell 76, seg 0 (0.5) [0.5 on Epop[76]] -> cell 40, seg 0 (0.5) [0.5 on Epop[40]], weight: 4.1363508E-4, delay 1.5
        h("Epop[40] syn_projEE_ampa[6120] = new ampa(0.5)")
        h("Epop[76] netConn_projEE_ampa[6120] = new NetCon(&v(0.5), syn_projEE_ampa[6120], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6121: cell 76, seg 0 (0.5) [0.5 on Epop[76]] -> cell 41, seg 0 (0.5) [0.5 on Epop[41]], weight: 4.1363508E-4, delay 1.5
        h("Epop[41] syn_projEE_ampa[6121] = new ampa(0.5)")
        h("Epop[76] netConn_projEE_ampa[6121] = new NetCon(&v(0.5), syn_projEE_ampa[6121], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6122: cell 76, seg 0 (0.5) [0.5 on Epop[76]] -> cell 42, seg 0 (0.5) [0.5 on Epop[42]], weight: 4.1363508E-4, delay 1.5
        h("Epop[42] syn_projEE_ampa[6122] = new ampa(0.5)")
        h("Epop[76] netConn_projEE_ampa[6122] = new NetCon(&v(0.5), syn_projEE_ampa[6122], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6123: cell 76, seg 0 (0.5) [0.5 on Epop[76]] -> cell 43, seg 0 (0.5) [0.5 on Epop[43]], weight: 4.1363508E-4, delay 1.5
        h("Epop[43] syn_projEE_ampa[6123] = new ampa(0.5)")
        h("Epop[76] netConn_projEE_ampa[6123] = new NetCon(&v(0.5), syn_projEE_ampa[6123], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6124: cell 76, seg 0 (0.5) [0.5 on Epop[76]] -> cell 44, seg 0 (0.5) [0.5 on Epop[44]], weight: 4.1363508E-4, delay 1.5
        h("Epop[44] syn_projEE_ampa[6124] = new ampa(0.5)")
        h("Epop[76] netConn_projEE_ampa[6124] = new NetCon(&v(0.5), syn_projEE_ampa[6124], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6125: cell 76, seg 0 (0.5) [0.5 on Epop[76]] -> cell 45, seg 0 (0.5) [0.5 on Epop[45]], weight: 4.1363508E-4, delay 1.5
        h("Epop[45] syn_projEE_ampa[6125] = new ampa(0.5)")
        h("Epop[76] netConn_projEE_ampa[6125] = new NetCon(&v(0.5), syn_projEE_ampa[6125], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6126: cell 76, seg 0 (0.5) [0.5 on Epop[76]] -> cell 46, seg 0 (0.5) [0.5 on Epop[46]], weight: 4.1363508E-4, delay 1.5
        h("Epop[46] syn_projEE_ampa[6126] = new ampa(0.5)")
        h("Epop[76] netConn_projEE_ampa[6126] = new NetCon(&v(0.5), syn_projEE_ampa[6126], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6127: cell 76, seg 0 (0.5) [0.5 on Epop[76]] -> cell 47, seg 0 (0.5) [0.5 on Epop[47]], weight: 4.1363508E-4, delay 1.5
        h("Epop[47] syn_projEE_ampa[6127] = new ampa(0.5)")
        h("Epop[76] netConn_projEE_ampa[6127] = new NetCon(&v(0.5), syn_projEE_ampa[6127], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6128: cell 76, seg 0 (0.5) [0.5 on Epop[76]] -> cell 48, seg 0 (0.5) [0.5 on Epop[48]], weight: 4.1363508E-4, delay 1.5
        h("Epop[48] syn_projEE_ampa[6128] = new ampa(0.5)")
        h("Epop[76] netConn_projEE_ampa[6128] = new NetCon(&v(0.5), syn_projEE_ampa[6128], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6129: cell 76, seg 0 (0.5) [0.5 on Epop[76]] -> cell 49, seg 0 (0.5) [0.5 on Epop[49]], weight: 4.1363508E-4, delay 1.5
        h("Epop[49] syn_projEE_ampa[6129] = new ampa(0.5)")
        h("Epop[76] netConn_projEE_ampa[6129] = new NetCon(&v(0.5), syn_projEE_ampa[6129], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6130: cell 76, seg 0 (0.5) [0.5 on Epop[76]] -> cell 50, seg 0 (0.5) [0.5 on Epop[50]], weight: 4.1363508E-4, delay 1.5
        h("Epop[50] syn_projEE_ampa[6130] = new ampa(0.5)")
        h("Epop[76] netConn_projEE_ampa[6130] = new NetCon(&v(0.5), syn_projEE_ampa[6130], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6131: cell 76, seg 0 (0.5) [0.5 on Epop[76]] -> cell 51, seg 0 (0.5) [0.5 on Epop[51]], weight: 4.1363508E-4, delay 1.5
        h("Epop[51] syn_projEE_ampa[6131] = new ampa(0.5)")
        h("Epop[76] netConn_projEE_ampa[6131] = new NetCon(&v(0.5), syn_projEE_ampa[6131], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6132: cell 76, seg 0 (0.5) [0.5 on Epop[76]] -> cell 52, seg 0 (0.5) [0.5 on Epop[52]], weight: 4.1363508E-4, delay 1.5
        h("Epop[52] syn_projEE_ampa[6132] = new ampa(0.5)")
        h("Epop[76] netConn_projEE_ampa[6132] = new NetCon(&v(0.5), syn_projEE_ampa[6132], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6133: cell 76, seg 0 (0.5) [0.5 on Epop[76]] -> cell 53, seg 0 (0.5) [0.5 on Epop[53]], weight: 4.1363508E-4, delay 1.5
        h("Epop[53] syn_projEE_ampa[6133] = new ampa(0.5)")
        h("Epop[76] netConn_projEE_ampa[6133] = new NetCon(&v(0.5), syn_projEE_ampa[6133], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6134: cell 76, seg 0 (0.5) [0.5 on Epop[76]] -> cell 54, seg 0 (0.5) [0.5 on Epop[54]], weight: 4.1363508E-4, delay 1.5
        h("Epop[54] syn_projEE_ampa[6134] = new ampa(0.5)")
        h("Epop[76] netConn_projEE_ampa[6134] = new NetCon(&v(0.5), syn_projEE_ampa[6134], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6135: cell 76, seg 0 (0.5) [0.5 on Epop[76]] -> cell 55, seg 0 (0.5) [0.5 on Epop[55]], weight: 4.1363508E-4, delay 1.5
        h("Epop[55] syn_projEE_ampa[6135] = new ampa(0.5)")
        h("Epop[76] netConn_projEE_ampa[6135] = new NetCon(&v(0.5), syn_projEE_ampa[6135], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6136: cell 76, seg 0 (0.5) [0.5 on Epop[76]] -> cell 56, seg 0 (0.5) [0.5 on Epop[56]], weight: 4.1363508E-4, delay 1.5
        h("Epop[56] syn_projEE_ampa[6136] = new ampa(0.5)")
        h("Epop[76] netConn_projEE_ampa[6136] = new NetCon(&v(0.5), syn_projEE_ampa[6136], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6137: cell 76, seg 0 (0.5) [0.5 on Epop[76]] -> cell 57, seg 0 (0.5) [0.5 on Epop[57]], weight: 4.1363508E-4, delay 1.5
        h("Epop[57] syn_projEE_ampa[6137] = new ampa(0.5)")
        h("Epop[76] netConn_projEE_ampa[6137] = new NetCon(&v(0.5), syn_projEE_ampa[6137], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6138: cell 76, seg 0 (0.5) [0.5 on Epop[76]] -> cell 58, seg 0 (0.5) [0.5 on Epop[58]], weight: 4.1363508E-4, delay 1.5
        h("Epop[58] syn_projEE_ampa[6138] = new ampa(0.5)")
        h("Epop[76] netConn_projEE_ampa[6138] = new NetCon(&v(0.5), syn_projEE_ampa[6138], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6139: cell 76, seg 0 (0.5) [0.5 on Epop[76]] -> cell 59, seg 0 (0.5) [0.5 on Epop[59]], weight: 4.1363508E-4, delay 1.5
        h("Epop[59] syn_projEE_ampa[6139] = new ampa(0.5)")
        h("Epop[76] netConn_projEE_ampa[6139] = new NetCon(&v(0.5), syn_projEE_ampa[6139], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6140: cell 76, seg 0 (0.5) [0.5 on Epop[76]] -> cell 60, seg 0 (0.5) [0.5 on Epop[60]], weight: 4.1363508E-4, delay 1.5
        h("Epop[60] syn_projEE_ampa[6140] = new ampa(0.5)")
        h("Epop[76] netConn_projEE_ampa[6140] = new NetCon(&v(0.5), syn_projEE_ampa[6140], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6141: cell 76, seg 0 (0.5) [0.5 on Epop[76]] -> cell 61, seg 0 (0.5) [0.5 on Epop[61]], weight: 4.1363508E-4, delay 1.5
        h("Epop[61] syn_projEE_ampa[6141] = new ampa(0.5)")
        h("Epop[76] netConn_projEE_ampa[6141] = new NetCon(&v(0.5), syn_projEE_ampa[6141], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6142: cell 76, seg 0 (0.5) [0.5 on Epop[76]] -> cell 62, seg 0 (0.5) [0.5 on Epop[62]], weight: 4.1363508E-4, delay 1.5
        h("Epop[62] syn_projEE_ampa[6142] = new ampa(0.5)")
        h("Epop[76] netConn_projEE_ampa[6142] = new NetCon(&v(0.5), syn_projEE_ampa[6142], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6143: cell 76, seg 0 (0.5) [0.5 on Epop[76]] -> cell 63, seg 0 (0.5) [0.5 on Epop[63]], weight: 4.1363508E-4, delay 1.5
        h("Epop[63] syn_projEE_ampa[6143] = new ampa(0.5)")
        h("Epop[76] netConn_projEE_ampa[6143] = new NetCon(&v(0.5), syn_projEE_ampa[6143], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6144: cell 76, seg 0 (0.5) [0.5 on Epop[76]] -> cell 64, seg 0 (0.5) [0.5 on Epop[64]], weight: 4.1363508E-4, delay 1.5
        h("Epop[64] syn_projEE_ampa[6144] = new ampa(0.5)")
        h("Epop[76] netConn_projEE_ampa[6144] = new NetCon(&v(0.5), syn_projEE_ampa[6144], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6145: cell 76, seg 0 (0.5) [0.5 on Epop[76]] -> cell 65, seg 0 (0.5) [0.5 on Epop[65]], weight: 4.1363508E-4, delay 1.5
        h("Epop[65] syn_projEE_ampa[6145] = new ampa(0.5)")
        h("Epop[76] netConn_projEE_ampa[6145] = new NetCon(&v(0.5), syn_projEE_ampa[6145], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6146: cell 76, seg 0 (0.5) [0.5 on Epop[76]] -> cell 66, seg 0 (0.5) [0.5 on Epop[66]], weight: 4.1363508E-4, delay 1.5
        h("Epop[66] syn_projEE_ampa[6146] = new ampa(0.5)")
        h("Epop[76] netConn_projEE_ampa[6146] = new NetCon(&v(0.5), syn_projEE_ampa[6146], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6147: cell 76, seg 0 (0.5) [0.5 on Epop[76]] -> cell 67, seg 0 (0.5) [0.5 on Epop[67]], weight: 4.1363508E-4, delay 1.5
        h("Epop[67] syn_projEE_ampa[6147] = new ampa(0.5)")
        h("Epop[76] netConn_projEE_ampa[6147] = new NetCon(&v(0.5), syn_projEE_ampa[6147], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6148: cell 76, seg 0 (0.5) [0.5 on Epop[76]] -> cell 68, seg 0 (0.5) [0.5 on Epop[68]], weight: 4.1363508E-4, delay 1.5
        h("Epop[68] syn_projEE_ampa[6148] = new ampa(0.5)")
        h("Epop[76] netConn_projEE_ampa[6148] = new NetCon(&v(0.5), syn_projEE_ampa[6148], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6149: cell 76, seg 0 (0.5) [0.5 on Epop[76]] -> cell 69, seg 0 (0.5) [0.5 on Epop[69]], weight: 4.1363508E-4, delay 1.5
        h("Epop[69] syn_projEE_ampa[6149] = new ampa(0.5)")
        h("Epop[76] netConn_projEE_ampa[6149] = new NetCon(&v(0.5), syn_projEE_ampa[6149], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6150: cell 76, seg 0 (0.5) [0.5 on Epop[76]] -> cell 70, seg 0 (0.5) [0.5 on Epop[70]], weight: 4.1363508E-4, delay 1.5
        h("Epop[70] syn_projEE_ampa[6150] = new ampa(0.5)")
        h("Epop[76] netConn_projEE_ampa[6150] = new NetCon(&v(0.5), syn_projEE_ampa[6150], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6151: cell 76, seg 0 (0.5) [0.5 on Epop[76]] -> cell 71, seg 0 (0.5) [0.5 on Epop[71]], weight: 4.1363508E-4, delay 1.5
        h("Epop[71] syn_projEE_ampa[6151] = new ampa(0.5)")
        h("Epop[76] netConn_projEE_ampa[6151] = new NetCon(&v(0.5), syn_projEE_ampa[6151], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6152: cell 76, seg 0 (0.5) [0.5 on Epop[76]] -> cell 72, seg 0 (0.5) [0.5 on Epop[72]], weight: 4.1363508E-4, delay 1.5
        h("Epop[72] syn_projEE_ampa[6152] = new ampa(0.5)")
        h("Epop[76] netConn_projEE_ampa[6152] = new NetCon(&v(0.5), syn_projEE_ampa[6152], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6153: cell 76, seg 0 (0.5) [0.5 on Epop[76]] -> cell 73, seg 0 (0.5) [0.5 on Epop[73]], weight: 4.1363508E-4, delay 1.5
        h("Epop[73] syn_projEE_ampa[6153] = new ampa(0.5)")
        h("Epop[76] netConn_projEE_ampa[6153] = new NetCon(&v(0.5), syn_projEE_ampa[6153], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6154: cell 76, seg 0 (0.5) [0.5 on Epop[76]] -> cell 74, seg 0 (0.5) [0.5 on Epop[74]], weight: 4.1363508E-4, delay 1.5
        h("Epop[74] syn_projEE_ampa[6154] = new ampa(0.5)")
        h("Epop[76] netConn_projEE_ampa[6154] = new NetCon(&v(0.5), syn_projEE_ampa[6154], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6155: cell 76, seg 0 (0.5) [0.5 on Epop[76]] -> cell 75, seg 0 (0.5) [0.5 on Epop[75]], weight: 4.1363508E-4, delay 1.5
        h("Epop[75] syn_projEE_ampa[6155] = new ampa(0.5)")
        h("Epop[76] netConn_projEE_ampa[6155] = new NetCon(&v(0.5), syn_projEE_ampa[6155], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6156: cell 76, seg 0 (0.5) [0.5 on Epop[76]] -> cell 76, seg 0 (0.5) [0.5 on Epop[76]], weight: 4.1363508E-4, delay 1.5
        h("Epop[76] syn_projEE_ampa[6156] = new ampa(0.5)")
        h("Epop[76] netConn_projEE_ampa[6156] = new NetCon(&v(0.5), syn_projEE_ampa[6156], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6157: cell 76, seg 0 (0.5) [0.5 on Epop[76]] -> cell 77, seg 0 (0.5) [0.5 on Epop[77]], weight: 4.1363508E-4, delay 1.5
        h("Epop[77] syn_projEE_ampa[6157] = new ampa(0.5)")
        h("Epop[76] netConn_projEE_ampa[6157] = new NetCon(&v(0.5), syn_projEE_ampa[6157], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6158: cell 76, seg 0 (0.5) [0.5 on Epop[76]] -> cell 78, seg 0 (0.5) [0.5 on Epop[78]], weight: 4.1363508E-4, delay 1.5
        h("Epop[78] syn_projEE_ampa[6158] = new ampa(0.5)")
        h("Epop[76] netConn_projEE_ampa[6158] = new NetCon(&v(0.5), syn_projEE_ampa[6158], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6159: cell 76, seg 0 (0.5) [0.5 on Epop[76]] -> cell 79, seg 0 (0.5) [0.5 on Epop[79]], weight: 4.1363508E-4, delay 1.5
        h("Epop[79] syn_projEE_ampa[6159] = new ampa(0.5)")
        h("Epop[76] netConn_projEE_ampa[6159] = new NetCon(&v(0.5), syn_projEE_ampa[6159], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6160: cell 77, seg 0 (0.5) [0.5 on Epop[77]] -> cell 0, seg 0 (0.5) [0.5 on Epop[0]], weight: 4.1363508E-4, delay 1.5
        h("Epop[0] syn_projEE_ampa[6160] = new ampa(0.5)")
        h("Epop[77] netConn_projEE_ampa[6160] = new NetCon(&v(0.5), syn_projEE_ampa[6160], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6161: cell 77, seg 0 (0.5) [0.5 on Epop[77]] -> cell 1, seg 0 (0.5) [0.5 on Epop[1]], weight: 4.1363508E-4, delay 1.5
        h("Epop[1] syn_projEE_ampa[6161] = new ampa(0.5)")
        h("Epop[77] netConn_projEE_ampa[6161] = new NetCon(&v(0.5), syn_projEE_ampa[6161], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6162: cell 77, seg 0 (0.5) [0.5 on Epop[77]] -> cell 2, seg 0 (0.5) [0.5 on Epop[2]], weight: 4.1363508E-4, delay 1.5
        h("Epop[2] syn_projEE_ampa[6162] = new ampa(0.5)")
        h("Epop[77] netConn_projEE_ampa[6162] = new NetCon(&v(0.5), syn_projEE_ampa[6162], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6163: cell 77, seg 0 (0.5) [0.5 on Epop[77]] -> cell 3, seg 0 (0.5) [0.5 on Epop[3]], weight: 4.1363508E-4, delay 1.5
        h("Epop[3] syn_projEE_ampa[6163] = new ampa(0.5)")
        h("Epop[77] netConn_projEE_ampa[6163] = new NetCon(&v(0.5), syn_projEE_ampa[6163], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6164: cell 77, seg 0 (0.5) [0.5 on Epop[77]] -> cell 4, seg 0 (0.5) [0.5 on Epop[4]], weight: 4.1363508E-4, delay 1.5
        h("Epop[4] syn_projEE_ampa[6164] = new ampa(0.5)")
        h("Epop[77] netConn_projEE_ampa[6164] = new NetCon(&v(0.5), syn_projEE_ampa[6164], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6165: cell 77, seg 0 (0.5) [0.5 on Epop[77]] -> cell 5, seg 0 (0.5) [0.5 on Epop[5]], weight: 4.1363508E-4, delay 1.5
        h("Epop[5] syn_projEE_ampa[6165] = new ampa(0.5)")
        h("Epop[77] netConn_projEE_ampa[6165] = new NetCon(&v(0.5), syn_projEE_ampa[6165], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6166: cell 77, seg 0 (0.5) [0.5 on Epop[77]] -> cell 6, seg 0 (0.5) [0.5 on Epop[6]], weight: 4.1363508E-4, delay 1.5
        h("Epop[6] syn_projEE_ampa[6166] = new ampa(0.5)")
        h("Epop[77] netConn_projEE_ampa[6166] = new NetCon(&v(0.5), syn_projEE_ampa[6166], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6167: cell 77, seg 0 (0.5) [0.5 on Epop[77]] -> cell 7, seg 0 (0.5) [0.5 on Epop[7]], weight: 4.1363508E-4, delay 1.5
        h("Epop[7] syn_projEE_ampa[6167] = new ampa(0.5)")
        h("Epop[77] netConn_projEE_ampa[6167] = new NetCon(&v(0.5), syn_projEE_ampa[6167], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6168: cell 77, seg 0 (0.5) [0.5 on Epop[77]] -> cell 8, seg 0 (0.5) [0.5 on Epop[8]], weight: 4.1363508E-4, delay 1.5
        h("Epop[8] syn_projEE_ampa[6168] = new ampa(0.5)")
        h("Epop[77] netConn_projEE_ampa[6168] = new NetCon(&v(0.5), syn_projEE_ampa[6168], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6169: cell 77, seg 0 (0.5) [0.5 on Epop[77]] -> cell 9, seg 0 (0.5) [0.5 on Epop[9]], weight: 4.1363508E-4, delay 1.5
        h("Epop[9] syn_projEE_ampa[6169] = new ampa(0.5)")
        h("Epop[77] netConn_projEE_ampa[6169] = new NetCon(&v(0.5), syn_projEE_ampa[6169], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6170: cell 77, seg 0 (0.5) [0.5 on Epop[77]] -> cell 10, seg 0 (0.5) [0.5 on Epop[10]], weight: 4.1363508E-4, delay 1.5
        h("Epop[10] syn_projEE_ampa[6170] = new ampa(0.5)")
        h("Epop[77] netConn_projEE_ampa[6170] = new NetCon(&v(0.5), syn_projEE_ampa[6170], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6171: cell 77, seg 0 (0.5) [0.5 on Epop[77]] -> cell 11, seg 0 (0.5) [0.5 on Epop[11]], weight: 4.1363508E-4, delay 1.5
        h("Epop[11] syn_projEE_ampa[6171] = new ampa(0.5)")
        h("Epop[77] netConn_projEE_ampa[6171] = new NetCon(&v(0.5), syn_projEE_ampa[6171], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6172: cell 77, seg 0 (0.5) [0.5 on Epop[77]] -> cell 12, seg 0 (0.5) [0.5 on Epop[12]], weight: 4.1363508E-4, delay 1.5
        h("Epop[12] syn_projEE_ampa[6172] = new ampa(0.5)")
        h("Epop[77] netConn_projEE_ampa[6172] = new NetCon(&v(0.5), syn_projEE_ampa[6172], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6173: cell 77, seg 0 (0.5) [0.5 on Epop[77]] -> cell 13, seg 0 (0.5) [0.5 on Epop[13]], weight: 4.1363508E-4, delay 1.5
        h("Epop[13] syn_projEE_ampa[6173] = new ampa(0.5)")
        h("Epop[77] netConn_projEE_ampa[6173] = new NetCon(&v(0.5), syn_projEE_ampa[6173], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6174: cell 77, seg 0 (0.5) [0.5 on Epop[77]] -> cell 14, seg 0 (0.5) [0.5 on Epop[14]], weight: 4.1363508E-4, delay 1.5
        h("Epop[14] syn_projEE_ampa[6174] = new ampa(0.5)")
        h("Epop[77] netConn_projEE_ampa[6174] = new NetCon(&v(0.5), syn_projEE_ampa[6174], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6175: cell 77, seg 0 (0.5) [0.5 on Epop[77]] -> cell 15, seg 0 (0.5) [0.5 on Epop[15]], weight: 4.1363508E-4, delay 1.5
        h("Epop[15] syn_projEE_ampa[6175] = new ampa(0.5)")
        h("Epop[77] netConn_projEE_ampa[6175] = new NetCon(&v(0.5), syn_projEE_ampa[6175], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6176: cell 77, seg 0 (0.5) [0.5 on Epop[77]] -> cell 16, seg 0 (0.5) [0.5 on Epop[16]], weight: 4.1363508E-4, delay 1.5
        h("Epop[16] syn_projEE_ampa[6176] = new ampa(0.5)")
        h("Epop[77] netConn_projEE_ampa[6176] = new NetCon(&v(0.5), syn_projEE_ampa[6176], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6177: cell 77, seg 0 (0.5) [0.5 on Epop[77]] -> cell 17, seg 0 (0.5) [0.5 on Epop[17]], weight: 4.1363508E-4, delay 1.5
        h("Epop[17] syn_projEE_ampa[6177] = new ampa(0.5)")
        h("Epop[77] netConn_projEE_ampa[6177] = new NetCon(&v(0.5), syn_projEE_ampa[6177], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6178: cell 77, seg 0 (0.5) [0.5 on Epop[77]] -> cell 18, seg 0 (0.5) [0.5 on Epop[18]], weight: 4.1363508E-4, delay 1.5
        h("Epop[18] syn_projEE_ampa[6178] = new ampa(0.5)")
        h("Epop[77] netConn_projEE_ampa[6178] = new NetCon(&v(0.5), syn_projEE_ampa[6178], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6179: cell 77, seg 0 (0.5) [0.5 on Epop[77]] -> cell 19, seg 0 (0.5) [0.5 on Epop[19]], weight: 4.1363508E-4, delay 1.5
        h("Epop[19] syn_projEE_ampa[6179] = new ampa(0.5)")
        h("Epop[77] netConn_projEE_ampa[6179] = new NetCon(&v(0.5), syn_projEE_ampa[6179], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6180: cell 77, seg 0 (0.5) [0.5 on Epop[77]] -> cell 20, seg 0 (0.5) [0.5 on Epop[20]], weight: 4.1363508E-4, delay 1.5
        h("Epop[20] syn_projEE_ampa[6180] = new ampa(0.5)")
        h("Epop[77] netConn_projEE_ampa[6180] = new NetCon(&v(0.5), syn_projEE_ampa[6180], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6181: cell 77, seg 0 (0.5) [0.5 on Epop[77]] -> cell 21, seg 0 (0.5) [0.5 on Epop[21]], weight: 4.1363508E-4, delay 1.5
        h("Epop[21] syn_projEE_ampa[6181] = new ampa(0.5)")
        h("Epop[77] netConn_projEE_ampa[6181] = new NetCon(&v(0.5), syn_projEE_ampa[6181], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6182: cell 77, seg 0 (0.5) [0.5 on Epop[77]] -> cell 22, seg 0 (0.5) [0.5 on Epop[22]], weight: 4.1363508E-4, delay 1.5
        h("Epop[22] syn_projEE_ampa[6182] = new ampa(0.5)")
        h("Epop[77] netConn_projEE_ampa[6182] = new NetCon(&v(0.5), syn_projEE_ampa[6182], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6183: cell 77, seg 0 (0.5) [0.5 on Epop[77]] -> cell 23, seg 0 (0.5) [0.5 on Epop[23]], weight: 4.1363508E-4, delay 1.5
        h("Epop[23] syn_projEE_ampa[6183] = new ampa(0.5)")
        h("Epop[77] netConn_projEE_ampa[6183] = new NetCon(&v(0.5), syn_projEE_ampa[6183], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6184: cell 77, seg 0 (0.5) [0.5 on Epop[77]] -> cell 24, seg 0 (0.5) [0.5 on Epop[24]], weight: 4.1363508E-4, delay 1.5
        h("Epop[24] syn_projEE_ampa[6184] = new ampa(0.5)")
        h("Epop[77] netConn_projEE_ampa[6184] = new NetCon(&v(0.5), syn_projEE_ampa[6184], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6185: cell 77, seg 0 (0.5) [0.5 on Epop[77]] -> cell 25, seg 0 (0.5) [0.5 on Epop[25]], weight: 4.1363508E-4, delay 1.5
        h("Epop[25] syn_projEE_ampa[6185] = new ampa(0.5)")
        h("Epop[77] netConn_projEE_ampa[6185] = new NetCon(&v(0.5), syn_projEE_ampa[6185], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6186: cell 77, seg 0 (0.5) [0.5 on Epop[77]] -> cell 26, seg 0 (0.5) [0.5 on Epop[26]], weight: 4.1363508E-4, delay 1.5
        h("Epop[26] syn_projEE_ampa[6186] = new ampa(0.5)")
        h("Epop[77] netConn_projEE_ampa[6186] = new NetCon(&v(0.5), syn_projEE_ampa[6186], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6187: cell 77, seg 0 (0.5) [0.5 on Epop[77]] -> cell 27, seg 0 (0.5) [0.5 on Epop[27]], weight: 4.1363508E-4, delay 1.5
        h("Epop[27] syn_projEE_ampa[6187] = new ampa(0.5)")
        h("Epop[77] netConn_projEE_ampa[6187] = new NetCon(&v(0.5), syn_projEE_ampa[6187], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6188: cell 77, seg 0 (0.5) [0.5 on Epop[77]] -> cell 28, seg 0 (0.5) [0.5 on Epop[28]], weight: 4.1363508E-4, delay 1.5
        h("Epop[28] syn_projEE_ampa[6188] = new ampa(0.5)")
        h("Epop[77] netConn_projEE_ampa[6188] = new NetCon(&v(0.5), syn_projEE_ampa[6188], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6189: cell 77, seg 0 (0.5) [0.5 on Epop[77]] -> cell 29, seg 0 (0.5) [0.5 on Epop[29]], weight: 4.1363508E-4, delay 1.5
        h("Epop[29] syn_projEE_ampa[6189] = new ampa(0.5)")
        h("Epop[77] netConn_projEE_ampa[6189] = new NetCon(&v(0.5), syn_projEE_ampa[6189], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6190: cell 77, seg 0 (0.5) [0.5 on Epop[77]] -> cell 30, seg 0 (0.5) [0.5 on Epop[30]], weight: 4.1363508E-4, delay 1.5
        h("Epop[30] syn_projEE_ampa[6190] = new ampa(0.5)")
        h("Epop[77] netConn_projEE_ampa[6190] = new NetCon(&v(0.5), syn_projEE_ampa[6190], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6191: cell 77, seg 0 (0.5) [0.5 on Epop[77]] -> cell 31, seg 0 (0.5) [0.5 on Epop[31]], weight: 4.1363508E-4, delay 1.5
        h("Epop[31] syn_projEE_ampa[6191] = new ampa(0.5)")
        h("Epop[77] netConn_projEE_ampa[6191] = new NetCon(&v(0.5), syn_projEE_ampa[6191], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6192: cell 77, seg 0 (0.5) [0.5 on Epop[77]] -> cell 32, seg 0 (0.5) [0.5 on Epop[32]], weight: 4.1363508E-4, delay 1.5
        h("Epop[32] syn_projEE_ampa[6192] = new ampa(0.5)")
        h("Epop[77] netConn_projEE_ampa[6192] = new NetCon(&v(0.5), syn_projEE_ampa[6192], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6193: cell 77, seg 0 (0.5) [0.5 on Epop[77]] -> cell 33, seg 0 (0.5) [0.5 on Epop[33]], weight: 4.1363508E-4, delay 1.5
        h("Epop[33] syn_projEE_ampa[6193] = new ampa(0.5)")
        h("Epop[77] netConn_projEE_ampa[6193] = new NetCon(&v(0.5), syn_projEE_ampa[6193], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6194: cell 77, seg 0 (0.5) [0.5 on Epop[77]] -> cell 34, seg 0 (0.5) [0.5 on Epop[34]], weight: 4.1363508E-4, delay 1.5
        h("Epop[34] syn_projEE_ampa[6194] = new ampa(0.5)")
        h("Epop[77] netConn_projEE_ampa[6194] = new NetCon(&v(0.5), syn_projEE_ampa[6194], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6195: cell 77, seg 0 (0.5) [0.5 on Epop[77]] -> cell 35, seg 0 (0.5) [0.5 on Epop[35]], weight: 4.1363508E-4, delay 1.5
        h("Epop[35] syn_projEE_ampa[6195] = new ampa(0.5)")
        h("Epop[77] netConn_projEE_ampa[6195] = new NetCon(&v(0.5), syn_projEE_ampa[6195], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6196: cell 77, seg 0 (0.5) [0.5 on Epop[77]] -> cell 36, seg 0 (0.5) [0.5 on Epop[36]], weight: 4.1363508E-4, delay 1.5
        h("Epop[36] syn_projEE_ampa[6196] = new ampa(0.5)")
        h("Epop[77] netConn_projEE_ampa[6196] = new NetCon(&v(0.5), syn_projEE_ampa[6196], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6197: cell 77, seg 0 (0.5) [0.5 on Epop[77]] -> cell 37, seg 0 (0.5) [0.5 on Epop[37]], weight: 4.1363508E-4, delay 1.5
        h("Epop[37] syn_projEE_ampa[6197] = new ampa(0.5)")
        h("Epop[77] netConn_projEE_ampa[6197] = new NetCon(&v(0.5), syn_projEE_ampa[6197], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6198: cell 77, seg 0 (0.5) [0.5 on Epop[77]] -> cell 38, seg 0 (0.5) [0.5 on Epop[38]], weight: 4.1363508E-4, delay 1.5
        h("Epop[38] syn_projEE_ampa[6198] = new ampa(0.5)")
        h("Epop[77] netConn_projEE_ampa[6198] = new NetCon(&v(0.5), syn_projEE_ampa[6198], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6199: cell 77, seg 0 (0.5) [0.5 on Epop[77]] -> cell 39, seg 0 (0.5) [0.5 on Epop[39]], weight: 4.1363508E-4, delay 1.5
        h("Epop[39] syn_projEE_ampa[6199] = new ampa(0.5)")
        h("Epop[77] netConn_projEE_ampa[6199] = new NetCon(&v(0.5), syn_projEE_ampa[6199], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6200: cell 77, seg 0 (0.5) [0.5 on Epop[77]] -> cell 40, seg 0 (0.5) [0.5 on Epop[40]], weight: 4.1363508E-4, delay 1.5
        h("Epop[40] syn_projEE_ampa[6200] = new ampa(0.5)")
        h("Epop[77] netConn_projEE_ampa[6200] = new NetCon(&v(0.5), syn_projEE_ampa[6200], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6201: cell 77, seg 0 (0.5) [0.5 on Epop[77]] -> cell 41, seg 0 (0.5) [0.5 on Epop[41]], weight: 4.1363508E-4, delay 1.5
        h("Epop[41] syn_projEE_ampa[6201] = new ampa(0.5)")
        h("Epop[77] netConn_projEE_ampa[6201] = new NetCon(&v(0.5), syn_projEE_ampa[6201], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6202: cell 77, seg 0 (0.5) [0.5 on Epop[77]] -> cell 42, seg 0 (0.5) [0.5 on Epop[42]], weight: 4.1363508E-4, delay 1.5
        h("Epop[42] syn_projEE_ampa[6202] = new ampa(0.5)")
        h("Epop[77] netConn_projEE_ampa[6202] = new NetCon(&v(0.5), syn_projEE_ampa[6202], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6203: cell 77, seg 0 (0.5) [0.5 on Epop[77]] -> cell 43, seg 0 (0.5) [0.5 on Epop[43]], weight: 4.1363508E-4, delay 1.5
        h("Epop[43] syn_projEE_ampa[6203] = new ampa(0.5)")
        h("Epop[77] netConn_projEE_ampa[6203] = new NetCon(&v(0.5), syn_projEE_ampa[6203], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6204: cell 77, seg 0 (0.5) [0.5 on Epop[77]] -> cell 44, seg 0 (0.5) [0.5 on Epop[44]], weight: 4.1363508E-4, delay 1.5
        h("Epop[44] syn_projEE_ampa[6204] = new ampa(0.5)")
        h("Epop[77] netConn_projEE_ampa[6204] = new NetCon(&v(0.5), syn_projEE_ampa[6204], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6205: cell 77, seg 0 (0.5) [0.5 on Epop[77]] -> cell 45, seg 0 (0.5) [0.5 on Epop[45]], weight: 4.1363508E-4, delay 1.5
        h("Epop[45] syn_projEE_ampa[6205] = new ampa(0.5)")
        h("Epop[77] netConn_projEE_ampa[6205] = new NetCon(&v(0.5), syn_projEE_ampa[6205], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6206: cell 77, seg 0 (0.5) [0.5 on Epop[77]] -> cell 46, seg 0 (0.5) [0.5 on Epop[46]], weight: 4.1363508E-4, delay 1.5
        h("Epop[46] syn_projEE_ampa[6206] = new ampa(0.5)")
        h("Epop[77] netConn_projEE_ampa[6206] = new NetCon(&v(0.5), syn_projEE_ampa[6206], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6207: cell 77, seg 0 (0.5) [0.5 on Epop[77]] -> cell 47, seg 0 (0.5) [0.5 on Epop[47]], weight: 4.1363508E-4, delay 1.5
        h("Epop[47] syn_projEE_ampa[6207] = new ampa(0.5)")
        h("Epop[77] netConn_projEE_ampa[6207] = new NetCon(&v(0.5), syn_projEE_ampa[6207], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6208: cell 77, seg 0 (0.5) [0.5 on Epop[77]] -> cell 48, seg 0 (0.5) [0.5 on Epop[48]], weight: 4.1363508E-4, delay 1.5
        h("Epop[48] syn_projEE_ampa[6208] = new ampa(0.5)")
        h("Epop[77] netConn_projEE_ampa[6208] = new NetCon(&v(0.5), syn_projEE_ampa[6208], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6209: cell 77, seg 0 (0.5) [0.5 on Epop[77]] -> cell 49, seg 0 (0.5) [0.5 on Epop[49]], weight: 4.1363508E-4, delay 1.5
        h("Epop[49] syn_projEE_ampa[6209] = new ampa(0.5)")
        h("Epop[77] netConn_projEE_ampa[6209] = new NetCon(&v(0.5), syn_projEE_ampa[6209], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6210: cell 77, seg 0 (0.5) [0.5 on Epop[77]] -> cell 50, seg 0 (0.5) [0.5 on Epop[50]], weight: 4.1363508E-4, delay 1.5
        h("Epop[50] syn_projEE_ampa[6210] = new ampa(0.5)")
        h("Epop[77] netConn_projEE_ampa[6210] = new NetCon(&v(0.5), syn_projEE_ampa[6210], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6211: cell 77, seg 0 (0.5) [0.5 on Epop[77]] -> cell 51, seg 0 (0.5) [0.5 on Epop[51]], weight: 4.1363508E-4, delay 1.5
        h("Epop[51] syn_projEE_ampa[6211] = new ampa(0.5)")
        h("Epop[77] netConn_projEE_ampa[6211] = new NetCon(&v(0.5), syn_projEE_ampa[6211], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6212: cell 77, seg 0 (0.5) [0.5 on Epop[77]] -> cell 52, seg 0 (0.5) [0.5 on Epop[52]], weight: 4.1363508E-4, delay 1.5
        h("Epop[52] syn_projEE_ampa[6212] = new ampa(0.5)")
        h("Epop[77] netConn_projEE_ampa[6212] = new NetCon(&v(0.5), syn_projEE_ampa[6212], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6213: cell 77, seg 0 (0.5) [0.5 on Epop[77]] -> cell 53, seg 0 (0.5) [0.5 on Epop[53]], weight: 4.1363508E-4, delay 1.5
        h("Epop[53] syn_projEE_ampa[6213] = new ampa(0.5)")
        h("Epop[77] netConn_projEE_ampa[6213] = new NetCon(&v(0.5), syn_projEE_ampa[6213], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6214: cell 77, seg 0 (0.5) [0.5 on Epop[77]] -> cell 54, seg 0 (0.5) [0.5 on Epop[54]], weight: 4.1363508E-4, delay 1.5
        h("Epop[54] syn_projEE_ampa[6214] = new ampa(0.5)")
        h("Epop[77] netConn_projEE_ampa[6214] = new NetCon(&v(0.5), syn_projEE_ampa[6214], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6215: cell 77, seg 0 (0.5) [0.5 on Epop[77]] -> cell 55, seg 0 (0.5) [0.5 on Epop[55]], weight: 4.1363508E-4, delay 1.5
        h("Epop[55] syn_projEE_ampa[6215] = new ampa(0.5)")
        h("Epop[77] netConn_projEE_ampa[6215] = new NetCon(&v(0.5), syn_projEE_ampa[6215], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6216: cell 77, seg 0 (0.5) [0.5 on Epop[77]] -> cell 56, seg 0 (0.5) [0.5 on Epop[56]], weight: 4.1363508E-4, delay 1.5
        h("Epop[56] syn_projEE_ampa[6216] = new ampa(0.5)")
        h("Epop[77] netConn_projEE_ampa[6216] = new NetCon(&v(0.5), syn_projEE_ampa[6216], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6217: cell 77, seg 0 (0.5) [0.5 on Epop[77]] -> cell 57, seg 0 (0.5) [0.5 on Epop[57]], weight: 4.1363508E-4, delay 1.5
        h("Epop[57] syn_projEE_ampa[6217] = new ampa(0.5)")
        h("Epop[77] netConn_projEE_ampa[6217] = new NetCon(&v(0.5), syn_projEE_ampa[6217], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6218: cell 77, seg 0 (0.5) [0.5 on Epop[77]] -> cell 58, seg 0 (0.5) [0.5 on Epop[58]], weight: 4.1363508E-4, delay 1.5
        h("Epop[58] syn_projEE_ampa[6218] = new ampa(0.5)")
        h("Epop[77] netConn_projEE_ampa[6218] = new NetCon(&v(0.5), syn_projEE_ampa[6218], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6219: cell 77, seg 0 (0.5) [0.5 on Epop[77]] -> cell 59, seg 0 (0.5) [0.5 on Epop[59]], weight: 4.1363508E-4, delay 1.5
        h("Epop[59] syn_projEE_ampa[6219] = new ampa(0.5)")
        h("Epop[77] netConn_projEE_ampa[6219] = new NetCon(&v(0.5), syn_projEE_ampa[6219], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6220: cell 77, seg 0 (0.5) [0.5 on Epop[77]] -> cell 60, seg 0 (0.5) [0.5 on Epop[60]], weight: 4.1363508E-4, delay 1.5
        h("Epop[60] syn_projEE_ampa[6220] = new ampa(0.5)")
        h("Epop[77] netConn_projEE_ampa[6220] = new NetCon(&v(0.5), syn_projEE_ampa[6220], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6221: cell 77, seg 0 (0.5) [0.5 on Epop[77]] -> cell 61, seg 0 (0.5) [0.5 on Epop[61]], weight: 4.1363508E-4, delay 1.5
        h("Epop[61] syn_projEE_ampa[6221] = new ampa(0.5)")
        h("Epop[77] netConn_projEE_ampa[6221] = new NetCon(&v(0.5), syn_projEE_ampa[6221], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6222: cell 77, seg 0 (0.5) [0.5 on Epop[77]] -> cell 62, seg 0 (0.5) [0.5 on Epop[62]], weight: 4.1363508E-4, delay 1.5
        h("Epop[62] syn_projEE_ampa[6222] = new ampa(0.5)")
        h("Epop[77] netConn_projEE_ampa[6222] = new NetCon(&v(0.5), syn_projEE_ampa[6222], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6223: cell 77, seg 0 (0.5) [0.5 on Epop[77]] -> cell 63, seg 0 (0.5) [0.5 on Epop[63]], weight: 4.1363508E-4, delay 1.5
        h("Epop[63] syn_projEE_ampa[6223] = new ampa(0.5)")
        h("Epop[77] netConn_projEE_ampa[6223] = new NetCon(&v(0.5), syn_projEE_ampa[6223], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6224: cell 77, seg 0 (0.5) [0.5 on Epop[77]] -> cell 64, seg 0 (0.5) [0.5 on Epop[64]], weight: 4.1363508E-4, delay 1.5
        h("Epop[64] syn_projEE_ampa[6224] = new ampa(0.5)")
        h("Epop[77] netConn_projEE_ampa[6224] = new NetCon(&v(0.5), syn_projEE_ampa[6224], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6225: cell 77, seg 0 (0.5) [0.5 on Epop[77]] -> cell 65, seg 0 (0.5) [0.5 on Epop[65]], weight: 4.1363508E-4, delay 1.5
        h("Epop[65] syn_projEE_ampa[6225] = new ampa(0.5)")
        h("Epop[77] netConn_projEE_ampa[6225] = new NetCon(&v(0.5), syn_projEE_ampa[6225], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6226: cell 77, seg 0 (0.5) [0.5 on Epop[77]] -> cell 66, seg 0 (0.5) [0.5 on Epop[66]], weight: 4.1363508E-4, delay 1.5
        h("Epop[66] syn_projEE_ampa[6226] = new ampa(0.5)")
        h("Epop[77] netConn_projEE_ampa[6226] = new NetCon(&v(0.5), syn_projEE_ampa[6226], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6227: cell 77, seg 0 (0.5) [0.5 on Epop[77]] -> cell 67, seg 0 (0.5) [0.5 on Epop[67]], weight: 4.1363508E-4, delay 1.5
        h("Epop[67] syn_projEE_ampa[6227] = new ampa(0.5)")
        h("Epop[77] netConn_projEE_ampa[6227] = new NetCon(&v(0.5), syn_projEE_ampa[6227], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6228: cell 77, seg 0 (0.5) [0.5 on Epop[77]] -> cell 68, seg 0 (0.5) [0.5 on Epop[68]], weight: 4.1363508E-4, delay 1.5
        h("Epop[68] syn_projEE_ampa[6228] = new ampa(0.5)")
        h("Epop[77] netConn_projEE_ampa[6228] = new NetCon(&v(0.5), syn_projEE_ampa[6228], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6229: cell 77, seg 0 (0.5) [0.5 on Epop[77]] -> cell 69, seg 0 (0.5) [0.5 on Epop[69]], weight: 4.1363508E-4, delay 1.5
        h("Epop[69] syn_projEE_ampa[6229] = new ampa(0.5)")
        h("Epop[77] netConn_projEE_ampa[6229] = new NetCon(&v(0.5), syn_projEE_ampa[6229], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6230: cell 77, seg 0 (0.5) [0.5 on Epop[77]] -> cell 70, seg 0 (0.5) [0.5 on Epop[70]], weight: 4.1363508E-4, delay 1.5
        h("Epop[70] syn_projEE_ampa[6230] = new ampa(0.5)")
        h("Epop[77] netConn_projEE_ampa[6230] = new NetCon(&v(0.5), syn_projEE_ampa[6230], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6231: cell 77, seg 0 (0.5) [0.5 on Epop[77]] -> cell 71, seg 0 (0.5) [0.5 on Epop[71]], weight: 4.1363508E-4, delay 1.5
        h("Epop[71] syn_projEE_ampa[6231] = new ampa(0.5)")
        h("Epop[77] netConn_projEE_ampa[6231] = new NetCon(&v(0.5), syn_projEE_ampa[6231], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6232: cell 77, seg 0 (0.5) [0.5 on Epop[77]] -> cell 72, seg 0 (0.5) [0.5 on Epop[72]], weight: 4.1363508E-4, delay 1.5
        h("Epop[72] syn_projEE_ampa[6232] = new ampa(0.5)")
        h("Epop[77] netConn_projEE_ampa[6232] = new NetCon(&v(0.5), syn_projEE_ampa[6232], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6233: cell 77, seg 0 (0.5) [0.5 on Epop[77]] -> cell 73, seg 0 (0.5) [0.5 on Epop[73]], weight: 4.1363508E-4, delay 1.5
        h("Epop[73] syn_projEE_ampa[6233] = new ampa(0.5)")
        h("Epop[77] netConn_projEE_ampa[6233] = new NetCon(&v(0.5), syn_projEE_ampa[6233], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6234: cell 77, seg 0 (0.5) [0.5 on Epop[77]] -> cell 74, seg 0 (0.5) [0.5 on Epop[74]], weight: 4.1363508E-4, delay 1.5
        h("Epop[74] syn_projEE_ampa[6234] = new ampa(0.5)")
        h("Epop[77] netConn_projEE_ampa[6234] = new NetCon(&v(0.5), syn_projEE_ampa[6234], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6235: cell 77, seg 0 (0.5) [0.5 on Epop[77]] -> cell 75, seg 0 (0.5) [0.5 on Epop[75]], weight: 4.1363508E-4, delay 1.5
        h("Epop[75] syn_projEE_ampa[6235] = new ampa(0.5)")
        h("Epop[77] netConn_projEE_ampa[6235] = new NetCon(&v(0.5), syn_projEE_ampa[6235], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6236: cell 77, seg 0 (0.5) [0.5 on Epop[77]] -> cell 76, seg 0 (0.5) [0.5 on Epop[76]], weight: 4.1363508E-4, delay 1.5
        h("Epop[76] syn_projEE_ampa[6236] = new ampa(0.5)")
        h("Epop[77] netConn_projEE_ampa[6236] = new NetCon(&v(0.5), syn_projEE_ampa[6236], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6237: cell 77, seg 0 (0.5) [0.5 on Epop[77]] -> cell 77, seg 0 (0.5) [0.5 on Epop[77]], weight: 4.1363508E-4, delay 1.5
        h("Epop[77] syn_projEE_ampa[6237] = new ampa(0.5)")
        h("Epop[77] netConn_projEE_ampa[6237] = new NetCon(&v(0.5), syn_projEE_ampa[6237], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6238: cell 77, seg 0 (0.5) [0.5 on Epop[77]] -> cell 78, seg 0 (0.5) [0.5 on Epop[78]], weight: 4.1363508E-4, delay 1.5
        h("Epop[78] syn_projEE_ampa[6238] = new ampa(0.5)")
        h("Epop[77] netConn_projEE_ampa[6238] = new NetCon(&v(0.5), syn_projEE_ampa[6238], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6239: cell 77, seg 0 (0.5) [0.5 on Epop[77]] -> cell 79, seg 0 (0.5) [0.5 on Epop[79]], weight: 4.1363508E-4, delay 1.5
        h("Epop[79] syn_projEE_ampa[6239] = new ampa(0.5)")
        h("Epop[77] netConn_projEE_ampa[6239] = new NetCon(&v(0.5), syn_projEE_ampa[6239], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6240: cell 78, seg 0 (0.5) [0.5 on Epop[78]] -> cell 0, seg 0 (0.5) [0.5 on Epop[0]], weight: 4.1363508E-4, delay 1.5
        h("Epop[0] syn_projEE_ampa[6240] = new ampa(0.5)")
        h("Epop[78] netConn_projEE_ampa[6240] = new NetCon(&v(0.5), syn_projEE_ampa[6240], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6241: cell 78, seg 0 (0.5) [0.5 on Epop[78]] -> cell 1, seg 0 (0.5) [0.5 on Epop[1]], weight: 4.1363508E-4, delay 1.5
        h("Epop[1] syn_projEE_ampa[6241] = new ampa(0.5)")
        h("Epop[78] netConn_projEE_ampa[6241] = new NetCon(&v(0.5), syn_projEE_ampa[6241], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6242: cell 78, seg 0 (0.5) [0.5 on Epop[78]] -> cell 2, seg 0 (0.5) [0.5 on Epop[2]], weight: 4.1363508E-4, delay 1.5
        h("Epop[2] syn_projEE_ampa[6242] = new ampa(0.5)")
        h("Epop[78] netConn_projEE_ampa[6242] = new NetCon(&v(0.5), syn_projEE_ampa[6242], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6243: cell 78, seg 0 (0.5) [0.5 on Epop[78]] -> cell 3, seg 0 (0.5) [0.5 on Epop[3]], weight: 4.1363508E-4, delay 1.5
        h("Epop[3] syn_projEE_ampa[6243] = new ampa(0.5)")
        h("Epop[78] netConn_projEE_ampa[6243] = new NetCon(&v(0.5), syn_projEE_ampa[6243], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6244: cell 78, seg 0 (0.5) [0.5 on Epop[78]] -> cell 4, seg 0 (0.5) [0.5 on Epop[4]], weight: 4.1363508E-4, delay 1.5
        h("Epop[4] syn_projEE_ampa[6244] = new ampa(0.5)")
        h("Epop[78] netConn_projEE_ampa[6244] = new NetCon(&v(0.5), syn_projEE_ampa[6244], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6245: cell 78, seg 0 (0.5) [0.5 on Epop[78]] -> cell 5, seg 0 (0.5) [0.5 on Epop[5]], weight: 4.1363508E-4, delay 1.5
        h("Epop[5] syn_projEE_ampa[6245] = new ampa(0.5)")
        h("Epop[78] netConn_projEE_ampa[6245] = new NetCon(&v(0.5), syn_projEE_ampa[6245], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6246: cell 78, seg 0 (0.5) [0.5 on Epop[78]] -> cell 6, seg 0 (0.5) [0.5 on Epop[6]], weight: 4.1363508E-4, delay 1.5
        h("Epop[6] syn_projEE_ampa[6246] = new ampa(0.5)")
        h("Epop[78] netConn_projEE_ampa[6246] = new NetCon(&v(0.5), syn_projEE_ampa[6246], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6247: cell 78, seg 0 (0.5) [0.5 on Epop[78]] -> cell 7, seg 0 (0.5) [0.5 on Epop[7]], weight: 4.1363508E-4, delay 1.5
        h("Epop[7] syn_projEE_ampa[6247] = new ampa(0.5)")
        h("Epop[78] netConn_projEE_ampa[6247] = new NetCon(&v(0.5), syn_projEE_ampa[6247], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6248: cell 78, seg 0 (0.5) [0.5 on Epop[78]] -> cell 8, seg 0 (0.5) [0.5 on Epop[8]], weight: 4.1363508E-4, delay 1.5
        h("Epop[8] syn_projEE_ampa[6248] = new ampa(0.5)")
        h("Epop[78] netConn_projEE_ampa[6248] = new NetCon(&v(0.5), syn_projEE_ampa[6248], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6249: cell 78, seg 0 (0.5) [0.5 on Epop[78]] -> cell 9, seg 0 (0.5) [0.5 on Epop[9]], weight: 4.1363508E-4, delay 1.5
        h("Epop[9] syn_projEE_ampa[6249] = new ampa(0.5)")
        h("Epop[78] netConn_projEE_ampa[6249] = new NetCon(&v(0.5), syn_projEE_ampa[6249], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6250: cell 78, seg 0 (0.5) [0.5 on Epop[78]] -> cell 10, seg 0 (0.5) [0.5 on Epop[10]], weight: 4.1363508E-4, delay 1.5
        h("Epop[10] syn_projEE_ampa[6250] = new ampa(0.5)")
        h("Epop[78] netConn_projEE_ampa[6250] = new NetCon(&v(0.5), syn_projEE_ampa[6250], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6251: cell 78, seg 0 (0.5) [0.5 on Epop[78]] -> cell 11, seg 0 (0.5) [0.5 on Epop[11]], weight: 4.1363508E-4, delay 1.5
        h("Epop[11] syn_projEE_ampa[6251] = new ampa(0.5)")
        h("Epop[78] netConn_projEE_ampa[6251] = new NetCon(&v(0.5), syn_projEE_ampa[6251], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6252: cell 78, seg 0 (0.5) [0.5 on Epop[78]] -> cell 12, seg 0 (0.5) [0.5 on Epop[12]], weight: 4.1363508E-4, delay 1.5
        h("Epop[12] syn_projEE_ampa[6252] = new ampa(0.5)")
        h("Epop[78] netConn_projEE_ampa[6252] = new NetCon(&v(0.5), syn_projEE_ampa[6252], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6253: cell 78, seg 0 (0.5) [0.5 on Epop[78]] -> cell 13, seg 0 (0.5) [0.5 on Epop[13]], weight: 4.1363508E-4, delay 1.5
        h("Epop[13] syn_projEE_ampa[6253] = new ampa(0.5)")
        h("Epop[78] netConn_projEE_ampa[6253] = new NetCon(&v(0.5), syn_projEE_ampa[6253], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6254: cell 78, seg 0 (0.5) [0.5 on Epop[78]] -> cell 14, seg 0 (0.5) [0.5 on Epop[14]], weight: 4.1363508E-4, delay 1.5
        h("Epop[14] syn_projEE_ampa[6254] = new ampa(0.5)")
        h("Epop[78] netConn_projEE_ampa[6254] = new NetCon(&v(0.5), syn_projEE_ampa[6254], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6255: cell 78, seg 0 (0.5) [0.5 on Epop[78]] -> cell 15, seg 0 (0.5) [0.5 on Epop[15]], weight: 4.1363508E-4, delay 1.5
        h("Epop[15] syn_projEE_ampa[6255] = new ampa(0.5)")
        h("Epop[78] netConn_projEE_ampa[6255] = new NetCon(&v(0.5), syn_projEE_ampa[6255], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6256: cell 78, seg 0 (0.5) [0.5 on Epop[78]] -> cell 16, seg 0 (0.5) [0.5 on Epop[16]], weight: 4.1363508E-4, delay 1.5
        h("Epop[16] syn_projEE_ampa[6256] = new ampa(0.5)")
        h("Epop[78] netConn_projEE_ampa[6256] = new NetCon(&v(0.5), syn_projEE_ampa[6256], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6257: cell 78, seg 0 (0.5) [0.5 on Epop[78]] -> cell 17, seg 0 (0.5) [0.5 on Epop[17]], weight: 4.1363508E-4, delay 1.5
        h("Epop[17] syn_projEE_ampa[6257] = new ampa(0.5)")
        h("Epop[78] netConn_projEE_ampa[6257] = new NetCon(&v(0.5), syn_projEE_ampa[6257], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6258: cell 78, seg 0 (0.5) [0.5 on Epop[78]] -> cell 18, seg 0 (0.5) [0.5 on Epop[18]], weight: 4.1363508E-4, delay 1.5
        h("Epop[18] syn_projEE_ampa[6258] = new ampa(0.5)")
        h("Epop[78] netConn_projEE_ampa[6258] = new NetCon(&v(0.5), syn_projEE_ampa[6258], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6259: cell 78, seg 0 (0.5) [0.5 on Epop[78]] -> cell 19, seg 0 (0.5) [0.5 on Epop[19]], weight: 4.1363508E-4, delay 1.5
        h("Epop[19] syn_projEE_ampa[6259] = new ampa(0.5)")
        h("Epop[78] netConn_projEE_ampa[6259] = new NetCon(&v(0.5), syn_projEE_ampa[6259], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6260: cell 78, seg 0 (0.5) [0.5 on Epop[78]] -> cell 20, seg 0 (0.5) [0.5 on Epop[20]], weight: 4.1363508E-4, delay 1.5
        h("Epop[20] syn_projEE_ampa[6260] = new ampa(0.5)")
        h("Epop[78] netConn_projEE_ampa[6260] = new NetCon(&v(0.5), syn_projEE_ampa[6260], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6261: cell 78, seg 0 (0.5) [0.5 on Epop[78]] -> cell 21, seg 0 (0.5) [0.5 on Epop[21]], weight: 4.1363508E-4, delay 1.5
        h("Epop[21] syn_projEE_ampa[6261] = new ampa(0.5)")
        h("Epop[78] netConn_projEE_ampa[6261] = new NetCon(&v(0.5), syn_projEE_ampa[6261], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6262: cell 78, seg 0 (0.5) [0.5 on Epop[78]] -> cell 22, seg 0 (0.5) [0.5 on Epop[22]], weight: 4.1363508E-4, delay 1.5
        h("Epop[22] syn_projEE_ampa[6262] = new ampa(0.5)")
        h("Epop[78] netConn_projEE_ampa[6262] = new NetCon(&v(0.5), syn_projEE_ampa[6262], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6263: cell 78, seg 0 (0.5) [0.5 on Epop[78]] -> cell 23, seg 0 (0.5) [0.5 on Epop[23]], weight: 4.1363508E-4, delay 1.5
        h("Epop[23] syn_projEE_ampa[6263] = new ampa(0.5)")
        h("Epop[78] netConn_projEE_ampa[6263] = new NetCon(&v(0.5), syn_projEE_ampa[6263], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6264: cell 78, seg 0 (0.5) [0.5 on Epop[78]] -> cell 24, seg 0 (0.5) [0.5 on Epop[24]], weight: 4.1363508E-4, delay 1.5
        h("Epop[24] syn_projEE_ampa[6264] = new ampa(0.5)")
        h("Epop[78] netConn_projEE_ampa[6264] = new NetCon(&v(0.5), syn_projEE_ampa[6264], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6265: cell 78, seg 0 (0.5) [0.5 on Epop[78]] -> cell 25, seg 0 (0.5) [0.5 on Epop[25]], weight: 4.1363508E-4, delay 1.5
        h("Epop[25] syn_projEE_ampa[6265] = new ampa(0.5)")
        h("Epop[78] netConn_projEE_ampa[6265] = new NetCon(&v(0.5), syn_projEE_ampa[6265], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6266: cell 78, seg 0 (0.5) [0.5 on Epop[78]] -> cell 26, seg 0 (0.5) [0.5 on Epop[26]], weight: 4.1363508E-4, delay 1.5
        h("Epop[26] syn_projEE_ampa[6266] = new ampa(0.5)")
        h("Epop[78] netConn_projEE_ampa[6266] = new NetCon(&v(0.5), syn_projEE_ampa[6266], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6267: cell 78, seg 0 (0.5) [0.5 on Epop[78]] -> cell 27, seg 0 (0.5) [0.5 on Epop[27]], weight: 4.1363508E-4, delay 1.5
        h("Epop[27] syn_projEE_ampa[6267] = new ampa(0.5)")
        h("Epop[78] netConn_projEE_ampa[6267] = new NetCon(&v(0.5), syn_projEE_ampa[6267], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6268: cell 78, seg 0 (0.5) [0.5 on Epop[78]] -> cell 28, seg 0 (0.5) [0.5 on Epop[28]], weight: 4.1363508E-4, delay 1.5
        h("Epop[28] syn_projEE_ampa[6268] = new ampa(0.5)")
        h("Epop[78] netConn_projEE_ampa[6268] = new NetCon(&v(0.5), syn_projEE_ampa[6268], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6269: cell 78, seg 0 (0.5) [0.5 on Epop[78]] -> cell 29, seg 0 (0.5) [0.5 on Epop[29]], weight: 4.1363508E-4, delay 1.5
        h("Epop[29] syn_projEE_ampa[6269] = new ampa(0.5)")
        h("Epop[78] netConn_projEE_ampa[6269] = new NetCon(&v(0.5), syn_projEE_ampa[6269], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6270: cell 78, seg 0 (0.5) [0.5 on Epop[78]] -> cell 30, seg 0 (0.5) [0.5 on Epop[30]], weight: 4.1363508E-4, delay 1.5
        h("Epop[30] syn_projEE_ampa[6270] = new ampa(0.5)")
        h("Epop[78] netConn_projEE_ampa[6270] = new NetCon(&v(0.5), syn_projEE_ampa[6270], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6271: cell 78, seg 0 (0.5) [0.5 on Epop[78]] -> cell 31, seg 0 (0.5) [0.5 on Epop[31]], weight: 4.1363508E-4, delay 1.5
        h("Epop[31] syn_projEE_ampa[6271] = new ampa(0.5)")
        h("Epop[78] netConn_projEE_ampa[6271] = new NetCon(&v(0.5), syn_projEE_ampa[6271], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6272: cell 78, seg 0 (0.5) [0.5 on Epop[78]] -> cell 32, seg 0 (0.5) [0.5 on Epop[32]], weight: 4.1363508E-4, delay 1.5
        h("Epop[32] syn_projEE_ampa[6272] = new ampa(0.5)")
        h("Epop[78] netConn_projEE_ampa[6272] = new NetCon(&v(0.5), syn_projEE_ampa[6272], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6273: cell 78, seg 0 (0.5) [0.5 on Epop[78]] -> cell 33, seg 0 (0.5) [0.5 on Epop[33]], weight: 4.1363508E-4, delay 1.5
        h("Epop[33] syn_projEE_ampa[6273] = new ampa(0.5)")
        h("Epop[78] netConn_projEE_ampa[6273] = new NetCon(&v(0.5), syn_projEE_ampa[6273], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6274: cell 78, seg 0 (0.5) [0.5 on Epop[78]] -> cell 34, seg 0 (0.5) [0.5 on Epop[34]], weight: 4.1363508E-4, delay 1.5
        h("Epop[34] syn_projEE_ampa[6274] = new ampa(0.5)")
        h("Epop[78] netConn_projEE_ampa[6274] = new NetCon(&v(0.5), syn_projEE_ampa[6274], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6275: cell 78, seg 0 (0.5) [0.5 on Epop[78]] -> cell 35, seg 0 (0.5) [0.5 on Epop[35]], weight: 4.1363508E-4, delay 1.5
        h("Epop[35] syn_projEE_ampa[6275] = new ampa(0.5)")
        h("Epop[78] netConn_projEE_ampa[6275] = new NetCon(&v(0.5), syn_projEE_ampa[6275], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6276: cell 78, seg 0 (0.5) [0.5 on Epop[78]] -> cell 36, seg 0 (0.5) [0.5 on Epop[36]], weight: 4.1363508E-4, delay 1.5
        h("Epop[36] syn_projEE_ampa[6276] = new ampa(0.5)")
        h("Epop[78] netConn_projEE_ampa[6276] = new NetCon(&v(0.5), syn_projEE_ampa[6276], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6277: cell 78, seg 0 (0.5) [0.5 on Epop[78]] -> cell 37, seg 0 (0.5) [0.5 on Epop[37]], weight: 4.1363508E-4, delay 1.5
        h("Epop[37] syn_projEE_ampa[6277] = new ampa(0.5)")
        h("Epop[78] netConn_projEE_ampa[6277] = new NetCon(&v(0.5), syn_projEE_ampa[6277], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6278: cell 78, seg 0 (0.5) [0.5 on Epop[78]] -> cell 38, seg 0 (0.5) [0.5 on Epop[38]], weight: 4.1363508E-4, delay 1.5
        h("Epop[38] syn_projEE_ampa[6278] = new ampa(0.5)")
        h("Epop[78] netConn_projEE_ampa[6278] = new NetCon(&v(0.5), syn_projEE_ampa[6278], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6279: cell 78, seg 0 (0.5) [0.5 on Epop[78]] -> cell 39, seg 0 (0.5) [0.5 on Epop[39]], weight: 4.1363508E-4, delay 1.5
        h("Epop[39] syn_projEE_ampa[6279] = new ampa(0.5)")
        h("Epop[78] netConn_projEE_ampa[6279] = new NetCon(&v(0.5), syn_projEE_ampa[6279], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6280: cell 78, seg 0 (0.5) [0.5 on Epop[78]] -> cell 40, seg 0 (0.5) [0.5 on Epop[40]], weight: 4.1363508E-4, delay 1.5
        h("Epop[40] syn_projEE_ampa[6280] = new ampa(0.5)")
        h("Epop[78] netConn_projEE_ampa[6280] = new NetCon(&v(0.5), syn_projEE_ampa[6280], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6281: cell 78, seg 0 (0.5) [0.5 on Epop[78]] -> cell 41, seg 0 (0.5) [0.5 on Epop[41]], weight: 4.1363508E-4, delay 1.5
        h("Epop[41] syn_projEE_ampa[6281] = new ampa(0.5)")
        h("Epop[78] netConn_projEE_ampa[6281] = new NetCon(&v(0.5), syn_projEE_ampa[6281], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6282: cell 78, seg 0 (0.5) [0.5 on Epop[78]] -> cell 42, seg 0 (0.5) [0.5 on Epop[42]], weight: 4.1363508E-4, delay 1.5
        h("Epop[42] syn_projEE_ampa[6282] = new ampa(0.5)")
        h("Epop[78] netConn_projEE_ampa[6282] = new NetCon(&v(0.5), syn_projEE_ampa[6282], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6283: cell 78, seg 0 (0.5) [0.5 on Epop[78]] -> cell 43, seg 0 (0.5) [0.5 on Epop[43]], weight: 4.1363508E-4, delay 1.5
        h("Epop[43] syn_projEE_ampa[6283] = new ampa(0.5)")
        h("Epop[78] netConn_projEE_ampa[6283] = new NetCon(&v(0.5), syn_projEE_ampa[6283], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6284: cell 78, seg 0 (0.5) [0.5 on Epop[78]] -> cell 44, seg 0 (0.5) [0.5 on Epop[44]], weight: 4.1363508E-4, delay 1.5
        h("Epop[44] syn_projEE_ampa[6284] = new ampa(0.5)")
        h("Epop[78] netConn_projEE_ampa[6284] = new NetCon(&v(0.5), syn_projEE_ampa[6284], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6285: cell 78, seg 0 (0.5) [0.5 on Epop[78]] -> cell 45, seg 0 (0.5) [0.5 on Epop[45]], weight: 4.1363508E-4, delay 1.5
        h("Epop[45] syn_projEE_ampa[6285] = new ampa(0.5)")
        h("Epop[78] netConn_projEE_ampa[6285] = new NetCon(&v(0.5), syn_projEE_ampa[6285], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6286: cell 78, seg 0 (0.5) [0.5 on Epop[78]] -> cell 46, seg 0 (0.5) [0.5 on Epop[46]], weight: 4.1363508E-4, delay 1.5
        h("Epop[46] syn_projEE_ampa[6286] = new ampa(0.5)")
        h("Epop[78] netConn_projEE_ampa[6286] = new NetCon(&v(0.5), syn_projEE_ampa[6286], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6287: cell 78, seg 0 (0.5) [0.5 on Epop[78]] -> cell 47, seg 0 (0.5) [0.5 on Epop[47]], weight: 4.1363508E-4, delay 1.5
        h("Epop[47] syn_projEE_ampa[6287] = new ampa(0.5)")
        h("Epop[78] netConn_projEE_ampa[6287] = new NetCon(&v(0.5), syn_projEE_ampa[6287], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6288: cell 78, seg 0 (0.5) [0.5 on Epop[78]] -> cell 48, seg 0 (0.5) [0.5 on Epop[48]], weight: 4.1363508E-4, delay 1.5
        h("Epop[48] syn_projEE_ampa[6288] = new ampa(0.5)")
        h("Epop[78] netConn_projEE_ampa[6288] = new NetCon(&v(0.5), syn_projEE_ampa[6288], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6289: cell 78, seg 0 (0.5) [0.5 on Epop[78]] -> cell 49, seg 0 (0.5) [0.5 on Epop[49]], weight: 4.1363508E-4, delay 1.5
        h("Epop[49] syn_projEE_ampa[6289] = new ampa(0.5)")
        h("Epop[78] netConn_projEE_ampa[6289] = new NetCon(&v(0.5), syn_projEE_ampa[6289], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6290: cell 78, seg 0 (0.5) [0.5 on Epop[78]] -> cell 50, seg 0 (0.5) [0.5 on Epop[50]], weight: 4.1363508E-4, delay 1.5
        h("Epop[50] syn_projEE_ampa[6290] = new ampa(0.5)")
        h("Epop[78] netConn_projEE_ampa[6290] = new NetCon(&v(0.5), syn_projEE_ampa[6290], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6291: cell 78, seg 0 (0.5) [0.5 on Epop[78]] -> cell 51, seg 0 (0.5) [0.5 on Epop[51]], weight: 4.1363508E-4, delay 1.5
        h("Epop[51] syn_projEE_ampa[6291] = new ampa(0.5)")
        h("Epop[78] netConn_projEE_ampa[6291] = new NetCon(&v(0.5), syn_projEE_ampa[6291], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6292: cell 78, seg 0 (0.5) [0.5 on Epop[78]] -> cell 52, seg 0 (0.5) [0.5 on Epop[52]], weight: 4.1363508E-4, delay 1.5
        h("Epop[52] syn_projEE_ampa[6292] = new ampa(0.5)")
        h("Epop[78] netConn_projEE_ampa[6292] = new NetCon(&v(0.5), syn_projEE_ampa[6292], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6293: cell 78, seg 0 (0.5) [0.5 on Epop[78]] -> cell 53, seg 0 (0.5) [0.5 on Epop[53]], weight: 4.1363508E-4, delay 1.5
        h("Epop[53] syn_projEE_ampa[6293] = new ampa(0.5)")
        h("Epop[78] netConn_projEE_ampa[6293] = new NetCon(&v(0.5), syn_projEE_ampa[6293], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6294: cell 78, seg 0 (0.5) [0.5 on Epop[78]] -> cell 54, seg 0 (0.5) [0.5 on Epop[54]], weight: 4.1363508E-4, delay 1.5
        h("Epop[54] syn_projEE_ampa[6294] = new ampa(0.5)")
        h("Epop[78] netConn_projEE_ampa[6294] = new NetCon(&v(0.5), syn_projEE_ampa[6294], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6295: cell 78, seg 0 (0.5) [0.5 on Epop[78]] -> cell 55, seg 0 (0.5) [0.5 on Epop[55]], weight: 4.1363508E-4, delay 1.5
        h("Epop[55] syn_projEE_ampa[6295] = new ampa(0.5)")
        h("Epop[78] netConn_projEE_ampa[6295] = new NetCon(&v(0.5), syn_projEE_ampa[6295], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6296: cell 78, seg 0 (0.5) [0.5 on Epop[78]] -> cell 56, seg 0 (0.5) [0.5 on Epop[56]], weight: 4.1363508E-4, delay 1.5
        h("Epop[56] syn_projEE_ampa[6296] = new ampa(0.5)")
        h("Epop[78] netConn_projEE_ampa[6296] = new NetCon(&v(0.5), syn_projEE_ampa[6296], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6297: cell 78, seg 0 (0.5) [0.5 on Epop[78]] -> cell 57, seg 0 (0.5) [0.5 on Epop[57]], weight: 4.1363508E-4, delay 1.5
        h("Epop[57] syn_projEE_ampa[6297] = new ampa(0.5)")
        h("Epop[78] netConn_projEE_ampa[6297] = new NetCon(&v(0.5), syn_projEE_ampa[6297], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6298: cell 78, seg 0 (0.5) [0.5 on Epop[78]] -> cell 58, seg 0 (0.5) [0.5 on Epop[58]], weight: 4.1363508E-4, delay 1.5
        h("Epop[58] syn_projEE_ampa[6298] = new ampa(0.5)")
        h("Epop[78] netConn_projEE_ampa[6298] = new NetCon(&v(0.5), syn_projEE_ampa[6298], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6299: cell 78, seg 0 (0.5) [0.5 on Epop[78]] -> cell 59, seg 0 (0.5) [0.5 on Epop[59]], weight: 4.1363508E-4, delay 1.5
        h("Epop[59] syn_projEE_ampa[6299] = new ampa(0.5)")
        h("Epop[78] netConn_projEE_ampa[6299] = new NetCon(&v(0.5), syn_projEE_ampa[6299], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6300: cell 78, seg 0 (0.5) [0.5 on Epop[78]] -> cell 60, seg 0 (0.5) [0.5 on Epop[60]], weight: 4.1363508E-4, delay 1.5
        h("Epop[60] syn_projEE_ampa[6300] = new ampa(0.5)")
        h("Epop[78] netConn_projEE_ampa[6300] = new NetCon(&v(0.5), syn_projEE_ampa[6300], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6301: cell 78, seg 0 (0.5) [0.5 on Epop[78]] -> cell 61, seg 0 (0.5) [0.5 on Epop[61]], weight: 4.1363508E-4, delay 1.5
        h("Epop[61] syn_projEE_ampa[6301] = new ampa(0.5)")
        h("Epop[78] netConn_projEE_ampa[6301] = new NetCon(&v(0.5), syn_projEE_ampa[6301], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6302: cell 78, seg 0 (0.5) [0.5 on Epop[78]] -> cell 62, seg 0 (0.5) [0.5 on Epop[62]], weight: 4.1363508E-4, delay 1.5
        h("Epop[62] syn_projEE_ampa[6302] = new ampa(0.5)")
        h("Epop[78] netConn_projEE_ampa[6302] = new NetCon(&v(0.5), syn_projEE_ampa[6302], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6303: cell 78, seg 0 (0.5) [0.5 on Epop[78]] -> cell 63, seg 0 (0.5) [0.5 on Epop[63]], weight: 4.1363508E-4, delay 1.5
        h("Epop[63] syn_projEE_ampa[6303] = new ampa(0.5)")
        h("Epop[78] netConn_projEE_ampa[6303] = new NetCon(&v(0.5), syn_projEE_ampa[6303], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6304: cell 78, seg 0 (0.5) [0.5 on Epop[78]] -> cell 64, seg 0 (0.5) [0.5 on Epop[64]], weight: 4.1363508E-4, delay 1.5
        h("Epop[64] syn_projEE_ampa[6304] = new ampa(0.5)")
        h("Epop[78] netConn_projEE_ampa[6304] = new NetCon(&v(0.5), syn_projEE_ampa[6304], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6305: cell 78, seg 0 (0.5) [0.5 on Epop[78]] -> cell 65, seg 0 (0.5) [0.5 on Epop[65]], weight: 4.1363508E-4, delay 1.5
        h("Epop[65] syn_projEE_ampa[6305] = new ampa(0.5)")
        h("Epop[78] netConn_projEE_ampa[6305] = new NetCon(&v(0.5), syn_projEE_ampa[6305], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6306: cell 78, seg 0 (0.5) [0.5 on Epop[78]] -> cell 66, seg 0 (0.5) [0.5 on Epop[66]], weight: 4.1363508E-4, delay 1.5
        h("Epop[66] syn_projEE_ampa[6306] = new ampa(0.5)")
        h("Epop[78] netConn_projEE_ampa[6306] = new NetCon(&v(0.5), syn_projEE_ampa[6306], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6307: cell 78, seg 0 (0.5) [0.5 on Epop[78]] -> cell 67, seg 0 (0.5) [0.5 on Epop[67]], weight: 4.1363508E-4, delay 1.5
        h("Epop[67] syn_projEE_ampa[6307] = new ampa(0.5)")
        h("Epop[78] netConn_projEE_ampa[6307] = new NetCon(&v(0.5), syn_projEE_ampa[6307], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6308: cell 78, seg 0 (0.5) [0.5 on Epop[78]] -> cell 68, seg 0 (0.5) [0.5 on Epop[68]], weight: 4.1363508E-4, delay 1.5
        h("Epop[68] syn_projEE_ampa[6308] = new ampa(0.5)")
        h("Epop[78] netConn_projEE_ampa[6308] = new NetCon(&v(0.5), syn_projEE_ampa[6308], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6309: cell 78, seg 0 (0.5) [0.5 on Epop[78]] -> cell 69, seg 0 (0.5) [0.5 on Epop[69]], weight: 4.1363508E-4, delay 1.5
        h("Epop[69] syn_projEE_ampa[6309] = new ampa(0.5)")
        h("Epop[78] netConn_projEE_ampa[6309] = new NetCon(&v(0.5), syn_projEE_ampa[6309], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6310: cell 78, seg 0 (0.5) [0.5 on Epop[78]] -> cell 70, seg 0 (0.5) [0.5 on Epop[70]], weight: 4.1363508E-4, delay 1.5
        h("Epop[70] syn_projEE_ampa[6310] = new ampa(0.5)")
        h("Epop[78] netConn_projEE_ampa[6310] = new NetCon(&v(0.5), syn_projEE_ampa[6310], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6311: cell 78, seg 0 (0.5) [0.5 on Epop[78]] -> cell 71, seg 0 (0.5) [0.5 on Epop[71]], weight: 4.1363508E-4, delay 1.5
        h("Epop[71] syn_projEE_ampa[6311] = new ampa(0.5)")
        h("Epop[78] netConn_projEE_ampa[6311] = new NetCon(&v(0.5), syn_projEE_ampa[6311], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6312: cell 78, seg 0 (0.5) [0.5 on Epop[78]] -> cell 72, seg 0 (0.5) [0.5 on Epop[72]], weight: 4.1363508E-4, delay 1.5
        h("Epop[72] syn_projEE_ampa[6312] = new ampa(0.5)")
        h("Epop[78] netConn_projEE_ampa[6312] = new NetCon(&v(0.5), syn_projEE_ampa[6312], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6313: cell 78, seg 0 (0.5) [0.5 on Epop[78]] -> cell 73, seg 0 (0.5) [0.5 on Epop[73]], weight: 4.1363508E-4, delay 1.5
        h("Epop[73] syn_projEE_ampa[6313] = new ampa(0.5)")
        h("Epop[78] netConn_projEE_ampa[6313] = new NetCon(&v(0.5), syn_projEE_ampa[6313], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6314: cell 78, seg 0 (0.5) [0.5 on Epop[78]] -> cell 74, seg 0 (0.5) [0.5 on Epop[74]], weight: 4.1363508E-4, delay 1.5
        h("Epop[74] syn_projEE_ampa[6314] = new ampa(0.5)")
        h("Epop[78] netConn_projEE_ampa[6314] = new NetCon(&v(0.5), syn_projEE_ampa[6314], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6315: cell 78, seg 0 (0.5) [0.5 on Epop[78]] -> cell 75, seg 0 (0.5) [0.5 on Epop[75]], weight: 4.1363508E-4, delay 1.5
        h("Epop[75] syn_projEE_ampa[6315] = new ampa(0.5)")
        h("Epop[78] netConn_projEE_ampa[6315] = new NetCon(&v(0.5), syn_projEE_ampa[6315], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6316: cell 78, seg 0 (0.5) [0.5 on Epop[78]] -> cell 76, seg 0 (0.5) [0.5 on Epop[76]], weight: 4.1363508E-4, delay 1.5
        h("Epop[76] syn_projEE_ampa[6316] = new ampa(0.5)")
        h("Epop[78] netConn_projEE_ampa[6316] = new NetCon(&v(0.5), syn_projEE_ampa[6316], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6317: cell 78, seg 0 (0.5) [0.5 on Epop[78]] -> cell 77, seg 0 (0.5) [0.5 on Epop[77]], weight: 4.1363508E-4, delay 1.5
        h("Epop[77] syn_projEE_ampa[6317] = new ampa(0.5)")
        h("Epop[78] netConn_projEE_ampa[6317] = new NetCon(&v(0.5), syn_projEE_ampa[6317], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6318: cell 78, seg 0 (0.5) [0.5 on Epop[78]] -> cell 78, seg 0 (0.5) [0.5 on Epop[78]], weight: 4.1363508E-4, delay 1.5
        h("Epop[78] syn_projEE_ampa[6318] = new ampa(0.5)")
        h("Epop[78] netConn_projEE_ampa[6318] = new NetCon(&v(0.5), syn_projEE_ampa[6318], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6319: cell 78, seg 0 (0.5) [0.5 on Epop[78]] -> cell 79, seg 0 (0.5) [0.5 on Epop[79]], weight: 4.1363508E-4, delay 1.5
        h("Epop[79] syn_projEE_ampa[6319] = new ampa(0.5)")
        h("Epop[78] netConn_projEE_ampa[6319] = new NetCon(&v(0.5), syn_projEE_ampa[6319], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6320: cell 79, seg 0 (0.5) [0.5 on Epop[79]] -> cell 0, seg 0 (0.5) [0.5 on Epop[0]], weight: 4.1363508E-4, delay 1.5
        h("Epop[0] syn_projEE_ampa[6320] = new ampa(0.5)")
        h("Epop[79] netConn_projEE_ampa[6320] = new NetCon(&v(0.5), syn_projEE_ampa[6320], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6321: cell 79, seg 0 (0.5) [0.5 on Epop[79]] -> cell 1, seg 0 (0.5) [0.5 on Epop[1]], weight: 4.1363508E-4, delay 1.5
        h("Epop[1] syn_projEE_ampa[6321] = new ampa(0.5)")
        h("Epop[79] netConn_projEE_ampa[6321] = new NetCon(&v(0.5), syn_projEE_ampa[6321], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6322: cell 79, seg 0 (0.5) [0.5 on Epop[79]] -> cell 2, seg 0 (0.5) [0.5 on Epop[2]], weight: 4.1363508E-4, delay 1.5
        h("Epop[2] syn_projEE_ampa[6322] = new ampa(0.5)")
        h("Epop[79] netConn_projEE_ampa[6322] = new NetCon(&v(0.5), syn_projEE_ampa[6322], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6323: cell 79, seg 0 (0.5) [0.5 on Epop[79]] -> cell 3, seg 0 (0.5) [0.5 on Epop[3]], weight: 4.1363508E-4, delay 1.5
        h("Epop[3] syn_projEE_ampa[6323] = new ampa(0.5)")
        h("Epop[79] netConn_projEE_ampa[6323] = new NetCon(&v(0.5), syn_projEE_ampa[6323], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6324: cell 79, seg 0 (0.5) [0.5 on Epop[79]] -> cell 4, seg 0 (0.5) [0.5 on Epop[4]], weight: 4.1363508E-4, delay 1.5
        h("Epop[4] syn_projEE_ampa[6324] = new ampa(0.5)")
        h("Epop[79] netConn_projEE_ampa[6324] = new NetCon(&v(0.5), syn_projEE_ampa[6324], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6325: cell 79, seg 0 (0.5) [0.5 on Epop[79]] -> cell 5, seg 0 (0.5) [0.5 on Epop[5]], weight: 4.1363508E-4, delay 1.5
        h("Epop[5] syn_projEE_ampa[6325] = new ampa(0.5)")
        h("Epop[79] netConn_projEE_ampa[6325] = new NetCon(&v(0.5), syn_projEE_ampa[6325], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6326: cell 79, seg 0 (0.5) [0.5 on Epop[79]] -> cell 6, seg 0 (0.5) [0.5 on Epop[6]], weight: 4.1363508E-4, delay 1.5
        h("Epop[6] syn_projEE_ampa[6326] = new ampa(0.5)")
        h("Epop[79] netConn_projEE_ampa[6326] = new NetCon(&v(0.5), syn_projEE_ampa[6326], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6327: cell 79, seg 0 (0.5) [0.5 on Epop[79]] -> cell 7, seg 0 (0.5) [0.5 on Epop[7]], weight: 4.1363508E-4, delay 1.5
        h("Epop[7] syn_projEE_ampa[6327] = new ampa(0.5)")
        h("Epop[79] netConn_projEE_ampa[6327] = new NetCon(&v(0.5), syn_projEE_ampa[6327], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6328: cell 79, seg 0 (0.5) [0.5 on Epop[79]] -> cell 8, seg 0 (0.5) [0.5 on Epop[8]], weight: 4.1363508E-4, delay 1.5
        h("Epop[8] syn_projEE_ampa[6328] = new ampa(0.5)")
        h("Epop[79] netConn_projEE_ampa[6328] = new NetCon(&v(0.5), syn_projEE_ampa[6328], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6329: cell 79, seg 0 (0.5) [0.5 on Epop[79]] -> cell 9, seg 0 (0.5) [0.5 on Epop[9]], weight: 4.1363508E-4, delay 1.5
        h("Epop[9] syn_projEE_ampa[6329] = new ampa(0.5)")
        h("Epop[79] netConn_projEE_ampa[6329] = new NetCon(&v(0.5), syn_projEE_ampa[6329], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6330: cell 79, seg 0 (0.5) [0.5 on Epop[79]] -> cell 10, seg 0 (0.5) [0.5 on Epop[10]], weight: 4.1363508E-4, delay 1.5
        h("Epop[10] syn_projEE_ampa[6330] = new ampa(0.5)")
        h("Epop[79] netConn_projEE_ampa[6330] = new NetCon(&v(0.5), syn_projEE_ampa[6330], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6331: cell 79, seg 0 (0.5) [0.5 on Epop[79]] -> cell 11, seg 0 (0.5) [0.5 on Epop[11]], weight: 4.1363508E-4, delay 1.5
        h("Epop[11] syn_projEE_ampa[6331] = new ampa(0.5)")
        h("Epop[79] netConn_projEE_ampa[6331] = new NetCon(&v(0.5), syn_projEE_ampa[6331], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6332: cell 79, seg 0 (0.5) [0.5 on Epop[79]] -> cell 12, seg 0 (0.5) [0.5 on Epop[12]], weight: 4.1363508E-4, delay 1.5
        h("Epop[12] syn_projEE_ampa[6332] = new ampa(0.5)")
        h("Epop[79] netConn_projEE_ampa[6332] = new NetCon(&v(0.5), syn_projEE_ampa[6332], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6333: cell 79, seg 0 (0.5) [0.5 on Epop[79]] -> cell 13, seg 0 (0.5) [0.5 on Epop[13]], weight: 4.1363508E-4, delay 1.5
        h("Epop[13] syn_projEE_ampa[6333] = new ampa(0.5)")
        h("Epop[79] netConn_projEE_ampa[6333] = new NetCon(&v(0.5), syn_projEE_ampa[6333], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6334: cell 79, seg 0 (0.5) [0.5 on Epop[79]] -> cell 14, seg 0 (0.5) [0.5 on Epop[14]], weight: 4.1363508E-4, delay 1.5
        h("Epop[14] syn_projEE_ampa[6334] = new ampa(0.5)")
        h("Epop[79] netConn_projEE_ampa[6334] = new NetCon(&v(0.5), syn_projEE_ampa[6334], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6335: cell 79, seg 0 (0.5) [0.5 on Epop[79]] -> cell 15, seg 0 (0.5) [0.5 on Epop[15]], weight: 4.1363508E-4, delay 1.5
        h("Epop[15] syn_projEE_ampa[6335] = new ampa(0.5)")
        h("Epop[79] netConn_projEE_ampa[6335] = new NetCon(&v(0.5), syn_projEE_ampa[6335], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6336: cell 79, seg 0 (0.5) [0.5 on Epop[79]] -> cell 16, seg 0 (0.5) [0.5 on Epop[16]], weight: 4.1363508E-4, delay 1.5
        h("Epop[16] syn_projEE_ampa[6336] = new ampa(0.5)")
        h("Epop[79] netConn_projEE_ampa[6336] = new NetCon(&v(0.5), syn_projEE_ampa[6336], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6337: cell 79, seg 0 (0.5) [0.5 on Epop[79]] -> cell 17, seg 0 (0.5) [0.5 on Epop[17]], weight: 4.1363508E-4, delay 1.5
        h("Epop[17] syn_projEE_ampa[6337] = new ampa(0.5)")
        h("Epop[79] netConn_projEE_ampa[6337] = new NetCon(&v(0.5), syn_projEE_ampa[6337], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6338: cell 79, seg 0 (0.5) [0.5 on Epop[79]] -> cell 18, seg 0 (0.5) [0.5 on Epop[18]], weight: 4.1363508E-4, delay 1.5
        h("Epop[18] syn_projEE_ampa[6338] = new ampa(0.5)")
        h("Epop[79] netConn_projEE_ampa[6338] = new NetCon(&v(0.5), syn_projEE_ampa[6338], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6339: cell 79, seg 0 (0.5) [0.5 on Epop[79]] -> cell 19, seg 0 (0.5) [0.5 on Epop[19]], weight: 4.1363508E-4, delay 1.5
        h("Epop[19] syn_projEE_ampa[6339] = new ampa(0.5)")
        h("Epop[79] netConn_projEE_ampa[6339] = new NetCon(&v(0.5), syn_projEE_ampa[6339], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6340: cell 79, seg 0 (0.5) [0.5 on Epop[79]] -> cell 20, seg 0 (0.5) [0.5 on Epop[20]], weight: 4.1363508E-4, delay 1.5
        h("Epop[20] syn_projEE_ampa[6340] = new ampa(0.5)")
        h("Epop[79] netConn_projEE_ampa[6340] = new NetCon(&v(0.5), syn_projEE_ampa[6340], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6341: cell 79, seg 0 (0.5) [0.5 on Epop[79]] -> cell 21, seg 0 (0.5) [0.5 on Epop[21]], weight: 4.1363508E-4, delay 1.5
        h("Epop[21] syn_projEE_ampa[6341] = new ampa(0.5)")
        h("Epop[79] netConn_projEE_ampa[6341] = new NetCon(&v(0.5), syn_projEE_ampa[6341], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6342: cell 79, seg 0 (0.5) [0.5 on Epop[79]] -> cell 22, seg 0 (0.5) [0.5 on Epop[22]], weight: 4.1363508E-4, delay 1.5
        h("Epop[22] syn_projEE_ampa[6342] = new ampa(0.5)")
        h("Epop[79] netConn_projEE_ampa[6342] = new NetCon(&v(0.5), syn_projEE_ampa[6342], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6343: cell 79, seg 0 (0.5) [0.5 on Epop[79]] -> cell 23, seg 0 (0.5) [0.5 on Epop[23]], weight: 4.1363508E-4, delay 1.5
        h("Epop[23] syn_projEE_ampa[6343] = new ampa(0.5)")
        h("Epop[79] netConn_projEE_ampa[6343] = new NetCon(&v(0.5), syn_projEE_ampa[6343], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6344: cell 79, seg 0 (0.5) [0.5 on Epop[79]] -> cell 24, seg 0 (0.5) [0.5 on Epop[24]], weight: 4.1363508E-4, delay 1.5
        h("Epop[24] syn_projEE_ampa[6344] = new ampa(0.5)")
        h("Epop[79] netConn_projEE_ampa[6344] = new NetCon(&v(0.5), syn_projEE_ampa[6344], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6345: cell 79, seg 0 (0.5) [0.5 on Epop[79]] -> cell 25, seg 0 (0.5) [0.5 on Epop[25]], weight: 4.1363508E-4, delay 1.5
        h("Epop[25] syn_projEE_ampa[6345] = new ampa(0.5)")
        h("Epop[79] netConn_projEE_ampa[6345] = new NetCon(&v(0.5), syn_projEE_ampa[6345], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6346: cell 79, seg 0 (0.5) [0.5 on Epop[79]] -> cell 26, seg 0 (0.5) [0.5 on Epop[26]], weight: 4.1363508E-4, delay 1.5
        h("Epop[26] syn_projEE_ampa[6346] = new ampa(0.5)")
        h("Epop[79] netConn_projEE_ampa[6346] = new NetCon(&v(0.5), syn_projEE_ampa[6346], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6347: cell 79, seg 0 (0.5) [0.5 on Epop[79]] -> cell 27, seg 0 (0.5) [0.5 on Epop[27]], weight: 4.1363508E-4, delay 1.5
        h("Epop[27] syn_projEE_ampa[6347] = new ampa(0.5)")
        h("Epop[79] netConn_projEE_ampa[6347] = new NetCon(&v(0.5), syn_projEE_ampa[6347], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6348: cell 79, seg 0 (0.5) [0.5 on Epop[79]] -> cell 28, seg 0 (0.5) [0.5 on Epop[28]], weight: 4.1363508E-4, delay 1.5
        h("Epop[28] syn_projEE_ampa[6348] = new ampa(0.5)")
        h("Epop[79] netConn_projEE_ampa[6348] = new NetCon(&v(0.5), syn_projEE_ampa[6348], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6349: cell 79, seg 0 (0.5) [0.5 on Epop[79]] -> cell 29, seg 0 (0.5) [0.5 on Epop[29]], weight: 4.1363508E-4, delay 1.5
        h("Epop[29] syn_projEE_ampa[6349] = new ampa(0.5)")
        h("Epop[79] netConn_projEE_ampa[6349] = new NetCon(&v(0.5), syn_projEE_ampa[6349], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6350: cell 79, seg 0 (0.5) [0.5 on Epop[79]] -> cell 30, seg 0 (0.5) [0.5 on Epop[30]], weight: 4.1363508E-4, delay 1.5
        h("Epop[30] syn_projEE_ampa[6350] = new ampa(0.5)")
        h("Epop[79] netConn_projEE_ampa[6350] = new NetCon(&v(0.5), syn_projEE_ampa[6350], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6351: cell 79, seg 0 (0.5) [0.5 on Epop[79]] -> cell 31, seg 0 (0.5) [0.5 on Epop[31]], weight: 4.1363508E-4, delay 1.5
        h("Epop[31] syn_projEE_ampa[6351] = new ampa(0.5)")
        h("Epop[79] netConn_projEE_ampa[6351] = new NetCon(&v(0.5), syn_projEE_ampa[6351], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6352: cell 79, seg 0 (0.5) [0.5 on Epop[79]] -> cell 32, seg 0 (0.5) [0.5 on Epop[32]], weight: 4.1363508E-4, delay 1.5
        h("Epop[32] syn_projEE_ampa[6352] = new ampa(0.5)")
        h("Epop[79] netConn_projEE_ampa[6352] = new NetCon(&v(0.5), syn_projEE_ampa[6352], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6353: cell 79, seg 0 (0.5) [0.5 on Epop[79]] -> cell 33, seg 0 (0.5) [0.5 on Epop[33]], weight: 4.1363508E-4, delay 1.5
        h("Epop[33] syn_projEE_ampa[6353] = new ampa(0.5)")
        h("Epop[79] netConn_projEE_ampa[6353] = new NetCon(&v(0.5), syn_projEE_ampa[6353], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6354: cell 79, seg 0 (0.5) [0.5 on Epop[79]] -> cell 34, seg 0 (0.5) [0.5 on Epop[34]], weight: 4.1363508E-4, delay 1.5
        h("Epop[34] syn_projEE_ampa[6354] = new ampa(0.5)")
        h("Epop[79] netConn_projEE_ampa[6354] = new NetCon(&v(0.5), syn_projEE_ampa[6354], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6355: cell 79, seg 0 (0.5) [0.5 on Epop[79]] -> cell 35, seg 0 (0.5) [0.5 on Epop[35]], weight: 4.1363508E-4, delay 1.5
        h("Epop[35] syn_projEE_ampa[6355] = new ampa(0.5)")
        h("Epop[79] netConn_projEE_ampa[6355] = new NetCon(&v(0.5), syn_projEE_ampa[6355], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6356: cell 79, seg 0 (0.5) [0.5 on Epop[79]] -> cell 36, seg 0 (0.5) [0.5 on Epop[36]], weight: 4.1363508E-4, delay 1.5
        h("Epop[36] syn_projEE_ampa[6356] = new ampa(0.5)")
        h("Epop[79] netConn_projEE_ampa[6356] = new NetCon(&v(0.5), syn_projEE_ampa[6356], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6357: cell 79, seg 0 (0.5) [0.5 on Epop[79]] -> cell 37, seg 0 (0.5) [0.5 on Epop[37]], weight: 4.1363508E-4, delay 1.5
        h("Epop[37] syn_projEE_ampa[6357] = new ampa(0.5)")
        h("Epop[79] netConn_projEE_ampa[6357] = new NetCon(&v(0.5), syn_projEE_ampa[6357], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6358: cell 79, seg 0 (0.5) [0.5 on Epop[79]] -> cell 38, seg 0 (0.5) [0.5 on Epop[38]], weight: 4.1363508E-4, delay 1.5
        h("Epop[38] syn_projEE_ampa[6358] = new ampa(0.5)")
        h("Epop[79] netConn_projEE_ampa[6358] = new NetCon(&v(0.5), syn_projEE_ampa[6358], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6359: cell 79, seg 0 (0.5) [0.5 on Epop[79]] -> cell 39, seg 0 (0.5) [0.5 on Epop[39]], weight: 4.1363508E-4, delay 1.5
        h("Epop[39] syn_projEE_ampa[6359] = new ampa(0.5)")
        h("Epop[79] netConn_projEE_ampa[6359] = new NetCon(&v(0.5), syn_projEE_ampa[6359], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6360: cell 79, seg 0 (0.5) [0.5 on Epop[79]] -> cell 40, seg 0 (0.5) [0.5 on Epop[40]], weight: 4.1363508E-4, delay 1.5
        h("Epop[40] syn_projEE_ampa[6360] = new ampa(0.5)")
        h("Epop[79] netConn_projEE_ampa[6360] = new NetCon(&v(0.5), syn_projEE_ampa[6360], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6361: cell 79, seg 0 (0.5) [0.5 on Epop[79]] -> cell 41, seg 0 (0.5) [0.5 on Epop[41]], weight: 4.1363508E-4, delay 1.5
        h("Epop[41] syn_projEE_ampa[6361] = new ampa(0.5)")
        h("Epop[79] netConn_projEE_ampa[6361] = new NetCon(&v(0.5), syn_projEE_ampa[6361], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6362: cell 79, seg 0 (0.5) [0.5 on Epop[79]] -> cell 42, seg 0 (0.5) [0.5 on Epop[42]], weight: 4.1363508E-4, delay 1.5
        h("Epop[42] syn_projEE_ampa[6362] = new ampa(0.5)")
        h("Epop[79] netConn_projEE_ampa[6362] = new NetCon(&v(0.5), syn_projEE_ampa[6362], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6363: cell 79, seg 0 (0.5) [0.5 on Epop[79]] -> cell 43, seg 0 (0.5) [0.5 on Epop[43]], weight: 4.1363508E-4, delay 1.5
        h("Epop[43] syn_projEE_ampa[6363] = new ampa(0.5)")
        h("Epop[79] netConn_projEE_ampa[6363] = new NetCon(&v(0.5), syn_projEE_ampa[6363], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6364: cell 79, seg 0 (0.5) [0.5 on Epop[79]] -> cell 44, seg 0 (0.5) [0.5 on Epop[44]], weight: 4.1363508E-4, delay 1.5
        h("Epop[44] syn_projEE_ampa[6364] = new ampa(0.5)")
        h("Epop[79] netConn_projEE_ampa[6364] = new NetCon(&v(0.5), syn_projEE_ampa[6364], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6365: cell 79, seg 0 (0.5) [0.5 on Epop[79]] -> cell 45, seg 0 (0.5) [0.5 on Epop[45]], weight: 4.1363508E-4, delay 1.5
        h("Epop[45] syn_projEE_ampa[6365] = new ampa(0.5)")
        h("Epop[79] netConn_projEE_ampa[6365] = new NetCon(&v(0.5), syn_projEE_ampa[6365], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6366: cell 79, seg 0 (0.5) [0.5 on Epop[79]] -> cell 46, seg 0 (0.5) [0.5 on Epop[46]], weight: 4.1363508E-4, delay 1.5
        h("Epop[46] syn_projEE_ampa[6366] = new ampa(0.5)")
        h("Epop[79] netConn_projEE_ampa[6366] = new NetCon(&v(0.5), syn_projEE_ampa[6366], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6367: cell 79, seg 0 (0.5) [0.5 on Epop[79]] -> cell 47, seg 0 (0.5) [0.5 on Epop[47]], weight: 4.1363508E-4, delay 1.5
        h("Epop[47] syn_projEE_ampa[6367] = new ampa(0.5)")
        h("Epop[79] netConn_projEE_ampa[6367] = new NetCon(&v(0.5), syn_projEE_ampa[6367], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6368: cell 79, seg 0 (0.5) [0.5 on Epop[79]] -> cell 48, seg 0 (0.5) [0.5 on Epop[48]], weight: 4.1363508E-4, delay 1.5
        h("Epop[48] syn_projEE_ampa[6368] = new ampa(0.5)")
        h("Epop[79] netConn_projEE_ampa[6368] = new NetCon(&v(0.5), syn_projEE_ampa[6368], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6369: cell 79, seg 0 (0.5) [0.5 on Epop[79]] -> cell 49, seg 0 (0.5) [0.5 on Epop[49]], weight: 4.1363508E-4, delay 1.5
        h("Epop[49] syn_projEE_ampa[6369] = new ampa(0.5)")
        h("Epop[79] netConn_projEE_ampa[6369] = new NetCon(&v(0.5), syn_projEE_ampa[6369], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6370: cell 79, seg 0 (0.5) [0.5 on Epop[79]] -> cell 50, seg 0 (0.5) [0.5 on Epop[50]], weight: 4.1363508E-4, delay 1.5
        h("Epop[50] syn_projEE_ampa[6370] = new ampa(0.5)")
        h("Epop[79] netConn_projEE_ampa[6370] = new NetCon(&v(0.5), syn_projEE_ampa[6370], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6371: cell 79, seg 0 (0.5) [0.5 on Epop[79]] -> cell 51, seg 0 (0.5) [0.5 on Epop[51]], weight: 4.1363508E-4, delay 1.5
        h("Epop[51] syn_projEE_ampa[6371] = new ampa(0.5)")
        h("Epop[79] netConn_projEE_ampa[6371] = new NetCon(&v(0.5), syn_projEE_ampa[6371], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6372: cell 79, seg 0 (0.5) [0.5 on Epop[79]] -> cell 52, seg 0 (0.5) [0.5 on Epop[52]], weight: 4.1363508E-4, delay 1.5
        h("Epop[52] syn_projEE_ampa[6372] = new ampa(0.5)")
        h("Epop[79] netConn_projEE_ampa[6372] = new NetCon(&v(0.5), syn_projEE_ampa[6372], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6373: cell 79, seg 0 (0.5) [0.5 on Epop[79]] -> cell 53, seg 0 (0.5) [0.5 on Epop[53]], weight: 4.1363508E-4, delay 1.5
        h("Epop[53] syn_projEE_ampa[6373] = new ampa(0.5)")
        h("Epop[79] netConn_projEE_ampa[6373] = new NetCon(&v(0.5), syn_projEE_ampa[6373], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6374: cell 79, seg 0 (0.5) [0.5 on Epop[79]] -> cell 54, seg 0 (0.5) [0.5 on Epop[54]], weight: 4.1363508E-4, delay 1.5
        h("Epop[54] syn_projEE_ampa[6374] = new ampa(0.5)")
        h("Epop[79] netConn_projEE_ampa[6374] = new NetCon(&v(0.5), syn_projEE_ampa[6374], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6375: cell 79, seg 0 (0.5) [0.5 on Epop[79]] -> cell 55, seg 0 (0.5) [0.5 on Epop[55]], weight: 4.1363508E-4, delay 1.5
        h("Epop[55] syn_projEE_ampa[6375] = new ampa(0.5)")
        h("Epop[79] netConn_projEE_ampa[6375] = new NetCon(&v(0.5), syn_projEE_ampa[6375], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6376: cell 79, seg 0 (0.5) [0.5 on Epop[79]] -> cell 56, seg 0 (0.5) [0.5 on Epop[56]], weight: 4.1363508E-4, delay 1.5
        h("Epop[56] syn_projEE_ampa[6376] = new ampa(0.5)")
        h("Epop[79] netConn_projEE_ampa[6376] = new NetCon(&v(0.5), syn_projEE_ampa[6376], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6377: cell 79, seg 0 (0.5) [0.5 on Epop[79]] -> cell 57, seg 0 (0.5) [0.5 on Epop[57]], weight: 4.1363508E-4, delay 1.5
        h("Epop[57] syn_projEE_ampa[6377] = new ampa(0.5)")
        h("Epop[79] netConn_projEE_ampa[6377] = new NetCon(&v(0.5), syn_projEE_ampa[6377], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6378: cell 79, seg 0 (0.5) [0.5 on Epop[79]] -> cell 58, seg 0 (0.5) [0.5 on Epop[58]], weight: 4.1363508E-4, delay 1.5
        h("Epop[58] syn_projEE_ampa[6378] = new ampa(0.5)")
        h("Epop[79] netConn_projEE_ampa[6378] = new NetCon(&v(0.5), syn_projEE_ampa[6378], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6379: cell 79, seg 0 (0.5) [0.5 on Epop[79]] -> cell 59, seg 0 (0.5) [0.5 on Epop[59]], weight: 4.1363508E-4, delay 1.5
        h("Epop[59] syn_projEE_ampa[6379] = new ampa(0.5)")
        h("Epop[79] netConn_projEE_ampa[6379] = new NetCon(&v(0.5), syn_projEE_ampa[6379], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6380: cell 79, seg 0 (0.5) [0.5 on Epop[79]] -> cell 60, seg 0 (0.5) [0.5 on Epop[60]], weight: 4.1363508E-4, delay 1.5
        h("Epop[60] syn_projEE_ampa[6380] = new ampa(0.5)")
        h("Epop[79] netConn_projEE_ampa[6380] = new NetCon(&v(0.5), syn_projEE_ampa[6380], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6381: cell 79, seg 0 (0.5) [0.5 on Epop[79]] -> cell 61, seg 0 (0.5) [0.5 on Epop[61]], weight: 4.1363508E-4, delay 1.5
        h("Epop[61] syn_projEE_ampa[6381] = new ampa(0.5)")
        h("Epop[79] netConn_projEE_ampa[6381] = new NetCon(&v(0.5), syn_projEE_ampa[6381], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6382: cell 79, seg 0 (0.5) [0.5 on Epop[79]] -> cell 62, seg 0 (0.5) [0.5 on Epop[62]], weight: 4.1363508E-4, delay 1.5
        h("Epop[62] syn_projEE_ampa[6382] = new ampa(0.5)")
        h("Epop[79] netConn_projEE_ampa[6382] = new NetCon(&v(0.5), syn_projEE_ampa[6382], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6383: cell 79, seg 0 (0.5) [0.5 on Epop[79]] -> cell 63, seg 0 (0.5) [0.5 on Epop[63]], weight: 4.1363508E-4, delay 1.5
        h("Epop[63] syn_projEE_ampa[6383] = new ampa(0.5)")
        h("Epop[79] netConn_projEE_ampa[6383] = new NetCon(&v(0.5), syn_projEE_ampa[6383], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6384: cell 79, seg 0 (0.5) [0.5 on Epop[79]] -> cell 64, seg 0 (0.5) [0.5 on Epop[64]], weight: 4.1363508E-4, delay 1.5
        h("Epop[64] syn_projEE_ampa[6384] = new ampa(0.5)")
        h("Epop[79] netConn_projEE_ampa[6384] = new NetCon(&v(0.5), syn_projEE_ampa[6384], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6385: cell 79, seg 0 (0.5) [0.5 on Epop[79]] -> cell 65, seg 0 (0.5) [0.5 on Epop[65]], weight: 4.1363508E-4, delay 1.5
        h("Epop[65] syn_projEE_ampa[6385] = new ampa(0.5)")
        h("Epop[79] netConn_projEE_ampa[6385] = new NetCon(&v(0.5), syn_projEE_ampa[6385], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6386: cell 79, seg 0 (0.5) [0.5 on Epop[79]] -> cell 66, seg 0 (0.5) [0.5 on Epop[66]], weight: 4.1363508E-4, delay 1.5
        h("Epop[66] syn_projEE_ampa[6386] = new ampa(0.5)")
        h("Epop[79] netConn_projEE_ampa[6386] = new NetCon(&v(0.5), syn_projEE_ampa[6386], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6387: cell 79, seg 0 (0.5) [0.5 on Epop[79]] -> cell 67, seg 0 (0.5) [0.5 on Epop[67]], weight: 4.1363508E-4, delay 1.5
        h("Epop[67] syn_projEE_ampa[6387] = new ampa(0.5)")
        h("Epop[79] netConn_projEE_ampa[6387] = new NetCon(&v(0.5), syn_projEE_ampa[6387], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6388: cell 79, seg 0 (0.5) [0.5 on Epop[79]] -> cell 68, seg 0 (0.5) [0.5 on Epop[68]], weight: 4.1363508E-4, delay 1.5
        h("Epop[68] syn_projEE_ampa[6388] = new ampa(0.5)")
        h("Epop[79] netConn_projEE_ampa[6388] = new NetCon(&v(0.5), syn_projEE_ampa[6388], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6389: cell 79, seg 0 (0.5) [0.5 on Epop[79]] -> cell 69, seg 0 (0.5) [0.5 on Epop[69]], weight: 4.1363508E-4, delay 1.5
        h("Epop[69] syn_projEE_ampa[6389] = new ampa(0.5)")
        h("Epop[79] netConn_projEE_ampa[6389] = new NetCon(&v(0.5), syn_projEE_ampa[6389], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6390: cell 79, seg 0 (0.5) [0.5 on Epop[79]] -> cell 70, seg 0 (0.5) [0.5 on Epop[70]], weight: 4.1363508E-4, delay 1.5
        h("Epop[70] syn_projEE_ampa[6390] = new ampa(0.5)")
        h("Epop[79] netConn_projEE_ampa[6390] = new NetCon(&v(0.5), syn_projEE_ampa[6390], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6391: cell 79, seg 0 (0.5) [0.5 on Epop[79]] -> cell 71, seg 0 (0.5) [0.5 on Epop[71]], weight: 4.1363508E-4, delay 1.5
        h("Epop[71] syn_projEE_ampa[6391] = new ampa(0.5)")
        h("Epop[79] netConn_projEE_ampa[6391] = new NetCon(&v(0.5), syn_projEE_ampa[6391], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6392: cell 79, seg 0 (0.5) [0.5 on Epop[79]] -> cell 72, seg 0 (0.5) [0.5 on Epop[72]], weight: 4.1363508E-4, delay 1.5
        h("Epop[72] syn_projEE_ampa[6392] = new ampa(0.5)")
        h("Epop[79] netConn_projEE_ampa[6392] = new NetCon(&v(0.5), syn_projEE_ampa[6392], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6393: cell 79, seg 0 (0.5) [0.5 on Epop[79]] -> cell 73, seg 0 (0.5) [0.5 on Epop[73]], weight: 4.1363508E-4, delay 1.5
        h("Epop[73] syn_projEE_ampa[6393] = new ampa(0.5)")
        h("Epop[79] netConn_projEE_ampa[6393] = new NetCon(&v(0.5), syn_projEE_ampa[6393], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6394: cell 79, seg 0 (0.5) [0.5 on Epop[79]] -> cell 74, seg 0 (0.5) [0.5 on Epop[74]], weight: 4.1363508E-4, delay 1.5
        h("Epop[74] syn_projEE_ampa[6394] = new ampa(0.5)")
        h("Epop[79] netConn_projEE_ampa[6394] = new NetCon(&v(0.5), syn_projEE_ampa[6394], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6395: cell 79, seg 0 (0.5) [0.5 on Epop[79]] -> cell 75, seg 0 (0.5) [0.5 on Epop[75]], weight: 4.1363508E-4, delay 1.5
        h("Epop[75] syn_projEE_ampa[6395] = new ampa(0.5)")
        h("Epop[79] netConn_projEE_ampa[6395] = new NetCon(&v(0.5), syn_projEE_ampa[6395], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6396: cell 79, seg 0 (0.5) [0.5 on Epop[79]] -> cell 76, seg 0 (0.5) [0.5 on Epop[76]], weight: 4.1363508E-4, delay 1.5
        h("Epop[76] syn_projEE_ampa[6396] = new ampa(0.5)")
        h("Epop[79] netConn_projEE_ampa[6396] = new NetCon(&v(0.5), syn_projEE_ampa[6396], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6397: cell 79, seg 0 (0.5) [0.5 on Epop[79]] -> cell 77, seg 0 (0.5) [0.5 on Epop[77]], weight: 4.1363508E-4, delay 1.5
        h("Epop[77] syn_projEE_ampa[6397] = new ampa(0.5)")
        h("Epop[79] netConn_projEE_ampa[6397] = new NetCon(&v(0.5), syn_projEE_ampa[6397], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6398: cell 79, seg 0 (0.5) [0.5 on Epop[79]] -> cell 78, seg 0 (0.5) [0.5 on Epop[78]], weight: 4.1363508E-4, delay 1.5
        h("Epop[78] syn_projEE_ampa[6398] = new ampa(0.5)")
        h("Epop[79] netConn_projEE_ampa[6398] = new NetCon(&v(0.5), syn_projEE_ampa[6398], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6399: cell 79, seg 0 (0.5) [0.5 on Epop[79]] -> cell 79, seg 0 (0.5) [0.5 on Epop[79]], weight: 4.1363508E-4, delay 1.5
        h("Epop[79] syn_projEE_ampa[6399] = new ampa(0.5)")
        h("Epop[79] netConn_projEE_ampa[6399] = new NetCon(&v(0.5), syn_projEE_ampa[6399], 20.0, 1.5, 4.1363508E-4)")  

        # ######################   Projection: projEI
        print("Adding projection: projEI, from Epop to Ipop with synapse ampa, 1600 connection(s)")

        h("objectvar syn_projEI_ampa[1600]")

        h("objectvar netConn_projEI_ampa[1600]")

        # Connection 0: cell 0, seg 0 (0.5) [0.5 on Epop[0]] -> cell 0, seg 0 (0.5) [0.5 on Ipop[0]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[0] syn_projEI_ampa[0] = new ampa(0.5)")
        h("Epop[0] netConn_projEI_ampa[0] = new NetCon(&v(0.5), syn_projEI_ampa[0], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1: cell 0, seg 0 (0.5) [0.5 on Epop[0]] -> cell 1, seg 0 (0.5) [0.5 on Ipop[1]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[1] syn_projEI_ampa[1] = new ampa(0.5)")
        h("Epop[0] netConn_projEI_ampa[1] = new NetCon(&v(0.5), syn_projEI_ampa[1], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 2: cell 0, seg 0 (0.5) [0.5 on Epop[0]] -> cell 2, seg 0 (0.5) [0.5 on Ipop[2]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[2] syn_projEI_ampa[2] = new ampa(0.5)")
        h("Epop[0] netConn_projEI_ampa[2] = new NetCon(&v(0.5), syn_projEI_ampa[2], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 3: cell 0, seg 0 (0.5) [0.5 on Epop[0]] -> cell 3, seg 0 (0.5) [0.5 on Ipop[3]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[3] syn_projEI_ampa[3] = new ampa(0.5)")
        h("Epop[0] netConn_projEI_ampa[3] = new NetCon(&v(0.5), syn_projEI_ampa[3], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 4: cell 0, seg 0 (0.5) [0.5 on Epop[0]] -> cell 4, seg 0 (0.5) [0.5 on Ipop[4]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[4] syn_projEI_ampa[4] = new ampa(0.5)")
        h("Epop[0] netConn_projEI_ampa[4] = new NetCon(&v(0.5), syn_projEI_ampa[4], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 5: cell 0, seg 0 (0.5) [0.5 on Epop[0]] -> cell 5, seg 0 (0.5) [0.5 on Ipop[5]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[5] syn_projEI_ampa[5] = new ampa(0.5)")
        h("Epop[0] netConn_projEI_ampa[5] = new NetCon(&v(0.5), syn_projEI_ampa[5], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 6: cell 0, seg 0 (0.5) [0.5 on Epop[0]] -> cell 6, seg 0 (0.5) [0.5 on Ipop[6]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[6] syn_projEI_ampa[6] = new ampa(0.5)")
        h("Epop[0] netConn_projEI_ampa[6] = new NetCon(&v(0.5), syn_projEI_ampa[6], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 7: cell 0, seg 0 (0.5) [0.5 on Epop[0]] -> cell 7, seg 0 (0.5) [0.5 on Ipop[7]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[7] syn_projEI_ampa[7] = new ampa(0.5)")
        h("Epop[0] netConn_projEI_ampa[7] = new NetCon(&v(0.5), syn_projEI_ampa[7], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 8: cell 0, seg 0 (0.5) [0.5 on Epop[0]] -> cell 8, seg 0 (0.5) [0.5 on Ipop[8]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[8] syn_projEI_ampa[8] = new ampa(0.5)")
        h("Epop[0] netConn_projEI_ampa[8] = new NetCon(&v(0.5), syn_projEI_ampa[8], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 9: cell 0, seg 0 (0.5) [0.5 on Epop[0]] -> cell 9, seg 0 (0.5) [0.5 on Ipop[9]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[9] syn_projEI_ampa[9] = new ampa(0.5)")
        h("Epop[0] netConn_projEI_ampa[9] = new NetCon(&v(0.5), syn_projEI_ampa[9], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 10: cell 0, seg 0 (0.5) [0.5 on Epop[0]] -> cell 10, seg 0 (0.5) [0.5 on Ipop[10]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[10] syn_projEI_ampa[10] = new ampa(0.5)")
        h("Epop[0] netConn_projEI_ampa[10] = new NetCon(&v(0.5), syn_projEI_ampa[10], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 11: cell 0, seg 0 (0.5) [0.5 on Epop[0]] -> cell 11, seg 0 (0.5) [0.5 on Ipop[11]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[11] syn_projEI_ampa[11] = new ampa(0.5)")
        h("Epop[0] netConn_projEI_ampa[11] = new NetCon(&v(0.5), syn_projEI_ampa[11], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 12: cell 0, seg 0 (0.5) [0.5 on Epop[0]] -> cell 12, seg 0 (0.5) [0.5 on Ipop[12]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[12] syn_projEI_ampa[12] = new ampa(0.5)")
        h("Epop[0] netConn_projEI_ampa[12] = new NetCon(&v(0.5), syn_projEI_ampa[12], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 13: cell 0, seg 0 (0.5) [0.5 on Epop[0]] -> cell 13, seg 0 (0.5) [0.5 on Ipop[13]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[13] syn_projEI_ampa[13] = new ampa(0.5)")
        h("Epop[0] netConn_projEI_ampa[13] = new NetCon(&v(0.5), syn_projEI_ampa[13], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 14: cell 0, seg 0 (0.5) [0.5 on Epop[0]] -> cell 14, seg 0 (0.5) [0.5 on Ipop[14]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[14] syn_projEI_ampa[14] = new ampa(0.5)")
        h("Epop[0] netConn_projEI_ampa[14] = new NetCon(&v(0.5), syn_projEI_ampa[14], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 15: cell 0, seg 0 (0.5) [0.5 on Epop[0]] -> cell 15, seg 0 (0.5) [0.5 on Ipop[15]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[15] syn_projEI_ampa[15] = new ampa(0.5)")
        h("Epop[0] netConn_projEI_ampa[15] = new NetCon(&v(0.5), syn_projEI_ampa[15], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 16: cell 0, seg 0 (0.5) [0.5 on Epop[0]] -> cell 16, seg 0 (0.5) [0.5 on Ipop[16]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[16] syn_projEI_ampa[16] = new ampa(0.5)")
        h("Epop[0] netConn_projEI_ampa[16] = new NetCon(&v(0.5), syn_projEI_ampa[16], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 17: cell 0, seg 0 (0.5) [0.5 on Epop[0]] -> cell 17, seg 0 (0.5) [0.5 on Ipop[17]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[17] syn_projEI_ampa[17] = new ampa(0.5)")
        h("Epop[0] netConn_projEI_ampa[17] = new NetCon(&v(0.5), syn_projEI_ampa[17], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 18: cell 0, seg 0 (0.5) [0.5 on Epop[0]] -> cell 18, seg 0 (0.5) [0.5 on Ipop[18]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[18] syn_projEI_ampa[18] = new ampa(0.5)")
        h("Epop[0] netConn_projEI_ampa[18] = new NetCon(&v(0.5), syn_projEI_ampa[18], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 19: cell 0, seg 0 (0.5) [0.5 on Epop[0]] -> cell 19, seg 0 (0.5) [0.5 on Ipop[19]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[19] syn_projEI_ampa[19] = new ampa(0.5)")
        h("Epop[0] netConn_projEI_ampa[19] = new NetCon(&v(0.5), syn_projEI_ampa[19], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 20: cell 1, seg 0 (0.5) [0.5 on Epop[1]] -> cell 0, seg 0 (0.5) [0.5 on Ipop[0]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[0] syn_projEI_ampa[20] = new ampa(0.5)")
        h("Epop[1] netConn_projEI_ampa[20] = new NetCon(&v(0.5), syn_projEI_ampa[20], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 21: cell 1, seg 0 (0.5) [0.5 on Epop[1]] -> cell 1, seg 0 (0.5) [0.5 on Ipop[1]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[1] syn_projEI_ampa[21] = new ampa(0.5)")
        h("Epop[1] netConn_projEI_ampa[21] = new NetCon(&v(0.5), syn_projEI_ampa[21], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 22: cell 1, seg 0 (0.5) [0.5 on Epop[1]] -> cell 2, seg 0 (0.5) [0.5 on Ipop[2]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[2] syn_projEI_ampa[22] = new ampa(0.5)")
        h("Epop[1] netConn_projEI_ampa[22] = new NetCon(&v(0.5), syn_projEI_ampa[22], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 23: cell 1, seg 0 (0.5) [0.5 on Epop[1]] -> cell 3, seg 0 (0.5) [0.5 on Ipop[3]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[3] syn_projEI_ampa[23] = new ampa(0.5)")
        h("Epop[1] netConn_projEI_ampa[23] = new NetCon(&v(0.5), syn_projEI_ampa[23], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 24: cell 1, seg 0 (0.5) [0.5 on Epop[1]] -> cell 4, seg 0 (0.5) [0.5 on Ipop[4]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[4] syn_projEI_ampa[24] = new ampa(0.5)")
        h("Epop[1] netConn_projEI_ampa[24] = new NetCon(&v(0.5), syn_projEI_ampa[24], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 25: cell 1, seg 0 (0.5) [0.5 on Epop[1]] -> cell 5, seg 0 (0.5) [0.5 on Ipop[5]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[5] syn_projEI_ampa[25] = new ampa(0.5)")
        h("Epop[1] netConn_projEI_ampa[25] = new NetCon(&v(0.5), syn_projEI_ampa[25], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 26: cell 1, seg 0 (0.5) [0.5 on Epop[1]] -> cell 6, seg 0 (0.5) [0.5 on Ipop[6]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[6] syn_projEI_ampa[26] = new ampa(0.5)")
        h("Epop[1] netConn_projEI_ampa[26] = new NetCon(&v(0.5), syn_projEI_ampa[26], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 27: cell 1, seg 0 (0.5) [0.5 on Epop[1]] -> cell 7, seg 0 (0.5) [0.5 on Ipop[7]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[7] syn_projEI_ampa[27] = new ampa(0.5)")
        h("Epop[1] netConn_projEI_ampa[27] = new NetCon(&v(0.5), syn_projEI_ampa[27], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 28: cell 1, seg 0 (0.5) [0.5 on Epop[1]] -> cell 8, seg 0 (0.5) [0.5 on Ipop[8]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[8] syn_projEI_ampa[28] = new ampa(0.5)")
        h("Epop[1] netConn_projEI_ampa[28] = new NetCon(&v(0.5), syn_projEI_ampa[28], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 29: cell 1, seg 0 (0.5) [0.5 on Epop[1]] -> cell 9, seg 0 (0.5) [0.5 on Ipop[9]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[9] syn_projEI_ampa[29] = new ampa(0.5)")
        h("Epop[1] netConn_projEI_ampa[29] = new NetCon(&v(0.5), syn_projEI_ampa[29], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 30: cell 1, seg 0 (0.5) [0.5 on Epop[1]] -> cell 10, seg 0 (0.5) [0.5 on Ipop[10]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[10] syn_projEI_ampa[30] = new ampa(0.5)")
        h("Epop[1] netConn_projEI_ampa[30] = new NetCon(&v(0.5), syn_projEI_ampa[30], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 31: cell 1, seg 0 (0.5) [0.5 on Epop[1]] -> cell 11, seg 0 (0.5) [0.5 on Ipop[11]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[11] syn_projEI_ampa[31] = new ampa(0.5)")
        h("Epop[1] netConn_projEI_ampa[31] = new NetCon(&v(0.5), syn_projEI_ampa[31], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 32: cell 1, seg 0 (0.5) [0.5 on Epop[1]] -> cell 12, seg 0 (0.5) [0.5 on Ipop[12]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[12] syn_projEI_ampa[32] = new ampa(0.5)")
        h("Epop[1] netConn_projEI_ampa[32] = new NetCon(&v(0.5), syn_projEI_ampa[32], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 33: cell 1, seg 0 (0.5) [0.5 on Epop[1]] -> cell 13, seg 0 (0.5) [0.5 on Ipop[13]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[13] syn_projEI_ampa[33] = new ampa(0.5)")
        h("Epop[1] netConn_projEI_ampa[33] = new NetCon(&v(0.5), syn_projEI_ampa[33], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 34: cell 1, seg 0 (0.5) [0.5 on Epop[1]] -> cell 14, seg 0 (0.5) [0.5 on Ipop[14]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[14] syn_projEI_ampa[34] = new ampa(0.5)")
        h("Epop[1] netConn_projEI_ampa[34] = new NetCon(&v(0.5), syn_projEI_ampa[34], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 35: cell 1, seg 0 (0.5) [0.5 on Epop[1]] -> cell 15, seg 0 (0.5) [0.5 on Ipop[15]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[15] syn_projEI_ampa[35] = new ampa(0.5)")
        h("Epop[1] netConn_projEI_ampa[35] = new NetCon(&v(0.5), syn_projEI_ampa[35], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 36: cell 1, seg 0 (0.5) [0.5 on Epop[1]] -> cell 16, seg 0 (0.5) [0.5 on Ipop[16]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[16] syn_projEI_ampa[36] = new ampa(0.5)")
        h("Epop[1] netConn_projEI_ampa[36] = new NetCon(&v(0.5), syn_projEI_ampa[36], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 37: cell 1, seg 0 (0.5) [0.5 on Epop[1]] -> cell 17, seg 0 (0.5) [0.5 on Ipop[17]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[17] syn_projEI_ampa[37] = new ampa(0.5)")
        h("Epop[1] netConn_projEI_ampa[37] = new NetCon(&v(0.5), syn_projEI_ampa[37], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 38: cell 1, seg 0 (0.5) [0.5 on Epop[1]] -> cell 18, seg 0 (0.5) [0.5 on Ipop[18]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[18] syn_projEI_ampa[38] = new ampa(0.5)")
        h("Epop[1] netConn_projEI_ampa[38] = new NetCon(&v(0.5), syn_projEI_ampa[38], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 39: cell 1, seg 0 (0.5) [0.5 on Epop[1]] -> cell 19, seg 0 (0.5) [0.5 on Ipop[19]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[19] syn_projEI_ampa[39] = new ampa(0.5)")
        h("Epop[1] netConn_projEI_ampa[39] = new NetCon(&v(0.5), syn_projEI_ampa[39], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 40: cell 2, seg 0 (0.5) [0.5 on Epop[2]] -> cell 0, seg 0 (0.5) [0.5 on Ipop[0]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[0] syn_projEI_ampa[40] = new ampa(0.5)")
        h("Epop[2] netConn_projEI_ampa[40] = new NetCon(&v(0.5), syn_projEI_ampa[40], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 41: cell 2, seg 0 (0.5) [0.5 on Epop[2]] -> cell 1, seg 0 (0.5) [0.5 on Ipop[1]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[1] syn_projEI_ampa[41] = new ampa(0.5)")
        h("Epop[2] netConn_projEI_ampa[41] = new NetCon(&v(0.5), syn_projEI_ampa[41], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 42: cell 2, seg 0 (0.5) [0.5 on Epop[2]] -> cell 2, seg 0 (0.5) [0.5 on Ipop[2]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[2] syn_projEI_ampa[42] = new ampa(0.5)")
        h("Epop[2] netConn_projEI_ampa[42] = new NetCon(&v(0.5), syn_projEI_ampa[42], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 43: cell 2, seg 0 (0.5) [0.5 on Epop[2]] -> cell 3, seg 0 (0.5) [0.5 on Ipop[3]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[3] syn_projEI_ampa[43] = new ampa(0.5)")
        h("Epop[2] netConn_projEI_ampa[43] = new NetCon(&v(0.5), syn_projEI_ampa[43], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 44: cell 2, seg 0 (0.5) [0.5 on Epop[2]] -> cell 4, seg 0 (0.5) [0.5 on Ipop[4]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[4] syn_projEI_ampa[44] = new ampa(0.5)")
        h("Epop[2] netConn_projEI_ampa[44] = new NetCon(&v(0.5), syn_projEI_ampa[44], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 45: cell 2, seg 0 (0.5) [0.5 on Epop[2]] -> cell 5, seg 0 (0.5) [0.5 on Ipop[5]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[5] syn_projEI_ampa[45] = new ampa(0.5)")
        h("Epop[2] netConn_projEI_ampa[45] = new NetCon(&v(0.5), syn_projEI_ampa[45], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 46: cell 2, seg 0 (0.5) [0.5 on Epop[2]] -> cell 6, seg 0 (0.5) [0.5 on Ipop[6]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[6] syn_projEI_ampa[46] = new ampa(0.5)")
        h("Epop[2] netConn_projEI_ampa[46] = new NetCon(&v(0.5), syn_projEI_ampa[46], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 47: cell 2, seg 0 (0.5) [0.5 on Epop[2]] -> cell 7, seg 0 (0.5) [0.5 on Ipop[7]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[7] syn_projEI_ampa[47] = new ampa(0.5)")
        h("Epop[2] netConn_projEI_ampa[47] = new NetCon(&v(0.5), syn_projEI_ampa[47], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 48: cell 2, seg 0 (0.5) [0.5 on Epop[2]] -> cell 8, seg 0 (0.5) [0.5 on Ipop[8]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[8] syn_projEI_ampa[48] = new ampa(0.5)")
        h("Epop[2] netConn_projEI_ampa[48] = new NetCon(&v(0.5), syn_projEI_ampa[48], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 49: cell 2, seg 0 (0.5) [0.5 on Epop[2]] -> cell 9, seg 0 (0.5) [0.5 on Ipop[9]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[9] syn_projEI_ampa[49] = new ampa(0.5)")
        h("Epop[2] netConn_projEI_ampa[49] = new NetCon(&v(0.5), syn_projEI_ampa[49], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 50: cell 2, seg 0 (0.5) [0.5 on Epop[2]] -> cell 10, seg 0 (0.5) [0.5 on Ipop[10]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[10] syn_projEI_ampa[50] = new ampa(0.5)")
        h("Epop[2] netConn_projEI_ampa[50] = new NetCon(&v(0.5), syn_projEI_ampa[50], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 51: cell 2, seg 0 (0.5) [0.5 on Epop[2]] -> cell 11, seg 0 (0.5) [0.5 on Ipop[11]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[11] syn_projEI_ampa[51] = new ampa(0.5)")
        h("Epop[2] netConn_projEI_ampa[51] = new NetCon(&v(0.5), syn_projEI_ampa[51], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 52: cell 2, seg 0 (0.5) [0.5 on Epop[2]] -> cell 12, seg 0 (0.5) [0.5 on Ipop[12]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[12] syn_projEI_ampa[52] = new ampa(0.5)")
        h("Epop[2] netConn_projEI_ampa[52] = new NetCon(&v(0.5), syn_projEI_ampa[52], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 53: cell 2, seg 0 (0.5) [0.5 on Epop[2]] -> cell 13, seg 0 (0.5) [0.5 on Ipop[13]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[13] syn_projEI_ampa[53] = new ampa(0.5)")
        h("Epop[2] netConn_projEI_ampa[53] = new NetCon(&v(0.5), syn_projEI_ampa[53], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 54: cell 2, seg 0 (0.5) [0.5 on Epop[2]] -> cell 14, seg 0 (0.5) [0.5 on Ipop[14]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[14] syn_projEI_ampa[54] = new ampa(0.5)")
        h("Epop[2] netConn_projEI_ampa[54] = new NetCon(&v(0.5), syn_projEI_ampa[54], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 55: cell 2, seg 0 (0.5) [0.5 on Epop[2]] -> cell 15, seg 0 (0.5) [0.5 on Ipop[15]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[15] syn_projEI_ampa[55] = new ampa(0.5)")
        h("Epop[2] netConn_projEI_ampa[55] = new NetCon(&v(0.5), syn_projEI_ampa[55], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 56: cell 2, seg 0 (0.5) [0.5 on Epop[2]] -> cell 16, seg 0 (0.5) [0.5 on Ipop[16]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[16] syn_projEI_ampa[56] = new ampa(0.5)")
        h("Epop[2] netConn_projEI_ampa[56] = new NetCon(&v(0.5), syn_projEI_ampa[56], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 57: cell 2, seg 0 (0.5) [0.5 on Epop[2]] -> cell 17, seg 0 (0.5) [0.5 on Ipop[17]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[17] syn_projEI_ampa[57] = new ampa(0.5)")
        h("Epop[2] netConn_projEI_ampa[57] = new NetCon(&v(0.5), syn_projEI_ampa[57], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 58: cell 2, seg 0 (0.5) [0.5 on Epop[2]] -> cell 18, seg 0 (0.5) [0.5 on Ipop[18]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[18] syn_projEI_ampa[58] = new ampa(0.5)")
        h("Epop[2] netConn_projEI_ampa[58] = new NetCon(&v(0.5), syn_projEI_ampa[58], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 59: cell 2, seg 0 (0.5) [0.5 on Epop[2]] -> cell 19, seg 0 (0.5) [0.5 on Ipop[19]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[19] syn_projEI_ampa[59] = new ampa(0.5)")
        h("Epop[2] netConn_projEI_ampa[59] = new NetCon(&v(0.5), syn_projEI_ampa[59], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 60: cell 3, seg 0 (0.5) [0.5 on Epop[3]] -> cell 0, seg 0 (0.5) [0.5 on Ipop[0]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[0] syn_projEI_ampa[60] = new ampa(0.5)")
        h("Epop[3] netConn_projEI_ampa[60] = new NetCon(&v(0.5), syn_projEI_ampa[60], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 61: cell 3, seg 0 (0.5) [0.5 on Epop[3]] -> cell 1, seg 0 (0.5) [0.5 on Ipop[1]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[1] syn_projEI_ampa[61] = new ampa(0.5)")
        h("Epop[3] netConn_projEI_ampa[61] = new NetCon(&v(0.5), syn_projEI_ampa[61], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 62: cell 3, seg 0 (0.5) [0.5 on Epop[3]] -> cell 2, seg 0 (0.5) [0.5 on Ipop[2]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[2] syn_projEI_ampa[62] = new ampa(0.5)")
        h("Epop[3] netConn_projEI_ampa[62] = new NetCon(&v(0.5), syn_projEI_ampa[62], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 63: cell 3, seg 0 (0.5) [0.5 on Epop[3]] -> cell 3, seg 0 (0.5) [0.5 on Ipop[3]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[3] syn_projEI_ampa[63] = new ampa(0.5)")
        h("Epop[3] netConn_projEI_ampa[63] = new NetCon(&v(0.5), syn_projEI_ampa[63], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 64: cell 3, seg 0 (0.5) [0.5 on Epop[3]] -> cell 4, seg 0 (0.5) [0.5 on Ipop[4]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[4] syn_projEI_ampa[64] = new ampa(0.5)")
        h("Epop[3] netConn_projEI_ampa[64] = new NetCon(&v(0.5), syn_projEI_ampa[64], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 65: cell 3, seg 0 (0.5) [0.5 on Epop[3]] -> cell 5, seg 0 (0.5) [0.5 on Ipop[5]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[5] syn_projEI_ampa[65] = new ampa(0.5)")
        h("Epop[3] netConn_projEI_ampa[65] = new NetCon(&v(0.5), syn_projEI_ampa[65], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 66: cell 3, seg 0 (0.5) [0.5 on Epop[3]] -> cell 6, seg 0 (0.5) [0.5 on Ipop[6]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[6] syn_projEI_ampa[66] = new ampa(0.5)")
        h("Epop[3] netConn_projEI_ampa[66] = new NetCon(&v(0.5), syn_projEI_ampa[66], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 67: cell 3, seg 0 (0.5) [0.5 on Epop[3]] -> cell 7, seg 0 (0.5) [0.5 on Ipop[7]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[7] syn_projEI_ampa[67] = new ampa(0.5)")
        h("Epop[3] netConn_projEI_ampa[67] = new NetCon(&v(0.5), syn_projEI_ampa[67], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 68: cell 3, seg 0 (0.5) [0.5 on Epop[3]] -> cell 8, seg 0 (0.5) [0.5 on Ipop[8]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[8] syn_projEI_ampa[68] = new ampa(0.5)")
        h("Epop[3] netConn_projEI_ampa[68] = new NetCon(&v(0.5), syn_projEI_ampa[68], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 69: cell 3, seg 0 (0.5) [0.5 on Epop[3]] -> cell 9, seg 0 (0.5) [0.5 on Ipop[9]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[9] syn_projEI_ampa[69] = new ampa(0.5)")
        h("Epop[3] netConn_projEI_ampa[69] = new NetCon(&v(0.5), syn_projEI_ampa[69], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 70: cell 3, seg 0 (0.5) [0.5 on Epop[3]] -> cell 10, seg 0 (0.5) [0.5 on Ipop[10]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[10] syn_projEI_ampa[70] = new ampa(0.5)")
        h("Epop[3] netConn_projEI_ampa[70] = new NetCon(&v(0.5), syn_projEI_ampa[70], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 71: cell 3, seg 0 (0.5) [0.5 on Epop[3]] -> cell 11, seg 0 (0.5) [0.5 on Ipop[11]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[11] syn_projEI_ampa[71] = new ampa(0.5)")
        h("Epop[3] netConn_projEI_ampa[71] = new NetCon(&v(0.5), syn_projEI_ampa[71], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 72: cell 3, seg 0 (0.5) [0.5 on Epop[3]] -> cell 12, seg 0 (0.5) [0.5 on Ipop[12]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[12] syn_projEI_ampa[72] = new ampa(0.5)")
        h("Epop[3] netConn_projEI_ampa[72] = new NetCon(&v(0.5), syn_projEI_ampa[72], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 73: cell 3, seg 0 (0.5) [0.5 on Epop[3]] -> cell 13, seg 0 (0.5) [0.5 on Ipop[13]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[13] syn_projEI_ampa[73] = new ampa(0.5)")
        h("Epop[3] netConn_projEI_ampa[73] = new NetCon(&v(0.5), syn_projEI_ampa[73], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 74: cell 3, seg 0 (0.5) [0.5 on Epop[3]] -> cell 14, seg 0 (0.5) [0.5 on Ipop[14]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[14] syn_projEI_ampa[74] = new ampa(0.5)")
        h("Epop[3] netConn_projEI_ampa[74] = new NetCon(&v(0.5), syn_projEI_ampa[74], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 75: cell 3, seg 0 (0.5) [0.5 on Epop[3]] -> cell 15, seg 0 (0.5) [0.5 on Ipop[15]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[15] syn_projEI_ampa[75] = new ampa(0.5)")
        h("Epop[3] netConn_projEI_ampa[75] = new NetCon(&v(0.5), syn_projEI_ampa[75], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 76: cell 3, seg 0 (0.5) [0.5 on Epop[3]] -> cell 16, seg 0 (0.5) [0.5 on Ipop[16]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[16] syn_projEI_ampa[76] = new ampa(0.5)")
        h("Epop[3] netConn_projEI_ampa[76] = new NetCon(&v(0.5), syn_projEI_ampa[76], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 77: cell 3, seg 0 (0.5) [0.5 on Epop[3]] -> cell 17, seg 0 (0.5) [0.5 on Ipop[17]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[17] syn_projEI_ampa[77] = new ampa(0.5)")
        h("Epop[3] netConn_projEI_ampa[77] = new NetCon(&v(0.5), syn_projEI_ampa[77], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 78: cell 3, seg 0 (0.5) [0.5 on Epop[3]] -> cell 18, seg 0 (0.5) [0.5 on Ipop[18]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[18] syn_projEI_ampa[78] = new ampa(0.5)")
        h("Epop[3] netConn_projEI_ampa[78] = new NetCon(&v(0.5), syn_projEI_ampa[78], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 79: cell 3, seg 0 (0.5) [0.5 on Epop[3]] -> cell 19, seg 0 (0.5) [0.5 on Ipop[19]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[19] syn_projEI_ampa[79] = new ampa(0.5)")
        h("Epop[3] netConn_projEI_ampa[79] = new NetCon(&v(0.5), syn_projEI_ampa[79], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 80: cell 4, seg 0 (0.5) [0.5 on Epop[4]] -> cell 0, seg 0 (0.5) [0.5 on Ipop[0]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[0] syn_projEI_ampa[80] = new ampa(0.5)")
        h("Epop[4] netConn_projEI_ampa[80] = new NetCon(&v(0.5), syn_projEI_ampa[80], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 81: cell 4, seg 0 (0.5) [0.5 on Epop[4]] -> cell 1, seg 0 (0.5) [0.5 on Ipop[1]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[1] syn_projEI_ampa[81] = new ampa(0.5)")
        h("Epop[4] netConn_projEI_ampa[81] = new NetCon(&v(0.5), syn_projEI_ampa[81], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 82: cell 4, seg 0 (0.5) [0.5 on Epop[4]] -> cell 2, seg 0 (0.5) [0.5 on Ipop[2]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[2] syn_projEI_ampa[82] = new ampa(0.5)")
        h("Epop[4] netConn_projEI_ampa[82] = new NetCon(&v(0.5), syn_projEI_ampa[82], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 83: cell 4, seg 0 (0.5) [0.5 on Epop[4]] -> cell 3, seg 0 (0.5) [0.5 on Ipop[3]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[3] syn_projEI_ampa[83] = new ampa(0.5)")
        h("Epop[4] netConn_projEI_ampa[83] = new NetCon(&v(0.5), syn_projEI_ampa[83], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 84: cell 4, seg 0 (0.5) [0.5 on Epop[4]] -> cell 4, seg 0 (0.5) [0.5 on Ipop[4]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[4] syn_projEI_ampa[84] = new ampa(0.5)")
        h("Epop[4] netConn_projEI_ampa[84] = new NetCon(&v(0.5), syn_projEI_ampa[84], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 85: cell 4, seg 0 (0.5) [0.5 on Epop[4]] -> cell 5, seg 0 (0.5) [0.5 on Ipop[5]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[5] syn_projEI_ampa[85] = new ampa(0.5)")
        h("Epop[4] netConn_projEI_ampa[85] = new NetCon(&v(0.5), syn_projEI_ampa[85], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 86: cell 4, seg 0 (0.5) [0.5 on Epop[4]] -> cell 6, seg 0 (0.5) [0.5 on Ipop[6]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[6] syn_projEI_ampa[86] = new ampa(0.5)")
        h("Epop[4] netConn_projEI_ampa[86] = new NetCon(&v(0.5), syn_projEI_ampa[86], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 87: cell 4, seg 0 (0.5) [0.5 on Epop[4]] -> cell 7, seg 0 (0.5) [0.5 on Ipop[7]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[7] syn_projEI_ampa[87] = new ampa(0.5)")
        h("Epop[4] netConn_projEI_ampa[87] = new NetCon(&v(0.5), syn_projEI_ampa[87], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 88: cell 4, seg 0 (0.5) [0.5 on Epop[4]] -> cell 8, seg 0 (0.5) [0.5 on Ipop[8]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[8] syn_projEI_ampa[88] = new ampa(0.5)")
        h("Epop[4] netConn_projEI_ampa[88] = new NetCon(&v(0.5), syn_projEI_ampa[88], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 89: cell 4, seg 0 (0.5) [0.5 on Epop[4]] -> cell 9, seg 0 (0.5) [0.5 on Ipop[9]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[9] syn_projEI_ampa[89] = new ampa(0.5)")
        h("Epop[4] netConn_projEI_ampa[89] = new NetCon(&v(0.5), syn_projEI_ampa[89], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 90: cell 4, seg 0 (0.5) [0.5 on Epop[4]] -> cell 10, seg 0 (0.5) [0.5 on Ipop[10]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[10] syn_projEI_ampa[90] = new ampa(0.5)")
        h("Epop[4] netConn_projEI_ampa[90] = new NetCon(&v(0.5), syn_projEI_ampa[90], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 91: cell 4, seg 0 (0.5) [0.5 on Epop[4]] -> cell 11, seg 0 (0.5) [0.5 on Ipop[11]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[11] syn_projEI_ampa[91] = new ampa(0.5)")
        h("Epop[4] netConn_projEI_ampa[91] = new NetCon(&v(0.5), syn_projEI_ampa[91], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 92: cell 4, seg 0 (0.5) [0.5 on Epop[4]] -> cell 12, seg 0 (0.5) [0.5 on Ipop[12]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[12] syn_projEI_ampa[92] = new ampa(0.5)")
        h("Epop[4] netConn_projEI_ampa[92] = new NetCon(&v(0.5), syn_projEI_ampa[92], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 93: cell 4, seg 0 (0.5) [0.5 on Epop[4]] -> cell 13, seg 0 (0.5) [0.5 on Ipop[13]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[13] syn_projEI_ampa[93] = new ampa(0.5)")
        h("Epop[4] netConn_projEI_ampa[93] = new NetCon(&v(0.5), syn_projEI_ampa[93], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 94: cell 4, seg 0 (0.5) [0.5 on Epop[4]] -> cell 14, seg 0 (0.5) [0.5 on Ipop[14]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[14] syn_projEI_ampa[94] = new ampa(0.5)")
        h("Epop[4] netConn_projEI_ampa[94] = new NetCon(&v(0.5), syn_projEI_ampa[94], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 95: cell 4, seg 0 (0.5) [0.5 on Epop[4]] -> cell 15, seg 0 (0.5) [0.5 on Ipop[15]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[15] syn_projEI_ampa[95] = new ampa(0.5)")
        h("Epop[4] netConn_projEI_ampa[95] = new NetCon(&v(0.5), syn_projEI_ampa[95], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 96: cell 4, seg 0 (0.5) [0.5 on Epop[4]] -> cell 16, seg 0 (0.5) [0.5 on Ipop[16]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[16] syn_projEI_ampa[96] = new ampa(0.5)")
        h("Epop[4] netConn_projEI_ampa[96] = new NetCon(&v(0.5), syn_projEI_ampa[96], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 97: cell 4, seg 0 (0.5) [0.5 on Epop[4]] -> cell 17, seg 0 (0.5) [0.5 on Ipop[17]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[17] syn_projEI_ampa[97] = new ampa(0.5)")
        h("Epop[4] netConn_projEI_ampa[97] = new NetCon(&v(0.5), syn_projEI_ampa[97], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 98: cell 4, seg 0 (0.5) [0.5 on Epop[4]] -> cell 18, seg 0 (0.5) [0.5 on Ipop[18]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[18] syn_projEI_ampa[98] = new ampa(0.5)")
        h("Epop[4] netConn_projEI_ampa[98] = new NetCon(&v(0.5), syn_projEI_ampa[98], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 99: cell 4, seg 0 (0.5) [0.5 on Epop[4]] -> cell 19, seg 0 (0.5) [0.5 on Ipop[19]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[19] syn_projEI_ampa[99] = new ampa(0.5)")
        h("Epop[4] netConn_projEI_ampa[99] = new NetCon(&v(0.5), syn_projEI_ampa[99], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 100: cell 5, seg 0 (0.5) [0.5 on Epop[5]] -> cell 0, seg 0 (0.5) [0.5 on Ipop[0]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[0] syn_projEI_ampa[100] = new ampa(0.5)")
        h("Epop[5] netConn_projEI_ampa[100] = new NetCon(&v(0.5), syn_projEI_ampa[100], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 101: cell 5, seg 0 (0.5) [0.5 on Epop[5]] -> cell 1, seg 0 (0.5) [0.5 on Ipop[1]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[1] syn_projEI_ampa[101] = new ampa(0.5)")
        h("Epop[5] netConn_projEI_ampa[101] = new NetCon(&v(0.5), syn_projEI_ampa[101], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 102: cell 5, seg 0 (0.5) [0.5 on Epop[5]] -> cell 2, seg 0 (0.5) [0.5 on Ipop[2]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[2] syn_projEI_ampa[102] = new ampa(0.5)")
        h("Epop[5] netConn_projEI_ampa[102] = new NetCon(&v(0.5), syn_projEI_ampa[102], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 103: cell 5, seg 0 (0.5) [0.5 on Epop[5]] -> cell 3, seg 0 (0.5) [0.5 on Ipop[3]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[3] syn_projEI_ampa[103] = new ampa(0.5)")
        h("Epop[5] netConn_projEI_ampa[103] = new NetCon(&v(0.5), syn_projEI_ampa[103], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 104: cell 5, seg 0 (0.5) [0.5 on Epop[5]] -> cell 4, seg 0 (0.5) [0.5 on Ipop[4]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[4] syn_projEI_ampa[104] = new ampa(0.5)")
        h("Epop[5] netConn_projEI_ampa[104] = new NetCon(&v(0.5), syn_projEI_ampa[104], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 105: cell 5, seg 0 (0.5) [0.5 on Epop[5]] -> cell 5, seg 0 (0.5) [0.5 on Ipop[5]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[5] syn_projEI_ampa[105] = new ampa(0.5)")
        h("Epop[5] netConn_projEI_ampa[105] = new NetCon(&v(0.5), syn_projEI_ampa[105], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 106: cell 5, seg 0 (0.5) [0.5 on Epop[5]] -> cell 6, seg 0 (0.5) [0.5 on Ipop[6]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[6] syn_projEI_ampa[106] = new ampa(0.5)")
        h("Epop[5] netConn_projEI_ampa[106] = new NetCon(&v(0.5), syn_projEI_ampa[106], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 107: cell 5, seg 0 (0.5) [0.5 on Epop[5]] -> cell 7, seg 0 (0.5) [0.5 on Ipop[7]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[7] syn_projEI_ampa[107] = new ampa(0.5)")
        h("Epop[5] netConn_projEI_ampa[107] = new NetCon(&v(0.5), syn_projEI_ampa[107], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 108: cell 5, seg 0 (0.5) [0.5 on Epop[5]] -> cell 8, seg 0 (0.5) [0.5 on Ipop[8]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[8] syn_projEI_ampa[108] = new ampa(0.5)")
        h("Epop[5] netConn_projEI_ampa[108] = new NetCon(&v(0.5), syn_projEI_ampa[108], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 109: cell 5, seg 0 (0.5) [0.5 on Epop[5]] -> cell 9, seg 0 (0.5) [0.5 on Ipop[9]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[9] syn_projEI_ampa[109] = new ampa(0.5)")
        h("Epop[5] netConn_projEI_ampa[109] = new NetCon(&v(0.5), syn_projEI_ampa[109], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 110: cell 5, seg 0 (0.5) [0.5 on Epop[5]] -> cell 10, seg 0 (0.5) [0.5 on Ipop[10]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[10] syn_projEI_ampa[110] = new ampa(0.5)")
        h("Epop[5] netConn_projEI_ampa[110] = new NetCon(&v(0.5), syn_projEI_ampa[110], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 111: cell 5, seg 0 (0.5) [0.5 on Epop[5]] -> cell 11, seg 0 (0.5) [0.5 on Ipop[11]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[11] syn_projEI_ampa[111] = new ampa(0.5)")
        h("Epop[5] netConn_projEI_ampa[111] = new NetCon(&v(0.5), syn_projEI_ampa[111], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 112: cell 5, seg 0 (0.5) [0.5 on Epop[5]] -> cell 12, seg 0 (0.5) [0.5 on Ipop[12]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[12] syn_projEI_ampa[112] = new ampa(0.5)")
        h("Epop[5] netConn_projEI_ampa[112] = new NetCon(&v(0.5), syn_projEI_ampa[112], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 113: cell 5, seg 0 (0.5) [0.5 on Epop[5]] -> cell 13, seg 0 (0.5) [0.5 on Ipop[13]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[13] syn_projEI_ampa[113] = new ampa(0.5)")
        h("Epop[5] netConn_projEI_ampa[113] = new NetCon(&v(0.5), syn_projEI_ampa[113], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 114: cell 5, seg 0 (0.5) [0.5 on Epop[5]] -> cell 14, seg 0 (0.5) [0.5 on Ipop[14]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[14] syn_projEI_ampa[114] = new ampa(0.5)")
        h("Epop[5] netConn_projEI_ampa[114] = new NetCon(&v(0.5), syn_projEI_ampa[114], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 115: cell 5, seg 0 (0.5) [0.5 on Epop[5]] -> cell 15, seg 0 (0.5) [0.5 on Ipop[15]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[15] syn_projEI_ampa[115] = new ampa(0.5)")
        h("Epop[5] netConn_projEI_ampa[115] = new NetCon(&v(0.5), syn_projEI_ampa[115], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 116: cell 5, seg 0 (0.5) [0.5 on Epop[5]] -> cell 16, seg 0 (0.5) [0.5 on Ipop[16]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[16] syn_projEI_ampa[116] = new ampa(0.5)")
        h("Epop[5] netConn_projEI_ampa[116] = new NetCon(&v(0.5), syn_projEI_ampa[116], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 117: cell 5, seg 0 (0.5) [0.5 on Epop[5]] -> cell 17, seg 0 (0.5) [0.5 on Ipop[17]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[17] syn_projEI_ampa[117] = new ampa(0.5)")
        h("Epop[5] netConn_projEI_ampa[117] = new NetCon(&v(0.5), syn_projEI_ampa[117], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 118: cell 5, seg 0 (0.5) [0.5 on Epop[5]] -> cell 18, seg 0 (0.5) [0.5 on Ipop[18]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[18] syn_projEI_ampa[118] = new ampa(0.5)")
        h("Epop[5] netConn_projEI_ampa[118] = new NetCon(&v(0.5), syn_projEI_ampa[118], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 119: cell 5, seg 0 (0.5) [0.5 on Epop[5]] -> cell 19, seg 0 (0.5) [0.5 on Ipop[19]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[19] syn_projEI_ampa[119] = new ampa(0.5)")
        h("Epop[5] netConn_projEI_ampa[119] = new NetCon(&v(0.5), syn_projEI_ampa[119], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 120: cell 6, seg 0 (0.5) [0.5 on Epop[6]] -> cell 0, seg 0 (0.5) [0.5 on Ipop[0]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[0] syn_projEI_ampa[120] = new ampa(0.5)")
        h("Epop[6] netConn_projEI_ampa[120] = new NetCon(&v(0.5), syn_projEI_ampa[120], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 121: cell 6, seg 0 (0.5) [0.5 on Epop[6]] -> cell 1, seg 0 (0.5) [0.5 on Ipop[1]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[1] syn_projEI_ampa[121] = new ampa(0.5)")
        h("Epop[6] netConn_projEI_ampa[121] = new NetCon(&v(0.5), syn_projEI_ampa[121], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 122: cell 6, seg 0 (0.5) [0.5 on Epop[6]] -> cell 2, seg 0 (0.5) [0.5 on Ipop[2]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[2] syn_projEI_ampa[122] = new ampa(0.5)")
        h("Epop[6] netConn_projEI_ampa[122] = new NetCon(&v(0.5), syn_projEI_ampa[122], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 123: cell 6, seg 0 (0.5) [0.5 on Epop[6]] -> cell 3, seg 0 (0.5) [0.5 on Ipop[3]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[3] syn_projEI_ampa[123] = new ampa(0.5)")
        h("Epop[6] netConn_projEI_ampa[123] = new NetCon(&v(0.5), syn_projEI_ampa[123], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 124: cell 6, seg 0 (0.5) [0.5 on Epop[6]] -> cell 4, seg 0 (0.5) [0.5 on Ipop[4]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[4] syn_projEI_ampa[124] = new ampa(0.5)")
        h("Epop[6] netConn_projEI_ampa[124] = new NetCon(&v(0.5), syn_projEI_ampa[124], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 125: cell 6, seg 0 (0.5) [0.5 on Epop[6]] -> cell 5, seg 0 (0.5) [0.5 on Ipop[5]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[5] syn_projEI_ampa[125] = new ampa(0.5)")
        h("Epop[6] netConn_projEI_ampa[125] = new NetCon(&v(0.5), syn_projEI_ampa[125], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 126: cell 6, seg 0 (0.5) [0.5 on Epop[6]] -> cell 6, seg 0 (0.5) [0.5 on Ipop[6]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[6] syn_projEI_ampa[126] = new ampa(0.5)")
        h("Epop[6] netConn_projEI_ampa[126] = new NetCon(&v(0.5), syn_projEI_ampa[126], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 127: cell 6, seg 0 (0.5) [0.5 on Epop[6]] -> cell 7, seg 0 (0.5) [0.5 on Ipop[7]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[7] syn_projEI_ampa[127] = new ampa(0.5)")
        h("Epop[6] netConn_projEI_ampa[127] = new NetCon(&v(0.5), syn_projEI_ampa[127], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 128: cell 6, seg 0 (0.5) [0.5 on Epop[6]] -> cell 8, seg 0 (0.5) [0.5 on Ipop[8]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[8] syn_projEI_ampa[128] = new ampa(0.5)")
        h("Epop[6] netConn_projEI_ampa[128] = new NetCon(&v(0.5), syn_projEI_ampa[128], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 129: cell 6, seg 0 (0.5) [0.5 on Epop[6]] -> cell 9, seg 0 (0.5) [0.5 on Ipop[9]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[9] syn_projEI_ampa[129] = new ampa(0.5)")
        h("Epop[6] netConn_projEI_ampa[129] = new NetCon(&v(0.5), syn_projEI_ampa[129], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 130: cell 6, seg 0 (0.5) [0.5 on Epop[6]] -> cell 10, seg 0 (0.5) [0.5 on Ipop[10]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[10] syn_projEI_ampa[130] = new ampa(0.5)")
        h("Epop[6] netConn_projEI_ampa[130] = new NetCon(&v(0.5), syn_projEI_ampa[130], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 131: cell 6, seg 0 (0.5) [0.5 on Epop[6]] -> cell 11, seg 0 (0.5) [0.5 on Ipop[11]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[11] syn_projEI_ampa[131] = new ampa(0.5)")
        h("Epop[6] netConn_projEI_ampa[131] = new NetCon(&v(0.5), syn_projEI_ampa[131], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 132: cell 6, seg 0 (0.5) [0.5 on Epop[6]] -> cell 12, seg 0 (0.5) [0.5 on Ipop[12]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[12] syn_projEI_ampa[132] = new ampa(0.5)")
        h("Epop[6] netConn_projEI_ampa[132] = new NetCon(&v(0.5), syn_projEI_ampa[132], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 133: cell 6, seg 0 (0.5) [0.5 on Epop[6]] -> cell 13, seg 0 (0.5) [0.5 on Ipop[13]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[13] syn_projEI_ampa[133] = new ampa(0.5)")
        h("Epop[6] netConn_projEI_ampa[133] = new NetCon(&v(0.5), syn_projEI_ampa[133], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 134: cell 6, seg 0 (0.5) [0.5 on Epop[6]] -> cell 14, seg 0 (0.5) [0.5 on Ipop[14]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[14] syn_projEI_ampa[134] = new ampa(0.5)")
        h("Epop[6] netConn_projEI_ampa[134] = new NetCon(&v(0.5), syn_projEI_ampa[134], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 135: cell 6, seg 0 (0.5) [0.5 on Epop[6]] -> cell 15, seg 0 (0.5) [0.5 on Ipop[15]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[15] syn_projEI_ampa[135] = new ampa(0.5)")
        h("Epop[6] netConn_projEI_ampa[135] = new NetCon(&v(0.5), syn_projEI_ampa[135], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 136: cell 6, seg 0 (0.5) [0.5 on Epop[6]] -> cell 16, seg 0 (0.5) [0.5 on Ipop[16]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[16] syn_projEI_ampa[136] = new ampa(0.5)")
        h("Epop[6] netConn_projEI_ampa[136] = new NetCon(&v(0.5), syn_projEI_ampa[136], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 137: cell 6, seg 0 (0.5) [0.5 on Epop[6]] -> cell 17, seg 0 (0.5) [0.5 on Ipop[17]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[17] syn_projEI_ampa[137] = new ampa(0.5)")
        h("Epop[6] netConn_projEI_ampa[137] = new NetCon(&v(0.5), syn_projEI_ampa[137], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 138: cell 6, seg 0 (0.5) [0.5 on Epop[6]] -> cell 18, seg 0 (0.5) [0.5 on Ipop[18]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[18] syn_projEI_ampa[138] = new ampa(0.5)")
        h("Epop[6] netConn_projEI_ampa[138] = new NetCon(&v(0.5), syn_projEI_ampa[138], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 139: cell 6, seg 0 (0.5) [0.5 on Epop[6]] -> cell 19, seg 0 (0.5) [0.5 on Ipop[19]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[19] syn_projEI_ampa[139] = new ampa(0.5)")
        h("Epop[6] netConn_projEI_ampa[139] = new NetCon(&v(0.5), syn_projEI_ampa[139], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 140: cell 7, seg 0 (0.5) [0.5 on Epop[7]] -> cell 0, seg 0 (0.5) [0.5 on Ipop[0]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[0] syn_projEI_ampa[140] = new ampa(0.5)")
        h("Epop[7] netConn_projEI_ampa[140] = new NetCon(&v(0.5), syn_projEI_ampa[140], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 141: cell 7, seg 0 (0.5) [0.5 on Epop[7]] -> cell 1, seg 0 (0.5) [0.5 on Ipop[1]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[1] syn_projEI_ampa[141] = new ampa(0.5)")
        h("Epop[7] netConn_projEI_ampa[141] = new NetCon(&v(0.5), syn_projEI_ampa[141], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 142: cell 7, seg 0 (0.5) [0.5 on Epop[7]] -> cell 2, seg 0 (0.5) [0.5 on Ipop[2]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[2] syn_projEI_ampa[142] = new ampa(0.5)")
        h("Epop[7] netConn_projEI_ampa[142] = new NetCon(&v(0.5), syn_projEI_ampa[142], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 143: cell 7, seg 0 (0.5) [0.5 on Epop[7]] -> cell 3, seg 0 (0.5) [0.5 on Ipop[3]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[3] syn_projEI_ampa[143] = new ampa(0.5)")
        h("Epop[7] netConn_projEI_ampa[143] = new NetCon(&v(0.5), syn_projEI_ampa[143], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 144: cell 7, seg 0 (0.5) [0.5 on Epop[7]] -> cell 4, seg 0 (0.5) [0.5 on Ipop[4]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[4] syn_projEI_ampa[144] = new ampa(0.5)")
        h("Epop[7] netConn_projEI_ampa[144] = new NetCon(&v(0.5), syn_projEI_ampa[144], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 145: cell 7, seg 0 (0.5) [0.5 on Epop[7]] -> cell 5, seg 0 (0.5) [0.5 on Ipop[5]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[5] syn_projEI_ampa[145] = new ampa(0.5)")
        h("Epop[7] netConn_projEI_ampa[145] = new NetCon(&v(0.5), syn_projEI_ampa[145], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 146: cell 7, seg 0 (0.5) [0.5 on Epop[7]] -> cell 6, seg 0 (0.5) [0.5 on Ipop[6]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[6] syn_projEI_ampa[146] = new ampa(0.5)")
        h("Epop[7] netConn_projEI_ampa[146] = new NetCon(&v(0.5), syn_projEI_ampa[146], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 147: cell 7, seg 0 (0.5) [0.5 on Epop[7]] -> cell 7, seg 0 (0.5) [0.5 on Ipop[7]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[7] syn_projEI_ampa[147] = new ampa(0.5)")
        h("Epop[7] netConn_projEI_ampa[147] = new NetCon(&v(0.5), syn_projEI_ampa[147], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 148: cell 7, seg 0 (0.5) [0.5 on Epop[7]] -> cell 8, seg 0 (0.5) [0.5 on Ipop[8]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[8] syn_projEI_ampa[148] = new ampa(0.5)")
        h("Epop[7] netConn_projEI_ampa[148] = new NetCon(&v(0.5), syn_projEI_ampa[148], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 149: cell 7, seg 0 (0.5) [0.5 on Epop[7]] -> cell 9, seg 0 (0.5) [0.5 on Ipop[9]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[9] syn_projEI_ampa[149] = new ampa(0.5)")
        h("Epop[7] netConn_projEI_ampa[149] = new NetCon(&v(0.5), syn_projEI_ampa[149], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 150: cell 7, seg 0 (0.5) [0.5 on Epop[7]] -> cell 10, seg 0 (0.5) [0.5 on Ipop[10]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[10] syn_projEI_ampa[150] = new ampa(0.5)")
        h("Epop[7] netConn_projEI_ampa[150] = new NetCon(&v(0.5), syn_projEI_ampa[150], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 151: cell 7, seg 0 (0.5) [0.5 on Epop[7]] -> cell 11, seg 0 (0.5) [0.5 on Ipop[11]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[11] syn_projEI_ampa[151] = new ampa(0.5)")
        h("Epop[7] netConn_projEI_ampa[151] = new NetCon(&v(0.5), syn_projEI_ampa[151], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 152: cell 7, seg 0 (0.5) [0.5 on Epop[7]] -> cell 12, seg 0 (0.5) [0.5 on Ipop[12]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[12] syn_projEI_ampa[152] = new ampa(0.5)")
        h("Epop[7] netConn_projEI_ampa[152] = new NetCon(&v(0.5), syn_projEI_ampa[152], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 153: cell 7, seg 0 (0.5) [0.5 on Epop[7]] -> cell 13, seg 0 (0.5) [0.5 on Ipop[13]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[13] syn_projEI_ampa[153] = new ampa(0.5)")
        h("Epop[7] netConn_projEI_ampa[153] = new NetCon(&v(0.5), syn_projEI_ampa[153], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 154: cell 7, seg 0 (0.5) [0.5 on Epop[7]] -> cell 14, seg 0 (0.5) [0.5 on Ipop[14]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[14] syn_projEI_ampa[154] = new ampa(0.5)")
        h("Epop[7] netConn_projEI_ampa[154] = new NetCon(&v(0.5), syn_projEI_ampa[154], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 155: cell 7, seg 0 (0.5) [0.5 on Epop[7]] -> cell 15, seg 0 (0.5) [0.5 on Ipop[15]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[15] syn_projEI_ampa[155] = new ampa(0.5)")
        h("Epop[7] netConn_projEI_ampa[155] = new NetCon(&v(0.5), syn_projEI_ampa[155], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 156: cell 7, seg 0 (0.5) [0.5 on Epop[7]] -> cell 16, seg 0 (0.5) [0.5 on Ipop[16]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[16] syn_projEI_ampa[156] = new ampa(0.5)")
        h("Epop[7] netConn_projEI_ampa[156] = new NetCon(&v(0.5), syn_projEI_ampa[156], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 157: cell 7, seg 0 (0.5) [0.5 on Epop[7]] -> cell 17, seg 0 (0.5) [0.5 on Ipop[17]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[17] syn_projEI_ampa[157] = new ampa(0.5)")
        h("Epop[7] netConn_projEI_ampa[157] = new NetCon(&v(0.5), syn_projEI_ampa[157], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 158: cell 7, seg 0 (0.5) [0.5 on Epop[7]] -> cell 18, seg 0 (0.5) [0.5 on Ipop[18]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[18] syn_projEI_ampa[158] = new ampa(0.5)")
        h("Epop[7] netConn_projEI_ampa[158] = new NetCon(&v(0.5), syn_projEI_ampa[158], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 159: cell 7, seg 0 (0.5) [0.5 on Epop[7]] -> cell 19, seg 0 (0.5) [0.5 on Ipop[19]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[19] syn_projEI_ampa[159] = new ampa(0.5)")
        h("Epop[7] netConn_projEI_ampa[159] = new NetCon(&v(0.5), syn_projEI_ampa[159], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 160: cell 8, seg 0 (0.5) [0.5 on Epop[8]] -> cell 0, seg 0 (0.5) [0.5 on Ipop[0]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[0] syn_projEI_ampa[160] = new ampa(0.5)")
        h("Epop[8] netConn_projEI_ampa[160] = new NetCon(&v(0.5), syn_projEI_ampa[160], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 161: cell 8, seg 0 (0.5) [0.5 on Epop[8]] -> cell 1, seg 0 (0.5) [0.5 on Ipop[1]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[1] syn_projEI_ampa[161] = new ampa(0.5)")
        h("Epop[8] netConn_projEI_ampa[161] = new NetCon(&v(0.5), syn_projEI_ampa[161], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 162: cell 8, seg 0 (0.5) [0.5 on Epop[8]] -> cell 2, seg 0 (0.5) [0.5 on Ipop[2]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[2] syn_projEI_ampa[162] = new ampa(0.5)")
        h("Epop[8] netConn_projEI_ampa[162] = new NetCon(&v(0.5), syn_projEI_ampa[162], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 163: cell 8, seg 0 (0.5) [0.5 on Epop[8]] -> cell 3, seg 0 (0.5) [0.5 on Ipop[3]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[3] syn_projEI_ampa[163] = new ampa(0.5)")
        h("Epop[8] netConn_projEI_ampa[163] = new NetCon(&v(0.5), syn_projEI_ampa[163], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 164: cell 8, seg 0 (0.5) [0.5 on Epop[8]] -> cell 4, seg 0 (0.5) [0.5 on Ipop[4]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[4] syn_projEI_ampa[164] = new ampa(0.5)")
        h("Epop[8] netConn_projEI_ampa[164] = new NetCon(&v(0.5), syn_projEI_ampa[164], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 165: cell 8, seg 0 (0.5) [0.5 on Epop[8]] -> cell 5, seg 0 (0.5) [0.5 on Ipop[5]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[5] syn_projEI_ampa[165] = new ampa(0.5)")
        h("Epop[8] netConn_projEI_ampa[165] = new NetCon(&v(0.5), syn_projEI_ampa[165], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 166: cell 8, seg 0 (0.5) [0.5 on Epop[8]] -> cell 6, seg 0 (0.5) [0.5 on Ipop[6]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[6] syn_projEI_ampa[166] = new ampa(0.5)")
        h("Epop[8] netConn_projEI_ampa[166] = new NetCon(&v(0.5), syn_projEI_ampa[166], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 167: cell 8, seg 0 (0.5) [0.5 on Epop[8]] -> cell 7, seg 0 (0.5) [0.5 on Ipop[7]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[7] syn_projEI_ampa[167] = new ampa(0.5)")
        h("Epop[8] netConn_projEI_ampa[167] = new NetCon(&v(0.5), syn_projEI_ampa[167], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 168: cell 8, seg 0 (0.5) [0.5 on Epop[8]] -> cell 8, seg 0 (0.5) [0.5 on Ipop[8]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[8] syn_projEI_ampa[168] = new ampa(0.5)")
        h("Epop[8] netConn_projEI_ampa[168] = new NetCon(&v(0.5), syn_projEI_ampa[168], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 169: cell 8, seg 0 (0.5) [0.5 on Epop[8]] -> cell 9, seg 0 (0.5) [0.5 on Ipop[9]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[9] syn_projEI_ampa[169] = new ampa(0.5)")
        h("Epop[8] netConn_projEI_ampa[169] = new NetCon(&v(0.5), syn_projEI_ampa[169], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 170: cell 8, seg 0 (0.5) [0.5 on Epop[8]] -> cell 10, seg 0 (0.5) [0.5 on Ipop[10]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[10] syn_projEI_ampa[170] = new ampa(0.5)")
        h("Epop[8] netConn_projEI_ampa[170] = new NetCon(&v(0.5), syn_projEI_ampa[170], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 171: cell 8, seg 0 (0.5) [0.5 on Epop[8]] -> cell 11, seg 0 (0.5) [0.5 on Ipop[11]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[11] syn_projEI_ampa[171] = new ampa(0.5)")
        h("Epop[8] netConn_projEI_ampa[171] = new NetCon(&v(0.5), syn_projEI_ampa[171], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 172: cell 8, seg 0 (0.5) [0.5 on Epop[8]] -> cell 12, seg 0 (0.5) [0.5 on Ipop[12]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[12] syn_projEI_ampa[172] = new ampa(0.5)")
        h("Epop[8] netConn_projEI_ampa[172] = new NetCon(&v(0.5), syn_projEI_ampa[172], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 173: cell 8, seg 0 (0.5) [0.5 on Epop[8]] -> cell 13, seg 0 (0.5) [0.5 on Ipop[13]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[13] syn_projEI_ampa[173] = new ampa(0.5)")
        h("Epop[8] netConn_projEI_ampa[173] = new NetCon(&v(0.5), syn_projEI_ampa[173], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 174: cell 8, seg 0 (0.5) [0.5 on Epop[8]] -> cell 14, seg 0 (0.5) [0.5 on Ipop[14]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[14] syn_projEI_ampa[174] = new ampa(0.5)")
        h("Epop[8] netConn_projEI_ampa[174] = new NetCon(&v(0.5), syn_projEI_ampa[174], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 175: cell 8, seg 0 (0.5) [0.5 on Epop[8]] -> cell 15, seg 0 (0.5) [0.5 on Ipop[15]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[15] syn_projEI_ampa[175] = new ampa(0.5)")
        h("Epop[8] netConn_projEI_ampa[175] = new NetCon(&v(0.5), syn_projEI_ampa[175], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 176: cell 8, seg 0 (0.5) [0.5 on Epop[8]] -> cell 16, seg 0 (0.5) [0.5 on Ipop[16]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[16] syn_projEI_ampa[176] = new ampa(0.5)")
        h("Epop[8] netConn_projEI_ampa[176] = new NetCon(&v(0.5), syn_projEI_ampa[176], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 177: cell 8, seg 0 (0.5) [0.5 on Epop[8]] -> cell 17, seg 0 (0.5) [0.5 on Ipop[17]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[17] syn_projEI_ampa[177] = new ampa(0.5)")
        h("Epop[8] netConn_projEI_ampa[177] = new NetCon(&v(0.5), syn_projEI_ampa[177], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 178: cell 8, seg 0 (0.5) [0.5 on Epop[8]] -> cell 18, seg 0 (0.5) [0.5 on Ipop[18]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[18] syn_projEI_ampa[178] = new ampa(0.5)")
        h("Epop[8] netConn_projEI_ampa[178] = new NetCon(&v(0.5), syn_projEI_ampa[178], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 179: cell 8, seg 0 (0.5) [0.5 on Epop[8]] -> cell 19, seg 0 (0.5) [0.5 on Ipop[19]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[19] syn_projEI_ampa[179] = new ampa(0.5)")
        h("Epop[8] netConn_projEI_ampa[179] = new NetCon(&v(0.5), syn_projEI_ampa[179], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 180: cell 9, seg 0 (0.5) [0.5 on Epop[9]] -> cell 0, seg 0 (0.5) [0.5 on Ipop[0]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[0] syn_projEI_ampa[180] = new ampa(0.5)")
        h("Epop[9] netConn_projEI_ampa[180] = new NetCon(&v(0.5), syn_projEI_ampa[180], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 181: cell 9, seg 0 (0.5) [0.5 on Epop[9]] -> cell 1, seg 0 (0.5) [0.5 on Ipop[1]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[1] syn_projEI_ampa[181] = new ampa(0.5)")
        h("Epop[9] netConn_projEI_ampa[181] = new NetCon(&v(0.5), syn_projEI_ampa[181], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 182: cell 9, seg 0 (0.5) [0.5 on Epop[9]] -> cell 2, seg 0 (0.5) [0.5 on Ipop[2]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[2] syn_projEI_ampa[182] = new ampa(0.5)")
        h("Epop[9] netConn_projEI_ampa[182] = new NetCon(&v(0.5), syn_projEI_ampa[182], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 183: cell 9, seg 0 (0.5) [0.5 on Epop[9]] -> cell 3, seg 0 (0.5) [0.5 on Ipop[3]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[3] syn_projEI_ampa[183] = new ampa(0.5)")
        h("Epop[9] netConn_projEI_ampa[183] = new NetCon(&v(0.5), syn_projEI_ampa[183], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 184: cell 9, seg 0 (0.5) [0.5 on Epop[9]] -> cell 4, seg 0 (0.5) [0.5 on Ipop[4]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[4] syn_projEI_ampa[184] = new ampa(0.5)")
        h("Epop[9] netConn_projEI_ampa[184] = new NetCon(&v(0.5), syn_projEI_ampa[184], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 185: cell 9, seg 0 (0.5) [0.5 on Epop[9]] -> cell 5, seg 0 (0.5) [0.5 on Ipop[5]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[5] syn_projEI_ampa[185] = new ampa(0.5)")
        h("Epop[9] netConn_projEI_ampa[185] = new NetCon(&v(0.5), syn_projEI_ampa[185], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 186: cell 9, seg 0 (0.5) [0.5 on Epop[9]] -> cell 6, seg 0 (0.5) [0.5 on Ipop[6]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[6] syn_projEI_ampa[186] = new ampa(0.5)")
        h("Epop[9] netConn_projEI_ampa[186] = new NetCon(&v(0.5), syn_projEI_ampa[186], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 187: cell 9, seg 0 (0.5) [0.5 on Epop[9]] -> cell 7, seg 0 (0.5) [0.5 on Ipop[7]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[7] syn_projEI_ampa[187] = new ampa(0.5)")
        h("Epop[9] netConn_projEI_ampa[187] = new NetCon(&v(0.5), syn_projEI_ampa[187], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 188: cell 9, seg 0 (0.5) [0.5 on Epop[9]] -> cell 8, seg 0 (0.5) [0.5 on Ipop[8]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[8] syn_projEI_ampa[188] = new ampa(0.5)")
        h("Epop[9] netConn_projEI_ampa[188] = new NetCon(&v(0.5), syn_projEI_ampa[188], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 189: cell 9, seg 0 (0.5) [0.5 on Epop[9]] -> cell 9, seg 0 (0.5) [0.5 on Ipop[9]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[9] syn_projEI_ampa[189] = new ampa(0.5)")
        h("Epop[9] netConn_projEI_ampa[189] = new NetCon(&v(0.5), syn_projEI_ampa[189], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 190: cell 9, seg 0 (0.5) [0.5 on Epop[9]] -> cell 10, seg 0 (0.5) [0.5 on Ipop[10]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[10] syn_projEI_ampa[190] = new ampa(0.5)")
        h("Epop[9] netConn_projEI_ampa[190] = new NetCon(&v(0.5), syn_projEI_ampa[190], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 191: cell 9, seg 0 (0.5) [0.5 on Epop[9]] -> cell 11, seg 0 (0.5) [0.5 on Ipop[11]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[11] syn_projEI_ampa[191] = new ampa(0.5)")
        h("Epop[9] netConn_projEI_ampa[191] = new NetCon(&v(0.5), syn_projEI_ampa[191], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 192: cell 9, seg 0 (0.5) [0.5 on Epop[9]] -> cell 12, seg 0 (0.5) [0.5 on Ipop[12]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[12] syn_projEI_ampa[192] = new ampa(0.5)")
        h("Epop[9] netConn_projEI_ampa[192] = new NetCon(&v(0.5), syn_projEI_ampa[192], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 193: cell 9, seg 0 (0.5) [0.5 on Epop[9]] -> cell 13, seg 0 (0.5) [0.5 on Ipop[13]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[13] syn_projEI_ampa[193] = new ampa(0.5)")
        h("Epop[9] netConn_projEI_ampa[193] = new NetCon(&v(0.5), syn_projEI_ampa[193], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 194: cell 9, seg 0 (0.5) [0.5 on Epop[9]] -> cell 14, seg 0 (0.5) [0.5 on Ipop[14]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[14] syn_projEI_ampa[194] = new ampa(0.5)")
        h("Epop[9] netConn_projEI_ampa[194] = new NetCon(&v(0.5), syn_projEI_ampa[194], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 195: cell 9, seg 0 (0.5) [0.5 on Epop[9]] -> cell 15, seg 0 (0.5) [0.5 on Ipop[15]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[15] syn_projEI_ampa[195] = new ampa(0.5)")
        h("Epop[9] netConn_projEI_ampa[195] = new NetCon(&v(0.5), syn_projEI_ampa[195], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 196: cell 9, seg 0 (0.5) [0.5 on Epop[9]] -> cell 16, seg 0 (0.5) [0.5 on Ipop[16]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[16] syn_projEI_ampa[196] = new ampa(0.5)")
        h("Epop[9] netConn_projEI_ampa[196] = new NetCon(&v(0.5), syn_projEI_ampa[196], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 197: cell 9, seg 0 (0.5) [0.5 on Epop[9]] -> cell 17, seg 0 (0.5) [0.5 on Ipop[17]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[17] syn_projEI_ampa[197] = new ampa(0.5)")
        h("Epop[9] netConn_projEI_ampa[197] = new NetCon(&v(0.5), syn_projEI_ampa[197], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 198: cell 9, seg 0 (0.5) [0.5 on Epop[9]] -> cell 18, seg 0 (0.5) [0.5 on Ipop[18]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[18] syn_projEI_ampa[198] = new ampa(0.5)")
        h("Epop[9] netConn_projEI_ampa[198] = new NetCon(&v(0.5), syn_projEI_ampa[198], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 199: cell 9, seg 0 (0.5) [0.5 on Epop[9]] -> cell 19, seg 0 (0.5) [0.5 on Ipop[19]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[19] syn_projEI_ampa[199] = new ampa(0.5)")
        h("Epop[9] netConn_projEI_ampa[199] = new NetCon(&v(0.5), syn_projEI_ampa[199], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 200: cell 10, seg 0 (0.5) [0.5 on Epop[10]] -> cell 0, seg 0 (0.5) [0.5 on Ipop[0]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[0] syn_projEI_ampa[200] = new ampa(0.5)")
        h("Epop[10] netConn_projEI_ampa[200] = new NetCon(&v(0.5), syn_projEI_ampa[200], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 201: cell 10, seg 0 (0.5) [0.5 on Epop[10]] -> cell 1, seg 0 (0.5) [0.5 on Ipop[1]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[1] syn_projEI_ampa[201] = new ampa(0.5)")
        h("Epop[10] netConn_projEI_ampa[201] = new NetCon(&v(0.5), syn_projEI_ampa[201], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 202: cell 10, seg 0 (0.5) [0.5 on Epop[10]] -> cell 2, seg 0 (0.5) [0.5 on Ipop[2]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[2] syn_projEI_ampa[202] = new ampa(0.5)")
        h("Epop[10] netConn_projEI_ampa[202] = new NetCon(&v(0.5), syn_projEI_ampa[202], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 203: cell 10, seg 0 (0.5) [0.5 on Epop[10]] -> cell 3, seg 0 (0.5) [0.5 on Ipop[3]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[3] syn_projEI_ampa[203] = new ampa(0.5)")
        h("Epop[10] netConn_projEI_ampa[203] = new NetCon(&v(0.5), syn_projEI_ampa[203], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 204: cell 10, seg 0 (0.5) [0.5 on Epop[10]] -> cell 4, seg 0 (0.5) [0.5 on Ipop[4]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[4] syn_projEI_ampa[204] = new ampa(0.5)")
        h("Epop[10] netConn_projEI_ampa[204] = new NetCon(&v(0.5), syn_projEI_ampa[204], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 205: cell 10, seg 0 (0.5) [0.5 on Epop[10]] -> cell 5, seg 0 (0.5) [0.5 on Ipop[5]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[5] syn_projEI_ampa[205] = new ampa(0.5)")
        h("Epop[10] netConn_projEI_ampa[205] = new NetCon(&v(0.5), syn_projEI_ampa[205], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 206: cell 10, seg 0 (0.5) [0.5 on Epop[10]] -> cell 6, seg 0 (0.5) [0.5 on Ipop[6]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[6] syn_projEI_ampa[206] = new ampa(0.5)")
        h("Epop[10] netConn_projEI_ampa[206] = new NetCon(&v(0.5), syn_projEI_ampa[206], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 207: cell 10, seg 0 (0.5) [0.5 on Epop[10]] -> cell 7, seg 0 (0.5) [0.5 on Ipop[7]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[7] syn_projEI_ampa[207] = new ampa(0.5)")
        h("Epop[10] netConn_projEI_ampa[207] = new NetCon(&v(0.5), syn_projEI_ampa[207], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 208: cell 10, seg 0 (0.5) [0.5 on Epop[10]] -> cell 8, seg 0 (0.5) [0.5 on Ipop[8]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[8] syn_projEI_ampa[208] = new ampa(0.5)")
        h("Epop[10] netConn_projEI_ampa[208] = new NetCon(&v(0.5), syn_projEI_ampa[208], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 209: cell 10, seg 0 (0.5) [0.5 on Epop[10]] -> cell 9, seg 0 (0.5) [0.5 on Ipop[9]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[9] syn_projEI_ampa[209] = new ampa(0.5)")
        h("Epop[10] netConn_projEI_ampa[209] = new NetCon(&v(0.5), syn_projEI_ampa[209], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 210: cell 10, seg 0 (0.5) [0.5 on Epop[10]] -> cell 10, seg 0 (0.5) [0.5 on Ipop[10]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[10] syn_projEI_ampa[210] = new ampa(0.5)")
        h("Epop[10] netConn_projEI_ampa[210] = new NetCon(&v(0.5), syn_projEI_ampa[210], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 211: cell 10, seg 0 (0.5) [0.5 on Epop[10]] -> cell 11, seg 0 (0.5) [0.5 on Ipop[11]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[11] syn_projEI_ampa[211] = new ampa(0.5)")
        h("Epop[10] netConn_projEI_ampa[211] = new NetCon(&v(0.5), syn_projEI_ampa[211], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 212: cell 10, seg 0 (0.5) [0.5 on Epop[10]] -> cell 12, seg 0 (0.5) [0.5 on Ipop[12]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[12] syn_projEI_ampa[212] = new ampa(0.5)")
        h("Epop[10] netConn_projEI_ampa[212] = new NetCon(&v(0.5), syn_projEI_ampa[212], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 213: cell 10, seg 0 (0.5) [0.5 on Epop[10]] -> cell 13, seg 0 (0.5) [0.5 on Ipop[13]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[13] syn_projEI_ampa[213] = new ampa(0.5)")
        h("Epop[10] netConn_projEI_ampa[213] = new NetCon(&v(0.5), syn_projEI_ampa[213], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 214: cell 10, seg 0 (0.5) [0.5 on Epop[10]] -> cell 14, seg 0 (0.5) [0.5 on Ipop[14]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[14] syn_projEI_ampa[214] = new ampa(0.5)")
        h("Epop[10] netConn_projEI_ampa[214] = new NetCon(&v(0.5), syn_projEI_ampa[214], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 215: cell 10, seg 0 (0.5) [0.5 on Epop[10]] -> cell 15, seg 0 (0.5) [0.5 on Ipop[15]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[15] syn_projEI_ampa[215] = new ampa(0.5)")
        h("Epop[10] netConn_projEI_ampa[215] = new NetCon(&v(0.5), syn_projEI_ampa[215], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 216: cell 10, seg 0 (0.5) [0.5 on Epop[10]] -> cell 16, seg 0 (0.5) [0.5 on Ipop[16]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[16] syn_projEI_ampa[216] = new ampa(0.5)")
        h("Epop[10] netConn_projEI_ampa[216] = new NetCon(&v(0.5), syn_projEI_ampa[216], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 217: cell 10, seg 0 (0.5) [0.5 on Epop[10]] -> cell 17, seg 0 (0.5) [0.5 on Ipop[17]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[17] syn_projEI_ampa[217] = new ampa(0.5)")
        h("Epop[10] netConn_projEI_ampa[217] = new NetCon(&v(0.5), syn_projEI_ampa[217], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 218: cell 10, seg 0 (0.5) [0.5 on Epop[10]] -> cell 18, seg 0 (0.5) [0.5 on Ipop[18]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[18] syn_projEI_ampa[218] = new ampa(0.5)")
        h("Epop[10] netConn_projEI_ampa[218] = new NetCon(&v(0.5), syn_projEI_ampa[218], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 219: cell 10, seg 0 (0.5) [0.5 on Epop[10]] -> cell 19, seg 0 (0.5) [0.5 on Ipop[19]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[19] syn_projEI_ampa[219] = new ampa(0.5)")
        h("Epop[10] netConn_projEI_ampa[219] = new NetCon(&v(0.5), syn_projEI_ampa[219], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 220: cell 11, seg 0 (0.5) [0.5 on Epop[11]] -> cell 0, seg 0 (0.5) [0.5 on Ipop[0]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[0] syn_projEI_ampa[220] = new ampa(0.5)")
        h("Epop[11] netConn_projEI_ampa[220] = new NetCon(&v(0.5), syn_projEI_ampa[220], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 221: cell 11, seg 0 (0.5) [0.5 on Epop[11]] -> cell 1, seg 0 (0.5) [0.5 on Ipop[1]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[1] syn_projEI_ampa[221] = new ampa(0.5)")
        h("Epop[11] netConn_projEI_ampa[221] = new NetCon(&v(0.5), syn_projEI_ampa[221], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 222: cell 11, seg 0 (0.5) [0.5 on Epop[11]] -> cell 2, seg 0 (0.5) [0.5 on Ipop[2]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[2] syn_projEI_ampa[222] = new ampa(0.5)")
        h("Epop[11] netConn_projEI_ampa[222] = new NetCon(&v(0.5), syn_projEI_ampa[222], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 223: cell 11, seg 0 (0.5) [0.5 on Epop[11]] -> cell 3, seg 0 (0.5) [0.5 on Ipop[3]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[3] syn_projEI_ampa[223] = new ampa(0.5)")
        h("Epop[11] netConn_projEI_ampa[223] = new NetCon(&v(0.5), syn_projEI_ampa[223], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 224: cell 11, seg 0 (0.5) [0.5 on Epop[11]] -> cell 4, seg 0 (0.5) [0.5 on Ipop[4]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[4] syn_projEI_ampa[224] = new ampa(0.5)")
        h("Epop[11] netConn_projEI_ampa[224] = new NetCon(&v(0.5), syn_projEI_ampa[224], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 225: cell 11, seg 0 (0.5) [0.5 on Epop[11]] -> cell 5, seg 0 (0.5) [0.5 on Ipop[5]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[5] syn_projEI_ampa[225] = new ampa(0.5)")
        h("Epop[11] netConn_projEI_ampa[225] = new NetCon(&v(0.5), syn_projEI_ampa[225], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 226: cell 11, seg 0 (0.5) [0.5 on Epop[11]] -> cell 6, seg 0 (0.5) [0.5 on Ipop[6]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[6] syn_projEI_ampa[226] = new ampa(0.5)")
        h("Epop[11] netConn_projEI_ampa[226] = new NetCon(&v(0.5), syn_projEI_ampa[226], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 227: cell 11, seg 0 (0.5) [0.5 on Epop[11]] -> cell 7, seg 0 (0.5) [0.5 on Ipop[7]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[7] syn_projEI_ampa[227] = new ampa(0.5)")
        h("Epop[11] netConn_projEI_ampa[227] = new NetCon(&v(0.5), syn_projEI_ampa[227], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 228: cell 11, seg 0 (0.5) [0.5 on Epop[11]] -> cell 8, seg 0 (0.5) [0.5 on Ipop[8]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[8] syn_projEI_ampa[228] = new ampa(0.5)")
        h("Epop[11] netConn_projEI_ampa[228] = new NetCon(&v(0.5), syn_projEI_ampa[228], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 229: cell 11, seg 0 (0.5) [0.5 on Epop[11]] -> cell 9, seg 0 (0.5) [0.5 on Ipop[9]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[9] syn_projEI_ampa[229] = new ampa(0.5)")
        h("Epop[11] netConn_projEI_ampa[229] = new NetCon(&v(0.5), syn_projEI_ampa[229], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 230: cell 11, seg 0 (0.5) [0.5 on Epop[11]] -> cell 10, seg 0 (0.5) [0.5 on Ipop[10]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[10] syn_projEI_ampa[230] = new ampa(0.5)")
        h("Epop[11] netConn_projEI_ampa[230] = new NetCon(&v(0.5), syn_projEI_ampa[230], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 231: cell 11, seg 0 (0.5) [0.5 on Epop[11]] -> cell 11, seg 0 (0.5) [0.5 on Ipop[11]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[11] syn_projEI_ampa[231] = new ampa(0.5)")
        h("Epop[11] netConn_projEI_ampa[231] = new NetCon(&v(0.5), syn_projEI_ampa[231], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 232: cell 11, seg 0 (0.5) [0.5 on Epop[11]] -> cell 12, seg 0 (0.5) [0.5 on Ipop[12]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[12] syn_projEI_ampa[232] = new ampa(0.5)")
        h("Epop[11] netConn_projEI_ampa[232] = new NetCon(&v(0.5), syn_projEI_ampa[232], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 233: cell 11, seg 0 (0.5) [0.5 on Epop[11]] -> cell 13, seg 0 (0.5) [0.5 on Ipop[13]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[13] syn_projEI_ampa[233] = new ampa(0.5)")
        h("Epop[11] netConn_projEI_ampa[233] = new NetCon(&v(0.5), syn_projEI_ampa[233], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 234: cell 11, seg 0 (0.5) [0.5 on Epop[11]] -> cell 14, seg 0 (0.5) [0.5 on Ipop[14]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[14] syn_projEI_ampa[234] = new ampa(0.5)")
        h("Epop[11] netConn_projEI_ampa[234] = new NetCon(&v(0.5), syn_projEI_ampa[234], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 235: cell 11, seg 0 (0.5) [0.5 on Epop[11]] -> cell 15, seg 0 (0.5) [0.5 on Ipop[15]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[15] syn_projEI_ampa[235] = new ampa(0.5)")
        h("Epop[11] netConn_projEI_ampa[235] = new NetCon(&v(0.5), syn_projEI_ampa[235], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 236: cell 11, seg 0 (0.5) [0.5 on Epop[11]] -> cell 16, seg 0 (0.5) [0.5 on Ipop[16]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[16] syn_projEI_ampa[236] = new ampa(0.5)")
        h("Epop[11] netConn_projEI_ampa[236] = new NetCon(&v(0.5), syn_projEI_ampa[236], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 237: cell 11, seg 0 (0.5) [0.5 on Epop[11]] -> cell 17, seg 0 (0.5) [0.5 on Ipop[17]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[17] syn_projEI_ampa[237] = new ampa(0.5)")
        h("Epop[11] netConn_projEI_ampa[237] = new NetCon(&v(0.5), syn_projEI_ampa[237], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 238: cell 11, seg 0 (0.5) [0.5 on Epop[11]] -> cell 18, seg 0 (0.5) [0.5 on Ipop[18]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[18] syn_projEI_ampa[238] = new ampa(0.5)")
        h("Epop[11] netConn_projEI_ampa[238] = new NetCon(&v(0.5), syn_projEI_ampa[238], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 239: cell 11, seg 0 (0.5) [0.5 on Epop[11]] -> cell 19, seg 0 (0.5) [0.5 on Ipop[19]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[19] syn_projEI_ampa[239] = new ampa(0.5)")
        h("Epop[11] netConn_projEI_ampa[239] = new NetCon(&v(0.5), syn_projEI_ampa[239], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 240: cell 12, seg 0 (0.5) [0.5 on Epop[12]] -> cell 0, seg 0 (0.5) [0.5 on Ipop[0]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[0] syn_projEI_ampa[240] = new ampa(0.5)")
        h("Epop[12] netConn_projEI_ampa[240] = new NetCon(&v(0.5), syn_projEI_ampa[240], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 241: cell 12, seg 0 (0.5) [0.5 on Epop[12]] -> cell 1, seg 0 (0.5) [0.5 on Ipop[1]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[1] syn_projEI_ampa[241] = new ampa(0.5)")
        h("Epop[12] netConn_projEI_ampa[241] = new NetCon(&v(0.5), syn_projEI_ampa[241], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 242: cell 12, seg 0 (0.5) [0.5 on Epop[12]] -> cell 2, seg 0 (0.5) [0.5 on Ipop[2]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[2] syn_projEI_ampa[242] = new ampa(0.5)")
        h("Epop[12] netConn_projEI_ampa[242] = new NetCon(&v(0.5), syn_projEI_ampa[242], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 243: cell 12, seg 0 (0.5) [0.5 on Epop[12]] -> cell 3, seg 0 (0.5) [0.5 on Ipop[3]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[3] syn_projEI_ampa[243] = new ampa(0.5)")
        h("Epop[12] netConn_projEI_ampa[243] = new NetCon(&v(0.5), syn_projEI_ampa[243], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 244: cell 12, seg 0 (0.5) [0.5 on Epop[12]] -> cell 4, seg 0 (0.5) [0.5 on Ipop[4]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[4] syn_projEI_ampa[244] = new ampa(0.5)")
        h("Epop[12] netConn_projEI_ampa[244] = new NetCon(&v(0.5), syn_projEI_ampa[244], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 245: cell 12, seg 0 (0.5) [0.5 on Epop[12]] -> cell 5, seg 0 (0.5) [0.5 on Ipop[5]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[5] syn_projEI_ampa[245] = new ampa(0.5)")
        h("Epop[12] netConn_projEI_ampa[245] = new NetCon(&v(0.5), syn_projEI_ampa[245], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 246: cell 12, seg 0 (0.5) [0.5 on Epop[12]] -> cell 6, seg 0 (0.5) [0.5 on Ipop[6]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[6] syn_projEI_ampa[246] = new ampa(0.5)")
        h("Epop[12] netConn_projEI_ampa[246] = new NetCon(&v(0.5), syn_projEI_ampa[246], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 247: cell 12, seg 0 (0.5) [0.5 on Epop[12]] -> cell 7, seg 0 (0.5) [0.5 on Ipop[7]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[7] syn_projEI_ampa[247] = new ampa(0.5)")
        h("Epop[12] netConn_projEI_ampa[247] = new NetCon(&v(0.5), syn_projEI_ampa[247], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 248: cell 12, seg 0 (0.5) [0.5 on Epop[12]] -> cell 8, seg 0 (0.5) [0.5 on Ipop[8]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[8] syn_projEI_ampa[248] = new ampa(0.5)")
        h("Epop[12] netConn_projEI_ampa[248] = new NetCon(&v(0.5), syn_projEI_ampa[248], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 249: cell 12, seg 0 (0.5) [0.5 on Epop[12]] -> cell 9, seg 0 (0.5) [0.5 on Ipop[9]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[9] syn_projEI_ampa[249] = new ampa(0.5)")
        h("Epop[12] netConn_projEI_ampa[249] = new NetCon(&v(0.5), syn_projEI_ampa[249], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 250: cell 12, seg 0 (0.5) [0.5 on Epop[12]] -> cell 10, seg 0 (0.5) [0.5 on Ipop[10]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[10] syn_projEI_ampa[250] = new ampa(0.5)")
        h("Epop[12] netConn_projEI_ampa[250] = new NetCon(&v(0.5), syn_projEI_ampa[250], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 251: cell 12, seg 0 (0.5) [0.5 on Epop[12]] -> cell 11, seg 0 (0.5) [0.5 on Ipop[11]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[11] syn_projEI_ampa[251] = new ampa(0.5)")
        h("Epop[12] netConn_projEI_ampa[251] = new NetCon(&v(0.5), syn_projEI_ampa[251], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 252: cell 12, seg 0 (0.5) [0.5 on Epop[12]] -> cell 12, seg 0 (0.5) [0.5 on Ipop[12]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[12] syn_projEI_ampa[252] = new ampa(0.5)")
        h("Epop[12] netConn_projEI_ampa[252] = new NetCon(&v(0.5), syn_projEI_ampa[252], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 253: cell 12, seg 0 (0.5) [0.5 on Epop[12]] -> cell 13, seg 0 (0.5) [0.5 on Ipop[13]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[13] syn_projEI_ampa[253] = new ampa(0.5)")
        h("Epop[12] netConn_projEI_ampa[253] = new NetCon(&v(0.5), syn_projEI_ampa[253], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 254: cell 12, seg 0 (0.5) [0.5 on Epop[12]] -> cell 14, seg 0 (0.5) [0.5 on Ipop[14]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[14] syn_projEI_ampa[254] = new ampa(0.5)")
        h("Epop[12] netConn_projEI_ampa[254] = new NetCon(&v(0.5), syn_projEI_ampa[254], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 255: cell 12, seg 0 (0.5) [0.5 on Epop[12]] -> cell 15, seg 0 (0.5) [0.5 on Ipop[15]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[15] syn_projEI_ampa[255] = new ampa(0.5)")
        h("Epop[12] netConn_projEI_ampa[255] = new NetCon(&v(0.5), syn_projEI_ampa[255], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 256: cell 12, seg 0 (0.5) [0.5 on Epop[12]] -> cell 16, seg 0 (0.5) [0.5 on Ipop[16]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[16] syn_projEI_ampa[256] = new ampa(0.5)")
        h("Epop[12] netConn_projEI_ampa[256] = new NetCon(&v(0.5), syn_projEI_ampa[256], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 257: cell 12, seg 0 (0.5) [0.5 on Epop[12]] -> cell 17, seg 0 (0.5) [0.5 on Ipop[17]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[17] syn_projEI_ampa[257] = new ampa(0.5)")
        h("Epop[12] netConn_projEI_ampa[257] = new NetCon(&v(0.5), syn_projEI_ampa[257], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 258: cell 12, seg 0 (0.5) [0.5 on Epop[12]] -> cell 18, seg 0 (0.5) [0.5 on Ipop[18]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[18] syn_projEI_ampa[258] = new ampa(0.5)")
        h("Epop[12] netConn_projEI_ampa[258] = new NetCon(&v(0.5), syn_projEI_ampa[258], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 259: cell 12, seg 0 (0.5) [0.5 on Epop[12]] -> cell 19, seg 0 (0.5) [0.5 on Ipop[19]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[19] syn_projEI_ampa[259] = new ampa(0.5)")
        h("Epop[12] netConn_projEI_ampa[259] = new NetCon(&v(0.5), syn_projEI_ampa[259], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 260: cell 13, seg 0 (0.5) [0.5 on Epop[13]] -> cell 0, seg 0 (0.5) [0.5 on Ipop[0]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[0] syn_projEI_ampa[260] = new ampa(0.5)")
        h("Epop[13] netConn_projEI_ampa[260] = new NetCon(&v(0.5), syn_projEI_ampa[260], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 261: cell 13, seg 0 (0.5) [0.5 on Epop[13]] -> cell 1, seg 0 (0.5) [0.5 on Ipop[1]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[1] syn_projEI_ampa[261] = new ampa(0.5)")
        h("Epop[13] netConn_projEI_ampa[261] = new NetCon(&v(0.5), syn_projEI_ampa[261], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 262: cell 13, seg 0 (0.5) [0.5 on Epop[13]] -> cell 2, seg 0 (0.5) [0.5 on Ipop[2]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[2] syn_projEI_ampa[262] = new ampa(0.5)")
        h("Epop[13] netConn_projEI_ampa[262] = new NetCon(&v(0.5), syn_projEI_ampa[262], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 263: cell 13, seg 0 (0.5) [0.5 on Epop[13]] -> cell 3, seg 0 (0.5) [0.5 on Ipop[3]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[3] syn_projEI_ampa[263] = new ampa(0.5)")
        h("Epop[13] netConn_projEI_ampa[263] = new NetCon(&v(0.5), syn_projEI_ampa[263], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 264: cell 13, seg 0 (0.5) [0.5 on Epop[13]] -> cell 4, seg 0 (0.5) [0.5 on Ipop[4]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[4] syn_projEI_ampa[264] = new ampa(0.5)")
        h("Epop[13] netConn_projEI_ampa[264] = new NetCon(&v(0.5), syn_projEI_ampa[264], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 265: cell 13, seg 0 (0.5) [0.5 on Epop[13]] -> cell 5, seg 0 (0.5) [0.5 on Ipop[5]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[5] syn_projEI_ampa[265] = new ampa(0.5)")
        h("Epop[13] netConn_projEI_ampa[265] = new NetCon(&v(0.5), syn_projEI_ampa[265], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 266: cell 13, seg 0 (0.5) [0.5 on Epop[13]] -> cell 6, seg 0 (0.5) [0.5 on Ipop[6]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[6] syn_projEI_ampa[266] = new ampa(0.5)")
        h("Epop[13] netConn_projEI_ampa[266] = new NetCon(&v(0.5), syn_projEI_ampa[266], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 267: cell 13, seg 0 (0.5) [0.5 on Epop[13]] -> cell 7, seg 0 (0.5) [0.5 on Ipop[7]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[7] syn_projEI_ampa[267] = new ampa(0.5)")
        h("Epop[13] netConn_projEI_ampa[267] = new NetCon(&v(0.5), syn_projEI_ampa[267], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 268: cell 13, seg 0 (0.5) [0.5 on Epop[13]] -> cell 8, seg 0 (0.5) [0.5 on Ipop[8]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[8] syn_projEI_ampa[268] = new ampa(0.5)")
        h("Epop[13] netConn_projEI_ampa[268] = new NetCon(&v(0.5), syn_projEI_ampa[268], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 269: cell 13, seg 0 (0.5) [0.5 on Epop[13]] -> cell 9, seg 0 (0.5) [0.5 on Ipop[9]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[9] syn_projEI_ampa[269] = new ampa(0.5)")
        h("Epop[13] netConn_projEI_ampa[269] = new NetCon(&v(0.5), syn_projEI_ampa[269], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 270: cell 13, seg 0 (0.5) [0.5 on Epop[13]] -> cell 10, seg 0 (0.5) [0.5 on Ipop[10]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[10] syn_projEI_ampa[270] = new ampa(0.5)")
        h("Epop[13] netConn_projEI_ampa[270] = new NetCon(&v(0.5), syn_projEI_ampa[270], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 271: cell 13, seg 0 (0.5) [0.5 on Epop[13]] -> cell 11, seg 0 (0.5) [0.5 on Ipop[11]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[11] syn_projEI_ampa[271] = new ampa(0.5)")
        h("Epop[13] netConn_projEI_ampa[271] = new NetCon(&v(0.5), syn_projEI_ampa[271], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 272: cell 13, seg 0 (0.5) [0.5 on Epop[13]] -> cell 12, seg 0 (0.5) [0.5 on Ipop[12]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[12] syn_projEI_ampa[272] = new ampa(0.5)")
        h("Epop[13] netConn_projEI_ampa[272] = new NetCon(&v(0.5), syn_projEI_ampa[272], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 273: cell 13, seg 0 (0.5) [0.5 on Epop[13]] -> cell 13, seg 0 (0.5) [0.5 on Ipop[13]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[13] syn_projEI_ampa[273] = new ampa(0.5)")
        h("Epop[13] netConn_projEI_ampa[273] = new NetCon(&v(0.5), syn_projEI_ampa[273], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 274: cell 13, seg 0 (0.5) [0.5 on Epop[13]] -> cell 14, seg 0 (0.5) [0.5 on Ipop[14]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[14] syn_projEI_ampa[274] = new ampa(0.5)")
        h("Epop[13] netConn_projEI_ampa[274] = new NetCon(&v(0.5), syn_projEI_ampa[274], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 275: cell 13, seg 0 (0.5) [0.5 on Epop[13]] -> cell 15, seg 0 (0.5) [0.5 on Ipop[15]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[15] syn_projEI_ampa[275] = new ampa(0.5)")
        h("Epop[13] netConn_projEI_ampa[275] = new NetCon(&v(0.5), syn_projEI_ampa[275], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 276: cell 13, seg 0 (0.5) [0.5 on Epop[13]] -> cell 16, seg 0 (0.5) [0.5 on Ipop[16]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[16] syn_projEI_ampa[276] = new ampa(0.5)")
        h("Epop[13] netConn_projEI_ampa[276] = new NetCon(&v(0.5), syn_projEI_ampa[276], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 277: cell 13, seg 0 (0.5) [0.5 on Epop[13]] -> cell 17, seg 0 (0.5) [0.5 on Ipop[17]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[17] syn_projEI_ampa[277] = new ampa(0.5)")
        h("Epop[13] netConn_projEI_ampa[277] = new NetCon(&v(0.5), syn_projEI_ampa[277], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 278: cell 13, seg 0 (0.5) [0.5 on Epop[13]] -> cell 18, seg 0 (0.5) [0.5 on Ipop[18]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[18] syn_projEI_ampa[278] = new ampa(0.5)")
        h("Epop[13] netConn_projEI_ampa[278] = new NetCon(&v(0.5), syn_projEI_ampa[278], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 279: cell 13, seg 0 (0.5) [0.5 on Epop[13]] -> cell 19, seg 0 (0.5) [0.5 on Ipop[19]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[19] syn_projEI_ampa[279] = new ampa(0.5)")
        h("Epop[13] netConn_projEI_ampa[279] = new NetCon(&v(0.5), syn_projEI_ampa[279], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 280: cell 14, seg 0 (0.5) [0.5 on Epop[14]] -> cell 0, seg 0 (0.5) [0.5 on Ipop[0]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[0] syn_projEI_ampa[280] = new ampa(0.5)")
        h("Epop[14] netConn_projEI_ampa[280] = new NetCon(&v(0.5), syn_projEI_ampa[280], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 281: cell 14, seg 0 (0.5) [0.5 on Epop[14]] -> cell 1, seg 0 (0.5) [0.5 on Ipop[1]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[1] syn_projEI_ampa[281] = new ampa(0.5)")
        h("Epop[14] netConn_projEI_ampa[281] = new NetCon(&v(0.5), syn_projEI_ampa[281], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 282: cell 14, seg 0 (0.5) [0.5 on Epop[14]] -> cell 2, seg 0 (0.5) [0.5 on Ipop[2]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[2] syn_projEI_ampa[282] = new ampa(0.5)")
        h("Epop[14] netConn_projEI_ampa[282] = new NetCon(&v(0.5), syn_projEI_ampa[282], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 283: cell 14, seg 0 (0.5) [0.5 on Epop[14]] -> cell 3, seg 0 (0.5) [0.5 on Ipop[3]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[3] syn_projEI_ampa[283] = new ampa(0.5)")
        h("Epop[14] netConn_projEI_ampa[283] = new NetCon(&v(0.5), syn_projEI_ampa[283], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 284: cell 14, seg 0 (0.5) [0.5 on Epop[14]] -> cell 4, seg 0 (0.5) [0.5 on Ipop[4]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[4] syn_projEI_ampa[284] = new ampa(0.5)")
        h("Epop[14] netConn_projEI_ampa[284] = new NetCon(&v(0.5), syn_projEI_ampa[284], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 285: cell 14, seg 0 (0.5) [0.5 on Epop[14]] -> cell 5, seg 0 (0.5) [0.5 on Ipop[5]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[5] syn_projEI_ampa[285] = new ampa(0.5)")
        h("Epop[14] netConn_projEI_ampa[285] = new NetCon(&v(0.5), syn_projEI_ampa[285], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 286: cell 14, seg 0 (0.5) [0.5 on Epop[14]] -> cell 6, seg 0 (0.5) [0.5 on Ipop[6]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[6] syn_projEI_ampa[286] = new ampa(0.5)")
        h("Epop[14] netConn_projEI_ampa[286] = new NetCon(&v(0.5), syn_projEI_ampa[286], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 287: cell 14, seg 0 (0.5) [0.5 on Epop[14]] -> cell 7, seg 0 (0.5) [0.5 on Ipop[7]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[7] syn_projEI_ampa[287] = new ampa(0.5)")
        h("Epop[14] netConn_projEI_ampa[287] = new NetCon(&v(0.5), syn_projEI_ampa[287], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 288: cell 14, seg 0 (0.5) [0.5 on Epop[14]] -> cell 8, seg 0 (0.5) [0.5 on Ipop[8]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[8] syn_projEI_ampa[288] = new ampa(0.5)")
        h("Epop[14] netConn_projEI_ampa[288] = new NetCon(&v(0.5), syn_projEI_ampa[288], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 289: cell 14, seg 0 (0.5) [0.5 on Epop[14]] -> cell 9, seg 0 (0.5) [0.5 on Ipop[9]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[9] syn_projEI_ampa[289] = new ampa(0.5)")
        h("Epop[14] netConn_projEI_ampa[289] = new NetCon(&v(0.5), syn_projEI_ampa[289], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 290: cell 14, seg 0 (0.5) [0.5 on Epop[14]] -> cell 10, seg 0 (0.5) [0.5 on Ipop[10]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[10] syn_projEI_ampa[290] = new ampa(0.5)")
        h("Epop[14] netConn_projEI_ampa[290] = new NetCon(&v(0.5), syn_projEI_ampa[290], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 291: cell 14, seg 0 (0.5) [0.5 on Epop[14]] -> cell 11, seg 0 (0.5) [0.5 on Ipop[11]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[11] syn_projEI_ampa[291] = new ampa(0.5)")
        h("Epop[14] netConn_projEI_ampa[291] = new NetCon(&v(0.5), syn_projEI_ampa[291], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 292: cell 14, seg 0 (0.5) [0.5 on Epop[14]] -> cell 12, seg 0 (0.5) [0.5 on Ipop[12]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[12] syn_projEI_ampa[292] = new ampa(0.5)")
        h("Epop[14] netConn_projEI_ampa[292] = new NetCon(&v(0.5), syn_projEI_ampa[292], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 293: cell 14, seg 0 (0.5) [0.5 on Epop[14]] -> cell 13, seg 0 (0.5) [0.5 on Ipop[13]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[13] syn_projEI_ampa[293] = new ampa(0.5)")
        h("Epop[14] netConn_projEI_ampa[293] = new NetCon(&v(0.5), syn_projEI_ampa[293], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 294: cell 14, seg 0 (0.5) [0.5 on Epop[14]] -> cell 14, seg 0 (0.5) [0.5 on Ipop[14]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[14] syn_projEI_ampa[294] = new ampa(0.5)")
        h("Epop[14] netConn_projEI_ampa[294] = new NetCon(&v(0.5), syn_projEI_ampa[294], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 295: cell 14, seg 0 (0.5) [0.5 on Epop[14]] -> cell 15, seg 0 (0.5) [0.5 on Ipop[15]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[15] syn_projEI_ampa[295] = new ampa(0.5)")
        h("Epop[14] netConn_projEI_ampa[295] = new NetCon(&v(0.5), syn_projEI_ampa[295], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 296: cell 14, seg 0 (0.5) [0.5 on Epop[14]] -> cell 16, seg 0 (0.5) [0.5 on Ipop[16]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[16] syn_projEI_ampa[296] = new ampa(0.5)")
        h("Epop[14] netConn_projEI_ampa[296] = new NetCon(&v(0.5), syn_projEI_ampa[296], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 297: cell 14, seg 0 (0.5) [0.5 on Epop[14]] -> cell 17, seg 0 (0.5) [0.5 on Ipop[17]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[17] syn_projEI_ampa[297] = new ampa(0.5)")
        h("Epop[14] netConn_projEI_ampa[297] = new NetCon(&v(0.5), syn_projEI_ampa[297], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 298: cell 14, seg 0 (0.5) [0.5 on Epop[14]] -> cell 18, seg 0 (0.5) [0.5 on Ipop[18]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[18] syn_projEI_ampa[298] = new ampa(0.5)")
        h("Epop[14] netConn_projEI_ampa[298] = new NetCon(&v(0.5), syn_projEI_ampa[298], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 299: cell 14, seg 0 (0.5) [0.5 on Epop[14]] -> cell 19, seg 0 (0.5) [0.5 on Ipop[19]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[19] syn_projEI_ampa[299] = new ampa(0.5)")
        h("Epop[14] netConn_projEI_ampa[299] = new NetCon(&v(0.5), syn_projEI_ampa[299], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 300: cell 15, seg 0 (0.5) [0.5 on Epop[15]] -> cell 0, seg 0 (0.5) [0.5 on Ipop[0]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[0] syn_projEI_ampa[300] = new ampa(0.5)")
        h("Epop[15] netConn_projEI_ampa[300] = new NetCon(&v(0.5), syn_projEI_ampa[300], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 301: cell 15, seg 0 (0.5) [0.5 on Epop[15]] -> cell 1, seg 0 (0.5) [0.5 on Ipop[1]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[1] syn_projEI_ampa[301] = new ampa(0.5)")
        h("Epop[15] netConn_projEI_ampa[301] = new NetCon(&v(0.5), syn_projEI_ampa[301], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 302: cell 15, seg 0 (0.5) [0.5 on Epop[15]] -> cell 2, seg 0 (0.5) [0.5 on Ipop[2]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[2] syn_projEI_ampa[302] = new ampa(0.5)")
        h("Epop[15] netConn_projEI_ampa[302] = new NetCon(&v(0.5), syn_projEI_ampa[302], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 303: cell 15, seg 0 (0.5) [0.5 on Epop[15]] -> cell 3, seg 0 (0.5) [0.5 on Ipop[3]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[3] syn_projEI_ampa[303] = new ampa(0.5)")
        h("Epop[15] netConn_projEI_ampa[303] = new NetCon(&v(0.5), syn_projEI_ampa[303], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 304: cell 15, seg 0 (0.5) [0.5 on Epop[15]] -> cell 4, seg 0 (0.5) [0.5 on Ipop[4]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[4] syn_projEI_ampa[304] = new ampa(0.5)")
        h("Epop[15] netConn_projEI_ampa[304] = new NetCon(&v(0.5), syn_projEI_ampa[304], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 305: cell 15, seg 0 (0.5) [0.5 on Epop[15]] -> cell 5, seg 0 (0.5) [0.5 on Ipop[5]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[5] syn_projEI_ampa[305] = new ampa(0.5)")
        h("Epop[15] netConn_projEI_ampa[305] = new NetCon(&v(0.5), syn_projEI_ampa[305], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 306: cell 15, seg 0 (0.5) [0.5 on Epop[15]] -> cell 6, seg 0 (0.5) [0.5 on Ipop[6]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[6] syn_projEI_ampa[306] = new ampa(0.5)")
        h("Epop[15] netConn_projEI_ampa[306] = new NetCon(&v(0.5), syn_projEI_ampa[306], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 307: cell 15, seg 0 (0.5) [0.5 on Epop[15]] -> cell 7, seg 0 (0.5) [0.5 on Ipop[7]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[7] syn_projEI_ampa[307] = new ampa(0.5)")
        h("Epop[15] netConn_projEI_ampa[307] = new NetCon(&v(0.5), syn_projEI_ampa[307], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 308: cell 15, seg 0 (0.5) [0.5 on Epop[15]] -> cell 8, seg 0 (0.5) [0.5 on Ipop[8]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[8] syn_projEI_ampa[308] = new ampa(0.5)")
        h("Epop[15] netConn_projEI_ampa[308] = new NetCon(&v(0.5), syn_projEI_ampa[308], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 309: cell 15, seg 0 (0.5) [0.5 on Epop[15]] -> cell 9, seg 0 (0.5) [0.5 on Ipop[9]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[9] syn_projEI_ampa[309] = new ampa(0.5)")
        h("Epop[15] netConn_projEI_ampa[309] = new NetCon(&v(0.5), syn_projEI_ampa[309], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 310: cell 15, seg 0 (0.5) [0.5 on Epop[15]] -> cell 10, seg 0 (0.5) [0.5 on Ipop[10]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[10] syn_projEI_ampa[310] = new ampa(0.5)")
        h("Epop[15] netConn_projEI_ampa[310] = new NetCon(&v(0.5), syn_projEI_ampa[310], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 311: cell 15, seg 0 (0.5) [0.5 on Epop[15]] -> cell 11, seg 0 (0.5) [0.5 on Ipop[11]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[11] syn_projEI_ampa[311] = new ampa(0.5)")
        h("Epop[15] netConn_projEI_ampa[311] = new NetCon(&v(0.5), syn_projEI_ampa[311], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 312: cell 15, seg 0 (0.5) [0.5 on Epop[15]] -> cell 12, seg 0 (0.5) [0.5 on Ipop[12]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[12] syn_projEI_ampa[312] = new ampa(0.5)")
        h("Epop[15] netConn_projEI_ampa[312] = new NetCon(&v(0.5), syn_projEI_ampa[312], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 313: cell 15, seg 0 (0.5) [0.5 on Epop[15]] -> cell 13, seg 0 (0.5) [0.5 on Ipop[13]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[13] syn_projEI_ampa[313] = new ampa(0.5)")
        h("Epop[15] netConn_projEI_ampa[313] = new NetCon(&v(0.5), syn_projEI_ampa[313], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 314: cell 15, seg 0 (0.5) [0.5 on Epop[15]] -> cell 14, seg 0 (0.5) [0.5 on Ipop[14]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[14] syn_projEI_ampa[314] = new ampa(0.5)")
        h("Epop[15] netConn_projEI_ampa[314] = new NetCon(&v(0.5), syn_projEI_ampa[314], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 315: cell 15, seg 0 (0.5) [0.5 on Epop[15]] -> cell 15, seg 0 (0.5) [0.5 on Ipop[15]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[15] syn_projEI_ampa[315] = new ampa(0.5)")
        h("Epop[15] netConn_projEI_ampa[315] = new NetCon(&v(0.5), syn_projEI_ampa[315], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 316: cell 15, seg 0 (0.5) [0.5 on Epop[15]] -> cell 16, seg 0 (0.5) [0.5 on Ipop[16]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[16] syn_projEI_ampa[316] = new ampa(0.5)")
        h("Epop[15] netConn_projEI_ampa[316] = new NetCon(&v(0.5), syn_projEI_ampa[316], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 317: cell 15, seg 0 (0.5) [0.5 on Epop[15]] -> cell 17, seg 0 (0.5) [0.5 on Ipop[17]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[17] syn_projEI_ampa[317] = new ampa(0.5)")
        h("Epop[15] netConn_projEI_ampa[317] = new NetCon(&v(0.5), syn_projEI_ampa[317], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 318: cell 15, seg 0 (0.5) [0.5 on Epop[15]] -> cell 18, seg 0 (0.5) [0.5 on Ipop[18]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[18] syn_projEI_ampa[318] = new ampa(0.5)")
        h("Epop[15] netConn_projEI_ampa[318] = new NetCon(&v(0.5), syn_projEI_ampa[318], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 319: cell 15, seg 0 (0.5) [0.5 on Epop[15]] -> cell 19, seg 0 (0.5) [0.5 on Ipop[19]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[19] syn_projEI_ampa[319] = new ampa(0.5)")
        h("Epop[15] netConn_projEI_ampa[319] = new NetCon(&v(0.5), syn_projEI_ampa[319], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 320: cell 16, seg 0 (0.5) [0.5 on Epop[16]] -> cell 0, seg 0 (0.5) [0.5 on Ipop[0]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[0] syn_projEI_ampa[320] = new ampa(0.5)")
        h("Epop[16] netConn_projEI_ampa[320] = new NetCon(&v(0.5), syn_projEI_ampa[320], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 321: cell 16, seg 0 (0.5) [0.5 on Epop[16]] -> cell 1, seg 0 (0.5) [0.5 on Ipop[1]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[1] syn_projEI_ampa[321] = new ampa(0.5)")
        h("Epop[16] netConn_projEI_ampa[321] = new NetCon(&v(0.5), syn_projEI_ampa[321], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 322: cell 16, seg 0 (0.5) [0.5 on Epop[16]] -> cell 2, seg 0 (0.5) [0.5 on Ipop[2]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[2] syn_projEI_ampa[322] = new ampa(0.5)")
        h("Epop[16] netConn_projEI_ampa[322] = new NetCon(&v(0.5), syn_projEI_ampa[322], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 323: cell 16, seg 0 (0.5) [0.5 on Epop[16]] -> cell 3, seg 0 (0.5) [0.5 on Ipop[3]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[3] syn_projEI_ampa[323] = new ampa(0.5)")
        h("Epop[16] netConn_projEI_ampa[323] = new NetCon(&v(0.5), syn_projEI_ampa[323], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 324: cell 16, seg 0 (0.5) [0.5 on Epop[16]] -> cell 4, seg 0 (0.5) [0.5 on Ipop[4]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[4] syn_projEI_ampa[324] = new ampa(0.5)")
        h("Epop[16] netConn_projEI_ampa[324] = new NetCon(&v(0.5), syn_projEI_ampa[324], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 325: cell 16, seg 0 (0.5) [0.5 on Epop[16]] -> cell 5, seg 0 (0.5) [0.5 on Ipop[5]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[5] syn_projEI_ampa[325] = new ampa(0.5)")
        h("Epop[16] netConn_projEI_ampa[325] = new NetCon(&v(0.5), syn_projEI_ampa[325], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 326: cell 16, seg 0 (0.5) [0.5 on Epop[16]] -> cell 6, seg 0 (0.5) [0.5 on Ipop[6]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[6] syn_projEI_ampa[326] = new ampa(0.5)")
        h("Epop[16] netConn_projEI_ampa[326] = new NetCon(&v(0.5), syn_projEI_ampa[326], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 327: cell 16, seg 0 (0.5) [0.5 on Epop[16]] -> cell 7, seg 0 (0.5) [0.5 on Ipop[7]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[7] syn_projEI_ampa[327] = new ampa(0.5)")
        h("Epop[16] netConn_projEI_ampa[327] = new NetCon(&v(0.5), syn_projEI_ampa[327], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 328: cell 16, seg 0 (0.5) [0.5 on Epop[16]] -> cell 8, seg 0 (0.5) [0.5 on Ipop[8]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[8] syn_projEI_ampa[328] = new ampa(0.5)")
        h("Epop[16] netConn_projEI_ampa[328] = new NetCon(&v(0.5), syn_projEI_ampa[328], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 329: cell 16, seg 0 (0.5) [0.5 on Epop[16]] -> cell 9, seg 0 (0.5) [0.5 on Ipop[9]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[9] syn_projEI_ampa[329] = new ampa(0.5)")
        h("Epop[16] netConn_projEI_ampa[329] = new NetCon(&v(0.5), syn_projEI_ampa[329], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 330: cell 16, seg 0 (0.5) [0.5 on Epop[16]] -> cell 10, seg 0 (0.5) [0.5 on Ipop[10]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[10] syn_projEI_ampa[330] = new ampa(0.5)")
        h("Epop[16] netConn_projEI_ampa[330] = new NetCon(&v(0.5), syn_projEI_ampa[330], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 331: cell 16, seg 0 (0.5) [0.5 on Epop[16]] -> cell 11, seg 0 (0.5) [0.5 on Ipop[11]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[11] syn_projEI_ampa[331] = new ampa(0.5)")
        h("Epop[16] netConn_projEI_ampa[331] = new NetCon(&v(0.5), syn_projEI_ampa[331], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 332: cell 16, seg 0 (0.5) [0.5 on Epop[16]] -> cell 12, seg 0 (0.5) [0.5 on Ipop[12]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[12] syn_projEI_ampa[332] = new ampa(0.5)")
        h("Epop[16] netConn_projEI_ampa[332] = new NetCon(&v(0.5), syn_projEI_ampa[332], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 333: cell 16, seg 0 (0.5) [0.5 on Epop[16]] -> cell 13, seg 0 (0.5) [0.5 on Ipop[13]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[13] syn_projEI_ampa[333] = new ampa(0.5)")
        h("Epop[16] netConn_projEI_ampa[333] = new NetCon(&v(0.5), syn_projEI_ampa[333], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 334: cell 16, seg 0 (0.5) [0.5 on Epop[16]] -> cell 14, seg 0 (0.5) [0.5 on Ipop[14]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[14] syn_projEI_ampa[334] = new ampa(0.5)")
        h("Epop[16] netConn_projEI_ampa[334] = new NetCon(&v(0.5), syn_projEI_ampa[334], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 335: cell 16, seg 0 (0.5) [0.5 on Epop[16]] -> cell 15, seg 0 (0.5) [0.5 on Ipop[15]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[15] syn_projEI_ampa[335] = new ampa(0.5)")
        h("Epop[16] netConn_projEI_ampa[335] = new NetCon(&v(0.5), syn_projEI_ampa[335], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 336: cell 16, seg 0 (0.5) [0.5 on Epop[16]] -> cell 16, seg 0 (0.5) [0.5 on Ipop[16]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[16] syn_projEI_ampa[336] = new ampa(0.5)")
        h("Epop[16] netConn_projEI_ampa[336] = new NetCon(&v(0.5), syn_projEI_ampa[336], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 337: cell 16, seg 0 (0.5) [0.5 on Epop[16]] -> cell 17, seg 0 (0.5) [0.5 on Ipop[17]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[17] syn_projEI_ampa[337] = new ampa(0.5)")
        h("Epop[16] netConn_projEI_ampa[337] = new NetCon(&v(0.5), syn_projEI_ampa[337], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 338: cell 16, seg 0 (0.5) [0.5 on Epop[16]] -> cell 18, seg 0 (0.5) [0.5 on Ipop[18]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[18] syn_projEI_ampa[338] = new ampa(0.5)")
        h("Epop[16] netConn_projEI_ampa[338] = new NetCon(&v(0.5), syn_projEI_ampa[338], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 339: cell 16, seg 0 (0.5) [0.5 on Epop[16]] -> cell 19, seg 0 (0.5) [0.5 on Ipop[19]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[19] syn_projEI_ampa[339] = new ampa(0.5)")
        h("Epop[16] netConn_projEI_ampa[339] = new NetCon(&v(0.5), syn_projEI_ampa[339], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 340: cell 17, seg 0 (0.5) [0.5 on Epop[17]] -> cell 0, seg 0 (0.5) [0.5 on Ipop[0]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[0] syn_projEI_ampa[340] = new ampa(0.5)")
        h("Epop[17] netConn_projEI_ampa[340] = new NetCon(&v(0.5), syn_projEI_ampa[340], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 341: cell 17, seg 0 (0.5) [0.5 on Epop[17]] -> cell 1, seg 0 (0.5) [0.5 on Ipop[1]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[1] syn_projEI_ampa[341] = new ampa(0.5)")
        h("Epop[17] netConn_projEI_ampa[341] = new NetCon(&v(0.5), syn_projEI_ampa[341], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 342: cell 17, seg 0 (0.5) [0.5 on Epop[17]] -> cell 2, seg 0 (0.5) [0.5 on Ipop[2]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[2] syn_projEI_ampa[342] = new ampa(0.5)")
        h("Epop[17] netConn_projEI_ampa[342] = new NetCon(&v(0.5), syn_projEI_ampa[342], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 343: cell 17, seg 0 (0.5) [0.5 on Epop[17]] -> cell 3, seg 0 (0.5) [0.5 on Ipop[3]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[3] syn_projEI_ampa[343] = new ampa(0.5)")
        h("Epop[17] netConn_projEI_ampa[343] = new NetCon(&v(0.5), syn_projEI_ampa[343], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 344: cell 17, seg 0 (0.5) [0.5 on Epop[17]] -> cell 4, seg 0 (0.5) [0.5 on Ipop[4]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[4] syn_projEI_ampa[344] = new ampa(0.5)")
        h("Epop[17] netConn_projEI_ampa[344] = new NetCon(&v(0.5), syn_projEI_ampa[344], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 345: cell 17, seg 0 (0.5) [0.5 on Epop[17]] -> cell 5, seg 0 (0.5) [0.5 on Ipop[5]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[5] syn_projEI_ampa[345] = new ampa(0.5)")
        h("Epop[17] netConn_projEI_ampa[345] = new NetCon(&v(0.5), syn_projEI_ampa[345], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 346: cell 17, seg 0 (0.5) [0.5 on Epop[17]] -> cell 6, seg 0 (0.5) [0.5 on Ipop[6]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[6] syn_projEI_ampa[346] = new ampa(0.5)")
        h("Epop[17] netConn_projEI_ampa[346] = new NetCon(&v(0.5), syn_projEI_ampa[346], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 347: cell 17, seg 0 (0.5) [0.5 on Epop[17]] -> cell 7, seg 0 (0.5) [0.5 on Ipop[7]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[7] syn_projEI_ampa[347] = new ampa(0.5)")
        h("Epop[17] netConn_projEI_ampa[347] = new NetCon(&v(0.5), syn_projEI_ampa[347], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 348: cell 17, seg 0 (0.5) [0.5 on Epop[17]] -> cell 8, seg 0 (0.5) [0.5 on Ipop[8]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[8] syn_projEI_ampa[348] = new ampa(0.5)")
        h("Epop[17] netConn_projEI_ampa[348] = new NetCon(&v(0.5), syn_projEI_ampa[348], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 349: cell 17, seg 0 (0.5) [0.5 on Epop[17]] -> cell 9, seg 0 (0.5) [0.5 on Ipop[9]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[9] syn_projEI_ampa[349] = new ampa(0.5)")
        h("Epop[17] netConn_projEI_ampa[349] = new NetCon(&v(0.5), syn_projEI_ampa[349], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 350: cell 17, seg 0 (0.5) [0.5 on Epop[17]] -> cell 10, seg 0 (0.5) [0.5 on Ipop[10]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[10] syn_projEI_ampa[350] = new ampa(0.5)")
        h("Epop[17] netConn_projEI_ampa[350] = new NetCon(&v(0.5), syn_projEI_ampa[350], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 351: cell 17, seg 0 (0.5) [0.5 on Epop[17]] -> cell 11, seg 0 (0.5) [0.5 on Ipop[11]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[11] syn_projEI_ampa[351] = new ampa(0.5)")
        h("Epop[17] netConn_projEI_ampa[351] = new NetCon(&v(0.5), syn_projEI_ampa[351], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 352: cell 17, seg 0 (0.5) [0.5 on Epop[17]] -> cell 12, seg 0 (0.5) [0.5 on Ipop[12]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[12] syn_projEI_ampa[352] = new ampa(0.5)")
        h("Epop[17] netConn_projEI_ampa[352] = new NetCon(&v(0.5), syn_projEI_ampa[352], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 353: cell 17, seg 0 (0.5) [0.5 on Epop[17]] -> cell 13, seg 0 (0.5) [0.5 on Ipop[13]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[13] syn_projEI_ampa[353] = new ampa(0.5)")
        h("Epop[17] netConn_projEI_ampa[353] = new NetCon(&v(0.5), syn_projEI_ampa[353], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 354: cell 17, seg 0 (0.5) [0.5 on Epop[17]] -> cell 14, seg 0 (0.5) [0.5 on Ipop[14]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[14] syn_projEI_ampa[354] = new ampa(0.5)")
        h("Epop[17] netConn_projEI_ampa[354] = new NetCon(&v(0.5), syn_projEI_ampa[354], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 355: cell 17, seg 0 (0.5) [0.5 on Epop[17]] -> cell 15, seg 0 (0.5) [0.5 on Ipop[15]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[15] syn_projEI_ampa[355] = new ampa(0.5)")
        h("Epop[17] netConn_projEI_ampa[355] = new NetCon(&v(0.5), syn_projEI_ampa[355], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 356: cell 17, seg 0 (0.5) [0.5 on Epop[17]] -> cell 16, seg 0 (0.5) [0.5 on Ipop[16]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[16] syn_projEI_ampa[356] = new ampa(0.5)")
        h("Epop[17] netConn_projEI_ampa[356] = new NetCon(&v(0.5), syn_projEI_ampa[356], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 357: cell 17, seg 0 (0.5) [0.5 on Epop[17]] -> cell 17, seg 0 (0.5) [0.5 on Ipop[17]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[17] syn_projEI_ampa[357] = new ampa(0.5)")
        h("Epop[17] netConn_projEI_ampa[357] = new NetCon(&v(0.5), syn_projEI_ampa[357], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 358: cell 17, seg 0 (0.5) [0.5 on Epop[17]] -> cell 18, seg 0 (0.5) [0.5 on Ipop[18]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[18] syn_projEI_ampa[358] = new ampa(0.5)")
        h("Epop[17] netConn_projEI_ampa[358] = new NetCon(&v(0.5), syn_projEI_ampa[358], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 359: cell 17, seg 0 (0.5) [0.5 on Epop[17]] -> cell 19, seg 0 (0.5) [0.5 on Ipop[19]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[19] syn_projEI_ampa[359] = new ampa(0.5)")
        h("Epop[17] netConn_projEI_ampa[359] = new NetCon(&v(0.5), syn_projEI_ampa[359], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 360: cell 18, seg 0 (0.5) [0.5 on Epop[18]] -> cell 0, seg 0 (0.5) [0.5 on Ipop[0]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[0] syn_projEI_ampa[360] = new ampa(0.5)")
        h("Epop[18] netConn_projEI_ampa[360] = new NetCon(&v(0.5), syn_projEI_ampa[360], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 361: cell 18, seg 0 (0.5) [0.5 on Epop[18]] -> cell 1, seg 0 (0.5) [0.5 on Ipop[1]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[1] syn_projEI_ampa[361] = new ampa(0.5)")
        h("Epop[18] netConn_projEI_ampa[361] = new NetCon(&v(0.5), syn_projEI_ampa[361], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 362: cell 18, seg 0 (0.5) [0.5 on Epop[18]] -> cell 2, seg 0 (0.5) [0.5 on Ipop[2]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[2] syn_projEI_ampa[362] = new ampa(0.5)")
        h("Epop[18] netConn_projEI_ampa[362] = new NetCon(&v(0.5), syn_projEI_ampa[362], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 363: cell 18, seg 0 (0.5) [0.5 on Epop[18]] -> cell 3, seg 0 (0.5) [0.5 on Ipop[3]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[3] syn_projEI_ampa[363] = new ampa(0.5)")
        h("Epop[18] netConn_projEI_ampa[363] = new NetCon(&v(0.5), syn_projEI_ampa[363], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 364: cell 18, seg 0 (0.5) [0.5 on Epop[18]] -> cell 4, seg 0 (0.5) [0.5 on Ipop[4]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[4] syn_projEI_ampa[364] = new ampa(0.5)")
        h("Epop[18] netConn_projEI_ampa[364] = new NetCon(&v(0.5), syn_projEI_ampa[364], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 365: cell 18, seg 0 (0.5) [0.5 on Epop[18]] -> cell 5, seg 0 (0.5) [0.5 on Ipop[5]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[5] syn_projEI_ampa[365] = new ampa(0.5)")
        h("Epop[18] netConn_projEI_ampa[365] = new NetCon(&v(0.5), syn_projEI_ampa[365], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 366: cell 18, seg 0 (0.5) [0.5 on Epop[18]] -> cell 6, seg 0 (0.5) [0.5 on Ipop[6]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[6] syn_projEI_ampa[366] = new ampa(0.5)")
        h("Epop[18] netConn_projEI_ampa[366] = new NetCon(&v(0.5), syn_projEI_ampa[366], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 367: cell 18, seg 0 (0.5) [0.5 on Epop[18]] -> cell 7, seg 0 (0.5) [0.5 on Ipop[7]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[7] syn_projEI_ampa[367] = new ampa(0.5)")
        h("Epop[18] netConn_projEI_ampa[367] = new NetCon(&v(0.5), syn_projEI_ampa[367], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 368: cell 18, seg 0 (0.5) [0.5 on Epop[18]] -> cell 8, seg 0 (0.5) [0.5 on Ipop[8]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[8] syn_projEI_ampa[368] = new ampa(0.5)")
        h("Epop[18] netConn_projEI_ampa[368] = new NetCon(&v(0.5), syn_projEI_ampa[368], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 369: cell 18, seg 0 (0.5) [0.5 on Epop[18]] -> cell 9, seg 0 (0.5) [0.5 on Ipop[9]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[9] syn_projEI_ampa[369] = new ampa(0.5)")
        h("Epop[18] netConn_projEI_ampa[369] = new NetCon(&v(0.5), syn_projEI_ampa[369], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 370: cell 18, seg 0 (0.5) [0.5 on Epop[18]] -> cell 10, seg 0 (0.5) [0.5 on Ipop[10]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[10] syn_projEI_ampa[370] = new ampa(0.5)")
        h("Epop[18] netConn_projEI_ampa[370] = new NetCon(&v(0.5), syn_projEI_ampa[370], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 371: cell 18, seg 0 (0.5) [0.5 on Epop[18]] -> cell 11, seg 0 (0.5) [0.5 on Ipop[11]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[11] syn_projEI_ampa[371] = new ampa(0.5)")
        h("Epop[18] netConn_projEI_ampa[371] = new NetCon(&v(0.5), syn_projEI_ampa[371], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 372: cell 18, seg 0 (0.5) [0.5 on Epop[18]] -> cell 12, seg 0 (0.5) [0.5 on Ipop[12]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[12] syn_projEI_ampa[372] = new ampa(0.5)")
        h("Epop[18] netConn_projEI_ampa[372] = new NetCon(&v(0.5), syn_projEI_ampa[372], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 373: cell 18, seg 0 (0.5) [0.5 on Epop[18]] -> cell 13, seg 0 (0.5) [0.5 on Ipop[13]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[13] syn_projEI_ampa[373] = new ampa(0.5)")
        h("Epop[18] netConn_projEI_ampa[373] = new NetCon(&v(0.5), syn_projEI_ampa[373], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 374: cell 18, seg 0 (0.5) [0.5 on Epop[18]] -> cell 14, seg 0 (0.5) [0.5 on Ipop[14]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[14] syn_projEI_ampa[374] = new ampa(0.5)")
        h("Epop[18] netConn_projEI_ampa[374] = new NetCon(&v(0.5), syn_projEI_ampa[374], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 375: cell 18, seg 0 (0.5) [0.5 on Epop[18]] -> cell 15, seg 0 (0.5) [0.5 on Ipop[15]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[15] syn_projEI_ampa[375] = new ampa(0.5)")
        h("Epop[18] netConn_projEI_ampa[375] = new NetCon(&v(0.5), syn_projEI_ampa[375], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 376: cell 18, seg 0 (0.5) [0.5 on Epop[18]] -> cell 16, seg 0 (0.5) [0.5 on Ipop[16]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[16] syn_projEI_ampa[376] = new ampa(0.5)")
        h("Epop[18] netConn_projEI_ampa[376] = new NetCon(&v(0.5), syn_projEI_ampa[376], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 377: cell 18, seg 0 (0.5) [0.5 on Epop[18]] -> cell 17, seg 0 (0.5) [0.5 on Ipop[17]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[17] syn_projEI_ampa[377] = new ampa(0.5)")
        h("Epop[18] netConn_projEI_ampa[377] = new NetCon(&v(0.5), syn_projEI_ampa[377], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 378: cell 18, seg 0 (0.5) [0.5 on Epop[18]] -> cell 18, seg 0 (0.5) [0.5 on Ipop[18]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[18] syn_projEI_ampa[378] = new ampa(0.5)")
        h("Epop[18] netConn_projEI_ampa[378] = new NetCon(&v(0.5), syn_projEI_ampa[378], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 379: cell 18, seg 0 (0.5) [0.5 on Epop[18]] -> cell 19, seg 0 (0.5) [0.5 on Ipop[19]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[19] syn_projEI_ampa[379] = new ampa(0.5)")
        h("Epop[18] netConn_projEI_ampa[379] = new NetCon(&v(0.5), syn_projEI_ampa[379], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 380: cell 19, seg 0 (0.5) [0.5 on Epop[19]] -> cell 0, seg 0 (0.5) [0.5 on Ipop[0]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[0] syn_projEI_ampa[380] = new ampa(0.5)")
        h("Epop[19] netConn_projEI_ampa[380] = new NetCon(&v(0.5), syn_projEI_ampa[380], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 381: cell 19, seg 0 (0.5) [0.5 on Epop[19]] -> cell 1, seg 0 (0.5) [0.5 on Ipop[1]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[1] syn_projEI_ampa[381] = new ampa(0.5)")
        h("Epop[19] netConn_projEI_ampa[381] = new NetCon(&v(0.5), syn_projEI_ampa[381], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 382: cell 19, seg 0 (0.5) [0.5 on Epop[19]] -> cell 2, seg 0 (0.5) [0.5 on Ipop[2]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[2] syn_projEI_ampa[382] = new ampa(0.5)")
        h("Epop[19] netConn_projEI_ampa[382] = new NetCon(&v(0.5), syn_projEI_ampa[382], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 383: cell 19, seg 0 (0.5) [0.5 on Epop[19]] -> cell 3, seg 0 (0.5) [0.5 on Ipop[3]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[3] syn_projEI_ampa[383] = new ampa(0.5)")
        h("Epop[19] netConn_projEI_ampa[383] = new NetCon(&v(0.5), syn_projEI_ampa[383], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 384: cell 19, seg 0 (0.5) [0.5 on Epop[19]] -> cell 4, seg 0 (0.5) [0.5 on Ipop[4]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[4] syn_projEI_ampa[384] = new ampa(0.5)")
        h("Epop[19] netConn_projEI_ampa[384] = new NetCon(&v(0.5), syn_projEI_ampa[384], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 385: cell 19, seg 0 (0.5) [0.5 on Epop[19]] -> cell 5, seg 0 (0.5) [0.5 on Ipop[5]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[5] syn_projEI_ampa[385] = new ampa(0.5)")
        h("Epop[19] netConn_projEI_ampa[385] = new NetCon(&v(0.5), syn_projEI_ampa[385], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 386: cell 19, seg 0 (0.5) [0.5 on Epop[19]] -> cell 6, seg 0 (0.5) [0.5 on Ipop[6]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[6] syn_projEI_ampa[386] = new ampa(0.5)")
        h("Epop[19] netConn_projEI_ampa[386] = new NetCon(&v(0.5), syn_projEI_ampa[386], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 387: cell 19, seg 0 (0.5) [0.5 on Epop[19]] -> cell 7, seg 0 (0.5) [0.5 on Ipop[7]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[7] syn_projEI_ampa[387] = new ampa(0.5)")
        h("Epop[19] netConn_projEI_ampa[387] = new NetCon(&v(0.5), syn_projEI_ampa[387], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 388: cell 19, seg 0 (0.5) [0.5 on Epop[19]] -> cell 8, seg 0 (0.5) [0.5 on Ipop[8]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[8] syn_projEI_ampa[388] = new ampa(0.5)")
        h("Epop[19] netConn_projEI_ampa[388] = new NetCon(&v(0.5), syn_projEI_ampa[388], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 389: cell 19, seg 0 (0.5) [0.5 on Epop[19]] -> cell 9, seg 0 (0.5) [0.5 on Ipop[9]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[9] syn_projEI_ampa[389] = new ampa(0.5)")
        h("Epop[19] netConn_projEI_ampa[389] = new NetCon(&v(0.5), syn_projEI_ampa[389], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 390: cell 19, seg 0 (0.5) [0.5 on Epop[19]] -> cell 10, seg 0 (0.5) [0.5 on Ipop[10]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[10] syn_projEI_ampa[390] = new ampa(0.5)")
        h("Epop[19] netConn_projEI_ampa[390] = new NetCon(&v(0.5), syn_projEI_ampa[390], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 391: cell 19, seg 0 (0.5) [0.5 on Epop[19]] -> cell 11, seg 0 (0.5) [0.5 on Ipop[11]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[11] syn_projEI_ampa[391] = new ampa(0.5)")
        h("Epop[19] netConn_projEI_ampa[391] = new NetCon(&v(0.5), syn_projEI_ampa[391], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 392: cell 19, seg 0 (0.5) [0.5 on Epop[19]] -> cell 12, seg 0 (0.5) [0.5 on Ipop[12]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[12] syn_projEI_ampa[392] = new ampa(0.5)")
        h("Epop[19] netConn_projEI_ampa[392] = new NetCon(&v(0.5), syn_projEI_ampa[392], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 393: cell 19, seg 0 (0.5) [0.5 on Epop[19]] -> cell 13, seg 0 (0.5) [0.5 on Ipop[13]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[13] syn_projEI_ampa[393] = new ampa(0.5)")
        h("Epop[19] netConn_projEI_ampa[393] = new NetCon(&v(0.5), syn_projEI_ampa[393], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 394: cell 19, seg 0 (0.5) [0.5 on Epop[19]] -> cell 14, seg 0 (0.5) [0.5 on Ipop[14]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[14] syn_projEI_ampa[394] = new ampa(0.5)")
        h("Epop[19] netConn_projEI_ampa[394] = new NetCon(&v(0.5), syn_projEI_ampa[394], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 395: cell 19, seg 0 (0.5) [0.5 on Epop[19]] -> cell 15, seg 0 (0.5) [0.5 on Ipop[15]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[15] syn_projEI_ampa[395] = new ampa(0.5)")
        h("Epop[19] netConn_projEI_ampa[395] = new NetCon(&v(0.5), syn_projEI_ampa[395], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 396: cell 19, seg 0 (0.5) [0.5 on Epop[19]] -> cell 16, seg 0 (0.5) [0.5 on Ipop[16]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[16] syn_projEI_ampa[396] = new ampa(0.5)")
        h("Epop[19] netConn_projEI_ampa[396] = new NetCon(&v(0.5), syn_projEI_ampa[396], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 397: cell 19, seg 0 (0.5) [0.5 on Epop[19]] -> cell 17, seg 0 (0.5) [0.5 on Ipop[17]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[17] syn_projEI_ampa[397] = new ampa(0.5)")
        h("Epop[19] netConn_projEI_ampa[397] = new NetCon(&v(0.5), syn_projEI_ampa[397], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 398: cell 19, seg 0 (0.5) [0.5 on Epop[19]] -> cell 18, seg 0 (0.5) [0.5 on Ipop[18]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[18] syn_projEI_ampa[398] = new ampa(0.5)")
        h("Epop[19] netConn_projEI_ampa[398] = new NetCon(&v(0.5), syn_projEI_ampa[398], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 399: cell 19, seg 0 (0.5) [0.5 on Epop[19]] -> cell 19, seg 0 (0.5) [0.5 on Ipop[19]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[19] syn_projEI_ampa[399] = new ampa(0.5)")
        h("Epop[19] netConn_projEI_ampa[399] = new NetCon(&v(0.5), syn_projEI_ampa[399], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 400: cell 20, seg 0 (0.5) [0.5 on Epop[20]] -> cell 0, seg 0 (0.5) [0.5 on Ipop[0]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[0] syn_projEI_ampa[400] = new ampa(0.5)")
        h("Epop[20] netConn_projEI_ampa[400] = new NetCon(&v(0.5), syn_projEI_ampa[400], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 401: cell 20, seg 0 (0.5) [0.5 on Epop[20]] -> cell 1, seg 0 (0.5) [0.5 on Ipop[1]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[1] syn_projEI_ampa[401] = new ampa(0.5)")
        h("Epop[20] netConn_projEI_ampa[401] = new NetCon(&v(0.5), syn_projEI_ampa[401], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 402: cell 20, seg 0 (0.5) [0.5 on Epop[20]] -> cell 2, seg 0 (0.5) [0.5 on Ipop[2]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[2] syn_projEI_ampa[402] = new ampa(0.5)")
        h("Epop[20] netConn_projEI_ampa[402] = new NetCon(&v(0.5), syn_projEI_ampa[402], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 403: cell 20, seg 0 (0.5) [0.5 on Epop[20]] -> cell 3, seg 0 (0.5) [0.5 on Ipop[3]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[3] syn_projEI_ampa[403] = new ampa(0.5)")
        h("Epop[20] netConn_projEI_ampa[403] = new NetCon(&v(0.5), syn_projEI_ampa[403], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 404: cell 20, seg 0 (0.5) [0.5 on Epop[20]] -> cell 4, seg 0 (0.5) [0.5 on Ipop[4]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[4] syn_projEI_ampa[404] = new ampa(0.5)")
        h("Epop[20] netConn_projEI_ampa[404] = new NetCon(&v(0.5), syn_projEI_ampa[404], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 405: cell 20, seg 0 (0.5) [0.5 on Epop[20]] -> cell 5, seg 0 (0.5) [0.5 on Ipop[5]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[5] syn_projEI_ampa[405] = new ampa(0.5)")
        h("Epop[20] netConn_projEI_ampa[405] = new NetCon(&v(0.5), syn_projEI_ampa[405], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 406: cell 20, seg 0 (0.5) [0.5 on Epop[20]] -> cell 6, seg 0 (0.5) [0.5 on Ipop[6]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[6] syn_projEI_ampa[406] = new ampa(0.5)")
        h("Epop[20] netConn_projEI_ampa[406] = new NetCon(&v(0.5), syn_projEI_ampa[406], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 407: cell 20, seg 0 (0.5) [0.5 on Epop[20]] -> cell 7, seg 0 (0.5) [0.5 on Ipop[7]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[7] syn_projEI_ampa[407] = new ampa(0.5)")
        h("Epop[20] netConn_projEI_ampa[407] = new NetCon(&v(0.5), syn_projEI_ampa[407], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 408: cell 20, seg 0 (0.5) [0.5 on Epop[20]] -> cell 8, seg 0 (0.5) [0.5 on Ipop[8]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[8] syn_projEI_ampa[408] = new ampa(0.5)")
        h("Epop[20] netConn_projEI_ampa[408] = new NetCon(&v(0.5), syn_projEI_ampa[408], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 409: cell 20, seg 0 (0.5) [0.5 on Epop[20]] -> cell 9, seg 0 (0.5) [0.5 on Ipop[9]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[9] syn_projEI_ampa[409] = new ampa(0.5)")
        h("Epop[20] netConn_projEI_ampa[409] = new NetCon(&v(0.5), syn_projEI_ampa[409], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 410: cell 20, seg 0 (0.5) [0.5 on Epop[20]] -> cell 10, seg 0 (0.5) [0.5 on Ipop[10]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[10] syn_projEI_ampa[410] = new ampa(0.5)")
        h("Epop[20] netConn_projEI_ampa[410] = new NetCon(&v(0.5), syn_projEI_ampa[410], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 411: cell 20, seg 0 (0.5) [0.5 on Epop[20]] -> cell 11, seg 0 (0.5) [0.5 on Ipop[11]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[11] syn_projEI_ampa[411] = new ampa(0.5)")
        h("Epop[20] netConn_projEI_ampa[411] = new NetCon(&v(0.5), syn_projEI_ampa[411], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 412: cell 20, seg 0 (0.5) [0.5 on Epop[20]] -> cell 12, seg 0 (0.5) [0.5 on Ipop[12]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[12] syn_projEI_ampa[412] = new ampa(0.5)")
        h("Epop[20] netConn_projEI_ampa[412] = new NetCon(&v(0.5), syn_projEI_ampa[412], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 413: cell 20, seg 0 (0.5) [0.5 on Epop[20]] -> cell 13, seg 0 (0.5) [0.5 on Ipop[13]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[13] syn_projEI_ampa[413] = new ampa(0.5)")
        h("Epop[20] netConn_projEI_ampa[413] = new NetCon(&v(0.5), syn_projEI_ampa[413], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 414: cell 20, seg 0 (0.5) [0.5 on Epop[20]] -> cell 14, seg 0 (0.5) [0.5 on Ipop[14]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[14] syn_projEI_ampa[414] = new ampa(0.5)")
        h("Epop[20] netConn_projEI_ampa[414] = new NetCon(&v(0.5), syn_projEI_ampa[414], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 415: cell 20, seg 0 (0.5) [0.5 on Epop[20]] -> cell 15, seg 0 (0.5) [0.5 on Ipop[15]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[15] syn_projEI_ampa[415] = new ampa(0.5)")
        h("Epop[20] netConn_projEI_ampa[415] = new NetCon(&v(0.5), syn_projEI_ampa[415], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 416: cell 20, seg 0 (0.5) [0.5 on Epop[20]] -> cell 16, seg 0 (0.5) [0.5 on Ipop[16]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[16] syn_projEI_ampa[416] = new ampa(0.5)")
        h("Epop[20] netConn_projEI_ampa[416] = new NetCon(&v(0.5), syn_projEI_ampa[416], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 417: cell 20, seg 0 (0.5) [0.5 on Epop[20]] -> cell 17, seg 0 (0.5) [0.5 on Ipop[17]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[17] syn_projEI_ampa[417] = new ampa(0.5)")
        h("Epop[20] netConn_projEI_ampa[417] = new NetCon(&v(0.5), syn_projEI_ampa[417], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 418: cell 20, seg 0 (0.5) [0.5 on Epop[20]] -> cell 18, seg 0 (0.5) [0.5 on Ipop[18]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[18] syn_projEI_ampa[418] = new ampa(0.5)")
        h("Epop[20] netConn_projEI_ampa[418] = new NetCon(&v(0.5), syn_projEI_ampa[418], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 419: cell 20, seg 0 (0.5) [0.5 on Epop[20]] -> cell 19, seg 0 (0.5) [0.5 on Ipop[19]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[19] syn_projEI_ampa[419] = new ampa(0.5)")
        h("Epop[20] netConn_projEI_ampa[419] = new NetCon(&v(0.5), syn_projEI_ampa[419], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 420: cell 21, seg 0 (0.5) [0.5 on Epop[21]] -> cell 0, seg 0 (0.5) [0.5 on Ipop[0]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[0] syn_projEI_ampa[420] = new ampa(0.5)")
        h("Epop[21] netConn_projEI_ampa[420] = new NetCon(&v(0.5), syn_projEI_ampa[420], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 421: cell 21, seg 0 (0.5) [0.5 on Epop[21]] -> cell 1, seg 0 (0.5) [0.5 on Ipop[1]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[1] syn_projEI_ampa[421] = new ampa(0.5)")
        h("Epop[21] netConn_projEI_ampa[421] = new NetCon(&v(0.5), syn_projEI_ampa[421], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 422: cell 21, seg 0 (0.5) [0.5 on Epop[21]] -> cell 2, seg 0 (0.5) [0.5 on Ipop[2]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[2] syn_projEI_ampa[422] = new ampa(0.5)")
        h("Epop[21] netConn_projEI_ampa[422] = new NetCon(&v(0.5), syn_projEI_ampa[422], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 423: cell 21, seg 0 (0.5) [0.5 on Epop[21]] -> cell 3, seg 0 (0.5) [0.5 on Ipop[3]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[3] syn_projEI_ampa[423] = new ampa(0.5)")
        h("Epop[21] netConn_projEI_ampa[423] = new NetCon(&v(0.5), syn_projEI_ampa[423], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 424: cell 21, seg 0 (0.5) [0.5 on Epop[21]] -> cell 4, seg 0 (0.5) [0.5 on Ipop[4]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[4] syn_projEI_ampa[424] = new ampa(0.5)")
        h("Epop[21] netConn_projEI_ampa[424] = new NetCon(&v(0.5), syn_projEI_ampa[424], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 425: cell 21, seg 0 (0.5) [0.5 on Epop[21]] -> cell 5, seg 0 (0.5) [0.5 on Ipop[5]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[5] syn_projEI_ampa[425] = new ampa(0.5)")
        h("Epop[21] netConn_projEI_ampa[425] = new NetCon(&v(0.5), syn_projEI_ampa[425], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 426: cell 21, seg 0 (0.5) [0.5 on Epop[21]] -> cell 6, seg 0 (0.5) [0.5 on Ipop[6]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[6] syn_projEI_ampa[426] = new ampa(0.5)")
        h("Epop[21] netConn_projEI_ampa[426] = new NetCon(&v(0.5), syn_projEI_ampa[426], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 427: cell 21, seg 0 (0.5) [0.5 on Epop[21]] -> cell 7, seg 0 (0.5) [0.5 on Ipop[7]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[7] syn_projEI_ampa[427] = new ampa(0.5)")
        h("Epop[21] netConn_projEI_ampa[427] = new NetCon(&v(0.5), syn_projEI_ampa[427], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 428: cell 21, seg 0 (0.5) [0.5 on Epop[21]] -> cell 8, seg 0 (0.5) [0.5 on Ipop[8]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[8] syn_projEI_ampa[428] = new ampa(0.5)")
        h("Epop[21] netConn_projEI_ampa[428] = new NetCon(&v(0.5), syn_projEI_ampa[428], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 429: cell 21, seg 0 (0.5) [0.5 on Epop[21]] -> cell 9, seg 0 (0.5) [0.5 on Ipop[9]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[9] syn_projEI_ampa[429] = new ampa(0.5)")
        h("Epop[21] netConn_projEI_ampa[429] = new NetCon(&v(0.5), syn_projEI_ampa[429], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 430: cell 21, seg 0 (0.5) [0.5 on Epop[21]] -> cell 10, seg 0 (0.5) [0.5 on Ipop[10]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[10] syn_projEI_ampa[430] = new ampa(0.5)")
        h("Epop[21] netConn_projEI_ampa[430] = new NetCon(&v(0.5), syn_projEI_ampa[430], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 431: cell 21, seg 0 (0.5) [0.5 on Epop[21]] -> cell 11, seg 0 (0.5) [0.5 on Ipop[11]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[11] syn_projEI_ampa[431] = new ampa(0.5)")
        h("Epop[21] netConn_projEI_ampa[431] = new NetCon(&v(0.5), syn_projEI_ampa[431], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 432: cell 21, seg 0 (0.5) [0.5 on Epop[21]] -> cell 12, seg 0 (0.5) [0.5 on Ipop[12]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[12] syn_projEI_ampa[432] = new ampa(0.5)")
        h("Epop[21] netConn_projEI_ampa[432] = new NetCon(&v(0.5), syn_projEI_ampa[432], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 433: cell 21, seg 0 (0.5) [0.5 on Epop[21]] -> cell 13, seg 0 (0.5) [0.5 on Ipop[13]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[13] syn_projEI_ampa[433] = new ampa(0.5)")
        h("Epop[21] netConn_projEI_ampa[433] = new NetCon(&v(0.5), syn_projEI_ampa[433], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 434: cell 21, seg 0 (0.5) [0.5 on Epop[21]] -> cell 14, seg 0 (0.5) [0.5 on Ipop[14]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[14] syn_projEI_ampa[434] = new ampa(0.5)")
        h("Epop[21] netConn_projEI_ampa[434] = new NetCon(&v(0.5), syn_projEI_ampa[434], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 435: cell 21, seg 0 (0.5) [0.5 on Epop[21]] -> cell 15, seg 0 (0.5) [0.5 on Ipop[15]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[15] syn_projEI_ampa[435] = new ampa(0.5)")
        h("Epop[21] netConn_projEI_ampa[435] = new NetCon(&v(0.5), syn_projEI_ampa[435], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 436: cell 21, seg 0 (0.5) [0.5 on Epop[21]] -> cell 16, seg 0 (0.5) [0.5 on Ipop[16]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[16] syn_projEI_ampa[436] = new ampa(0.5)")
        h("Epop[21] netConn_projEI_ampa[436] = new NetCon(&v(0.5), syn_projEI_ampa[436], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 437: cell 21, seg 0 (0.5) [0.5 on Epop[21]] -> cell 17, seg 0 (0.5) [0.5 on Ipop[17]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[17] syn_projEI_ampa[437] = new ampa(0.5)")
        h("Epop[21] netConn_projEI_ampa[437] = new NetCon(&v(0.5), syn_projEI_ampa[437], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 438: cell 21, seg 0 (0.5) [0.5 on Epop[21]] -> cell 18, seg 0 (0.5) [0.5 on Ipop[18]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[18] syn_projEI_ampa[438] = new ampa(0.5)")
        h("Epop[21] netConn_projEI_ampa[438] = new NetCon(&v(0.5), syn_projEI_ampa[438], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 439: cell 21, seg 0 (0.5) [0.5 on Epop[21]] -> cell 19, seg 0 (0.5) [0.5 on Ipop[19]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[19] syn_projEI_ampa[439] = new ampa(0.5)")
        h("Epop[21] netConn_projEI_ampa[439] = new NetCon(&v(0.5), syn_projEI_ampa[439], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 440: cell 22, seg 0 (0.5) [0.5 on Epop[22]] -> cell 0, seg 0 (0.5) [0.5 on Ipop[0]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[0] syn_projEI_ampa[440] = new ampa(0.5)")
        h("Epop[22] netConn_projEI_ampa[440] = new NetCon(&v(0.5), syn_projEI_ampa[440], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 441: cell 22, seg 0 (0.5) [0.5 on Epop[22]] -> cell 1, seg 0 (0.5) [0.5 on Ipop[1]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[1] syn_projEI_ampa[441] = new ampa(0.5)")
        h("Epop[22] netConn_projEI_ampa[441] = new NetCon(&v(0.5), syn_projEI_ampa[441], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 442: cell 22, seg 0 (0.5) [0.5 on Epop[22]] -> cell 2, seg 0 (0.5) [0.5 on Ipop[2]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[2] syn_projEI_ampa[442] = new ampa(0.5)")
        h("Epop[22] netConn_projEI_ampa[442] = new NetCon(&v(0.5), syn_projEI_ampa[442], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 443: cell 22, seg 0 (0.5) [0.5 on Epop[22]] -> cell 3, seg 0 (0.5) [0.5 on Ipop[3]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[3] syn_projEI_ampa[443] = new ampa(0.5)")
        h("Epop[22] netConn_projEI_ampa[443] = new NetCon(&v(0.5), syn_projEI_ampa[443], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 444: cell 22, seg 0 (0.5) [0.5 on Epop[22]] -> cell 4, seg 0 (0.5) [0.5 on Ipop[4]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[4] syn_projEI_ampa[444] = new ampa(0.5)")
        h("Epop[22] netConn_projEI_ampa[444] = new NetCon(&v(0.5), syn_projEI_ampa[444], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 445: cell 22, seg 0 (0.5) [0.5 on Epop[22]] -> cell 5, seg 0 (0.5) [0.5 on Ipop[5]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[5] syn_projEI_ampa[445] = new ampa(0.5)")
        h("Epop[22] netConn_projEI_ampa[445] = new NetCon(&v(0.5), syn_projEI_ampa[445], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 446: cell 22, seg 0 (0.5) [0.5 on Epop[22]] -> cell 6, seg 0 (0.5) [0.5 on Ipop[6]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[6] syn_projEI_ampa[446] = new ampa(0.5)")
        h("Epop[22] netConn_projEI_ampa[446] = new NetCon(&v(0.5), syn_projEI_ampa[446], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 447: cell 22, seg 0 (0.5) [0.5 on Epop[22]] -> cell 7, seg 0 (0.5) [0.5 on Ipop[7]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[7] syn_projEI_ampa[447] = new ampa(0.5)")
        h("Epop[22] netConn_projEI_ampa[447] = new NetCon(&v(0.5), syn_projEI_ampa[447], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 448: cell 22, seg 0 (0.5) [0.5 on Epop[22]] -> cell 8, seg 0 (0.5) [0.5 on Ipop[8]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[8] syn_projEI_ampa[448] = new ampa(0.5)")
        h("Epop[22] netConn_projEI_ampa[448] = new NetCon(&v(0.5), syn_projEI_ampa[448], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 449: cell 22, seg 0 (0.5) [0.5 on Epop[22]] -> cell 9, seg 0 (0.5) [0.5 on Ipop[9]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[9] syn_projEI_ampa[449] = new ampa(0.5)")
        h("Epop[22] netConn_projEI_ampa[449] = new NetCon(&v(0.5), syn_projEI_ampa[449], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 450: cell 22, seg 0 (0.5) [0.5 on Epop[22]] -> cell 10, seg 0 (0.5) [0.5 on Ipop[10]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[10] syn_projEI_ampa[450] = new ampa(0.5)")
        h("Epop[22] netConn_projEI_ampa[450] = new NetCon(&v(0.5), syn_projEI_ampa[450], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 451: cell 22, seg 0 (0.5) [0.5 on Epop[22]] -> cell 11, seg 0 (0.5) [0.5 on Ipop[11]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[11] syn_projEI_ampa[451] = new ampa(0.5)")
        h("Epop[22] netConn_projEI_ampa[451] = new NetCon(&v(0.5), syn_projEI_ampa[451], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 452: cell 22, seg 0 (0.5) [0.5 on Epop[22]] -> cell 12, seg 0 (0.5) [0.5 on Ipop[12]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[12] syn_projEI_ampa[452] = new ampa(0.5)")
        h("Epop[22] netConn_projEI_ampa[452] = new NetCon(&v(0.5), syn_projEI_ampa[452], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 453: cell 22, seg 0 (0.5) [0.5 on Epop[22]] -> cell 13, seg 0 (0.5) [0.5 on Ipop[13]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[13] syn_projEI_ampa[453] = new ampa(0.5)")
        h("Epop[22] netConn_projEI_ampa[453] = new NetCon(&v(0.5), syn_projEI_ampa[453], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 454: cell 22, seg 0 (0.5) [0.5 on Epop[22]] -> cell 14, seg 0 (0.5) [0.5 on Ipop[14]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[14] syn_projEI_ampa[454] = new ampa(0.5)")
        h("Epop[22] netConn_projEI_ampa[454] = new NetCon(&v(0.5), syn_projEI_ampa[454], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 455: cell 22, seg 0 (0.5) [0.5 on Epop[22]] -> cell 15, seg 0 (0.5) [0.5 on Ipop[15]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[15] syn_projEI_ampa[455] = new ampa(0.5)")
        h("Epop[22] netConn_projEI_ampa[455] = new NetCon(&v(0.5), syn_projEI_ampa[455], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 456: cell 22, seg 0 (0.5) [0.5 on Epop[22]] -> cell 16, seg 0 (0.5) [0.5 on Ipop[16]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[16] syn_projEI_ampa[456] = new ampa(0.5)")
        h("Epop[22] netConn_projEI_ampa[456] = new NetCon(&v(0.5), syn_projEI_ampa[456], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 457: cell 22, seg 0 (0.5) [0.5 on Epop[22]] -> cell 17, seg 0 (0.5) [0.5 on Ipop[17]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[17] syn_projEI_ampa[457] = new ampa(0.5)")
        h("Epop[22] netConn_projEI_ampa[457] = new NetCon(&v(0.5), syn_projEI_ampa[457], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 458: cell 22, seg 0 (0.5) [0.5 on Epop[22]] -> cell 18, seg 0 (0.5) [0.5 on Ipop[18]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[18] syn_projEI_ampa[458] = new ampa(0.5)")
        h("Epop[22] netConn_projEI_ampa[458] = new NetCon(&v(0.5), syn_projEI_ampa[458], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 459: cell 22, seg 0 (0.5) [0.5 on Epop[22]] -> cell 19, seg 0 (0.5) [0.5 on Ipop[19]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[19] syn_projEI_ampa[459] = new ampa(0.5)")
        h("Epop[22] netConn_projEI_ampa[459] = new NetCon(&v(0.5), syn_projEI_ampa[459], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 460: cell 23, seg 0 (0.5) [0.5 on Epop[23]] -> cell 0, seg 0 (0.5) [0.5 on Ipop[0]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[0] syn_projEI_ampa[460] = new ampa(0.5)")
        h("Epop[23] netConn_projEI_ampa[460] = new NetCon(&v(0.5), syn_projEI_ampa[460], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 461: cell 23, seg 0 (0.5) [0.5 on Epop[23]] -> cell 1, seg 0 (0.5) [0.5 on Ipop[1]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[1] syn_projEI_ampa[461] = new ampa(0.5)")
        h("Epop[23] netConn_projEI_ampa[461] = new NetCon(&v(0.5), syn_projEI_ampa[461], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 462: cell 23, seg 0 (0.5) [0.5 on Epop[23]] -> cell 2, seg 0 (0.5) [0.5 on Ipop[2]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[2] syn_projEI_ampa[462] = new ampa(0.5)")
        h("Epop[23] netConn_projEI_ampa[462] = new NetCon(&v(0.5), syn_projEI_ampa[462], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 463: cell 23, seg 0 (0.5) [0.5 on Epop[23]] -> cell 3, seg 0 (0.5) [0.5 on Ipop[3]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[3] syn_projEI_ampa[463] = new ampa(0.5)")
        h("Epop[23] netConn_projEI_ampa[463] = new NetCon(&v(0.5), syn_projEI_ampa[463], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 464: cell 23, seg 0 (0.5) [0.5 on Epop[23]] -> cell 4, seg 0 (0.5) [0.5 on Ipop[4]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[4] syn_projEI_ampa[464] = new ampa(0.5)")
        h("Epop[23] netConn_projEI_ampa[464] = new NetCon(&v(0.5), syn_projEI_ampa[464], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 465: cell 23, seg 0 (0.5) [0.5 on Epop[23]] -> cell 5, seg 0 (0.5) [0.5 on Ipop[5]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[5] syn_projEI_ampa[465] = new ampa(0.5)")
        h("Epop[23] netConn_projEI_ampa[465] = new NetCon(&v(0.5), syn_projEI_ampa[465], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 466: cell 23, seg 0 (0.5) [0.5 on Epop[23]] -> cell 6, seg 0 (0.5) [0.5 on Ipop[6]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[6] syn_projEI_ampa[466] = new ampa(0.5)")
        h("Epop[23] netConn_projEI_ampa[466] = new NetCon(&v(0.5), syn_projEI_ampa[466], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 467: cell 23, seg 0 (0.5) [0.5 on Epop[23]] -> cell 7, seg 0 (0.5) [0.5 on Ipop[7]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[7] syn_projEI_ampa[467] = new ampa(0.5)")
        h("Epop[23] netConn_projEI_ampa[467] = new NetCon(&v(0.5), syn_projEI_ampa[467], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 468: cell 23, seg 0 (0.5) [0.5 on Epop[23]] -> cell 8, seg 0 (0.5) [0.5 on Ipop[8]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[8] syn_projEI_ampa[468] = new ampa(0.5)")
        h("Epop[23] netConn_projEI_ampa[468] = new NetCon(&v(0.5), syn_projEI_ampa[468], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 469: cell 23, seg 0 (0.5) [0.5 on Epop[23]] -> cell 9, seg 0 (0.5) [0.5 on Ipop[9]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[9] syn_projEI_ampa[469] = new ampa(0.5)")
        h("Epop[23] netConn_projEI_ampa[469] = new NetCon(&v(0.5), syn_projEI_ampa[469], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 470: cell 23, seg 0 (0.5) [0.5 on Epop[23]] -> cell 10, seg 0 (0.5) [0.5 on Ipop[10]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[10] syn_projEI_ampa[470] = new ampa(0.5)")
        h("Epop[23] netConn_projEI_ampa[470] = new NetCon(&v(0.5), syn_projEI_ampa[470], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 471: cell 23, seg 0 (0.5) [0.5 on Epop[23]] -> cell 11, seg 0 (0.5) [0.5 on Ipop[11]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[11] syn_projEI_ampa[471] = new ampa(0.5)")
        h("Epop[23] netConn_projEI_ampa[471] = new NetCon(&v(0.5), syn_projEI_ampa[471], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 472: cell 23, seg 0 (0.5) [0.5 on Epop[23]] -> cell 12, seg 0 (0.5) [0.5 on Ipop[12]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[12] syn_projEI_ampa[472] = new ampa(0.5)")
        h("Epop[23] netConn_projEI_ampa[472] = new NetCon(&v(0.5), syn_projEI_ampa[472], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 473: cell 23, seg 0 (0.5) [0.5 on Epop[23]] -> cell 13, seg 0 (0.5) [0.5 on Ipop[13]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[13] syn_projEI_ampa[473] = new ampa(0.5)")
        h("Epop[23] netConn_projEI_ampa[473] = new NetCon(&v(0.5), syn_projEI_ampa[473], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 474: cell 23, seg 0 (0.5) [0.5 on Epop[23]] -> cell 14, seg 0 (0.5) [0.5 on Ipop[14]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[14] syn_projEI_ampa[474] = new ampa(0.5)")
        h("Epop[23] netConn_projEI_ampa[474] = new NetCon(&v(0.5), syn_projEI_ampa[474], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 475: cell 23, seg 0 (0.5) [0.5 on Epop[23]] -> cell 15, seg 0 (0.5) [0.5 on Ipop[15]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[15] syn_projEI_ampa[475] = new ampa(0.5)")
        h("Epop[23] netConn_projEI_ampa[475] = new NetCon(&v(0.5), syn_projEI_ampa[475], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 476: cell 23, seg 0 (0.5) [0.5 on Epop[23]] -> cell 16, seg 0 (0.5) [0.5 on Ipop[16]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[16] syn_projEI_ampa[476] = new ampa(0.5)")
        h("Epop[23] netConn_projEI_ampa[476] = new NetCon(&v(0.5), syn_projEI_ampa[476], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 477: cell 23, seg 0 (0.5) [0.5 on Epop[23]] -> cell 17, seg 0 (0.5) [0.5 on Ipop[17]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[17] syn_projEI_ampa[477] = new ampa(0.5)")
        h("Epop[23] netConn_projEI_ampa[477] = new NetCon(&v(0.5), syn_projEI_ampa[477], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 478: cell 23, seg 0 (0.5) [0.5 on Epop[23]] -> cell 18, seg 0 (0.5) [0.5 on Ipop[18]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[18] syn_projEI_ampa[478] = new ampa(0.5)")
        h("Epop[23] netConn_projEI_ampa[478] = new NetCon(&v(0.5), syn_projEI_ampa[478], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 479: cell 23, seg 0 (0.5) [0.5 on Epop[23]] -> cell 19, seg 0 (0.5) [0.5 on Ipop[19]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[19] syn_projEI_ampa[479] = new ampa(0.5)")
        h("Epop[23] netConn_projEI_ampa[479] = new NetCon(&v(0.5), syn_projEI_ampa[479], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 480: cell 24, seg 0 (0.5) [0.5 on Epop[24]] -> cell 0, seg 0 (0.5) [0.5 on Ipop[0]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[0] syn_projEI_ampa[480] = new ampa(0.5)")
        h("Epop[24] netConn_projEI_ampa[480] = new NetCon(&v(0.5), syn_projEI_ampa[480], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 481: cell 24, seg 0 (0.5) [0.5 on Epop[24]] -> cell 1, seg 0 (0.5) [0.5 on Ipop[1]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[1] syn_projEI_ampa[481] = new ampa(0.5)")
        h("Epop[24] netConn_projEI_ampa[481] = new NetCon(&v(0.5), syn_projEI_ampa[481], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 482: cell 24, seg 0 (0.5) [0.5 on Epop[24]] -> cell 2, seg 0 (0.5) [0.5 on Ipop[2]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[2] syn_projEI_ampa[482] = new ampa(0.5)")
        h("Epop[24] netConn_projEI_ampa[482] = new NetCon(&v(0.5), syn_projEI_ampa[482], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 483: cell 24, seg 0 (0.5) [0.5 on Epop[24]] -> cell 3, seg 0 (0.5) [0.5 on Ipop[3]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[3] syn_projEI_ampa[483] = new ampa(0.5)")
        h("Epop[24] netConn_projEI_ampa[483] = new NetCon(&v(0.5), syn_projEI_ampa[483], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 484: cell 24, seg 0 (0.5) [0.5 on Epop[24]] -> cell 4, seg 0 (0.5) [0.5 on Ipop[4]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[4] syn_projEI_ampa[484] = new ampa(0.5)")
        h("Epop[24] netConn_projEI_ampa[484] = new NetCon(&v(0.5), syn_projEI_ampa[484], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 485: cell 24, seg 0 (0.5) [0.5 on Epop[24]] -> cell 5, seg 0 (0.5) [0.5 on Ipop[5]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[5] syn_projEI_ampa[485] = new ampa(0.5)")
        h("Epop[24] netConn_projEI_ampa[485] = new NetCon(&v(0.5), syn_projEI_ampa[485], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 486: cell 24, seg 0 (0.5) [0.5 on Epop[24]] -> cell 6, seg 0 (0.5) [0.5 on Ipop[6]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[6] syn_projEI_ampa[486] = new ampa(0.5)")
        h("Epop[24] netConn_projEI_ampa[486] = new NetCon(&v(0.5), syn_projEI_ampa[486], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 487: cell 24, seg 0 (0.5) [0.5 on Epop[24]] -> cell 7, seg 0 (0.5) [0.5 on Ipop[7]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[7] syn_projEI_ampa[487] = new ampa(0.5)")
        h("Epop[24] netConn_projEI_ampa[487] = new NetCon(&v(0.5), syn_projEI_ampa[487], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 488: cell 24, seg 0 (0.5) [0.5 on Epop[24]] -> cell 8, seg 0 (0.5) [0.5 on Ipop[8]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[8] syn_projEI_ampa[488] = new ampa(0.5)")
        h("Epop[24] netConn_projEI_ampa[488] = new NetCon(&v(0.5), syn_projEI_ampa[488], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 489: cell 24, seg 0 (0.5) [0.5 on Epop[24]] -> cell 9, seg 0 (0.5) [0.5 on Ipop[9]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[9] syn_projEI_ampa[489] = new ampa(0.5)")
        h("Epop[24] netConn_projEI_ampa[489] = new NetCon(&v(0.5), syn_projEI_ampa[489], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 490: cell 24, seg 0 (0.5) [0.5 on Epop[24]] -> cell 10, seg 0 (0.5) [0.5 on Ipop[10]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[10] syn_projEI_ampa[490] = new ampa(0.5)")
        h("Epop[24] netConn_projEI_ampa[490] = new NetCon(&v(0.5), syn_projEI_ampa[490], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 491: cell 24, seg 0 (0.5) [0.5 on Epop[24]] -> cell 11, seg 0 (0.5) [0.5 on Ipop[11]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[11] syn_projEI_ampa[491] = new ampa(0.5)")
        h("Epop[24] netConn_projEI_ampa[491] = new NetCon(&v(0.5), syn_projEI_ampa[491], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 492: cell 24, seg 0 (0.5) [0.5 on Epop[24]] -> cell 12, seg 0 (0.5) [0.5 on Ipop[12]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[12] syn_projEI_ampa[492] = new ampa(0.5)")
        h("Epop[24] netConn_projEI_ampa[492] = new NetCon(&v(0.5), syn_projEI_ampa[492], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 493: cell 24, seg 0 (0.5) [0.5 on Epop[24]] -> cell 13, seg 0 (0.5) [0.5 on Ipop[13]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[13] syn_projEI_ampa[493] = new ampa(0.5)")
        h("Epop[24] netConn_projEI_ampa[493] = new NetCon(&v(0.5), syn_projEI_ampa[493], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 494: cell 24, seg 0 (0.5) [0.5 on Epop[24]] -> cell 14, seg 0 (0.5) [0.5 on Ipop[14]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[14] syn_projEI_ampa[494] = new ampa(0.5)")
        h("Epop[24] netConn_projEI_ampa[494] = new NetCon(&v(0.5), syn_projEI_ampa[494], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 495: cell 24, seg 0 (0.5) [0.5 on Epop[24]] -> cell 15, seg 0 (0.5) [0.5 on Ipop[15]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[15] syn_projEI_ampa[495] = new ampa(0.5)")
        h("Epop[24] netConn_projEI_ampa[495] = new NetCon(&v(0.5), syn_projEI_ampa[495], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 496: cell 24, seg 0 (0.5) [0.5 on Epop[24]] -> cell 16, seg 0 (0.5) [0.5 on Ipop[16]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[16] syn_projEI_ampa[496] = new ampa(0.5)")
        h("Epop[24] netConn_projEI_ampa[496] = new NetCon(&v(0.5), syn_projEI_ampa[496], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 497: cell 24, seg 0 (0.5) [0.5 on Epop[24]] -> cell 17, seg 0 (0.5) [0.5 on Ipop[17]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[17] syn_projEI_ampa[497] = new ampa(0.5)")
        h("Epop[24] netConn_projEI_ampa[497] = new NetCon(&v(0.5), syn_projEI_ampa[497], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 498: cell 24, seg 0 (0.5) [0.5 on Epop[24]] -> cell 18, seg 0 (0.5) [0.5 on Ipop[18]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[18] syn_projEI_ampa[498] = new ampa(0.5)")
        h("Epop[24] netConn_projEI_ampa[498] = new NetCon(&v(0.5), syn_projEI_ampa[498], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 499: cell 24, seg 0 (0.5) [0.5 on Epop[24]] -> cell 19, seg 0 (0.5) [0.5 on Ipop[19]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[19] syn_projEI_ampa[499] = new ampa(0.5)")
        h("Epop[24] netConn_projEI_ampa[499] = new NetCon(&v(0.5), syn_projEI_ampa[499], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 500: cell 25, seg 0 (0.5) [0.5 on Epop[25]] -> cell 0, seg 0 (0.5) [0.5 on Ipop[0]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[0] syn_projEI_ampa[500] = new ampa(0.5)")
        h("Epop[25] netConn_projEI_ampa[500] = new NetCon(&v(0.5), syn_projEI_ampa[500], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 501: cell 25, seg 0 (0.5) [0.5 on Epop[25]] -> cell 1, seg 0 (0.5) [0.5 on Ipop[1]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[1] syn_projEI_ampa[501] = new ampa(0.5)")
        h("Epop[25] netConn_projEI_ampa[501] = new NetCon(&v(0.5), syn_projEI_ampa[501], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 502: cell 25, seg 0 (0.5) [0.5 on Epop[25]] -> cell 2, seg 0 (0.5) [0.5 on Ipop[2]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[2] syn_projEI_ampa[502] = new ampa(0.5)")
        h("Epop[25] netConn_projEI_ampa[502] = new NetCon(&v(0.5), syn_projEI_ampa[502], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 503: cell 25, seg 0 (0.5) [0.5 on Epop[25]] -> cell 3, seg 0 (0.5) [0.5 on Ipop[3]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[3] syn_projEI_ampa[503] = new ampa(0.5)")
        h("Epop[25] netConn_projEI_ampa[503] = new NetCon(&v(0.5), syn_projEI_ampa[503], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 504: cell 25, seg 0 (0.5) [0.5 on Epop[25]] -> cell 4, seg 0 (0.5) [0.5 on Ipop[4]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[4] syn_projEI_ampa[504] = new ampa(0.5)")
        h("Epop[25] netConn_projEI_ampa[504] = new NetCon(&v(0.5), syn_projEI_ampa[504], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 505: cell 25, seg 0 (0.5) [0.5 on Epop[25]] -> cell 5, seg 0 (0.5) [0.5 on Ipop[5]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[5] syn_projEI_ampa[505] = new ampa(0.5)")
        h("Epop[25] netConn_projEI_ampa[505] = new NetCon(&v(0.5), syn_projEI_ampa[505], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 506: cell 25, seg 0 (0.5) [0.5 on Epop[25]] -> cell 6, seg 0 (0.5) [0.5 on Ipop[6]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[6] syn_projEI_ampa[506] = new ampa(0.5)")
        h("Epop[25] netConn_projEI_ampa[506] = new NetCon(&v(0.5), syn_projEI_ampa[506], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 507: cell 25, seg 0 (0.5) [0.5 on Epop[25]] -> cell 7, seg 0 (0.5) [0.5 on Ipop[7]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[7] syn_projEI_ampa[507] = new ampa(0.5)")
        h("Epop[25] netConn_projEI_ampa[507] = new NetCon(&v(0.5), syn_projEI_ampa[507], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 508: cell 25, seg 0 (0.5) [0.5 on Epop[25]] -> cell 8, seg 0 (0.5) [0.5 on Ipop[8]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[8] syn_projEI_ampa[508] = new ampa(0.5)")
        h("Epop[25] netConn_projEI_ampa[508] = new NetCon(&v(0.5), syn_projEI_ampa[508], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 509: cell 25, seg 0 (0.5) [0.5 on Epop[25]] -> cell 9, seg 0 (0.5) [0.5 on Ipop[9]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[9] syn_projEI_ampa[509] = new ampa(0.5)")
        h("Epop[25] netConn_projEI_ampa[509] = new NetCon(&v(0.5), syn_projEI_ampa[509], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 510: cell 25, seg 0 (0.5) [0.5 on Epop[25]] -> cell 10, seg 0 (0.5) [0.5 on Ipop[10]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[10] syn_projEI_ampa[510] = new ampa(0.5)")
        h("Epop[25] netConn_projEI_ampa[510] = new NetCon(&v(0.5), syn_projEI_ampa[510], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 511: cell 25, seg 0 (0.5) [0.5 on Epop[25]] -> cell 11, seg 0 (0.5) [0.5 on Ipop[11]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[11] syn_projEI_ampa[511] = new ampa(0.5)")
        h("Epop[25] netConn_projEI_ampa[511] = new NetCon(&v(0.5), syn_projEI_ampa[511], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 512: cell 25, seg 0 (0.5) [0.5 on Epop[25]] -> cell 12, seg 0 (0.5) [0.5 on Ipop[12]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[12] syn_projEI_ampa[512] = new ampa(0.5)")
        h("Epop[25] netConn_projEI_ampa[512] = new NetCon(&v(0.5), syn_projEI_ampa[512], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 513: cell 25, seg 0 (0.5) [0.5 on Epop[25]] -> cell 13, seg 0 (0.5) [0.5 on Ipop[13]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[13] syn_projEI_ampa[513] = new ampa(0.5)")
        h("Epop[25] netConn_projEI_ampa[513] = new NetCon(&v(0.5), syn_projEI_ampa[513], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 514: cell 25, seg 0 (0.5) [0.5 on Epop[25]] -> cell 14, seg 0 (0.5) [0.5 on Ipop[14]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[14] syn_projEI_ampa[514] = new ampa(0.5)")
        h("Epop[25] netConn_projEI_ampa[514] = new NetCon(&v(0.5), syn_projEI_ampa[514], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 515: cell 25, seg 0 (0.5) [0.5 on Epop[25]] -> cell 15, seg 0 (0.5) [0.5 on Ipop[15]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[15] syn_projEI_ampa[515] = new ampa(0.5)")
        h("Epop[25] netConn_projEI_ampa[515] = new NetCon(&v(0.5), syn_projEI_ampa[515], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 516: cell 25, seg 0 (0.5) [0.5 on Epop[25]] -> cell 16, seg 0 (0.5) [0.5 on Ipop[16]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[16] syn_projEI_ampa[516] = new ampa(0.5)")
        h("Epop[25] netConn_projEI_ampa[516] = new NetCon(&v(0.5), syn_projEI_ampa[516], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 517: cell 25, seg 0 (0.5) [0.5 on Epop[25]] -> cell 17, seg 0 (0.5) [0.5 on Ipop[17]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[17] syn_projEI_ampa[517] = new ampa(0.5)")
        h("Epop[25] netConn_projEI_ampa[517] = new NetCon(&v(0.5), syn_projEI_ampa[517], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 518: cell 25, seg 0 (0.5) [0.5 on Epop[25]] -> cell 18, seg 0 (0.5) [0.5 on Ipop[18]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[18] syn_projEI_ampa[518] = new ampa(0.5)")
        h("Epop[25] netConn_projEI_ampa[518] = new NetCon(&v(0.5), syn_projEI_ampa[518], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 519: cell 25, seg 0 (0.5) [0.5 on Epop[25]] -> cell 19, seg 0 (0.5) [0.5 on Ipop[19]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[19] syn_projEI_ampa[519] = new ampa(0.5)")
        h("Epop[25] netConn_projEI_ampa[519] = new NetCon(&v(0.5), syn_projEI_ampa[519], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 520: cell 26, seg 0 (0.5) [0.5 on Epop[26]] -> cell 0, seg 0 (0.5) [0.5 on Ipop[0]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[0] syn_projEI_ampa[520] = new ampa(0.5)")
        h("Epop[26] netConn_projEI_ampa[520] = new NetCon(&v(0.5), syn_projEI_ampa[520], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 521: cell 26, seg 0 (0.5) [0.5 on Epop[26]] -> cell 1, seg 0 (0.5) [0.5 on Ipop[1]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[1] syn_projEI_ampa[521] = new ampa(0.5)")
        h("Epop[26] netConn_projEI_ampa[521] = new NetCon(&v(0.5), syn_projEI_ampa[521], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 522: cell 26, seg 0 (0.5) [0.5 on Epop[26]] -> cell 2, seg 0 (0.5) [0.5 on Ipop[2]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[2] syn_projEI_ampa[522] = new ampa(0.5)")
        h("Epop[26] netConn_projEI_ampa[522] = new NetCon(&v(0.5), syn_projEI_ampa[522], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 523: cell 26, seg 0 (0.5) [0.5 on Epop[26]] -> cell 3, seg 0 (0.5) [0.5 on Ipop[3]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[3] syn_projEI_ampa[523] = new ampa(0.5)")
        h("Epop[26] netConn_projEI_ampa[523] = new NetCon(&v(0.5), syn_projEI_ampa[523], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 524: cell 26, seg 0 (0.5) [0.5 on Epop[26]] -> cell 4, seg 0 (0.5) [0.5 on Ipop[4]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[4] syn_projEI_ampa[524] = new ampa(0.5)")
        h("Epop[26] netConn_projEI_ampa[524] = new NetCon(&v(0.5), syn_projEI_ampa[524], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 525: cell 26, seg 0 (0.5) [0.5 on Epop[26]] -> cell 5, seg 0 (0.5) [0.5 on Ipop[5]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[5] syn_projEI_ampa[525] = new ampa(0.5)")
        h("Epop[26] netConn_projEI_ampa[525] = new NetCon(&v(0.5), syn_projEI_ampa[525], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 526: cell 26, seg 0 (0.5) [0.5 on Epop[26]] -> cell 6, seg 0 (0.5) [0.5 on Ipop[6]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[6] syn_projEI_ampa[526] = new ampa(0.5)")
        h("Epop[26] netConn_projEI_ampa[526] = new NetCon(&v(0.5), syn_projEI_ampa[526], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 527: cell 26, seg 0 (0.5) [0.5 on Epop[26]] -> cell 7, seg 0 (0.5) [0.5 on Ipop[7]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[7] syn_projEI_ampa[527] = new ampa(0.5)")
        h("Epop[26] netConn_projEI_ampa[527] = new NetCon(&v(0.5), syn_projEI_ampa[527], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 528: cell 26, seg 0 (0.5) [0.5 on Epop[26]] -> cell 8, seg 0 (0.5) [0.5 on Ipop[8]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[8] syn_projEI_ampa[528] = new ampa(0.5)")
        h("Epop[26] netConn_projEI_ampa[528] = new NetCon(&v(0.5), syn_projEI_ampa[528], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 529: cell 26, seg 0 (0.5) [0.5 on Epop[26]] -> cell 9, seg 0 (0.5) [0.5 on Ipop[9]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[9] syn_projEI_ampa[529] = new ampa(0.5)")
        h("Epop[26] netConn_projEI_ampa[529] = new NetCon(&v(0.5), syn_projEI_ampa[529], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 530: cell 26, seg 0 (0.5) [0.5 on Epop[26]] -> cell 10, seg 0 (0.5) [0.5 on Ipop[10]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[10] syn_projEI_ampa[530] = new ampa(0.5)")
        h("Epop[26] netConn_projEI_ampa[530] = new NetCon(&v(0.5), syn_projEI_ampa[530], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 531: cell 26, seg 0 (0.5) [0.5 on Epop[26]] -> cell 11, seg 0 (0.5) [0.5 on Ipop[11]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[11] syn_projEI_ampa[531] = new ampa(0.5)")
        h("Epop[26] netConn_projEI_ampa[531] = new NetCon(&v(0.5), syn_projEI_ampa[531], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 532: cell 26, seg 0 (0.5) [0.5 on Epop[26]] -> cell 12, seg 0 (0.5) [0.5 on Ipop[12]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[12] syn_projEI_ampa[532] = new ampa(0.5)")
        h("Epop[26] netConn_projEI_ampa[532] = new NetCon(&v(0.5), syn_projEI_ampa[532], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 533: cell 26, seg 0 (0.5) [0.5 on Epop[26]] -> cell 13, seg 0 (0.5) [0.5 on Ipop[13]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[13] syn_projEI_ampa[533] = new ampa(0.5)")
        h("Epop[26] netConn_projEI_ampa[533] = new NetCon(&v(0.5), syn_projEI_ampa[533], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 534: cell 26, seg 0 (0.5) [0.5 on Epop[26]] -> cell 14, seg 0 (0.5) [0.5 on Ipop[14]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[14] syn_projEI_ampa[534] = new ampa(0.5)")
        h("Epop[26] netConn_projEI_ampa[534] = new NetCon(&v(0.5), syn_projEI_ampa[534], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 535: cell 26, seg 0 (0.5) [0.5 on Epop[26]] -> cell 15, seg 0 (0.5) [0.5 on Ipop[15]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[15] syn_projEI_ampa[535] = new ampa(0.5)")
        h("Epop[26] netConn_projEI_ampa[535] = new NetCon(&v(0.5), syn_projEI_ampa[535], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 536: cell 26, seg 0 (0.5) [0.5 on Epop[26]] -> cell 16, seg 0 (0.5) [0.5 on Ipop[16]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[16] syn_projEI_ampa[536] = new ampa(0.5)")
        h("Epop[26] netConn_projEI_ampa[536] = new NetCon(&v(0.5), syn_projEI_ampa[536], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 537: cell 26, seg 0 (0.5) [0.5 on Epop[26]] -> cell 17, seg 0 (0.5) [0.5 on Ipop[17]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[17] syn_projEI_ampa[537] = new ampa(0.5)")
        h("Epop[26] netConn_projEI_ampa[537] = new NetCon(&v(0.5), syn_projEI_ampa[537], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 538: cell 26, seg 0 (0.5) [0.5 on Epop[26]] -> cell 18, seg 0 (0.5) [0.5 on Ipop[18]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[18] syn_projEI_ampa[538] = new ampa(0.5)")
        h("Epop[26] netConn_projEI_ampa[538] = new NetCon(&v(0.5), syn_projEI_ampa[538], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 539: cell 26, seg 0 (0.5) [0.5 on Epop[26]] -> cell 19, seg 0 (0.5) [0.5 on Ipop[19]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[19] syn_projEI_ampa[539] = new ampa(0.5)")
        h("Epop[26] netConn_projEI_ampa[539] = new NetCon(&v(0.5), syn_projEI_ampa[539], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 540: cell 27, seg 0 (0.5) [0.5 on Epop[27]] -> cell 0, seg 0 (0.5) [0.5 on Ipop[0]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[0] syn_projEI_ampa[540] = new ampa(0.5)")
        h("Epop[27] netConn_projEI_ampa[540] = new NetCon(&v(0.5), syn_projEI_ampa[540], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 541: cell 27, seg 0 (0.5) [0.5 on Epop[27]] -> cell 1, seg 0 (0.5) [0.5 on Ipop[1]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[1] syn_projEI_ampa[541] = new ampa(0.5)")
        h("Epop[27] netConn_projEI_ampa[541] = new NetCon(&v(0.5), syn_projEI_ampa[541], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 542: cell 27, seg 0 (0.5) [0.5 on Epop[27]] -> cell 2, seg 0 (0.5) [0.5 on Ipop[2]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[2] syn_projEI_ampa[542] = new ampa(0.5)")
        h("Epop[27] netConn_projEI_ampa[542] = new NetCon(&v(0.5), syn_projEI_ampa[542], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 543: cell 27, seg 0 (0.5) [0.5 on Epop[27]] -> cell 3, seg 0 (0.5) [0.5 on Ipop[3]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[3] syn_projEI_ampa[543] = new ampa(0.5)")
        h("Epop[27] netConn_projEI_ampa[543] = new NetCon(&v(0.5), syn_projEI_ampa[543], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 544: cell 27, seg 0 (0.5) [0.5 on Epop[27]] -> cell 4, seg 0 (0.5) [0.5 on Ipop[4]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[4] syn_projEI_ampa[544] = new ampa(0.5)")
        h("Epop[27] netConn_projEI_ampa[544] = new NetCon(&v(0.5), syn_projEI_ampa[544], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 545: cell 27, seg 0 (0.5) [0.5 on Epop[27]] -> cell 5, seg 0 (0.5) [0.5 on Ipop[5]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[5] syn_projEI_ampa[545] = new ampa(0.5)")
        h("Epop[27] netConn_projEI_ampa[545] = new NetCon(&v(0.5), syn_projEI_ampa[545], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 546: cell 27, seg 0 (0.5) [0.5 on Epop[27]] -> cell 6, seg 0 (0.5) [0.5 on Ipop[6]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[6] syn_projEI_ampa[546] = new ampa(0.5)")
        h("Epop[27] netConn_projEI_ampa[546] = new NetCon(&v(0.5), syn_projEI_ampa[546], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 547: cell 27, seg 0 (0.5) [0.5 on Epop[27]] -> cell 7, seg 0 (0.5) [0.5 on Ipop[7]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[7] syn_projEI_ampa[547] = new ampa(0.5)")
        h("Epop[27] netConn_projEI_ampa[547] = new NetCon(&v(0.5), syn_projEI_ampa[547], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 548: cell 27, seg 0 (0.5) [0.5 on Epop[27]] -> cell 8, seg 0 (0.5) [0.5 on Ipop[8]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[8] syn_projEI_ampa[548] = new ampa(0.5)")
        h("Epop[27] netConn_projEI_ampa[548] = new NetCon(&v(0.5), syn_projEI_ampa[548], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 549: cell 27, seg 0 (0.5) [0.5 on Epop[27]] -> cell 9, seg 0 (0.5) [0.5 on Ipop[9]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[9] syn_projEI_ampa[549] = new ampa(0.5)")
        h("Epop[27] netConn_projEI_ampa[549] = new NetCon(&v(0.5), syn_projEI_ampa[549], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 550: cell 27, seg 0 (0.5) [0.5 on Epop[27]] -> cell 10, seg 0 (0.5) [0.5 on Ipop[10]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[10] syn_projEI_ampa[550] = new ampa(0.5)")
        h("Epop[27] netConn_projEI_ampa[550] = new NetCon(&v(0.5), syn_projEI_ampa[550], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 551: cell 27, seg 0 (0.5) [0.5 on Epop[27]] -> cell 11, seg 0 (0.5) [0.5 on Ipop[11]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[11] syn_projEI_ampa[551] = new ampa(0.5)")
        h("Epop[27] netConn_projEI_ampa[551] = new NetCon(&v(0.5), syn_projEI_ampa[551], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 552: cell 27, seg 0 (0.5) [0.5 on Epop[27]] -> cell 12, seg 0 (0.5) [0.5 on Ipop[12]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[12] syn_projEI_ampa[552] = new ampa(0.5)")
        h("Epop[27] netConn_projEI_ampa[552] = new NetCon(&v(0.5), syn_projEI_ampa[552], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 553: cell 27, seg 0 (0.5) [0.5 on Epop[27]] -> cell 13, seg 0 (0.5) [0.5 on Ipop[13]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[13] syn_projEI_ampa[553] = new ampa(0.5)")
        h("Epop[27] netConn_projEI_ampa[553] = new NetCon(&v(0.5), syn_projEI_ampa[553], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 554: cell 27, seg 0 (0.5) [0.5 on Epop[27]] -> cell 14, seg 0 (0.5) [0.5 on Ipop[14]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[14] syn_projEI_ampa[554] = new ampa(0.5)")
        h("Epop[27] netConn_projEI_ampa[554] = new NetCon(&v(0.5), syn_projEI_ampa[554], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 555: cell 27, seg 0 (0.5) [0.5 on Epop[27]] -> cell 15, seg 0 (0.5) [0.5 on Ipop[15]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[15] syn_projEI_ampa[555] = new ampa(0.5)")
        h("Epop[27] netConn_projEI_ampa[555] = new NetCon(&v(0.5), syn_projEI_ampa[555], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 556: cell 27, seg 0 (0.5) [0.5 on Epop[27]] -> cell 16, seg 0 (0.5) [0.5 on Ipop[16]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[16] syn_projEI_ampa[556] = new ampa(0.5)")
        h("Epop[27] netConn_projEI_ampa[556] = new NetCon(&v(0.5), syn_projEI_ampa[556], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 557: cell 27, seg 0 (0.5) [0.5 on Epop[27]] -> cell 17, seg 0 (0.5) [0.5 on Ipop[17]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[17] syn_projEI_ampa[557] = new ampa(0.5)")
        h("Epop[27] netConn_projEI_ampa[557] = new NetCon(&v(0.5), syn_projEI_ampa[557], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 558: cell 27, seg 0 (0.5) [0.5 on Epop[27]] -> cell 18, seg 0 (0.5) [0.5 on Ipop[18]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[18] syn_projEI_ampa[558] = new ampa(0.5)")
        h("Epop[27] netConn_projEI_ampa[558] = new NetCon(&v(0.5), syn_projEI_ampa[558], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 559: cell 27, seg 0 (0.5) [0.5 on Epop[27]] -> cell 19, seg 0 (0.5) [0.5 on Ipop[19]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[19] syn_projEI_ampa[559] = new ampa(0.5)")
        h("Epop[27] netConn_projEI_ampa[559] = new NetCon(&v(0.5), syn_projEI_ampa[559], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 560: cell 28, seg 0 (0.5) [0.5 on Epop[28]] -> cell 0, seg 0 (0.5) [0.5 on Ipop[0]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[0] syn_projEI_ampa[560] = new ampa(0.5)")
        h("Epop[28] netConn_projEI_ampa[560] = new NetCon(&v(0.5), syn_projEI_ampa[560], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 561: cell 28, seg 0 (0.5) [0.5 on Epop[28]] -> cell 1, seg 0 (0.5) [0.5 on Ipop[1]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[1] syn_projEI_ampa[561] = new ampa(0.5)")
        h("Epop[28] netConn_projEI_ampa[561] = new NetCon(&v(0.5), syn_projEI_ampa[561], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 562: cell 28, seg 0 (0.5) [0.5 on Epop[28]] -> cell 2, seg 0 (0.5) [0.5 on Ipop[2]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[2] syn_projEI_ampa[562] = new ampa(0.5)")
        h("Epop[28] netConn_projEI_ampa[562] = new NetCon(&v(0.5), syn_projEI_ampa[562], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 563: cell 28, seg 0 (0.5) [0.5 on Epop[28]] -> cell 3, seg 0 (0.5) [0.5 on Ipop[3]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[3] syn_projEI_ampa[563] = new ampa(0.5)")
        h("Epop[28] netConn_projEI_ampa[563] = new NetCon(&v(0.5), syn_projEI_ampa[563], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 564: cell 28, seg 0 (0.5) [0.5 on Epop[28]] -> cell 4, seg 0 (0.5) [0.5 on Ipop[4]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[4] syn_projEI_ampa[564] = new ampa(0.5)")
        h("Epop[28] netConn_projEI_ampa[564] = new NetCon(&v(0.5), syn_projEI_ampa[564], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 565: cell 28, seg 0 (0.5) [0.5 on Epop[28]] -> cell 5, seg 0 (0.5) [0.5 on Ipop[5]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[5] syn_projEI_ampa[565] = new ampa(0.5)")
        h("Epop[28] netConn_projEI_ampa[565] = new NetCon(&v(0.5), syn_projEI_ampa[565], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 566: cell 28, seg 0 (0.5) [0.5 on Epop[28]] -> cell 6, seg 0 (0.5) [0.5 on Ipop[6]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[6] syn_projEI_ampa[566] = new ampa(0.5)")
        h("Epop[28] netConn_projEI_ampa[566] = new NetCon(&v(0.5), syn_projEI_ampa[566], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 567: cell 28, seg 0 (0.5) [0.5 on Epop[28]] -> cell 7, seg 0 (0.5) [0.5 on Ipop[7]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[7] syn_projEI_ampa[567] = new ampa(0.5)")
        h("Epop[28] netConn_projEI_ampa[567] = new NetCon(&v(0.5), syn_projEI_ampa[567], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 568: cell 28, seg 0 (0.5) [0.5 on Epop[28]] -> cell 8, seg 0 (0.5) [0.5 on Ipop[8]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[8] syn_projEI_ampa[568] = new ampa(0.5)")
        h("Epop[28] netConn_projEI_ampa[568] = new NetCon(&v(0.5), syn_projEI_ampa[568], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 569: cell 28, seg 0 (0.5) [0.5 on Epop[28]] -> cell 9, seg 0 (0.5) [0.5 on Ipop[9]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[9] syn_projEI_ampa[569] = new ampa(0.5)")
        h("Epop[28] netConn_projEI_ampa[569] = new NetCon(&v(0.5), syn_projEI_ampa[569], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 570: cell 28, seg 0 (0.5) [0.5 on Epop[28]] -> cell 10, seg 0 (0.5) [0.5 on Ipop[10]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[10] syn_projEI_ampa[570] = new ampa(0.5)")
        h("Epop[28] netConn_projEI_ampa[570] = new NetCon(&v(0.5), syn_projEI_ampa[570], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 571: cell 28, seg 0 (0.5) [0.5 on Epop[28]] -> cell 11, seg 0 (0.5) [0.5 on Ipop[11]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[11] syn_projEI_ampa[571] = new ampa(0.5)")
        h("Epop[28] netConn_projEI_ampa[571] = new NetCon(&v(0.5), syn_projEI_ampa[571], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 572: cell 28, seg 0 (0.5) [0.5 on Epop[28]] -> cell 12, seg 0 (0.5) [0.5 on Ipop[12]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[12] syn_projEI_ampa[572] = new ampa(0.5)")
        h("Epop[28] netConn_projEI_ampa[572] = new NetCon(&v(0.5), syn_projEI_ampa[572], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 573: cell 28, seg 0 (0.5) [0.5 on Epop[28]] -> cell 13, seg 0 (0.5) [0.5 on Ipop[13]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[13] syn_projEI_ampa[573] = new ampa(0.5)")
        h("Epop[28] netConn_projEI_ampa[573] = new NetCon(&v(0.5), syn_projEI_ampa[573], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 574: cell 28, seg 0 (0.5) [0.5 on Epop[28]] -> cell 14, seg 0 (0.5) [0.5 on Ipop[14]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[14] syn_projEI_ampa[574] = new ampa(0.5)")
        h("Epop[28] netConn_projEI_ampa[574] = new NetCon(&v(0.5), syn_projEI_ampa[574], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 575: cell 28, seg 0 (0.5) [0.5 on Epop[28]] -> cell 15, seg 0 (0.5) [0.5 on Ipop[15]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[15] syn_projEI_ampa[575] = new ampa(0.5)")
        h("Epop[28] netConn_projEI_ampa[575] = new NetCon(&v(0.5), syn_projEI_ampa[575], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 576: cell 28, seg 0 (0.5) [0.5 on Epop[28]] -> cell 16, seg 0 (0.5) [0.5 on Ipop[16]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[16] syn_projEI_ampa[576] = new ampa(0.5)")
        h("Epop[28] netConn_projEI_ampa[576] = new NetCon(&v(0.5), syn_projEI_ampa[576], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 577: cell 28, seg 0 (0.5) [0.5 on Epop[28]] -> cell 17, seg 0 (0.5) [0.5 on Ipop[17]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[17] syn_projEI_ampa[577] = new ampa(0.5)")
        h("Epop[28] netConn_projEI_ampa[577] = new NetCon(&v(0.5), syn_projEI_ampa[577], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 578: cell 28, seg 0 (0.5) [0.5 on Epop[28]] -> cell 18, seg 0 (0.5) [0.5 on Ipop[18]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[18] syn_projEI_ampa[578] = new ampa(0.5)")
        h("Epop[28] netConn_projEI_ampa[578] = new NetCon(&v(0.5), syn_projEI_ampa[578], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 579: cell 28, seg 0 (0.5) [0.5 on Epop[28]] -> cell 19, seg 0 (0.5) [0.5 on Ipop[19]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[19] syn_projEI_ampa[579] = new ampa(0.5)")
        h("Epop[28] netConn_projEI_ampa[579] = new NetCon(&v(0.5), syn_projEI_ampa[579], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 580: cell 29, seg 0 (0.5) [0.5 on Epop[29]] -> cell 0, seg 0 (0.5) [0.5 on Ipop[0]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[0] syn_projEI_ampa[580] = new ampa(0.5)")
        h("Epop[29] netConn_projEI_ampa[580] = new NetCon(&v(0.5), syn_projEI_ampa[580], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 581: cell 29, seg 0 (0.5) [0.5 on Epop[29]] -> cell 1, seg 0 (0.5) [0.5 on Ipop[1]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[1] syn_projEI_ampa[581] = new ampa(0.5)")
        h("Epop[29] netConn_projEI_ampa[581] = new NetCon(&v(0.5), syn_projEI_ampa[581], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 582: cell 29, seg 0 (0.5) [0.5 on Epop[29]] -> cell 2, seg 0 (0.5) [0.5 on Ipop[2]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[2] syn_projEI_ampa[582] = new ampa(0.5)")
        h("Epop[29] netConn_projEI_ampa[582] = new NetCon(&v(0.5), syn_projEI_ampa[582], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 583: cell 29, seg 0 (0.5) [0.5 on Epop[29]] -> cell 3, seg 0 (0.5) [0.5 on Ipop[3]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[3] syn_projEI_ampa[583] = new ampa(0.5)")
        h("Epop[29] netConn_projEI_ampa[583] = new NetCon(&v(0.5), syn_projEI_ampa[583], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 584: cell 29, seg 0 (0.5) [0.5 on Epop[29]] -> cell 4, seg 0 (0.5) [0.5 on Ipop[4]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[4] syn_projEI_ampa[584] = new ampa(0.5)")
        h("Epop[29] netConn_projEI_ampa[584] = new NetCon(&v(0.5), syn_projEI_ampa[584], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 585: cell 29, seg 0 (0.5) [0.5 on Epop[29]] -> cell 5, seg 0 (0.5) [0.5 on Ipop[5]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[5] syn_projEI_ampa[585] = new ampa(0.5)")
        h("Epop[29] netConn_projEI_ampa[585] = new NetCon(&v(0.5), syn_projEI_ampa[585], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 586: cell 29, seg 0 (0.5) [0.5 on Epop[29]] -> cell 6, seg 0 (0.5) [0.5 on Ipop[6]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[6] syn_projEI_ampa[586] = new ampa(0.5)")
        h("Epop[29] netConn_projEI_ampa[586] = new NetCon(&v(0.5), syn_projEI_ampa[586], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 587: cell 29, seg 0 (0.5) [0.5 on Epop[29]] -> cell 7, seg 0 (0.5) [0.5 on Ipop[7]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[7] syn_projEI_ampa[587] = new ampa(0.5)")
        h("Epop[29] netConn_projEI_ampa[587] = new NetCon(&v(0.5), syn_projEI_ampa[587], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 588: cell 29, seg 0 (0.5) [0.5 on Epop[29]] -> cell 8, seg 0 (0.5) [0.5 on Ipop[8]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[8] syn_projEI_ampa[588] = new ampa(0.5)")
        h("Epop[29] netConn_projEI_ampa[588] = new NetCon(&v(0.5), syn_projEI_ampa[588], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 589: cell 29, seg 0 (0.5) [0.5 on Epop[29]] -> cell 9, seg 0 (0.5) [0.5 on Ipop[9]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[9] syn_projEI_ampa[589] = new ampa(0.5)")
        h("Epop[29] netConn_projEI_ampa[589] = new NetCon(&v(0.5), syn_projEI_ampa[589], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 590: cell 29, seg 0 (0.5) [0.5 on Epop[29]] -> cell 10, seg 0 (0.5) [0.5 on Ipop[10]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[10] syn_projEI_ampa[590] = new ampa(0.5)")
        h("Epop[29] netConn_projEI_ampa[590] = new NetCon(&v(0.5), syn_projEI_ampa[590], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 591: cell 29, seg 0 (0.5) [0.5 on Epop[29]] -> cell 11, seg 0 (0.5) [0.5 on Ipop[11]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[11] syn_projEI_ampa[591] = new ampa(0.5)")
        h("Epop[29] netConn_projEI_ampa[591] = new NetCon(&v(0.5), syn_projEI_ampa[591], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 592: cell 29, seg 0 (0.5) [0.5 on Epop[29]] -> cell 12, seg 0 (0.5) [0.5 on Ipop[12]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[12] syn_projEI_ampa[592] = new ampa(0.5)")
        h("Epop[29] netConn_projEI_ampa[592] = new NetCon(&v(0.5), syn_projEI_ampa[592], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 593: cell 29, seg 0 (0.5) [0.5 on Epop[29]] -> cell 13, seg 0 (0.5) [0.5 on Ipop[13]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[13] syn_projEI_ampa[593] = new ampa(0.5)")
        h("Epop[29] netConn_projEI_ampa[593] = new NetCon(&v(0.5), syn_projEI_ampa[593], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 594: cell 29, seg 0 (0.5) [0.5 on Epop[29]] -> cell 14, seg 0 (0.5) [0.5 on Ipop[14]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[14] syn_projEI_ampa[594] = new ampa(0.5)")
        h("Epop[29] netConn_projEI_ampa[594] = new NetCon(&v(0.5), syn_projEI_ampa[594], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 595: cell 29, seg 0 (0.5) [0.5 on Epop[29]] -> cell 15, seg 0 (0.5) [0.5 on Ipop[15]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[15] syn_projEI_ampa[595] = new ampa(0.5)")
        h("Epop[29] netConn_projEI_ampa[595] = new NetCon(&v(0.5), syn_projEI_ampa[595], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 596: cell 29, seg 0 (0.5) [0.5 on Epop[29]] -> cell 16, seg 0 (0.5) [0.5 on Ipop[16]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[16] syn_projEI_ampa[596] = new ampa(0.5)")
        h("Epop[29] netConn_projEI_ampa[596] = new NetCon(&v(0.5), syn_projEI_ampa[596], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 597: cell 29, seg 0 (0.5) [0.5 on Epop[29]] -> cell 17, seg 0 (0.5) [0.5 on Ipop[17]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[17] syn_projEI_ampa[597] = new ampa(0.5)")
        h("Epop[29] netConn_projEI_ampa[597] = new NetCon(&v(0.5), syn_projEI_ampa[597], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 598: cell 29, seg 0 (0.5) [0.5 on Epop[29]] -> cell 18, seg 0 (0.5) [0.5 on Ipop[18]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[18] syn_projEI_ampa[598] = new ampa(0.5)")
        h("Epop[29] netConn_projEI_ampa[598] = new NetCon(&v(0.5), syn_projEI_ampa[598], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 599: cell 29, seg 0 (0.5) [0.5 on Epop[29]] -> cell 19, seg 0 (0.5) [0.5 on Ipop[19]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[19] syn_projEI_ampa[599] = new ampa(0.5)")
        h("Epop[29] netConn_projEI_ampa[599] = new NetCon(&v(0.5), syn_projEI_ampa[599], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 600: cell 30, seg 0 (0.5) [0.5 on Epop[30]] -> cell 0, seg 0 (0.5) [0.5 on Ipop[0]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[0] syn_projEI_ampa[600] = new ampa(0.5)")
        h("Epop[30] netConn_projEI_ampa[600] = new NetCon(&v(0.5), syn_projEI_ampa[600], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 601: cell 30, seg 0 (0.5) [0.5 on Epop[30]] -> cell 1, seg 0 (0.5) [0.5 on Ipop[1]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[1] syn_projEI_ampa[601] = new ampa(0.5)")
        h("Epop[30] netConn_projEI_ampa[601] = new NetCon(&v(0.5), syn_projEI_ampa[601], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 602: cell 30, seg 0 (0.5) [0.5 on Epop[30]] -> cell 2, seg 0 (0.5) [0.5 on Ipop[2]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[2] syn_projEI_ampa[602] = new ampa(0.5)")
        h("Epop[30] netConn_projEI_ampa[602] = new NetCon(&v(0.5), syn_projEI_ampa[602], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 603: cell 30, seg 0 (0.5) [0.5 on Epop[30]] -> cell 3, seg 0 (0.5) [0.5 on Ipop[3]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[3] syn_projEI_ampa[603] = new ampa(0.5)")
        h("Epop[30] netConn_projEI_ampa[603] = new NetCon(&v(0.5), syn_projEI_ampa[603], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 604: cell 30, seg 0 (0.5) [0.5 on Epop[30]] -> cell 4, seg 0 (0.5) [0.5 on Ipop[4]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[4] syn_projEI_ampa[604] = new ampa(0.5)")
        h("Epop[30] netConn_projEI_ampa[604] = new NetCon(&v(0.5), syn_projEI_ampa[604], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 605: cell 30, seg 0 (0.5) [0.5 on Epop[30]] -> cell 5, seg 0 (0.5) [0.5 on Ipop[5]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[5] syn_projEI_ampa[605] = new ampa(0.5)")
        h("Epop[30] netConn_projEI_ampa[605] = new NetCon(&v(0.5), syn_projEI_ampa[605], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 606: cell 30, seg 0 (0.5) [0.5 on Epop[30]] -> cell 6, seg 0 (0.5) [0.5 on Ipop[6]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[6] syn_projEI_ampa[606] = new ampa(0.5)")
        h("Epop[30] netConn_projEI_ampa[606] = new NetCon(&v(0.5), syn_projEI_ampa[606], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 607: cell 30, seg 0 (0.5) [0.5 on Epop[30]] -> cell 7, seg 0 (0.5) [0.5 on Ipop[7]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[7] syn_projEI_ampa[607] = new ampa(0.5)")
        h("Epop[30] netConn_projEI_ampa[607] = new NetCon(&v(0.5), syn_projEI_ampa[607], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 608: cell 30, seg 0 (0.5) [0.5 on Epop[30]] -> cell 8, seg 0 (0.5) [0.5 on Ipop[8]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[8] syn_projEI_ampa[608] = new ampa(0.5)")
        h("Epop[30] netConn_projEI_ampa[608] = new NetCon(&v(0.5), syn_projEI_ampa[608], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 609: cell 30, seg 0 (0.5) [0.5 on Epop[30]] -> cell 9, seg 0 (0.5) [0.5 on Ipop[9]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[9] syn_projEI_ampa[609] = new ampa(0.5)")
        h("Epop[30] netConn_projEI_ampa[609] = new NetCon(&v(0.5), syn_projEI_ampa[609], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 610: cell 30, seg 0 (0.5) [0.5 on Epop[30]] -> cell 10, seg 0 (0.5) [0.5 on Ipop[10]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[10] syn_projEI_ampa[610] = new ampa(0.5)")
        h("Epop[30] netConn_projEI_ampa[610] = new NetCon(&v(0.5), syn_projEI_ampa[610], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 611: cell 30, seg 0 (0.5) [0.5 on Epop[30]] -> cell 11, seg 0 (0.5) [0.5 on Ipop[11]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[11] syn_projEI_ampa[611] = new ampa(0.5)")
        h("Epop[30] netConn_projEI_ampa[611] = new NetCon(&v(0.5), syn_projEI_ampa[611], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 612: cell 30, seg 0 (0.5) [0.5 on Epop[30]] -> cell 12, seg 0 (0.5) [0.5 on Ipop[12]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[12] syn_projEI_ampa[612] = new ampa(0.5)")
        h("Epop[30] netConn_projEI_ampa[612] = new NetCon(&v(0.5), syn_projEI_ampa[612], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 613: cell 30, seg 0 (0.5) [0.5 on Epop[30]] -> cell 13, seg 0 (0.5) [0.5 on Ipop[13]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[13] syn_projEI_ampa[613] = new ampa(0.5)")
        h("Epop[30] netConn_projEI_ampa[613] = new NetCon(&v(0.5), syn_projEI_ampa[613], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 614: cell 30, seg 0 (0.5) [0.5 on Epop[30]] -> cell 14, seg 0 (0.5) [0.5 on Ipop[14]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[14] syn_projEI_ampa[614] = new ampa(0.5)")
        h("Epop[30] netConn_projEI_ampa[614] = new NetCon(&v(0.5), syn_projEI_ampa[614], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 615: cell 30, seg 0 (0.5) [0.5 on Epop[30]] -> cell 15, seg 0 (0.5) [0.5 on Ipop[15]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[15] syn_projEI_ampa[615] = new ampa(0.5)")
        h("Epop[30] netConn_projEI_ampa[615] = new NetCon(&v(0.5), syn_projEI_ampa[615], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 616: cell 30, seg 0 (0.5) [0.5 on Epop[30]] -> cell 16, seg 0 (0.5) [0.5 on Ipop[16]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[16] syn_projEI_ampa[616] = new ampa(0.5)")
        h("Epop[30] netConn_projEI_ampa[616] = new NetCon(&v(0.5), syn_projEI_ampa[616], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 617: cell 30, seg 0 (0.5) [0.5 on Epop[30]] -> cell 17, seg 0 (0.5) [0.5 on Ipop[17]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[17] syn_projEI_ampa[617] = new ampa(0.5)")
        h("Epop[30] netConn_projEI_ampa[617] = new NetCon(&v(0.5), syn_projEI_ampa[617], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 618: cell 30, seg 0 (0.5) [0.5 on Epop[30]] -> cell 18, seg 0 (0.5) [0.5 on Ipop[18]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[18] syn_projEI_ampa[618] = new ampa(0.5)")
        h("Epop[30] netConn_projEI_ampa[618] = new NetCon(&v(0.5), syn_projEI_ampa[618], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 619: cell 30, seg 0 (0.5) [0.5 on Epop[30]] -> cell 19, seg 0 (0.5) [0.5 on Ipop[19]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[19] syn_projEI_ampa[619] = new ampa(0.5)")
        h("Epop[30] netConn_projEI_ampa[619] = new NetCon(&v(0.5), syn_projEI_ampa[619], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 620: cell 31, seg 0 (0.5) [0.5 on Epop[31]] -> cell 0, seg 0 (0.5) [0.5 on Ipop[0]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[0] syn_projEI_ampa[620] = new ampa(0.5)")
        h("Epop[31] netConn_projEI_ampa[620] = new NetCon(&v(0.5), syn_projEI_ampa[620], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 621: cell 31, seg 0 (0.5) [0.5 on Epop[31]] -> cell 1, seg 0 (0.5) [0.5 on Ipop[1]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[1] syn_projEI_ampa[621] = new ampa(0.5)")
        h("Epop[31] netConn_projEI_ampa[621] = new NetCon(&v(0.5), syn_projEI_ampa[621], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 622: cell 31, seg 0 (0.5) [0.5 on Epop[31]] -> cell 2, seg 0 (0.5) [0.5 on Ipop[2]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[2] syn_projEI_ampa[622] = new ampa(0.5)")
        h("Epop[31] netConn_projEI_ampa[622] = new NetCon(&v(0.5), syn_projEI_ampa[622], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 623: cell 31, seg 0 (0.5) [0.5 on Epop[31]] -> cell 3, seg 0 (0.5) [0.5 on Ipop[3]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[3] syn_projEI_ampa[623] = new ampa(0.5)")
        h("Epop[31] netConn_projEI_ampa[623] = new NetCon(&v(0.5), syn_projEI_ampa[623], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 624: cell 31, seg 0 (0.5) [0.5 on Epop[31]] -> cell 4, seg 0 (0.5) [0.5 on Ipop[4]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[4] syn_projEI_ampa[624] = new ampa(0.5)")
        h("Epop[31] netConn_projEI_ampa[624] = new NetCon(&v(0.5), syn_projEI_ampa[624], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 625: cell 31, seg 0 (0.5) [0.5 on Epop[31]] -> cell 5, seg 0 (0.5) [0.5 on Ipop[5]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[5] syn_projEI_ampa[625] = new ampa(0.5)")
        h("Epop[31] netConn_projEI_ampa[625] = new NetCon(&v(0.5), syn_projEI_ampa[625], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 626: cell 31, seg 0 (0.5) [0.5 on Epop[31]] -> cell 6, seg 0 (0.5) [0.5 on Ipop[6]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[6] syn_projEI_ampa[626] = new ampa(0.5)")
        h("Epop[31] netConn_projEI_ampa[626] = new NetCon(&v(0.5), syn_projEI_ampa[626], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 627: cell 31, seg 0 (0.5) [0.5 on Epop[31]] -> cell 7, seg 0 (0.5) [0.5 on Ipop[7]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[7] syn_projEI_ampa[627] = new ampa(0.5)")
        h("Epop[31] netConn_projEI_ampa[627] = new NetCon(&v(0.5), syn_projEI_ampa[627], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 628: cell 31, seg 0 (0.5) [0.5 on Epop[31]] -> cell 8, seg 0 (0.5) [0.5 on Ipop[8]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[8] syn_projEI_ampa[628] = new ampa(0.5)")
        h("Epop[31] netConn_projEI_ampa[628] = new NetCon(&v(0.5), syn_projEI_ampa[628], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 629: cell 31, seg 0 (0.5) [0.5 on Epop[31]] -> cell 9, seg 0 (0.5) [0.5 on Ipop[9]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[9] syn_projEI_ampa[629] = new ampa(0.5)")
        h("Epop[31] netConn_projEI_ampa[629] = new NetCon(&v(0.5), syn_projEI_ampa[629], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 630: cell 31, seg 0 (0.5) [0.5 on Epop[31]] -> cell 10, seg 0 (0.5) [0.5 on Ipop[10]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[10] syn_projEI_ampa[630] = new ampa(0.5)")
        h("Epop[31] netConn_projEI_ampa[630] = new NetCon(&v(0.5), syn_projEI_ampa[630], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 631: cell 31, seg 0 (0.5) [0.5 on Epop[31]] -> cell 11, seg 0 (0.5) [0.5 on Ipop[11]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[11] syn_projEI_ampa[631] = new ampa(0.5)")
        h("Epop[31] netConn_projEI_ampa[631] = new NetCon(&v(0.5), syn_projEI_ampa[631], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 632: cell 31, seg 0 (0.5) [0.5 on Epop[31]] -> cell 12, seg 0 (0.5) [0.5 on Ipop[12]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[12] syn_projEI_ampa[632] = new ampa(0.5)")
        h("Epop[31] netConn_projEI_ampa[632] = new NetCon(&v(0.5), syn_projEI_ampa[632], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 633: cell 31, seg 0 (0.5) [0.5 on Epop[31]] -> cell 13, seg 0 (0.5) [0.5 on Ipop[13]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[13] syn_projEI_ampa[633] = new ampa(0.5)")
        h("Epop[31] netConn_projEI_ampa[633] = new NetCon(&v(0.5), syn_projEI_ampa[633], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 634: cell 31, seg 0 (0.5) [0.5 on Epop[31]] -> cell 14, seg 0 (0.5) [0.5 on Ipop[14]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[14] syn_projEI_ampa[634] = new ampa(0.5)")
        h("Epop[31] netConn_projEI_ampa[634] = new NetCon(&v(0.5), syn_projEI_ampa[634], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 635: cell 31, seg 0 (0.5) [0.5 on Epop[31]] -> cell 15, seg 0 (0.5) [0.5 on Ipop[15]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[15] syn_projEI_ampa[635] = new ampa(0.5)")
        h("Epop[31] netConn_projEI_ampa[635] = new NetCon(&v(0.5), syn_projEI_ampa[635], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 636: cell 31, seg 0 (0.5) [0.5 on Epop[31]] -> cell 16, seg 0 (0.5) [0.5 on Ipop[16]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[16] syn_projEI_ampa[636] = new ampa(0.5)")
        h("Epop[31] netConn_projEI_ampa[636] = new NetCon(&v(0.5), syn_projEI_ampa[636], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 637: cell 31, seg 0 (0.5) [0.5 on Epop[31]] -> cell 17, seg 0 (0.5) [0.5 on Ipop[17]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[17] syn_projEI_ampa[637] = new ampa(0.5)")
        h("Epop[31] netConn_projEI_ampa[637] = new NetCon(&v(0.5), syn_projEI_ampa[637], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 638: cell 31, seg 0 (0.5) [0.5 on Epop[31]] -> cell 18, seg 0 (0.5) [0.5 on Ipop[18]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[18] syn_projEI_ampa[638] = new ampa(0.5)")
        h("Epop[31] netConn_projEI_ampa[638] = new NetCon(&v(0.5), syn_projEI_ampa[638], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 639: cell 31, seg 0 (0.5) [0.5 on Epop[31]] -> cell 19, seg 0 (0.5) [0.5 on Ipop[19]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[19] syn_projEI_ampa[639] = new ampa(0.5)")
        h("Epop[31] netConn_projEI_ampa[639] = new NetCon(&v(0.5), syn_projEI_ampa[639], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 640: cell 32, seg 0 (0.5) [0.5 on Epop[32]] -> cell 0, seg 0 (0.5) [0.5 on Ipop[0]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[0] syn_projEI_ampa[640] = new ampa(0.5)")
        h("Epop[32] netConn_projEI_ampa[640] = new NetCon(&v(0.5), syn_projEI_ampa[640], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 641: cell 32, seg 0 (0.5) [0.5 on Epop[32]] -> cell 1, seg 0 (0.5) [0.5 on Ipop[1]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[1] syn_projEI_ampa[641] = new ampa(0.5)")
        h("Epop[32] netConn_projEI_ampa[641] = new NetCon(&v(0.5), syn_projEI_ampa[641], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 642: cell 32, seg 0 (0.5) [0.5 on Epop[32]] -> cell 2, seg 0 (0.5) [0.5 on Ipop[2]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[2] syn_projEI_ampa[642] = new ampa(0.5)")
        h("Epop[32] netConn_projEI_ampa[642] = new NetCon(&v(0.5), syn_projEI_ampa[642], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 643: cell 32, seg 0 (0.5) [0.5 on Epop[32]] -> cell 3, seg 0 (0.5) [0.5 on Ipop[3]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[3] syn_projEI_ampa[643] = new ampa(0.5)")
        h("Epop[32] netConn_projEI_ampa[643] = new NetCon(&v(0.5), syn_projEI_ampa[643], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 644: cell 32, seg 0 (0.5) [0.5 on Epop[32]] -> cell 4, seg 0 (0.5) [0.5 on Ipop[4]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[4] syn_projEI_ampa[644] = new ampa(0.5)")
        h("Epop[32] netConn_projEI_ampa[644] = new NetCon(&v(0.5), syn_projEI_ampa[644], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 645: cell 32, seg 0 (0.5) [0.5 on Epop[32]] -> cell 5, seg 0 (0.5) [0.5 on Ipop[5]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[5] syn_projEI_ampa[645] = new ampa(0.5)")
        h("Epop[32] netConn_projEI_ampa[645] = new NetCon(&v(0.5), syn_projEI_ampa[645], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 646: cell 32, seg 0 (0.5) [0.5 on Epop[32]] -> cell 6, seg 0 (0.5) [0.5 on Ipop[6]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[6] syn_projEI_ampa[646] = new ampa(0.5)")
        h("Epop[32] netConn_projEI_ampa[646] = new NetCon(&v(0.5), syn_projEI_ampa[646], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 647: cell 32, seg 0 (0.5) [0.5 on Epop[32]] -> cell 7, seg 0 (0.5) [0.5 on Ipop[7]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[7] syn_projEI_ampa[647] = new ampa(0.5)")
        h("Epop[32] netConn_projEI_ampa[647] = new NetCon(&v(0.5), syn_projEI_ampa[647], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 648: cell 32, seg 0 (0.5) [0.5 on Epop[32]] -> cell 8, seg 0 (0.5) [0.5 on Ipop[8]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[8] syn_projEI_ampa[648] = new ampa(0.5)")
        h("Epop[32] netConn_projEI_ampa[648] = new NetCon(&v(0.5), syn_projEI_ampa[648], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 649: cell 32, seg 0 (0.5) [0.5 on Epop[32]] -> cell 9, seg 0 (0.5) [0.5 on Ipop[9]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[9] syn_projEI_ampa[649] = new ampa(0.5)")
        h("Epop[32] netConn_projEI_ampa[649] = new NetCon(&v(0.5), syn_projEI_ampa[649], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 650: cell 32, seg 0 (0.5) [0.5 on Epop[32]] -> cell 10, seg 0 (0.5) [0.5 on Ipop[10]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[10] syn_projEI_ampa[650] = new ampa(0.5)")
        h("Epop[32] netConn_projEI_ampa[650] = new NetCon(&v(0.5), syn_projEI_ampa[650], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 651: cell 32, seg 0 (0.5) [0.5 on Epop[32]] -> cell 11, seg 0 (0.5) [0.5 on Ipop[11]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[11] syn_projEI_ampa[651] = new ampa(0.5)")
        h("Epop[32] netConn_projEI_ampa[651] = new NetCon(&v(0.5), syn_projEI_ampa[651], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 652: cell 32, seg 0 (0.5) [0.5 on Epop[32]] -> cell 12, seg 0 (0.5) [0.5 on Ipop[12]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[12] syn_projEI_ampa[652] = new ampa(0.5)")
        h("Epop[32] netConn_projEI_ampa[652] = new NetCon(&v(0.5), syn_projEI_ampa[652], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 653: cell 32, seg 0 (0.5) [0.5 on Epop[32]] -> cell 13, seg 0 (0.5) [0.5 on Ipop[13]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[13] syn_projEI_ampa[653] = new ampa(0.5)")
        h("Epop[32] netConn_projEI_ampa[653] = new NetCon(&v(0.5), syn_projEI_ampa[653], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 654: cell 32, seg 0 (0.5) [0.5 on Epop[32]] -> cell 14, seg 0 (0.5) [0.5 on Ipop[14]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[14] syn_projEI_ampa[654] = new ampa(0.5)")
        h("Epop[32] netConn_projEI_ampa[654] = new NetCon(&v(0.5), syn_projEI_ampa[654], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 655: cell 32, seg 0 (0.5) [0.5 on Epop[32]] -> cell 15, seg 0 (0.5) [0.5 on Ipop[15]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[15] syn_projEI_ampa[655] = new ampa(0.5)")
        h("Epop[32] netConn_projEI_ampa[655] = new NetCon(&v(0.5), syn_projEI_ampa[655], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 656: cell 32, seg 0 (0.5) [0.5 on Epop[32]] -> cell 16, seg 0 (0.5) [0.5 on Ipop[16]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[16] syn_projEI_ampa[656] = new ampa(0.5)")
        h("Epop[32] netConn_projEI_ampa[656] = new NetCon(&v(0.5), syn_projEI_ampa[656], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 657: cell 32, seg 0 (0.5) [0.5 on Epop[32]] -> cell 17, seg 0 (0.5) [0.5 on Ipop[17]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[17] syn_projEI_ampa[657] = new ampa(0.5)")
        h("Epop[32] netConn_projEI_ampa[657] = new NetCon(&v(0.5), syn_projEI_ampa[657], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 658: cell 32, seg 0 (0.5) [0.5 on Epop[32]] -> cell 18, seg 0 (0.5) [0.5 on Ipop[18]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[18] syn_projEI_ampa[658] = new ampa(0.5)")
        h("Epop[32] netConn_projEI_ampa[658] = new NetCon(&v(0.5), syn_projEI_ampa[658], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 659: cell 32, seg 0 (0.5) [0.5 on Epop[32]] -> cell 19, seg 0 (0.5) [0.5 on Ipop[19]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[19] syn_projEI_ampa[659] = new ampa(0.5)")
        h("Epop[32] netConn_projEI_ampa[659] = new NetCon(&v(0.5), syn_projEI_ampa[659], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 660: cell 33, seg 0 (0.5) [0.5 on Epop[33]] -> cell 0, seg 0 (0.5) [0.5 on Ipop[0]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[0] syn_projEI_ampa[660] = new ampa(0.5)")
        h("Epop[33] netConn_projEI_ampa[660] = new NetCon(&v(0.5), syn_projEI_ampa[660], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 661: cell 33, seg 0 (0.5) [0.5 on Epop[33]] -> cell 1, seg 0 (0.5) [0.5 on Ipop[1]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[1] syn_projEI_ampa[661] = new ampa(0.5)")
        h("Epop[33] netConn_projEI_ampa[661] = new NetCon(&v(0.5), syn_projEI_ampa[661], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 662: cell 33, seg 0 (0.5) [0.5 on Epop[33]] -> cell 2, seg 0 (0.5) [0.5 on Ipop[2]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[2] syn_projEI_ampa[662] = new ampa(0.5)")
        h("Epop[33] netConn_projEI_ampa[662] = new NetCon(&v(0.5), syn_projEI_ampa[662], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 663: cell 33, seg 0 (0.5) [0.5 on Epop[33]] -> cell 3, seg 0 (0.5) [0.5 on Ipop[3]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[3] syn_projEI_ampa[663] = new ampa(0.5)")
        h("Epop[33] netConn_projEI_ampa[663] = new NetCon(&v(0.5), syn_projEI_ampa[663], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 664: cell 33, seg 0 (0.5) [0.5 on Epop[33]] -> cell 4, seg 0 (0.5) [0.5 on Ipop[4]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[4] syn_projEI_ampa[664] = new ampa(0.5)")
        h("Epop[33] netConn_projEI_ampa[664] = new NetCon(&v(0.5), syn_projEI_ampa[664], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 665: cell 33, seg 0 (0.5) [0.5 on Epop[33]] -> cell 5, seg 0 (0.5) [0.5 on Ipop[5]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[5] syn_projEI_ampa[665] = new ampa(0.5)")
        h("Epop[33] netConn_projEI_ampa[665] = new NetCon(&v(0.5), syn_projEI_ampa[665], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 666: cell 33, seg 0 (0.5) [0.5 on Epop[33]] -> cell 6, seg 0 (0.5) [0.5 on Ipop[6]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[6] syn_projEI_ampa[666] = new ampa(0.5)")
        h("Epop[33] netConn_projEI_ampa[666] = new NetCon(&v(0.5), syn_projEI_ampa[666], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 667: cell 33, seg 0 (0.5) [0.5 on Epop[33]] -> cell 7, seg 0 (0.5) [0.5 on Ipop[7]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[7] syn_projEI_ampa[667] = new ampa(0.5)")
        h("Epop[33] netConn_projEI_ampa[667] = new NetCon(&v(0.5), syn_projEI_ampa[667], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 668: cell 33, seg 0 (0.5) [0.5 on Epop[33]] -> cell 8, seg 0 (0.5) [0.5 on Ipop[8]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[8] syn_projEI_ampa[668] = new ampa(0.5)")
        h("Epop[33] netConn_projEI_ampa[668] = new NetCon(&v(0.5), syn_projEI_ampa[668], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 669: cell 33, seg 0 (0.5) [0.5 on Epop[33]] -> cell 9, seg 0 (0.5) [0.5 on Ipop[9]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[9] syn_projEI_ampa[669] = new ampa(0.5)")
        h("Epop[33] netConn_projEI_ampa[669] = new NetCon(&v(0.5), syn_projEI_ampa[669], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 670: cell 33, seg 0 (0.5) [0.5 on Epop[33]] -> cell 10, seg 0 (0.5) [0.5 on Ipop[10]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[10] syn_projEI_ampa[670] = new ampa(0.5)")
        h("Epop[33] netConn_projEI_ampa[670] = new NetCon(&v(0.5), syn_projEI_ampa[670], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 671: cell 33, seg 0 (0.5) [0.5 on Epop[33]] -> cell 11, seg 0 (0.5) [0.5 on Ipop[11]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[11] syn_projEI_ampa[671] = new ampa(0.5)")
        h("Epop[33] netConn_projEI_ampa[671] = new NetCon(&v(0.5), syn_projEI_ampa[671], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 672: cell 33, seg 0 (0.5) [0.5 on Epop[33]] -> cell 12, seg 0 (0.5) [0.5 on Ipop[12]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[12] syn_projEI_ampa[672] = new ampa(0.5)")
        h("Epop[33] netConn_projEI_ampa[672] = new NetCon(&v(0.5), syn_projEI_ampa[672], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 673: cell 33, seg 0 (0.5) [0.5 on Epop[33]] -> cell 13, seg 0 (0.5) [0.5 on Ipop[13]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[13] syn_projEI_ampa[673] = new ampa(0.5)")
        h("Epop[33] netConn_projEI_ampa[673] = new NetCon(&v(0.5), syn_projEI_ampa[673], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 674: cell 33, seg 0 (0.5) [0.5 on Epop[33]] -> cell 14, seg 0 (0.5) [0.5 on Ipop[14]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[14] syn_projEI_ampa[674] = new ampa(0.5)")
        h("Epop[33] netConn_projEI_ampa[674] = new NetCon(&v(0.5), syn_projEI_ampa[674], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 675: cell 33, seg 0 (0.5) [0.5 on Epop[33]] -> cell 15, seg 0 (0.5) [0.5 on Ipop[15]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[15] syn_projEI_ampa[675] = new ampa(0.5)")
        h("Epop[33] netConn_projEI_ampa[675] = new NetCon(&v(0.5), syn_projEI_ampa[675], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 676: cell 33, seg 0 (0.5) [0.5 on Epop[33]] -> cell 16, seg 0 (0.5) [0.5 on Ipop[16]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[16] syn_projEI_ampa[676] = new ampa(0.5)")
        h("Epop[33] netConn_projEI_ampa[676] = new NetCon(&v(0.5), syn_projEI_ampa[676], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 677: cell 33, seg 0 (0.5) [0.5 on Epop[33]] -> cell 17, seg 0 (0.5) [0.5 on Ipop[17]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[17] syn_projEI_ampa[677] = new ampa(0.5)")
        h("Epop[33] netConn_projEI_ampa[677] = new NetCon(&v(0.5), syn_projEI_ampa[677], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 678: cell 33, seg 0 (0.5) [0.5 on Epop[33]] -> cell 18, seg 0 (0.5) [0.5 on Ipop[18]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[18] syn_projEI_ampa[678] = new ampa(0.5)")
        h("Epop[33] netConn_projEI_ampa[678] = new NetCon(&v(0.5), syn_projEI_ampa[678], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 679: cell 33, seg 0 (0.5) [0.5 on Epop[33]] -> cell 19, seg 0 (0.5) [0.5 on Ipop[19]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[19] syn_projEI_ampa[679] = new ampa(0.5)")
        h("Epop[33] netConn_projEI_ampa[679] = new NetCon(&v(0.5), syn_projEI_ampa[679], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 680: cell 34, seg 0 (0.5) [0.5 on Epop[34]] -> cell 0, seg 0 (0.5) [0.5 on Ipop[0]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[0] syn_projEI_ampa[680] = new ampa(0.5)")
        h("Epop[34] netConn_projEI_ampa[680] = new NetCon(&v(0.5), syn_projEI_ampa[680], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 681: cell 34, seg 0 (0.5) [0.5 on Epop[34]] -> cell 1, seg 0 (0.5) [0.5 on Ipop[1]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[1] syn_projEI_ampa[681] = new ampa(0.5)")
        h("Epop[34] netConn_projEI_ampa[681] = new NetCon(&v(0.5), syn_projEI_ampa[681], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 682: cell 34, seg 0 (0.5) [0.5 on Epop[34]] -> cell 2, seg 0 (0.5) [0.5 on Ipop[2]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[2] syn_projEI_ampa[682] = new ampa(0.5)")
        h("Epop[34] netConn_projEI_ampa[682] = new NetCon(&v(0.5), syn_projEI_ampa[682], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 683: cell 34, seg 0 (0.5) [0.5 on Epop[34]] -> cell 3, seg 0 (0.5) [0.5 on Ipop[3]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[3] syn_projEI_ampa[683] = new ampa(0.5)")
        h("Epop[34] netConn_projEI_ampa[683] = new NetCon(&v(0.5), syn_projEI_ampa[683], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 684: cell 34, seg 0 (0.5) [0.5 on Epop[34]] -> cell 4, seg 0 (0.5) [0.5 on Ipop[4]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[4] syn_projEI_ampa[684] = new ampa(0.5)")
        h("Epop[34] netConn_projEI_ampa[684] = new NetCon(&v(0.5), syn_projEI_ampa[684], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 685: cell 34, seg 0 (0.5) [0.5 on Epop[34]] -> cell 5, seg 0 (0.5) [0.5 on Ipop[5]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[5] syn_projEI_ampa[685] = new ampa(0.5)")
        h("Epop[34] netConn_projEI_ampa[685] = new NetCon(&v(0.5), syn_projEI_ampa[685], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 686: cell 34, seg 0 (0.5) [0.5 on Epop[34]] -> cell 6, seg 0 (0.5) [0.5 on Ipop[6]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[6] syn_projEI_ampa[686] = new ampa(0.5)")
        h("Epop[34] netConn_projEI_ampa[686] = new NetCon(&v(0.5), syn_projEI_ampa[686], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 687: cell 34, seg 0 (0.5) [0.5 on Epop[34]] -> cell 7, seg 0 (0.5) [0.5 on Ipop[7]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[7] syn_projEI_ampa[687] = new ampa(0.5)")
        h("Epop[34] netConn_projEI_ampa[687] = new NetCon(&v(0.5), syn_projEI_ampa[687], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 688: cell 34, seg 0 (0.5) [0.5 on Epop[34]] -> cell 8, seg 0 (0.5) [0.5 on Ipop[8]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[8] syn_projEI_ampa[688] = new ampa(0.5)")
        h("Epop[34] netConn_projEI_ampa[688] = new NetCon(&v(0.5), syn_projEI_ampa[688], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 689: cell 34, seg 0 (0.5) [0.5 on Epop[34]] -> cell 9, seg 0 (0.5) [0.5 on Ipop[9]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[9] syn_projEI_ampa[689] = new ampa(0.5)")
        h("Epop[34] netConn_projEI_ampa[689] = new NetCon(&v(0.5), syn_projEI_ampa[689], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 690: cell 34, seg 0 (0.5) [0.5 on Epop[34]] -> cell 10, seg 0 (0.5) [0.5 on Ipop[10]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[10] syn_projEI_ampa[690] = new ampa(0.5)")
        h("Epop[34] netConn_projEI_ampa[690] = new NetCon(&v(0.5), syn_projEI_ampa[690], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 691: cell 34, seg 0 (0.5) [0.5 on Epop[34]] -> cell 11, seg 0 (0.5) [0.5 on Ipop[11]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[11] syn_projEI_ampa[691] = new ampa(0.5)")
        h("Epop[34] netConn_projEI_ampa[691] = new NetCon(&v(0.5), syn_projEI_ampa[691], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 692: cell 34, seg 0 (0.5) [0.5 on Epop[34]] -> cell 12, seg 0 (0.5) [0.5 on Ipop[12]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[12] syn_projEI_ampa[692] = new ampa(0.5)")
        h("Epop[34] netConn_projEI_ampa[692] = new NetCon(&v(0.5), syn_projEI_ampa[692], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 693: cell 34, seg 0 (0.5) [0.5 on Epop[34]] -> cell 13, seg 0 (0.5) [0.5 on Ipop[13]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[13] syn_projEI_ampa[693] = new ampa(0.5)")
        h("Epop[34] netConn_projEI_ampa[693] = new NetCon(&v(0.5), syn_projEI_ampa[693], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 694: cell 34, seg 0 (0.5) [0.5 on Epop[34]] -> cell 14, seg 0 (0.5) [0.5 on Ipop[14]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[14] syn_projEI_ampa[694] = new ampa(0.5)")
        h("Epop[34] netConn_projEI_ampa[694] = new NetCon(&v(0.5), syn_projEI_ampa[694], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 695: cell 34, seg 0 (0.5) [0.5 on Epop[34]] -> cell 15, seg 0 (0.5) [0.5 on Ipop[15]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[15] syn_projEI_ampa[695] = new ampa(0.5)")
        h("Epop[34] netConn_projEI_ampa[695] = new NetCon(&v(0.5), syn_projEI_ampa[695], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 696: cell 34, seg 0 (0.5) [0.5 on Epop[34]] -> cell 16, seg 0 (0.5) [0.5 on Ipop[16]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[16] syn_projEI_ampa[696] = new ampa(0.5)")
        h("Epop[34] netConn_projEI_ampa[696] = new NetCon(&v(0.5), syn_projEI_ampa[696], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 697: cell 34, seg 0 (0.5) [0.5 on Epop[34]] -> cell 17, seg 0 (0.5) [0.5 on Ipop[17]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[17] syn_projEI_ampa[697] = new ampa(0.5)")
        h("Epop[34] netConn_projEI_ampa[697] = new NetCon(&v(0.5), syn_projEI_ampa[697], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 698: cell 34, seg 0 (0.5) [0.5 on Epop[34]] -> cell 18, seg 0 (0.5) [0.5 on Ipop[18]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[18] syn_projEI_ampa[698] = new ampa(0.5)")
        h("Epop[34] netConn_projEI_ampa[698] = new NetCon(&v(0.5), syn_projEI_ampa[698], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 699: cell 34, seg 0 (0.5) [0.5 on Epop[34]] -> cell 19, seg 0 (0.5) [0.5 on Ipop[19]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[19] syn_projEI_ampa[699] = new ampa(0.5)")
        h("Epop[34] netConn_projEI_ampa[699] = new NetCon(&v(0.5), syn_projEI_ampa[699], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 700: cell 35, seg 0 (0.5) [0.5 on Epop[35]] -> cell 0, seg 0 (0.5) [0.5 on Ipop[0]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[0] syn_projEI_ampa[700] = new ampa(0.5)")
        h("Epop[35] netConn_projEI_ampa[700] = new NetCon(&v(0.5), syn_projEI_ampa[700], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 701: cell 35, seg 0 (0.5) [0.5 on Epop[35]] -> cell 1, seg 0 (0.5) [0.5 on Ipop[1]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[1] syn_projEI_ampa[701] = new ampa(0.5)")
        h("Epop[35] netConn_projEI_ampa[701] = new NetCon(&v(0.5), syn_projEI_ampa[701], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 702: cell 35, seg 0 (0.5) [0.5 on Epop[35]] -> cell 2, seg 0 (0.5) [0.5 on Ipop[2]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[2] syn_projEI_ampa[702] = new ampa(0.5)")
        h("Epop[35] netConn_projEI_ampa[702] = new NetCon(&v(0.5), syn_projEI_ampa[702], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 703: cell 35, seg 0 (0.5) [0.5 on Epop[35]] -> cell 3, seg 0 (0.5) [0.5 on Ipop[3]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[3] syn_projEI_ampa[703] = new ampa(0.5)")
        h("Epop[35] netConn_projEI_ampa[703] = new NetCon(&v(0.5), syn_projEI_ampa[703], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 704: cell 35, seg 0 (0.5) [0.5 on Epop[35]] -> cell 4, seg 0 (0.5) [0.5 on Ipop[4]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[4] syn_projEI_ampa[704] = new ampa(0.5)")
        h("Epop[35] netConn_projEI_ampa[704] = new NetCon(&v(0.5), syn_projEI_ampa[704], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 705: cell 35, seg 0 (0.5) [0.5 on Epop[35]] -> cell 5, seg 0 (0.5) [0.5 on Ipop[5]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[5] syn_projEI_ampa[705] = new ampa(0.5)")
        h("Epop[35] netConn_projEI_ampa[705] = new NetCon(&v(0.5), syn_projEI_ampa[705], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 706: cell 35, seg 0 (0.5) [0.5 on Epop[35]] -> cell 6, seg 0 (0.5) [0.5 on Ipop[6]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[6] syn_projEI_ampa[706] = new ampa(0.5)")
        h("Epop[35] netConn_projEI_ampa[706] = new NetCon(&v(0.5), syn_projEI_ampa[706], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 707: cell 35, seg 0 (0.5) [0.5 on Epop[35]] -> cell 7, seg 0 (0.5) [0.5 on Ipop[7]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[7] syn_projEI_ampa[707] = new ampa(0.5)")
        h("Epop[35] netConn_projEI_ampa[707] = new NetCon(&v(0.5), syn_projEI_ampa[707], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 708: cell 35, seg 0 (0.5) [0.5 on Epop[35]] -> cell 8, seg 0 (0.5) [0.5 on Ipop[8]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[8] syn_projEI_ampa[708] = new ampa(0.5)")
        h("Epop[35] netConn_projEI_ampa[708] = new NetCon(&v(0.5), syn_projEI_ampa[708], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 709: cell 35, seg 0 (0.5) [0.5 on Epop[35]] -> cell 9, seg 0 (0.5) [0.5 on Ipop[9]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[9] syn_projEI_ampa[709] = new ampa(0.5)")
        h("Epop[35] netConn_projEI_ampa[709] = new NetCon(&v(0.5), syn_projEI_ampa[709], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 710: cell 35, seg 0 (0.5) [0.5 on Epop[35]] -> cell 10, seg 0 (0.5) [0.5 on Ipop[10]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[10] syn_projEI_ampa[710] = new ampa(0.5)")
        h("Epop[35] netConn_projEI_ampa[710] = new NetCon(&v(0.5), syn_projEI_ampa[710], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 711: cell 35, seg 0 (0.5) [0.5 on Epop[35]] -> cell 11, seg 0 (0.5) [0.5 on Ipop[11]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[11] syn_projEI_ampa[711] = new ampa(0.5)")
        h("Epop[35] netConn_projEI_ampa[711] = new NetCon(&v(0.5), syn_projEI_ampa[711], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 712: cell 35, seg 0 (0.5) [0.5 on Epop[35]] -> cell 12, seg 0 (0.5) [0.5 on Ipop[12]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[12] syn_projEI_ampa[712] = new ampa(0.5)")
        h("Epop[35] netConn_projEI_ampa[712] = new NetCon(&v(0.5), syn_projEI_ampa[712], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 713: cell 35, seg 0 (0.5) [0.5 on Epop[35]] -> cell 13, seg 0 (0.5) [0.5 on Ipop[13]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[13] syn_projEI_ampa[713] = new ampa(0.5)")
        h("Epop[35] netConn_projEI_ampa[713] = new NetCon(&v(0.5), syn_projEI_ampa[713], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 714: cell 35, seg 0 (0.5) [0.5 on Epop[35]] -> cell 14, seg 0 (0.5) [0.5 on Ipop[14]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[14] syn_projEI_ampa[714] = new ampa(0.5)")
        h("Epop[35] netConn_projEI_ampa[714] = new NetCon(&v(0.5), syn_projEI_ampa[714], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 715: cell 35, seg 0 (0.5) [0.5 on Epop[35]] -> cell 15, seg 0 (0.5) [0.5 on Ipop[15]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[15] syn_projEI_ampa[715] = new ampa(0.5)")
        h("Epop[35] netConn_projEI_ampa[715] = new NetCon(&v(0.5), syn_projEI_ampa[715], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 716: cell 35, seg 0 (0.5) [0.5 on Epop[35]] -> cell 16, seg 0 (0.5) [0.5 on Ipop[16]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[16] syn_projEI_ampa[716] = new ampa(0.5)")
        h("Epop[35] netConn_projEI_ampa[716] = new NetCon(&v(0.5), syn_projEI_ampa[716], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 717: cell 35, seg 0 (0.5) [0.5 on Epop[35]] -> cell 17, seg 0 (0.5) [0.5 on Ipop[17]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[17] syn_projEI_ampa[717] = new ampa(0.5)")
        h("Epop[35] netConn_projEI_ampa[717] = new NetCon(&v(0.5), syn_projEI_ampa[717], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 718: cell 35, seg 0 (0.5) [0.5 on Epop[35]] -> cell 18, seg 0 (0.5) [0.5 on Ipop[18]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[18] syn_projEI_ampa[718] = new ampa(0.5)")
        h("Epop[35] netConn_projEI_ampa[718] = new NetCon(&v(0.5), syn_projEI_ampa[718], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 719: cell 35, seg 0 (0.5) [0.5 on Epop[35]] -> cell 19, seg 0 (0.5) [0.5 on Ipop[19]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[19] syn_projEI_ampa[719] = new ampa(0.5)")
        h("Epop[35] netConn_projEI_ampa[719] = new NetCon(&v(0.5), syn_projEI_ampa[719], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 720: cell 36, seg 0 (0.5) [0.5 on Epop[36]] -> cell 0, seg 0 (0.5) [0.5 on Ipop[0]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[0] syn_projEI_ampa[720] = new ampa(0.5)")
        h("Epop[36] netConn_projEI_ampa[720] = new NetCon(&v(0.5), syn_projEI_ampa[720], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 721: cell 36, seg 0 (0.5) [0.5 on Epop[36]] -> cell 1, seg 0 (0.5) [0.5 on Ipop[1]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[1] syn_projEI_ampa[721] = new ampa(0.5)")
        h("Epop[36] netConn_projEI_ampa[721] = new NetCon(&v(0.5), syn_projEI_ampa[721], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 722: cell 36, seg 0 (0.5) [0.5 on Epop[36]] -> cell 2, seg 0 (0.5) [0.5 on Ipop[2]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[2] syn_projEI_ampa[722] = new ampa(0.5)")
        h("Epop[36] netConn_projEI_ampa[722] = new NetCon(&v(0.5), syn_projEI_ampa[722], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 723: cell 36, seg 0 (0.5) [0.5 on Epop[36]] -> cell 3, seg 0 (0.5) [0.5 on Ipop[3]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[3] syn_projEI_ampa[723] = new ampa(0.5)")
        h("Epop[36] netConn_projEI_ampa[723] = new NetCon(&v(0.5), syn_projEI_ampa[723], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 724: cell 36, seg 0 (0.5) [0.5 on Epop[36]] -> cell 4, seg 0 (0.5) [0.5 on Ipop[4]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[4] syn_projEI_ampa[724] = new ampa(0.5)")
        h("Epop[36] netConn_projEI_ampa[724] = new NetCon(&v(0.5), syn_projEI_ampa[724], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 725: cell 36, seg 0 (0.5) [0.5 on Epop[36]] -> cell 5, seg 0 (0.5) [0.5 on Ipop[5]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[5] syn_projEI_ampa[725] = new ampa(0.5)")
        h("Epop[36] netConn_projEI_ampa[725] = new NetCon(&v(0.5), syn_projEI_ampa[725], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 726: cell 36, seg 0 (0.5) [0.5 on Epop[36]] -> cell 6, seg 0 (0.5) [0.5 on Ipop[6]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[6] syn_projEI_ampa[726] = new ampa(0.5)")
        h("Epop[36] netConn_projEI_ampa[726] = new NetCon(&v(0.5), syn_projEI_ampa[726], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 727: cell 36, seg 0 (0.5) [0.5 on Epop[36]] -> cell 7, seg 0 (0.5) [0.5 on Ipop[7]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[7] syn_projEI_ampa[727] = new ampa(0.5)")
        h("Epop[36] netConn_projEI_ampa[727] = new NetCon(&v(0.5), syn_projEI_ampa[727], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 728: cell 36, seg 0 (0.5) [0.5 on Epop[36]] -> cell 8, seg 0 (0.5) [0.5 on Ipop[8]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[8] syn_projEI_ampa[728] = new ampa(0.5)")
        h("Epop[36] netConn_projEI_ampa[728] = new NetCon(&v(0.5), syn_projEI_ampa[728], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 729: cell 36, seg 0 (0.5) [0.5 on Epop[36]] -> cell 9, seg 0 (0.5) [0.5 on Ipop[9]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[9] syn_projEI_ampa[729] = new ampa(0.5)")
        h("Epop[36] netConn_projEI_ampa[729] = new NetCon(&v(0.5), syn_projEI_ampa[729], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 730: cell 36, seg 0 (0.5) [0.5 on Epop[36]] -> cell 10, seg 0 (0.5) [0.5 on Ipop[10]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[10] syn_projEI_ampa[730] = new ampa(0.5)")
        h("Epop[36] netConn_projEI_ampa[730] = new NetCon(&v(0.5), syn_projEI_ampa[730], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 731: cell 36, seg 0 (0.5) [0.5 on Epop[36]] -> cell 11, seg 0 (0.5) [0.5 on Ipop[11]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[11] syn_projEI_ampa[731] = new ampa(0.5)")
        h("Epop[36] netConn_projEI_ampa[731] = new NetCon(&v(0.5), syn_projEI_ampa[731], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 732: cell 36, seg 0 (0.5) [0.5 on Epop[36]] -> cell 12, seg 0 (0.5) [0.5 on Ipop[12]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[12] syn_projEI_ampa[732] = new ampa(0.5)")
        h("Epop[36] netConn_projEI_ampa[732] = new NetCon(&v(0.5), syn_projEI_ampa[732], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 733: cell 36, seg 0 (0.5) [0.5 on Epop[36]] -> cell 13, seg 0 (0.5) [0.5 on Ipop[13]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[13] syn_projEI_ampa[733] = new ampa(0.5)")
        h("Epop[36] netConn_projEI_ampa[733] = new NetCon(&v(0.5), syn_projEI_ampa[733], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 734: cell 36, seg 0 (0.5) [0.5 on Epop[36]] -> cell 14, seg 0 (0.5) [0.5 on Ipop[14]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[14] syn_projEI_ampa[734] = new ampa(0.5)")
        h("Epop[36] netConn_projEI_ampa[734] = new NetCon(&v(0.5), syn_projEI_ampa[734], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 735: cell 36, seg 0 (0.5) [0.5 on Epop[36]] -> cell 15, seg 0 (0.5) [0.5 on Ipop[15]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[15] syn_projEI_ampa[735] = new ampa(0.5)")
        h("Epop[36] netConn_projEI_ampa[735] = new NetCon(&v(0.5), syn_projEI_ampa[735], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 736: cell 36, seg 0 (0.5) [0.5 on Epop[36]] -> cell 16, seg 0 (0.5) [0.5 on Ipop[16]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[16] syn_projEI_ampa[736] = new ampa(0.5)")
        h("Epop[36] netConn_projEI_ampa[736] = new NetCon(&v(0.5), syn_projEI_ampa[736], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 737: cell 36, seg 0 (0.5) [0.5 on Epop[36]] -> cell 17, seg 0 (0.5) [0.5 on Ipop[17]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[17] syn_projEI_ampa[737] = new ampa(0.5)")
        h("Epop[36] netConn_projEI_ampa[737] = new NetCon(&v(0.5), syn_projEI_ampa[737], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 738: cell 36, seg 0 (0.5) [0.5 on Epop[36]] -> cell 18, seg 0 (0.5) [0.5 on Ipop[18]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[18] syn_projEI_ampa[738] = new ampa(0.5)")
        h("Epop[36] netConn_projEI_ampa[738] = new NetCon(&v(0.5), syn_projEI_ampa[738], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 739: cell 36, seg 0 (0.5) [0.5 on Epop[36]] -> cell 19, seg 0 (0.5) [0.5 on Ipop[19]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[19] syn_projEI_ampa[739] = new ampa(0.5)")
        h("Epop[36] netConn_projEI_ampa[739] = new NetCon(&v(0.5), syn_projEI_ampa[739], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 740: cell 37, seg 0 (0.5) [0.5 on Epop[37]] -> cell 0, seg 0 (0.5) [0.5 on Ipop[0]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[0] syn_projEI_ampa[740] = new ampa(0.5)")
        h("Epop[37] netConn_projEI_ampa[740] = new NetCon(&v(0.5), syn_projEI_ampa[740], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 741: cell 37, seg 0 (0.5) [0.5 on Epop[37]] -> cell 1, seg 0 (0.5) [0.5 on Ipop[1]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[1] syn_projEI_ampa[741] = new ampa(0.5)")
        h("Epop[37] netConn_projEI_ampa[741] = new NetCon(&v(0.5), syn_projEI_ampa[741], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 742: cell 37, seg 0 (0.5) [0.5 on Epop[37]] -> cell 2, seg 0 (0.5) [0.5 on Ipop[2]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[2] syn_projEI_ampa[742] = new ampa(0.5)")
        h("Epop[37] netConn_projEI_ampa[742] = new NetCon(&v(0.5), syn_projEI_ampa[742], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 743: cell 37, seg 0 (0.5) [0.5 on Epop[37]] -> cell 3, seg 0 (0.5) [0.5 on Ipop[3]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[3] syn_projEI_ampa[743] = new ampa(0.5)")
        h("Epop[37] netConn_projEI_ampa[743] = new NetCon(&v(0.5), syn_projEI_ampa[743], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 744: cell 37, seg 0 (0.5) [0.5 on Epop[37]] -> cell 4, seg 0 (0.5) [0.5 on Ipop[4]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[4] syn_projEI_ampa[744] = new ampa(0.5)")
        h("Epop[37] netConn_projEI_ampa[744] = new NetCon(&v(0.5), syn_projEI_ampa[744], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 745: cell 37, seg 0 (0.5) [0.5 on Epop[37]] -> cell 5, seg 0 (0.5) [0.5 on Ipop[5]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[5] syn_projEI_ampa[745] = new ampa(0.5)")
        h("Epop[37] netConn_projEI_ampa[745] = new NetCon(&v(0.5), syn_projEI_ampa[745], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 746: cell 37, seg 0 (0.5) [0.5 on Epop[37]] -> cell 6, seg 0 (0.5) [0.5 on Ipop[6]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[6] syn_projEI_ampa[746] = new ampa(0.5)")
        h("Epop[37] netConn_projEI_ampa[746] = new NetCon(&v(0.5), syn_projEI_ampa[746], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 747: cell 37, seg 0 (0.5) [0.5 on Epop[37]] -> cell 7, seg 0 (0.5) [0.5 on Ipop[7]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[7] syn_projEI_ampa[747] = new ampa(0.5)")
        h("Epop[37] netConn_projEI_ampa[747] = new NetCon(&v(0.5), syn_projEI_ampa[747], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 748: cell 37, seg 0 (0.5) [0.5 on Epop[37]] -> cell 8, seg 0 (0.5) [0.5 on Ipop[8]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[8] syn_projEI_ampa[748] = new ampa(0.5)")
        h("Epop[37] netConn_projEI_ampa[748] = new NetCon(&v(0.5), syn_projEI_ampa[748], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 749: cell 37, seg 0 (0.5) [0.5 on Epop[37]] -> cell 9, seg 0 (0.5) [0.5 on Ipop[9]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[9] syn_projEI_ampa[749] = new ampa(0.5)")
        h("Epop[37] netConn_projEI_ampa[749] = new NetCon(&v(0.5), syn_projEI_ampa[749], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 750: cell 37, seg 0 (0.5) [0.5 on Epop[37]] -> cell 10, seg 0 (0.5) [0.5 on Ipop[10]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[10] syn_projEI_ampa[750] = new ampa(0.5)")
        h("Epop[37] netConn_projEI_ampa[750] = new NetCon(&v(0.5), syn_projEI_ampa[750], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 751: cell 37, seg 0 (0.5) [0.5 on Epop[37]] -> cell 11, seg 0 (0.5) [0.5 on Ipop[11]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[11] syn_projEI_ampa[751] = new ampa(0.5)")
        h("Epop[37] netConn_projEI_ampa[751] = new NetCon(&v(0.5), syn_projEI_ampa[751], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 752: cell 37, seg 0 (0.5) [0.5 on Epop[37]] -> cell 12, seg 0 (0.5) [0.5 on Ipop[12]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[12] syn_projEI_ampa[752] = new ampa(0.5)")
        h("Epop[37] netConn_projEI_ampa[752] = new NetCon(&v(0.5), syn_projEI_ampa[752], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 753: cell 37, seg 0 (0.5) [0.5 on Epop[37]] -> cell 13, seg 0 (0.5) [0.5 on Ipop[13]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[13] syn_projEI_ampa[753] = new ampa(0.5)")
        h("Epop[37] netConn_projEI_ampa[753] = new NetCon(&v(0.5), syn_projEI_ampa[753], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 754: cell 37, seg 0 (0.5) [0.5 on Epop[37]] -> cell 14, seg 0 (0.5) [0.5 on Ipop[14]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[14] syn_projEI_ampa[754] = new ampa(0.5)")
        h("Epop[37] netConn_projEI_ampa[754] = new NetCon(&v(0.5), syn_projEI_ampa[754], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 755: cell 37, seg 0 (0.5) [0.5 on Epop[37]] -> cell 15, seg 0 (0.5) [0.5 on Ipop[15]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[15] syn_projEI_ampa[755] = new ampa(0.5)")
        h("Epop[37] netConn_projEI_ampa[755] = new NetCon(&v(0.5), syn_projEI_ampa[755], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 756: cell 37, seg 0 (0.5) [0.5 on Epop[37]] -> cell 16, seg 0 (0.5) [0.5 on Ipop[16]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[16] syn_projEI_ampa[756] = new ampa(0.5)")
        h("Epop[37] netConn_projEI_ampa[756] = new NetCon(&v(0.5), syn_projEI_ampa[756], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 757: cell 37, seg 0 (0.5) [0.5 on Epop[37]] -> cell 17, seg 0 (0.5) [0.5 on Ipop[17]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[17] syn_projEI_ampa[757] = new ampa(0.5)")
        h("Epop[37] netConn_projEI_ampa[757] = new NetCon(&v(0.5), syn_projEI_ampa[757], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 758: cell 37, seg 0 (0.5) [0.5 on Epop[37]] -> cell 18, seg 0 (0.5) [0.5 on Ipop[18]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[18] syn_projEI_ampa[758] = new ampa(0.5)")
        h("Epop[37] netConn_projEI_ampa[758] = new NetCon(&v(0.5), syn_projEI_ampa[758], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 759: cell 37, seg 0 (0.5) [0.5 on Epop[37]] -> cell 19, seg 0 (0.5) [0.5 on Ipop[19]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[19] syn_projEI_ampa[759] = new ampa(0.5)")
        h("Epop[37] netConn_projEI_ampa[759] = new NetCon(&v(0.5), syn_projEI_ampa[759], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 760: cell 38, seg 0 (0.5) [0.5 on Epop[38]] -> cell 0, seg 0 (0.5) [0.5 on Ipop[0]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[0] syn_projEI_ampa[760] = new ampa(0.5)")
        h("Epop[38] netConn_projEI_ampa[760] = new NetCon(&v(0.5), syn_projEI_ampa[760], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 761: cell 38, seg 0 (0.5) [0.5 on Epop[38]] -> cell 1, seg 0 (0.5) [0.5 on Ipop[1]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[1] syn_projEI_ampa[761] = new ampa(0.5)")
        h("Epop[38] netConn_projEI_ampa[761] = new NetCon(&v(0.5), syn_projEI_ampa[761], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 762: cell 38, seg 0 (0.5) [0.5 on Epop[38]] -> cell 2, seg 0 (0.5) [0.5 on Ipop[2]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[2] syn_projEI_ampa[762] = new ampa(0.5)")
        h("Epop[38] netConn_projEI_ampa[762] = new NetCon(&v(0.5), syn_projEI_ampa[762], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 763: cell 38, seg 0 (0.5) [0.5 on Epop[38]] -> cell 3, seg 0 (0.5) [0.5 on Ipop[3]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[3] syn_projEI_ampa[763] = new ampa(0.5)")
        h("Epop[38] netConn_projEI_ampa[763] = new NetCon(&v(0.5), syn_projEI_ampa[763], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 764: cell 38, seg 0 (0.5) [0.5 on Epop[38]] -> cell 4, seg 0 (0.5) [0.5 on Ipop[4]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[4] syn_projEI_ampa[764] = new ampa(0.5)")
        h("Epop[38] netConn_projEI_ampa[764] = new NetCon(&v(0.5), syn_projEI_ampa[764], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 765: cell 38, seg 0 (0.5) [0.5 on Epop[38]] -> cell 5, seg 0 (0.5) [0.5 on Ipop[5]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[5] syn_projEI_ampa[765] = new ampa(0.5)")
        h("Epop[38] netConn_projEI_ampa[765] = new NetCon(&v(0.5), syn_projEI_ampa[765], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 766: cell 38, seg 0 (0.5) [0.5 on Epop[38]] -> cell 6, seg 0 (0.5) [0.5 on Ipop[6]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[6] syn_projEI_ampa[766] = new ampa(0.5)")
        h("Epop[38] netConn_projEI_ampa[766] = new NetCon(&v(0.5), syn_projEI_ampa[766], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 767: cell 38, seg 0 (0.5) [0.5 on Epop[38]] -> cell 7, seg 0 (0.5) [0.5 on Ipop[7]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[7] syn_projEI_ampa[767] = new ampa(0.5)")
        h("Epop[38] netConn_projEI_ampa[767] = new NetCon(&v(0.5), syn_projEI_ampa[767], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 768: cell 38, seg 0 (0.5) [0.5 on Epop[38]] -> cell 8, seg 0 (0.5) [0.5 on Ipop[8]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[8] syn_projEI_ampa[768] = new ampa(0.5)")
        h("Epop[38] netConn_projEI_ampa[768] = new NetCon(&v(0.5), syn_projEI_ampa[768], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 769: cell 38, seg 0 (0.5) [0.5 on Epop[38]] -> cell 9, seg 0 (0.5) [0.5 on Ipop[9]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[9] syn_projEI_ampa[769] = new ampa(0.5)")
        h("Epop[38] netConn_projEI_ampa[769] = new NetCon(&v(0.5), syn_projEI_ampa[769], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 770: cell 38, seg 0 (0.5) [0.5 on Epop[38]] -> cell 10, seg 0 (0.5) [0.5 on Ipop[10]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[10] syn_projEI_ampa[770] = new ampa(0.5)")
        h("Epop[38] netConn_projEI_ampa[770] = new NetCon(&v(0.5), syn_projEI_ampa[770], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 771: cell 38, seg 0 (0.5) [0.5 on Epop[38]] -> cell 11, seg 0 (0.5) [0.5 on Ipop[11]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[11] syn_projEI_ampa[771] = new ampa(0.5)")
        h("Epop[38] netConn_projEI_ampa[771] = new NetCon(&v(0.5), syn_projEI_ampa[771], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 772: cell 38, seg 0 (0.5) [0.5 on Epop[38]] -> cell 12, seg 0 (0.5) [0.5 on Ipop[12]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[12] syn_projEI_ampa[772] = new ampa(0.5)")
        h("Epop[38] netConn_projEI_ampa[772] = new NetCon(&v(0.5), syn_projEI_ampa[772], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 773: cell 38, seg 0 (0.5) [0.5 on Epop[38]] -> cell 13, seg 0 (0.5) [0.5 on Ipop[13]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[13] syn_projEI_ampa[773] = new ampa(0.5)")
        h("Epop[38] netConn_projEI_ampa[773] = new NetCon(&v(0.5), syn_projEI_ampa[773], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 774: cell 38, seg 0 (0.5) [0.5 on Epop[38]] -> cell 14, seg 0 (0.5) [0.5 on Ipop[14]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[14] syn_projEI_ampa[774] = new ampa(0.5)")
        h("Epop[38] netConn_projEI_ampa[774] = new NetCon(&v(0.5), syn_projEI_ampa[774], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 775: cell 38, seg 0 (0.5) [0.5 on Epop[38]] -> cell 15, seg 0 (0.5) [0.5 on Ipop[15]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[15] syn_projEI_ampa[775] = new ampa(0.5)")
        h("Epop[38] netConn_projEI_ampa[775] = new NetCon(&v(0.5), syn_projEI_ampa[775], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 776: cell 38, seg 0 (0.5) [0.5 on Epop[38]] -> cell 16, seg 0 (0.5) [0.5 on Ipop[16]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[16] syn_projEI_ampa[776] = new ampa(0.5)")
        h("Epop[38] netConn_projEI_ampa[776] = new NetCon(&v(0.5), syn_projEI_ampa[776], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 777: cell 38, seg 0 (0.5) [0.5 on Epop[38]] -> cell 17, seg 0 (0.5) [0.5 on Ipop[17]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[17] syn_projEI_ampa[777] = new ampa(0.5)")
        h("Epop[38] netConn_projEI_ampa[777] = new NetCon(&v(0.5), syn_projEI_ampa[777], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 778: cell 38, seg 0 (0.5) [0.5 on Epop[38]] -> cell 18, seg 0 (0.5) [0.5 on Ipop[18]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[18] syn_projEI_ampa[778] = new ampa(0.5)")
        h("Epop[38] netConn_projEI_ampa[778] = new NetCon(&v(0.5), syn_projEI_ampa[778], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 779: cell 38, seg 0 (0.5) [0.5 on Epop[38]] -> cell 19, seg 0 (0.5) [0.5 on Ipop[19]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[19] syn_projEI_ampa[779] = new ampa(0.5)")
        h("Epop[38] netConn_projEI_ampa[779] = new NetCon(&v(0.5), syn_projEI_ampa[779], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 780: cell 39, seg 0 (0.5) [0.5 on Epop[39]] -> cell 0, seg 0 (0.5) [0.5 on Ipop[0]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[0] syn_projEI_ampa[780] = new ampa(0.5)")
        h("Epop[39] netConn_projEI_ampa[780] = new NetCon(&v(0.5), syn_projEI_ampa[780], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 781: cell 39, seg 0 (0.5) [0.5 on Epop[39]] -> cell 1, seg 0 (0.5) [0.5 on Ipop[1]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[1] syn_projEI_ampa[781] = new ampa(0.5)")
        h("Epop[39] netConn_projEI_ampa[781] = new NetCon(&v(0.5), syn_projEI_ampa[781], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 782: cell 39, seg 0 (0.5) [0.5 on Epop[39]] -> cell 2, seg 0 (0.5) [0.5 on Ipop[2]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[2] syn_projEI_ampa[782] = new ampa(0.5)")
        h("Epop[39] netConn_projEI_ampa[782] = new NetCon(&v(0.5), syn_projEI_ampa[782], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 783: cell 39, seg 0 (0.5) [0.5 on Epop[39]] -> cell 3, seg 0 (0.5) [0.5 on Ipop[3]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[3] syn_projEI_ampa[783] = new ampa(0.5)")
        h("Epop[39] netConn_projEI_ampa[783] = new NetCon(&v(0.5), syn_projEI_ampa[783], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 784: cell 39, seg 0 (0.5) [0.5 on Epop[39]] -> cell 4, seg 0 (0.5) [0.5 on Ipop[4]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[4] syn_projEI_ampa[784] = new ampa(0.5)")
        h("Epop[39] netConn_projEI_ampa[784] = new NetCon(&v(0.5), syn_projEI_ampa[784], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 785: cell 39, seg 0 (0.5) [0.5 on Epop[39]] -> cell 5, seg 0 (0.5) [0.5 on Ipop[5]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[5] syn_projEI_ampa[785] = new ampa(0.5)")
        h("Epop[39] netConn_projEI_ampa[785] = new NetCon(&v(0.5), syn_projEI_ampa[785], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 786: cell 39, seg 0 (0.5) [0.5 on Epop[39]] -> cell 6, seg 0 (0.5) [0.5 on Ipop[6]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[6] syn_projEI_ampa[786] = new ampa(0.5)")
        h("Epop[39] netConn_projEI_ampa[786] = new NetCon(&v(0.5), syn_projEI_ampa[786], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 787: cell 39, seg 0 (0.5) [0.5 on Epop[39]] -> cell 7, seg 0 (0.5) [0.5 on Ipop[7]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[7] syn_projEI_ampa[787] = new ampa(0.5)")
        h("Epop[39] netConn_projEI_ampa[787] = new NetCon(&v(0.5), syn_projEI_ampa[787], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 788: cell 39, seg 0 (0.5) [0.5 on Epop[39]] -> cell 8, seg 0 (0.5) [0.5 on Ipop[8]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[8] syn_projEI_ampa[788] = new ampa(0.5)")
        h("Epop[39] netConn_projEI_ampa[788] = new NetCon(&v(0.5), syn_projEI_ampa[788], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 789: cell 39, seg 0 (0.5) [0.5 on Epop[39]] -> cell 9, seg 0 (0.5) [0.5 on Ipop[9]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[9] syn_projEI_ampa[789] = new ampa(0.5)")
        h("Epop[39] netConn_projEI_ampa[789] = new NetCon(&v(0.5), syn_projEI_ampa[789], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 790: cell 39, seg 0 (0.5) [0.5 on Epop[39]] -> cell 10, seg 0 (0.5) [0.5 on Ipop[10]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[10] syn_projEI_ampa[790] = new ampa(0.5)")
        h("Epop[39] netConn_projEI_ampa[790] = new NetCon(&v(0.5), syn_projEI_ampa[790], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 791: cell 39, seg 0 (0.5) [0.5 on Epop[39]] -> cell 11, seg 0 (0.5) [0.5 on Ipop[11]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[11] syn_projEI_ampa[791] = new ampa(0.5)")
        h("Epop[39] netConn_projEI_ampa[791] = new NetCon(&v(0.5), syn_projEI_ampa[791], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 792: cell 39, seg 0 (0.5) [0.5 on Epop[39]] -> cell 12, seg 0 (0.5) [0.5 on Ipop[12]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[12] syn_projEI_ampa[792] = new ampa(0.5)")
        h("Epop[39] netConn_projEI_ampa[792] = new NetCon(&v(0.5), syn_projEI_ampa[792], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 793: cell 39, seg 0 (0.5) [0.5 on Epop[39]] -> cell 13, seg 0 (0.5) [0.5 on Ipop[13]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[13] syn_projEI_ampa[793] = new ampa(0.5)")
        h("Epop[39] netConn_projEI_ampa[793] = new NetCon(&v(0.5), syn_projEI_ampa[793], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 794: cell 39, seg 0 (0.5) [0.5 on Epop[39]] -> cell 14, seg 0 (0.5) [0.5 on Ipop[14]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[14] syn_projEI_ampa[794] = new ampa(0.5)")
        h("Epop[39] netConn_projEI_ampa[794] = new NetCon(&v(0.5), syn_projEI_ampa[794], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 795: cell 39, seg 0 (0.5) [0.5 on Epop[39]] -> cell 15, seg 0 (0.5) [0.5 on Ipop[15]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[15] syn_projEI_ampa[795] = new ampa(0.5)")
        h("Epop[39] netConn_projEI_ampa[795] = new NetCon(&v(0.5), syn_projEI_ampa[795], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 796: cell 39, seg 0 (0.5) [0.5 on Epop[39]] -> cell 16, seg 0 (0.5) [0.5 on Ipop[16]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[16] syn_projEI_ampa[796] = new ampa(0.5)")
        h("Epop[39] netConn_projEI_ampa[796] = new NetCon(&v(0.5), syn_projEI_ampa[796], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 797: cell 39, seg 0 (0.5) [0.5 on Epop[39]] -> cell 17, seg 0 (0.5) [0.5 on Ipop[17]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[17] syn_projEI_ampa[797] = new ampa(0.5)")
        h("Epop[39] netConn_projEI_ampa[797] = new NetCon(&v(0.5), syn_projEI_ampa[797], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 798: cell 39, seg 0 (0.5) [0.5 on Epop[39]] -> cell 18, seg 0 (0.5) [0.5 on Ipop[18]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[18] syn_projEI_ampa[798] = new ampa(0.5)")
        h("Epop[39] netConn_projEI_ampa[798] = new NetCon(&v(0.5), syn_projEI_ampa[798], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 799: cell 39, seg 0 (0.5) [0.5 on Epop[39]] -> cell 19, seg 0 (0.5) [0.5 on Ipop[19]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[19] syn_projEI_ampa[799] = new ampa(0.5)")
        h("Epop[39] netConn_projEI_ampa[799] = new NetCon(&v(0.5), syn_projEI_ampa[799], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 800: cell 40, seg 0 (0.5) [0.5 on Epop[40]] -> cell 0, seg 0 (0.5) [0.5 on Ipop[0]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[0] syn_projEI_ampa[800] = new ampa(0.5)")
        h("Epop[40] netConn_projEI_ampa[800] = new NetCon(&v(0.5), syn_projEI_ampa[800], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 801: cell 40, seg 0 (0.5) [0.5 on Epop[40]] -> cell 1, seg 0 (0.5) [0.5 on Ipop[1]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[1] syn_projEI_ampa[801] = new ampa(0.5)")
        h("Epop[40] netConn_projEI_ampa[801] = new NetCon(&v(0.5), syn_projEI_ampa[801], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 802: cell 40, seg 0 (0.5) [0.5 on Epop[40]] -> cell 2, seg 0 (0.5) [0.5 on Ipop[2]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[2] syn_projEI_ampa[802] = new ampa(0.5)")
        h("Epop[40] netConn_projEI_ampa[802] = new NetCon(&v(0.5), syn_projEI_ampa[802], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 803: cell 40, seg 0 (0.5) [0.5 on Epop[40]] -> cell 3, seg 0 (0.5) [0.5 on Ipop[3]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[3] syn_projEI_ampa[803] = new ampa(0.5)")
        h("Epop[40] netConn_projEI_ampa[803] = new NetCon(&v(0.5), syn_projEI_ampa[803], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 804: cell 40, seg 0 (0.5) [0.5 on Epop[40]] -> cell 4, seg 0 (0.5) [0.5 on Ipop[4]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[4] syn_projEI_ampa[804] = new ampa(0.5)")
        h("Epop[40] netConn_projEI_ampa[804] = new NetCon(&v(0.5), syn_projEI_ampa[804], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 805: cell 40, seg 0 (0.5) [0.5 on Epop[40]] -> cell 5, seg 0 (0.5) [0.5 on Ipop[5]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[5] syn_projEI_ampa[805] = new ampa(0.5)")
        h("Epop[40] netConn_projEI_ampa[805] = new NetCon(&v(0.5), syn_projEI_ampa[805], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 806: cell 40, seg 0 (0.5) [0.5 on Epop[40]] -> cell 6, seg 0 (0.5) [0.5 on Ipop[6]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[6] syn_projEI_ampa[806] = new ampa(0.5)")
        h("Epop[40] netConn_projEI_ampa[806] = new NetCon(&v(0.5), syn_projEI_ampa[806], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 807: cell 40, seg 0 (0.5) [0.5 on Epop[40]] -> cell 7, seg 0 (0.5) [0.5 on Ipop[7]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[7] syn_projEI_ampa[807] = new ampa(0.5)")
        h("Epop[40] netConn_projEI_ampa[807] = new NetCon(&v(0.5), syn_projEI_ampa[807], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 808: cell 40, seg 0 (0.5) [0.5 on Epop[40]] -> cell 8, seg 0 (0.5) [0.5 on Ipop[8]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[8] syn_projEI_ampa[808] = new ampa(0.5)")
        h("Epop[40] netConn_projEI_ampa[808] = new NetCon(&v(0.5), syn_projEI_ampa[808], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 809: cell 40, seg 0 (0.5) [0.5 on Epop[40]] -> cell 9, seg 0 (0.5) [0.5 on Ipop[9]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[9] syn_projEI_ampa[809] = new ampa(0.5)")
        h("Epop[40] netConn_projEI_ampa[809] = new NetCon(&v(0.5), syn_projEI_ampa[809], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 810: cell 40, seg 0 (0.5) [0.5 on Epop[40]] -> cell 10, seg 0 (0.5) [0.5 on Ipop[10]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[10] syn_projEI_ampa[810] = new ampa(0.5)")
        h("Epop[40] netConn_projEI_ampa[810] = new NetCon(&v(0.5), syn_projEI_ampa[810], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 811: cell 40, seg 0 (0.5) [0.5 on Epop[40]] -> cell 11, seg 0 (0.5) [0.5 on Ipop[11]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[11] syn_projEI_ampa[811] = new ampa(0.5)")
        h("Epop[40] netConn_projEI_ampa[811] = new NetCon(&v(0.5), syn_projEI_ampa[811], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 812: cell 40, seg 0 (0.5) [0.5 on Epop[40]] -> cell 12, seg 0 (0.5) [0.5 on Ipop[12]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[12] syn_projEI_ampa[812] = new ampa(0.5)")
        h("Epop[40] netConn_projEI_ampa[812] = new NetCon(&v(0.5), syn_projEI_ampa[812], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 813: cell 40, seg 0 (0.5) [0.5 on Epop[40]] -> cell 13, seg 0 (0.5) [0.5 on Ipop[13]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[13] syn_projEI_ampa[813] = new ampa(0.5)")
        h("Epop[40] netConn_projEI_ampa[813] = new NetCon(&v(0.5), syn_projEI_ampa[813], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 814: cell 40, seg 0 (0.5) [0.5 on Epop[40]] -> cell 14, seg 0 (0.5) [0.5 on Ipop[14]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[14] syn_projEI_ampa[814] = new ampa(0.5)")
        h("Epop[40] netConn_projEI_ampa[814] = new NetCon(&v(0.5), syn_projEI_ampa[814], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 815: cell 40, seg 0 (0.5) [0.5 on Epop[40]] -> cell 15, seg 0 (0.5) [0.5 on Ipop[15]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[15] syn_projEI_ampa[815] = new ampa(0.5)")
        h("Epop[40] netConn_projEI_ampa[815] = new NetCon(&v(0.5), syn_projEI_ampa[815], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 816: cell 40, seg 0 (0.5) [0.5 on Epop[40]] -> cell 16, seg 0 (0.5) [0.5 on Ipop[16]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[16] syn_projEI_ampa[816] = new ampa(0.5)")
        h("Epop[40] netConn_projEI_ampa[816] = new NetCon(&v(0.5), syn_projEI_ampa[816], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 817: cell 40, seg 0 (0.5) [0.5 on Epop[40]] -> cell 17, seg 0 (0.5) [0.5 on Ipop[17]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[17] syn_projEI_ampa[817] = new ampa(0.5)")
        h("Epop[40] netConn_projEI_ampa[817] = new NetCon(&v(0.5), syn_projEI_ampa[817], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 818: cell 40, seg 0 (0.5) [0.5 on Epop[40]] -> cell 18, seg 0 (0.5) [0.5 on Ipop[18]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[18] syn_projEI_ampa[818] = new ampa(0.5)")
        h("Epop[40] netConn_projEI_ampa[818] = new NetCon(&v(0.5), syn_projEI_ampa[818], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 819: cell 40, seg 0 (0.5) [0.5 on Epop[40]] -> cell 19, seg 0 (0.5) [0.5 on Ipop[19]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[19] syn_projEI_ampa[819] = new ampa(0.5)")
        h("Epop[40] netConn_projEI_ampa[819] = new NetCon(&v(0.5), syn_projEI_ampa[819], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 820: cell 41, seg 0 (0.5) [0.5 on Epop[41]] -> cell 0, seg 0 (0.5) [0.5 on Ipop[0]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[0] syn_projEI_ampa[820] = new ampa(0.5)")
        h("Epop[41] netConn_projEI_ampa[820] = new NetCon(&v(0.5), syn_projEI_ampa[820], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 821: cell 41, seg 0 (0.5) [0.5 on Epop[41]] -> cell 1, seg 0 (0.5) [0.5 on Ipop[1]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[1] syn_projEI_ampa[821] = new ampa(0.5)")
        h("Epop[41] netConn_projEI_ampa[821] = new NetCon(&v(0.5), syn_projEI_ampa[821], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 822: cell 41, seg 0 (0.5) [0.5 on Epop[41]] -> cell 2, seg 0 (0.5) [0.5 on Ipop[2]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[2] syn_projEI_ampa[822] = new ampa(0.5)")
        h("Epop[41] netConn_projEI_ampa[822] = new NetCon(&v(0.5), syn_projEI_ampa[822], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 823: cell 41, seg 0 (0.5) [0.5 on Epop[41]] -> cell 3, seg 0 (0.5) [0.5 on Ipop[3]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[3] syn_projEI_ampa[823] = new ampa(0.5)")
        h("Epop[41] netConn_projEI_ampa[823] = new NetCon(&v(0.5), syn_projEI_ampa[823], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 824: cell 41, seg 0 (0.5) [0.5 on Epop[41]] -> cell 4, seg 0 (0.5) [0.5 on Ipop[4]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[4] syn_projEI_ampa[824] = new ampa(0.5)")
        h("Epop[41] netConn_projEI_ampa[824] = new NetCon(&v(0.5), syn_projEI_ampa[824], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 825: cell 41, seg 0 (0.5) [0.5 on Epop[41]] -> cell 5, seg 0 (0.5) [0.5 on Ipop[5]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[5] syn_projEI_ampa[825] = new ampa(0.5)")
        h("Epop[41] netConn_projEI_ampa[825] = new NetCon(&v(0.5), syn_projEI_ampa[825], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 826: cell 41, seg 0 (0.5) [0.5 on Epop[41]] -> cell 6, seg 0 (0.5) [0.5 on Ipop[6]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[6] syn_projEI_ampa[826] = new ampa(0.5)")
        h("Epop[41] netConn_projEI_ampa[826] = new NetCon(&v(0.5), syn_projEI_ampa[826], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 827: cell 41, seg 0 (0.5) [0.5 on Epop[41]] -> cell 7, seg 0 (0.5) [0.5 on Ipop[7]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[7] syn_projEI_ampa[827] = new ampa(0.5)")
        h("Epop[41] netConn_projEI_ampa[827] = new NetCon(&v(0.5), syn_projEI_ampa[827], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 828: cell 41, seg 0 (0.5) [0.5 on Epop[41]] -> cell 8, seg 0 (0.5) [0.5 on Ipop[8]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[8] syn_projEI_ampa[828] = new ampa(0.5)")
        h("Epop[41] netConn_projEI_ampa[828] = new NetCon(&v(0.5), syn_projEI_ampa[828], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 829: cell 41, seg 0 (0.5) [0.5 on Epop[41]] -> cell 9, seg 0 (0.5) [0.5 on Ipop[9]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[9] syn_projEI_ampa[829] = new ampa(0.5)")
        h("Epop[41] netConn_projEI_ampa[829] = new NetCon(&v(0.5), syn_projEI_ampa[829], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 830: cell 41, seg 0 (0.5) [0.5 on Epop[41]] -> cell 10, seg 0 (0.5) [0.5 on Ipop[10]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[10] syn_projEI_ampa[830] = new ampa(0.5)")
        h("Epop[41] netConn_projEI_ampa[830] = new NetCon(&v(0.5), syn_projEI_ampa[830], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 831: cell 41, seg 0 (0.5) [0.5 on Epop[41]] -> cell 11, seg 0 (0.5) [0.5 on Ipop[11]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[11] syn_projEI_ampa[831] = new ampa(0.5)")
        h("Epop[41] netConn_projEI_ampa[831] = new NetCon(&v(0.5), syn_projEI_ampa[831], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 832: cell 41, seg 0 (0.5) [0.5 on Epop[41]] -> cell 12, seg 0 (0.5) [0.5 on Ipop[12]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[12] syn_projEI_ampa[832] = new ampa(0.5)")
        h("Epop[41] netConn_projEI_ampa[832] = new NetCon(&v(0.5), syn_projEI_ampa[832], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 833: cell 41, seg 0 (0.5) [0.5 on Epop[41]] -> cell 13, seg 0 (0.5) [0.5 on Ipop[13]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[13] syn_projEI_ampa[833] = new ampa(0.5)")
        h("Epop[41] netConn_projEI_ampa[833] = new NetCon(&v(0.5), syn_projEI_ampa[833], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 834: cell 41, seg 0 (0.5) [0.5 on Epop[41]] -> cell 14, seg 0 (0.5) [0.5 on Ipop[14]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[14] syn_projEI_ampa[834] = new ampa(0.5)")
        h("Epop[41] netConn_projEI_ampa[834] = new NetCon(&v(0.5), syn_projEI_ampa[834], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 835: cell 41, seg 0 (0.5) [0.5 on Epop[41]] -> cell 15, seg 0 (0.5) [0.5 on Ipop[15]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[15] syn_projEI_ampa[835] = new ampa(0.5)")
        h("Epop[41] netConn_projEI_ampa[835] = new NetCon(&v(0.5), syn_projEI_ampa[835], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 836: cell 41, seg 0 (0.5) [0.5 on Epop[41]] -> cell 16, seg 0 (0.5) [0.5 on Ipop[16]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[16] syn_projEI_ampa[836] = new ampa(0.5)")
        h("Epop[41] netConn_projEI_ampa[836] = new NetCon(&v(0.5), syn_projEI_ampa[836], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 837: cell 41, seg 0 (0.5) [0.5 on Epop[41]] -> cell 17, seg 0 (0.5) [0.5 on Ipop[17]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[17] syn_projEI_ampa[837] = new ampa(0.5)")
        h("Epop[41] netConn_projEI_ampa[837] = new NetCon(&v(0.5), syn_projEI_ampa[837], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 838: cell 41, seg 0 (0.5) [0.5 on Epop[41]] -> cell 18, seg 0 (0.5) [0.5 on Ipop[18]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[18] syn_projEI_ampa[838] = new ampa(0.5)")
        h("Epop[41] netConn_projEI_ampa[838] = new NetCon(&v(0.5), syn_projEI_ampa[838], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 839: cell 41, seg 0 (0.5) [0.5 on Epop[41]] -> cell 19, seg 0 (0.5) [0.5 on Ipop[19]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[19] syn_projEI_ampa[839] = new ampa(0.5)")
        h("Epop[41] netConn_projEI_ampa[839] = new NetCon(&v(0.5), syn_projEI_ampa[839], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 840: cell 42, seg 0 (0.5) [0.5 on Epop[42]] -> cell 0, seg 0 (0.5) [0.5 on Ipop[0]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[0] syn_projEI_ampa[840] = new ampa(0.5)")
        h("Epop[42] netConn_projEI_ampa[840] = new NetCon(&v(0.5), syn_projEI_ampa[840], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 841: cell 42, seg 0 (0.5) [0.5 on Epop[42]] -> cell 1, seg 0 (0.5) [0.5 on Ipop[1]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[1] syn_projEI_ampa[841] = new ampa(0.5)")
        h("Epop[42] netConn_projEI_ampa[841] = new NetCon(&v(0.5), syn_projEI_ampa[841], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 842: cell 42, seg 0 (0.5) [0.5 on Epop[42]] -> cell 2, seg 0 (0.5) [0.5 on Ipop[2]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[2] syn_projEI_ampa[842] = new ampa(0.5)")
        h("Epop[42] netConn_projEI_ampa[842] = new NetCon(&v(0.5), syn_projEI_ampa[842], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 843: cell 42, seg 0 (0.5) [0.5 on Epop[42]] -> cell 3, seg 0 (0.5) [0.5 on Ipop[3]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[3] syn_projEI_ampa[843] = new ampa(0.5)")
        h("Epop[42] netConn_projEI_ampa[843] = new NetCon(&v(0.5), syn_projEI_ampa[843], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 844: cell 42, seg 0 (0.5) [0.5 on Epop[42]] -> cell 4, seg 0 (0.5) [0.5 on Ipop[4]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[4] syn_projEI_ampa[844] = new ampa(0.5)")
        h("Epop[42] netConn_projEI_ampa[844] = new NetCon(&v(0.5), syn_projEI_ampa[844], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 845: cell 42, seg 0 (0.5) [0.5 on Epop[42]] -> cell 5, seg 0 (0.5) [0.5 on Ipop[5]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[5] syn_projEI_ampa[845] = new ampa(0.5)")
        h("Epop[42] netConn_projEI_ampa[845] = new NetCon(&v(0.5), syn_projEI_ampa[845], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 846: cell 42, seg 0 (0.5) [0.5 on Epop[42]] -> cell 6, seg 0 (0.5) [0.5 on Ipop[6]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[6] syn_projEI_ampa[846] = new ampa(0.5)")
        h("Epop[42] netConn_projEI_ampa[846] = new NetCon(&v(0.5), syn_projEI_ampa[846], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 847: cell 42, seg 0 (0.5) [0.5 on Epop[42]] -> cell 7, seg 0 (0.5) [0.5 on Ipop[7]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[7] syn_projEI_ampa[847] = new ampa(0.5)")
        h("Epop[42] netConn_projEI_ampa[847] = new NetCon(&v(0.5), syn_projEI_ampa[847], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 848: cell 42, seg 0 (0.5) [0.5 on Epop[42]] -> cell 8, seg 0 (0.5) [0.5 on Ipop[8]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[8] syn_projEI_ampa[848] = new ampa(0.5)")
        h("Epop[42] netConn_projEI_ampa[848] = new NetCon(&v(0.5), syn_projEI_ampa[848], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 849: cell 42, seg 0 (0.5) [0.5 on Epop[42]] -> cell 9, seg 0 (0.5) [0.5 on Ipop[9]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[9] syn_projEI_ampa[849] = new ampa(0.5)")
        h("Epop[42] netConn_projEI_ampa[849] = new NetCon(&v(0.5), syn_projEI_ampa[849], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 850: cell 42, seg 0 (0.5) [0.5 on Epop[42]] -> cell 10, seg 0 (0.5) [0.5 on Ipop[10]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[10] syn_projEI_ampa[850] = new ampa(0.5)")
        h("Epop[42] netConn_projEI_ampa[850] = new NetCon(&v(0.5), syn_projEI_ampa[850], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 851: cell 42, seg 0 (0.5) [0.5 on Epop[42]] -> cell 11, seg 0 (0.5) [0.5 on Ipop[11]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[11] syn_projEI_ampa[851] = new ampa(0.5)")
        h("Epop[42] netConn_projEI_ampa[851] = new NetCon(&v(0.5), syn_projEI_ampa[851], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 852: cell 42, seg 0 (0.5) [0.5 on Epop[42]] -> cell 12, seg 0 (0.5) [0.5 on Ipop[12]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[12] syn_projEI_ampa[852] = new ampa(0.5)")
        h("Epop[42] netConn_projEI_ampa[852] = new NetCon(&v(0.5), syn_projEI_ampa[852], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 853: cell 42, seg 0 (0.5) [0.5 on Epop[42]] -> cell 13, seg 0 (0.5) [0.5 on Ipop[13]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[13] syn_projEI_ampa[853] = new ampa(0.5)")
        h("Epop[42] netConn_projEI_ampa[853] = new NetCon(&v(0.5), syn_projEI_ampa[853], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 854: cell 42, seg 0 (0.5) [0.5 on Epop[42]] -> cell 14, seg 0 (0.5) [0.5 on Ipop[14]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[14] syn_projEI_ampa[854] = new ampa(0.5)")
        h("Epop[42] netConn_projEI_ampa[854] = new NetCon(&v(0.5), syn_projEI_ampa[854], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 855: cell 42, seg 0 (0.5) [0.5 on Epop[42]] -> cell 15, seg 0 (0.5) [0.5 on Ipop[15]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[15] syn_projEI_ampa[855] = new ampa(0.5)")
        h("Epop[42] netConn_projEI_ampa[855] = new NetCon(&v(0.5), syn_projEI_ampa[855], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 856: cell 42, seg 0 (0.5) [0.5 on Epop[42]] -> cell 16, seg 0 (0.5) [0.5 on Ipop[16]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[16] syn_projEI_ampa[856] = new ampa(0.5)")
        h("Epop[42] netConn_projEI_ampa[856] = new NetCon(&v(0.5), syn_projEI_ampa[856], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 857: cell 42, seg 0 (0.5) [0.5 on Epop[42]] -> cell 17, seg 0 (0.5) [0.5 on Ipop[17]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[17] syn_projEI_ampa[857] = new ampa(0.5)")
        h("Epop[42] netConn_projEI_ampa[857] = new NetCon(&v(0.5), syn_projEI_ampa[857], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 858: cell 42, seg 0 (0.5) [0.5 on Epop[42]] -> cell 18, seg 0 (0.5) [0.5 on Ipop[18]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[18] syn_projEI_ampa[858] = new ampa(0.5)")
        h("Epop[42] netConn_projEI_ampa[858] = new NetCon(&v(0.5), syn_projEI_ampa[858], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 859: cell 42, seg 0 (0.5) [0.5 on Epop[42]] -> cell 19, seg 0 (0.5) [0.5 on Ipop[19]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[19] syn_projEI_ampa[859] = new ampa(0.5)")
        h("Epop[42] netConn_projEI_ampa[859] = new NetCon(&v(0.5), syn_projEI_ampa[859], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 860: cell 43, seg 0 (0.5) [0.5 on Epop[43]] -> cell 0, seg 0 (0.5) [0.5 on Ipop[0]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[0] syn_projEI_ampa[860] = new ampa(0.5)")
        h("Epop[43] netConn_projEI_ampa[860] = new NetCon(&v(0.5), syn_projEI_ampa[860], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 861: cell 43, seg 0 (0.5) [0.5 on Epop[43]] -> cell 1, seg 0 (0.5) [0.5 on Ipop[1]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[1] syn_projEI_ampa[861] = new ampa(0.5)")
        h("Epop[43] netConn_projEI_ampa[861] = new NetCon(&v(0.5), syn_projEI_ampa[861], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 862: cell 43, seg 0 (0.5) [0.5 on Epop[43]] -> cell 2, seg 0 (0.5) [0.5 on Ipop[2]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[2] syn_projEI_ampa[862] = new ampa(0.5)")
        h("Epop[43] netConn_projEI_ampa[862] = new NetCon(&v(0.5), syn_projEI_ampa[862], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 863: cell 43, seg 0 (0.5) [0.5 on Epop[43]] -> cell 3, seg 0 (0.5) [0.5 on Ipop[3]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[3] syn_projEI_ampa[863] = new ampa(0.5)")
        h("Epop[43] netConn_projEI_ampa[863] = new NetCon(&v(0.5), syn_projEI_ampa[863], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 864: cell 43, seg 0 (0.5) [0.5 on Epop[43]] -> cell 4, seg 0 (0.5) [0.5 on Ipop[4]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[4] syn_projEI_ampa[864] = new ampa(0.5)")
        h("Epop[43] netConn_projEI_ampa[864] = new NetCon(&v(0.5), syn_projEI_ampa[864], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 865: cell 43, seg 0 (0.5) [0.5 on Epop[43]] -> cell 5, seg 0 (0.5) [0.5 on Ipop[5]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[5] syn_projEI_ampa[865] = new ampa(0.5)")
        h("Epop[43] netConn_projEI_ampa[865] = new NetCon(&v(0.5), syn_projEI_ampa[865], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 866: cell 43, seg 0 (0.5) [0.5 on Epop[43]] -> cell 6, seg 0 (0.5) [0.5 on Ipop[6]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[6] syn_projEI_ampa[866] = new ampa(0.5)")
        h("Epop[43] netConn_projEI_ampa[866] = new NetCon(&v(0.5), syn_projEI_ampa[866], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 867: cell 43, seg 0 (0.5) [0.5 on Epop[43]] -> cell 7, seg 0 (0.5) [0.5 on Ipop[7]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[7] syn_projEI_ampa[867] = new ampa(0.5)")
        h("Epop[43] netConn_projEI_ampa[867] = new NetCon(&v(0.5), syn_projEI_ampa[867], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 868: cell 43, seg 0 (0.5) [0.5 on Epop[43]] -> cell 8, seg 0 (0.5) [0.5 on Ipop[8]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[8] syn_projEI_ampa[868] = new ampa(0.5)")
        h("Epop[43] netConn_projEI_ampa[868] = new NetCon(&v(0.5), syn_projEI_ampa[868], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 869: cell 43, seg 0 (0.5) [0.5 on Epop[43]] -> cell 9, seg 0 (0.5) [0.5 on Ipop[9]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[9] syn_projEI_ampa[869] = new ampa(0.5)")
        h("Epop[43] netConn_projEI_ampa[869] = new NetCon(&v(0.5), syn_projEI_ampa[869], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 870: cell 43, seg 0 (0.5) [0.5 on Epop[43]] -> cell 10, seg 0 (0.5) [0.5 on Ipop[10]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[10] syn_projEI_ampa[870] = new ampa(0.5)")
        h("Epop[43] netConn_projEI_ampa[870] = new NetCon(&v(0.5), syn_projEI_ampa[870], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 871: cell 43, seg 0 (0.5) [0.5 on Epop[43]] -> cell 11, seg 0 (0.5) [0.5 on Ipop[11]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[11] syn_projEI_ampa[871] = new ampa(0.5)")
        h("Epop[43] netConn_projEI_ampa[871] = new NetCon(&v(0.5), syn_projEI_ampa[871], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 872: cell 43, seg 0 (0.5) [0.5 on Epop[43]] -> cell 12, seg 0 (0.5) [0.5 on Ipop[12]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[12] syn_projEI_ampa[872] = new ampa(0.5)")
        h("Epop[43] netConn_projEI_ampa[872] = new NetCon(&v(0.5), syn_projEI_ampa[872], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 873: cell 43, seg 0 (0.5) [0.5 on Epop[43]] -> cell 13, seg 0 (0.5) [0.5 on Ipop[13]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[13] syn_projEI_ampa[873] = new ampa(0.5)")
        h("Epop[43] netConn_projEI_ampa[873] = new NetCon(&v(0.5), syn_projEI_ampa[873], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 874: cell 43, seg 0 (0.5) [0.5 on Epop[43]] -> cell 14, seg 0 (0.5) [0.5 on Ipop[14]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[14] syn_projEI_ampa[874] = new ampa(0.5)")
        h("Epop[43] netConn_projEI_ampa[874] = new NetCon(&v(0.5), syn_projEI_ampa[874], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 875: cell 43, seg 0 (0.5) [0.5 on Epop[43]] -> cell 15, seg 0 (0.5) [0.5 on Ipop[15]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[15] syn_projEI_ampa[875] = new ampa(0.5)")
        h("Epop[43] netConn_projEI_ampa[875] = new NetCon(&v(0.5), syn_projEI_ampa[875], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 876: cell 43, seg 0 (0.5) [0.5 on Epop[43]] -> cell 16, seg 0 (0.5) [0.5 on Ipop[16]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[16] syn_projEI_ampa[876] = new ampa(0.5)")
        h("Epop[43] netConn_projEI_ampa[876] = new NetCon(&v(0.5), syn_projEI_ampa[876], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 877: cell 43, seg 0 (0.5) [0.5 on Epop[43]] -> cell 17, seg 0 (0.5) [0.5 on Ipop[17]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[17] syn_projEI_ampa[877] = new ampa(0.5)")
        h("Epop[43] netConn_projEI_ampa[877] = new NetCon(&v(0.5), syn_projEI_ampa[877], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 878: cell 43, seg 0 (0.5) [0.5 on Epop[43]] -> cell 18, seg 0 (0.5) [0.5 on Ipop[18]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[18] syn_projEI_ampa[878] = new ampa(0.5)")
        h("Epop[43] netConn_projEI_ampa[878] = new NetCon(&v(0.5), syn_projEI_ampa[878], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 879: cell 43, seg 0 (0.5) [0.5 on Epop[43]] -> cell 19, seg 0 (0.5) [0.5 on Ipop[19]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[19] syn_projEI_ampa[879] = new ampa(0.5)")
        h("Epop[43] netConn_projEI_ampa[879] = new NetCon(&v(0.5), syn_projEI_ampa[879], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 880: cell 44, seg 0 (0.5) [0.5 on Epop[44]] -> cell 0, seg 0 (0.5) [0.5 on Ipop[0]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[0] syn_projEI_ampa[880] = new ampa(0.5)")
        h("Epop[44] netConn_projEI_ampa[880] = new NetCon(&v(0.5), syn_projEI_ampa[880], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 881: cell 44, seg 0 (0.5) [0.5 on Epop[44]] -> cell 1, seg 0 (0.5) [0.5 on Ipop[1]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[1] syn_projEI_ampa[881] = new ampa(0.5)")
        h("Epop[44] netConn_projEI_ampa[881] = new NetCon(&v(0.5), syn_projEI_ampa[881], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 882: cell 44, seg 0 (0.5) [0.5 on Epop[44]] -> cell 2, seg 0 (0.5) [0.5 on Ipop[2]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[2] syn_projEI_ampa[882] = new ampa(0.5)")
        h("Epop[44] netConn_projEI_ampa[882] = new NetCon(&v(0.5), syn_projEI_ampa[882], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 883: cell 44, seg 0 (0.5) [0.5 on Epop[44]] -> cell 3, seg 0 (0.5) [0.5 on Ipop[3]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[3] syn_projEI_ampa[883] = new ampa(0.5)")
        h("Epop[44] netConn_projEI_ampa[883] = new NetCon(&v(0.5), syn_projEI_ampa[883], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 884: cell 44, seg 0 (0.5) [0.5 on Epop[44]] -> cell 4, seg 0 (0.5) [0.5 on Ipop[4]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[4] syn_projEI_ampa[884] = new ampa(0.5)")
        h("Epop[44] netConn_projEI_ampa[884] = new NetCon(&v(0.5), syn_projEI_ampa[884], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 885: cell 44, seg 0 (0.5) [0.5 on Epop[44]] -> cell 5, seg 0 (0.5) [0.5 on Ipop[5]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[5] syn_projEI_ampa[885] = new ampa(0.5)")
        h("Epop[44] netConn_projEI_ampa[885] = new NetCon(&v(0.5), syn_projEI_ampa[885], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 886: cell 44, seg 0 (0.5) [0.5 on Epop[44]] -> cell 6, seg 0 (0.5) [0.5 on Ipop[6]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[6] syn_projEI_ampa[886] = new ampa(0.5)")
        h("Epop[44] netConn_projEI_ampa[886] = new NetCon(&v(0.5), syn_projEI_ampa[886], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 887: cell 44, seg 0 (0.5) [0.5 on Epop[44]] -> cell 7, seg 0 (0.5) [0.5 on Ipop[7]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[7] syn_projEI_ampa[887] = new ampa(0.5)")
        h("Epop[44] netConn_projEI_ampa[887] = new NetCon(&v(0.5), syn_projEI_ampa[887], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 888: cell 44, seg 0 (0.5) [0.5 on Epop[44]] -> cell 8, seg 0 (0.5) [0.5 on Ipop[8]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[8] syn_projEI_ampa[888] = new ampa(0.5)")
        h("Epop[44] netConn_projEI_ampa[888] = new NetCon(&v(0.5), syn_projEI_ampa[888], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 889: cell 44, seg 0 (0.5) [0.5 on Epop[44]] -> cell 9, seg 0 (0.5) [0.5 on Ipop[9]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[9] syn_projEI_ampa[889] = new ampa(0.5)")
        h("Epop[44] netConn_projEI_ampa[889] = new NetCon(&v(0.5), syn_projEI_ampa[889], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 890: cell 44, seg 0 (0.5) [0.5 on Epop[44]] -> cell 10, seg 0 (0.5) [0.5 on Ipop[10]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[10] syn_projEI_ampa[890] = new ampa(0.5)")
        h("Epop[44] netConn_projEI_ampa[890] = new NetCon(&v(0.5), syn_projEI_ampa[890], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 891: cell 44, seg 0 (0.5) [0.5 on Epop[44]] -> cell 11, seg 0 (0.5) [0.5 on Ipop[11]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[11] syn_projEI_ampa[891] = new ampa(0.5)")
        h("Epop[44] netConn_projEI_ampa[891] = new NetCon(&v(0.5), syn_projEI_ampa[891], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 892: cell 44, seg 0 (0.5) [0.5 on Epop[44]] -> cell 12, seg 0 (0.5) [0.5 on Ipop[12]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[12] syn_projEI_ampa[892] = new ampa(0.5)")
        h("Epop[44] netConn_projEI_ampa[892] = new NetCon(&v(0.5), syn_projEI_ampa[892], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 893: cell 44, seg 0 (0.5) [0.5 on Epop[44]] -> cell 13, seg 0 (0.5) [0.5 on Ipop[13]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[13] syn_projEI_ampa[893] = new ampa(0.5)")
        h("Epop[44] netConn_projEI_ampa[893] = new NetCon(&v(0.5), syn_projEI_ampa[893], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 894: cell 44, seg 0 (0.5) [0.5 on Epop[44]] -> cell 14, seg 0 (0.5) [0.5 on Ipop[14]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[14] syn_projEI_ampa[894] = new ampa(0.5)")
        h("Epop[44] netConn_projEI_ampa[894] = new NetCon(&v(0.5), syn_projEI_ampa[894], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 895: cell 44, seg 0 (0.5) [0.5 on Epop[44]] -> cell 15, seg 0 (0.5) [0.5 on Ipop[15]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[15] syn_projEI_ampa[895] = new ampa(0.5)")
        h("Epop[44] netConn_projEI_ampa[895] = new NetCon(&v(0.5), syn_projEI_ampa[895], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 896: cell 44, seg 0 (0.5) [0.5 on Epop[44]] -> cell 16, seg 0 (0.5) [0.5 on Ipop[16]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[16] syn_projEI_ampa[896] = new ampa(0.5)")
        h("Epop[44] netConn_projEI_ampa[896] = new NetCon(&v(0.5), syn_projEI_ampa[896], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 897: cell 44, seg 0 (0.5) [0.5 on Epop[44]] -> cell 17, seg 0 (0.5) [0.5 on Ipop[17]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[17] syn_projEI_ampa[897] = new ampa(0.5)")
        h("Epop[44] netConn_projEI_ampa[897] = new NetCon(&v(0.5), syn_projEI_ampa[897], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 898: cell 44, seg 0 (0.5) [0.5 on Epop[44]] -> cell 18, seg 0 (0.5) [0.5 on Ipop[18]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[18] syn_projEI_ampa[898] = new ampa(0.5)")
        h("Epop[44] netConn_projEI_ampa[898] = new NetCon(&v(0.5), syn_projEI_ampa[898], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 899: cell 44, seg 0 (0.5) [0.5 on Epop[44]] -> cell 19, seg 0 (0.5) [0.5 on Ipop[19]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[19] syn_projEI_ampa[899] = new ampa(0.5)")
        h("Epop[44] netConn_projEI_ampa[899] = new NetCon(&v(0.5), syn_projEI_ampa[899], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 900: cell 45, seg 0 (0.5) [0.5 on Epop[45]] -> cell 0, seg 0 (0.5) [0.5 on Ipop[0]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[0] syn_projEI_ampa[900] = new ampa(0.5)")
        h("Epop[45] netConn_projEI_ampa[900] = new NetCon(&v(0.5), syn_projEI_ampa[900], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 901: cell 45, seg 0 (0.5) [0.5 on Epop[45]] -> cell 1, seg 0 (0.5) [0.5 on Ipop[1]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[1] syn_projEI_ampa[901] = new ampa(0.5)")
        h("Epop[45] netConn_projEI_ampa[901] = new NetCon(&v(0.5), syn_projEI_ampa[901], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 902: cell 45, seg 0 (0.5) [0.5 on Epop[45]] -> cell 2, seg 0 (0.5) [0.5 on Ipop[2]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[2] syn_projEI_ampa[902] = new ampa(0.5)")
        h("Epop[45] netConn_projEI_ampa[902] = new NetCon(&v(0.5), syn_projEI_ampa[902], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 903: cell 45, seg 0 (0.5) [0.5 on Epop[45]] -> cell 3, seg 0 (0.5) [0.5 on Ipop[3]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[3] syn_projEI_ampa[903] = new ampa(0.5)")
        h("Epop[45] netConn_projEI_ampa[903] = new NetCon(&v(0.5), syn_projEI_ampa[903], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 904: cell 45, seg 0 (0.5) [0.5 on Epop[45]] -> cell 4, seg 0 (0.5) [0.5 on Ipop[4]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[4] syn_projEI_ampa[904] = new ampa(0.5)")
        h("Epop[45] netConn_projEI_ampa[904] = new NetCon(&v(0.5), syn_projEI_ampa[904], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 905: cell 45, seg 0 (0.5) [0.5 on Epop[45]] -> cell 5, seg 0 (0.5) [0.5 on Ipop[5]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[5] syn_projEI_ampa[905] = new ampa(0.5)")
        h("Epop[45] netConn_projEI_ampa[905] = new NetCon(&v(0.5), syn_projEI_ampa[905], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 906: cell 45, seg 0 (0.5) [0.5 on Epop[45]] -> cell 6, seg 0 (0.5) [0.5 on Ipop[6]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[6] syn_projEI_ampa[906] = new ampa(0.5)")
        h("Epop[45] netConn_projEI_ampa[906] = new NetCon(&v(0.5), syn_projEI_ampa[906], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 907: cell 45, seg 0 (0.5) [0.5 on Epop[45]] -> cell 7, seg 0 (0.5) [0.5 on Ipop[7]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[7] syn_projEI_ampa[907] = new ampa(0.5)")
        h("Epop[45] netConn_projEI_ampa[907] = new NetCon(&v(0.5), syn_projEI_ampa[907], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 908: cell 45, seg 0 (0.5) [0.5 on Epop[45]] -> cell 8, seg 0 (0.5) [0.5 on Ipop[8]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[8] syn_projEI_ampa[908] = new ampa(0.5)")
        h("Epop[45] netConn_projEI_ampa[908] = new NetCon(&v(0.5), syn_projEI_ampa[908], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 909: cell 45, seg 0 (0.5) [0.5 on Epop[45]] -> cell 9, seg 0 (0.5) [0.5 on Ipop[9]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[9] syn_projEI_ampa[909] = new ampa(0.5)")
        h("Epop[45] netConn_projEI_ampa[909] = new NetCon(&v(0.5), syn_projEI_ampa[909], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 910: cell 45, seg 0 (0.5) [0.5 on Epop[45]] -> cell 10, seg 0 (0.5) [0.5 on Ipop[10]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[10] syn_projEI_ampa[910] = new ampa(0.5)")
        h("Epop[45] netConn_projEI_ampa[910] = new NetCon(&v(0.5), syn_projEI_ampa[910], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 911: cell 45, seg 0 (0.5) [0.5 on Epop[45]] -> cell 11, seg 0 (0.5) [0.5 on Ipop[11]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[11] syn_projEI_ampa[911] = new ampa(0.5)")
        h("Epop[45] netConn_projEI_ampa[911] = new NetCon(&v(0.5), syn_projEI_ampa[911], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 912: cell 45, seg 0 (0.5) [0.5 on Epop[45]] -> cell 12, seg 0 (0.5) [0.5 on Ipop[12]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[12] syn_projEI_ampa[912] = new ampa(0.5)")
        h("Epop[45] netConn_projEI_ampa[912] = new NetCon(&v(0.5), syn_projEI_ampa[912], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 913: cell 45, seg 0 (0.5) [0.5 on Epop[45]] -> cell 13, seg 0 (0.5) [0.5 on Ipop[13]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[13] syn_projEI_ampa[913] = new ampa(0.5)")
        h("Epop[45] netConn_projEI_ampa[913] = new NetCon(&v(0.5), syn_projEI_ampa[913], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 914: cell 45, seg 0 (0.5) [0.5 on Epop[45]] -> cell 14, seg 0 (0.5) [0.5 on Ipop[14]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[14] syn_projEI_ampa[914] = new ampa(0.5)")
        h("Epop[45] netConn_projEI_ampa[914] = new NetCon(&v(0.5), syn_projEI_ampa[914], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 915: cell 45, seg 0 (0.5) [0.5 on Epop[45]] -> cell 15, seg 0 (0.5) [0.5 on Ipop[15]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[15] syn_projEI_ampa[915] = new ampa(0.5)")
        h("Epop[45] netConn_projEI_ampa[915] = new NetCon(&v(0.5), syn_projEI_ampa[915], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 916: cell 45, seg 0 (0.5) [0.5 on Epop[45]] -> cell 16, seg 0 (0.5) [0.5 on Ipop[16]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[16] syn_projEI_ampa[916] = new ampa(0.5)")
        h("Epop[45] netConn_projEI_ampa[916] = new NetCon(&v(0.5), syn_projEI_ampa[916], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 917: cell 45, seg 0 (0.5) [0.5 on Epop[45]] -> cell 17, seg 0 (0.5) [0.5 on Ipop[17]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[17] syn_projEI_ampa[917] = new ampa(0.5)")
        h("Epop[45] netConn_projEI_ampa[917] = new NetCon(&v(0.5), syn_projEI_ampa[917], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 918: cell 45, seg 0 (0.5) [0.5 on Epop[45]] -> cell 18, seg 0 (0.5) [0.5 on Ipop[18]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[18] syn_projEI_ampa[918] = new ampa(0.5)")
        h("Epop[45] netConn_projEI_ampa[918] = new NetCon(&v(0.5), syn_projEI_ampa[918], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 919: cell 45, seg 0 (0.5) [0.5 on Epop[45]] -> cell 19, seg 0 (0.5) [0.5 on Ipop[19]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[19] syn_projEI_ampa[919] = new ampa(0.5)")
        h("Epop[45] netConn_projEI_ampa[919] = new NetCon(&v(0.5), syn_projEI_ampa[919], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 920: cell 46, seg 0 (0.5) [0.5 on Epop[46]] -> cell 0, seg 0 (0.5) [0.5 on Ipop[0]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[0] syn_projEI_ampa[920] = new ampa(0.5)")
        h("Epop[46] netConn_projEI_ampa[920] = new NetCon(&v(0.5), syn_projEI_ampa[920], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 921: cell 46, seg 0 (0.5) [0.5 on Epop[46]] -> cell 1, seg 0 (0.5) [0.5 on Ipop[1]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[1] syn_projEI_ampa[921] = new ampa(0.5)")
        h("Epop[46] netConn_projEI_ampa[921] = new NetCon(&v(0.5), syn_projEI_ampa[921], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 922: cell 46, seg 0 (0.5) [0.5 on Epop[46]] -> cell 2, seg 0 (0.5) [0.5 on Ipop[2]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[2] syn_projEI_ampa[922] = new ampa(0.5)")
        h("Epop[46] netConn_projEI_ampa[922] = new NetCon(&v(0.5), syn_projEI_ampa[922], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 923: cell 46, seg 0 (0.5) [0.5 on Epop[46]] -> cell 3, seg 0 (0.5) [0.5 on Ipop[3]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[3] syn_projEI_ampa[923] = new ampa(0.5)")
        h("Epop[46] netConn_projEI_ampa[923] = new NetCon(&v(0.5), syn_projEI_ampa[923], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 924: cell 46, seg 0 (0.5) [0.5 on Epop[46]] -> cell 4, seg 0 (0.5) [0.5 on Ipop[4]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[4] syn_projEI_ampa[924] = new ampa(0.5)")
        h("Epop[46] netConn_projEI_ampa[924] = new NetCon(&v(0.5), syn_projEI_ampa[924], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 925: cell 46, seg 0 (0.5) [0.5 on Epop[46]] -> cell 5, seg 0 (0.5) [0.5 on Ipop[5]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[5] syn_projEI_ampa[925] = new ampa(0.5)")
        h("Epop[46] netConn_projEI_ampa[925] = new NetCon(&v(0.5), syn_projEI_ampa[925], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 926: cell 46, seg 0 (0.5) [0.5 on Epop[46]] -> cell 6, seg 0 (0.5) [0.5 on Ipop[6]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[6] syn_projEI_ampa[926] = new ampa(0.5)")
        h("Epop[46] netConn_projEI_ampa[926] = new NetCon(&v(0.5), syn_projEI_ampa[926], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 927: cell 46, seg 0 (0.5) [0.5 on Epop[46]] -> cell 7, seg 0 (0.5) [0.5 on Ipop[7]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[7] syn_projEI_ampa[927] = new ampa(0.5)")
        h("Epop[46] netConn_projEI_ampa[927] = new NetCon(&v(0.5), syn_projEI_ampa[927], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 928: cell 46, seg 0 (0.5) [0.5 on Epop[46]] -> cell 8, seg 0 (0.5) [0.5 on Ipop[8]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[8] syn_projEI_ampa[928] = new ampa(0.5)")
        h("Epop[46] netConn_projEI_ampa[928] = new NetCon(&v(0.5), syn_projEI_ampa[928], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 929: cell 46, seg 0 (0.5) [0.5 on Epop[46]] -> cell 9, seg 0 (0.5) [0.5 on Ipop[9]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[9] syn_projEI_ampa[929] = new ampa(0.5)")
        h("Epop[46] netConn_projEI_ampa[929] = new NetCon(&v(0.5), syn_projEI_ampa[929], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 930: cell 46, seg 0 (0.5) [0.5 on Epop[46]] -> cell 10, seg 0 (0.5) [0.5 on Ipop[10]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[10] syn_projEI_ampa[930] = new ampa(0.5)")
        h("Epop[46] netConn_projEI_ampa[930] = new NetCon(&v(0.5), syn_projEI_ampa[930], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 931: cell 46, seg 0 (0.5) [0.5 on Epop[46]] -> cell 11, seg 0 (0.5) [0.5 on Ipop[11]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[11] syn_projEI_ampa[931] = new ampa(0.5)")
        h("Epop[46] netConn_projEI_ampa[931] = new NetCon(&v(0.5), syn_projEI_ampa[931], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 932: cell 46, seg 0 (0.5) [0.5 on Epop[46]] -> cell 12, seg 0 (0.5) [0.5 on Ipop[12]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[12] syn_projEI_ampa[932] = new ampa(0.5)")
        h("Epop[46] netConn_projEI_ampa[932] = new NetCon(&v(0.5), syn_projEI_ampa[932], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 933: cell 46, seg 0 (0.5) [0.5 on Epop[46]] -> cell 13, seg 0 (0.5) [0.5 on Ipop[13]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[13] syn_projEI_ampa[933] = new ampa(0.5)")
        h("Epop[46] netConn_projEI_ampa[933] = new NetCon(&v(0.5), syn_projEI_ampa[933], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 934: cell 46, seg 0 (0.5) [0.5 on Epop[46]] -> cell 14, seg 0 (0.5) [0.5 on Ipop[14]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[14] syn_projEI_ampa[934] = new ampa(0.5)")
        h("Epop[46] netConn_projEI_ampa[934] = new NetCon(&v(0.5), syn_projEI_ampa[934], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 935: cell 46, seg 0 (0.5) [0.5 on Epop[46]] -> cell 15, seg 0 (0.5) [0.5 on Ipop[15]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[15] syn_projEI_ampa[935] = new ampa(0.5)")
        h("Epop[46] netConn_projEI_ampa[935] = new NetCon(&v(0.5), syn_projEI_ampa[935], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 936: cell 46, seg 0 (0.5) [0.5 on Epop[46]] -> cell 16, seg 0 (0.5) [0.5 on Ipop[16]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[16] syn_projEI_ampa[936] = new ampa(0.5)")
        h("Epop[46] netConn_projEI_ampa[936] = new NetCon(&v(0.5), syn_projEI_ampa[936], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 937: cell 46, seg 0 (0.5) [0.5 on Epop[46]] -> cell 17, seg 0 (0.5) [0.5 on Ipop[17]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[17] syn_projEI_ampa[937] = new ampa(0.5)")
        h("Epop[46] netConn_projEI_ampa[937] = new NetCon(&v(0.5), syn_projEI_ampa[937], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 938: cell 46, seg 0 (0.5) [0.5 on Epop[46]] -> cell 18, seg 0 (0.5) [0.5 on Ipop[18]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[18] syn_projEI_ampa[938] = new ampa(0.5)")
        h("Epop[46] netConn_projEI_ampa[938] = new NetCon(&v(0.5), syn_projEI_ampa[938], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 939: cell 46, seg 0 (0.5) [0.5 on Epop[46]] -> cell 19, seg 0 (0.5) [0.5 on Ipop[19]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[19] syn_projEI_ampa[939] = new ampa(0.5)")
        h("Epop[46] netConn_projEI_ampa[939] = new NetCon(&v(0.5), syn_projEI_ampa[939], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 940: cell 47, seg 0 (0.5) [0.5 on Epop[47]] -> cell 0, seg 0 (0.5) [0.5 on Ipop[0]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[0] syn_projEI_ampa[940] = new ampa(0.5)")
        h("Epop[47] netConn_projEI_ampa[940] = new NetCon(&v(0.5), syn_projEI_ampa[940], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 941: cell 47, seg 0 (0.5) [0.5 on Epop[47]] -> cell 1, seg 0 (0.5) [0.5 on Ipop[1]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[1] syn_projEI_ampa[941] = new ampa(0.5)")
        h("Epop[47] netConn_projEI_ampa[941] = new NetCon(&v(0.5), syn_projEI_ampa[941], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 942: cell 47, seg 0 (0.5) [0.5 on Epop[47]] -> cell 2, seg 0 (0.5) [0.5 on Ipop[2]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[2] syn_projEI_ampa[942] = new ampa(0.5)")
        h("Epop[47] netConn_projEI_ampa[942] = new NetCon(&v(0.5), syn_projEI_ampa[942], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 943: cell 47, seg 0 (0.5) [0.5 on Epop[47]] -> cell 3, seg 0 (0.5) [0.5 on Ipop[3]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[3] syn_projEI_ampa[943] = new ampa(0.5)")
        h("Epop[47] netConn_projEI_ampa[943] = new NetCon(&v(0.5), syn_projEI_ampa[943], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 944: cell 47, seg 0 (0.5) [0.5 on Epop[47]] -> cell 4, seg 0 (0.5) [0.5 on Ipop[4]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[4] syn_projEI_ampa[944] = new ampa(0.5)")
        h("Epop[47] netConn_projEI_ampa[944] = new NetCon(&v(0.5), syn_projEI_ampa[944], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 945: cell 47, seg 0 (0.5) [0.5 on Epop[47]] -> cell 5, seg 0 (0.5) [0.5 on Ipop[5]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[5] syn_projEI_ampa[945] = new ampa(0.5)")
        h("Epop[47] netConn_projEI_ampa[945] = new NetCon(&v(0.5), syn_projEI_ampa[945], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 946: cell 47, seg 0 (0.5) [0.5 on Epop[47]] -> cell 6, seg 0 (0.5) [0.5 on Ipop[6]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[6] syn_projEI_ampa[946] = new ampa(0.5)")
        h("Epop[47] netConn_projEI_ampa[946] = new NetCon(&v(0.5), syn_projEI_ampa[946], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 947: cell 47, seg 0 (0.5) [0.5 on Epop[47]] -> cell 7, seg 0 (0.5) [0.5 on Ipop[7]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[7] syn_projEI_ampa[947] = new ampa(0.5)")
        h("Epop[47] netConn_projEI_ampa[947] = new NetCon(&v(0.5), syn_projEI_ampa[947], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 948: cell 47, seg 0 (0.5) [0.5 on Epop[47]] -> cell 8, seg 0 (0.5) [0.5 on Ipop[8]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[8] syn_projEI_ampa[948] = new ampa(0.5)")
        h("Epop[47] netConn_projEI_ampa[948] = new NetCon(&v(0.5), syn_projEI_ampa[948], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 949: cell 47, seg 0 (0.5) [0.5 on Epop[47]] -> cell 9, seg 0 (0.5) [0.5 on Ipop[9]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[9] syn_projEI_ampa[949] = new ampa(0.5)")
        h("Epop[47] netConn_projEI_ampa[949] = new NetCon(&v(0.5), syn_projEI_ampa[949], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 950: cell 47, seg 0 (0.5) [0.5 on Epop[47]] -> cell 10, seg 0 (0.5) [0.5 on Ipop[10]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[10] syn_projEI_ampa[950] = new ampa(0.5)")
        h("Epop[47] netConn_projEI_ampa[950] = new NetCon(&v(0.5), syn_projEI_ampa[950], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 951: cell 47, seg 0 (0.5) [0.5 on Epop[47]] -> cell 11, seg 0 (0.5) [0.5 on Ipop[11]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[11] syn_projEI_ampa[951] = new ampa(0.5)")
        h("Epop[47] netConn_projEI_ampa[951] = new NetCon(&v(0.5), syn_projEI_ampa[951], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 952: cell 47, seg 0 (0.5) [0.5 on Epop[47]] -> cell 12, seg 0 (0.5) [0.5 on Ipop[12]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[12] syn_projEI_ampa[952] = new ampa(0.5)")
        h("Epop[47] netConn_projEI_ampa[952] = new NetCon(&v(0.5), syn_projEI_ampa[952], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 953: cell 47, seg 0 (0.5) [0.5 on Epop[47]] -> cell 13, seg 0 (0.5) [0.5 on Ipop[13]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[13] syn_projEI_ampa[953] = new ampa(0.5)")
        h("Epop[47] netConn_projEI_ampa[953] = new NetCon(&v(0.5), syn_projEI_ampa[953], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 954: cell 47, seg 0 (0.5) [0.5 on Epop[47]] -> cell 14, seg 0 (0.5) [0.5 on Ipop[14]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[14] syn_projEI_ampa[954] = new ampa(0.5)")
        h("Epop[47] netConn_projEI_ampa[954] = new NetCon(&v(0.5), syn_projEI_ampa[954], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 955: cell 47, seg 0 (0.5) [0.5 on Epop[47]] -> cell 15, seg 0 (0.5) [0.5 on Ipop[15]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[15] syn_projEI_ampa[955] = new ampa(0.5)")
        h("Epop[47] netConn_projEI_ampa[955] = new NetCon(&v(0.5), syn_projEI_ampa[955], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 956: cell 47, seg 0 (0.5) [0.5 on Epop[47]] -> cell 16, seg 0 (0.5) [0.5 on Ipop[16]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[16] syn_projEI_ampa[956] = new ampa(0.5)")
        h("Epop[47] netConn_projEI_ampa[956] = new NetCon(&v(0.5), syn_projEI_ampa[956], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 957: cell 47, seg 0 (0.5) [0.5 on Epop[47]] -> cell 17, seg 0 (0.5) [0.5 on Ipop[17]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[17] syn_projEI_ampa[957] = new ampa(0.5)")
        h("Epop[47] netConn_projEI_ampa[957] = new NetCon(&v(0.5), syn_projEI_ampa[957], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 958: cell 47, seg 0 (0.5) [0.5 on Epop[47]] -> cell 18, seg 0 (0.5) [0.5 on Ipop[18]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[18] syn_projEI_ampa[958] = new ampa(0.5)")
        h("Epop[47] netConn_projEI_ampa[958] = new NetCon(&v(0.5), syn_projEI_ampa[958], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 959: cell 47, seg 0 (0.5) [0.5 on Epop[47]] -> cell 19, seg 0 (0.5) [0.5 on Ipop[19]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[19] syn_projEI_ampa[959] = new ampa(0.5)")
        h("Epop[47] netConn_projEI_ampa[959] = new NetCon(&v(0.5), syn_projEI_ampa[959], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 960: cell 48, seg 0 (0.5) [0.5 on Epop[48]] -> cell 0, seg 0 (0.5) [0.5 on Ipop[0]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[0] syn_projEI_ampa[960] = new ampa(0.5)")
        h("Epop[48] netConn_projEI_ampa[960] = new NetCon(&v(0.5), syn_projEI_ampa[960], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 961: cell 48, seg 0 (0.5) [0.5 on Epop[48]] -> cell 1, seg 0 (0.5) [0.5 on Ipop[1]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[1] syn_projEI_ampa[961] = new ampa(0.5)")
        h("Epop[48] netConn_projEI_ampa[961] = new NetCon(&v(0.5), syn_projEI_ampa[961], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 962: cell 48, seg 0 (0.5) [0.5 on Epop[48]] -> cell 2, seg 0 (0.5) [0.5 on Ipop[2]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[2] syn_projEI_ampa[962] = new ampa(0.5)")
        h("Epop[48] netConn_projEI_ampa[962] = new NetCon(&v(0.5), syn_projEI_ampa[962], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 963: cell 48, seg 0 (0.5) [0.5 on Epop[48]] -> cell 3, seg 0 (0.5) [0.5 on Ipop[3]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[3] syn_projEI_ampa[963] = new ampa(0.5)")
        h("Epop[48] netConn_projEI_ampa[963] = new NetCon(&v(0.5), syn_projEI_ampa[963], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 964: cell 48, seg 0 (0.5) [0.5 on Epop[48]] -> cell 4, seg 0 (0.5) [0.5 on Ipop[4]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[4] syn_projEI_ampa[964] = new ampa(0.5)")
        h("Epop[48] netConn_projEI_ampa[964] = new NetCon(&v(0.5), syn_projEI_ampa[964], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 965: cell 48, seg 0 (0.5) [0.5 on Epop[48]] -> cell 5, seg 0 (0.5) [0.5 on Ipop[5]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[5] syn_projEI_ampa[965] = new ampa(0.5)")
        h("Epop[48] netConn_projEI_ampa[965] = new NetCon(&v(0.5), syn_projEI_ampa[965], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 966: cell 48, seg 0 (0.5) [0.5 on Epop[48]] -> cell 6, seg 0 (0.5) [0.5 on Ipop[6]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[6] syn_projEI_ampa[966] = new ampa(0.5)")
        h("Epop[48] netConn_projEI_ampa[966] = new NetCon(&v(0.5), syn_projEI_ampa[966], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 967: cell 48, seg 0 (0.5) [0.5 on Epop[48]] -> cell 7, seg 0 (0.5) [0.5 on Ipop[7]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[7] syn_projEI_ampa[967] = new ampa(0.5)")
        h("Epop[48] netConn_projEI_ampa[967] = new NetCon(&v(0.5), syn_projEI_ampa[967], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 968: cell 48, seg 0 (0.5) [0.5 on Epop[48]] -> cell 8, seg 0 (0.5) [0.5 on Ipop[8]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[8] syn_projEI_ampa[968] = new ampa(0.5)")
        h("Epop[48] netConn_projEI_ampa[968] = new NetCon(&v(0.5), syn_projEI_ampa[968], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 969: cell 48, seg 0 (0.5) [0.5 on Epop[48]] -> cell 9, seg 0 (0.5) [0.5 on Ipop[9]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[9] syn_projEI_ampa[969] = new ampa(0.5)")
        h("Epop[48] netConn_projEI_ampa[969] = new NetCon(&v(0.5), syn_projEI_ampa[969], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 970: cell 48, seg 0 (0.5) [0.5 on Epop[48]] -> cell 10, seg 0 (0.5) [0.5 on Ipop[10]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[10] syn_projEI_ampa[970] = new ampa(0.5)")
        h("Epop[48] netConn_projEI_ampa[970] = new NetCon(&v(0.5), syn_projEI_ampa[970], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 971: cell 48, seg 0 (0.5) [0.5 on Epop[48]] -> cell 11, seg 0 (0.5) [0.5 on Ipop[11]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[11] syn_projEI_ampa[971] = new ampa(0.5)")
        h("Epop[48] netConn_projEI_ampa[971] = new NetCon(&v(0.5), syn_projEI_ampa[971], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 972: cell 48, seg 0 (0.5) [0.5 on Epop[48]] -> cell 12, seg 0 (0.5) [0.5 on Ipop[12]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[12] syn_projEI_ampa[972] = new ampa(0.5)")
        h("Epop[48] netConn_projEI_ampa[972] = new NetCon(&v(0.5), syn_projEI_ampa[972], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 973: cell 48, seg 0 (0.5) [0.5 on Epop[48]] -> cell 13, seg 0 (0.5) [0.5 on Ipop[13]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[13] syn_projEI_ampa[973] = new ampa(0.5)")
        h("Epop[48] netConn_projEI_ampa[973] = new NetCon(&v(0.5), syn_projEI_ampa[973], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 974: cell 48, seg 0 (0.5) [0.5 on Epop[48]] -> cell 14, seg 0 (0.5) [0.5 on Ipop[14]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[14] syn_projEI_ampa[974] = new ampa(0.5)")
        h("Epop[48] netConn_projEI_ampa[974] = new NetCon(&v(0.5), syn_projEI_ampa[974], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 975: cell 48, seg 0 (0.5) [0.5 on Epop[48]] -> cell 15, seg 0 (0.5) [0.5 on Ipop[15]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[15] syn_projEI_ampa[975] = new ampa(0.5)")
        h("Epop[48] netConn_projEI_ampa[975] = new NetCon(&v(0.5), syn_projEI_ampa[975], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 976: cell 48, seg 0 (0.5) [0.5 on Epop[48]] -> cell 16, seg 0 (0.5) [0.5 on Ipop[16]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[16] syn_projEI_ampa[976] = new ampa(0.5)")
        h("Epop[48] netConn_projEI_ampa[976] = new NetCon(&v(0.5), syn_projEI_ampa[976], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 977: cell 48, seg 0 (0.5) [0.5 on Epop[48]] -> cell 17, seg 0 (0.5) [0.5 on Ipop[17]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[17] syn_projEI_ampa[977] = new ampa(0.5)")
        h("Epop[48] netConn_projEI_ampa[977] = new NetCon(&v(0.5), syn_projEI_ampa[977], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 978: cell 48, seg 0 (0.5) [0.5 on Epop[48]] -> cell 18, seg 0 (0.5) [0.5 on Ipop[18]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[18] syn_projEI_ampa[978] = new ampa(0.5)")
        h("Epop[48] netConn_projEI_ampa[978] = new NetCon(&v(0.5), syn_projEI_ampa[978], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 979: cell 48, seg 0 (0.5) [0.5 on Epop[48]] -> cell 19, seg 0 (0.5) [0.5 on Ipop[19]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[19] syn_projEI_ampa[979] = new ampa(0.5)")
        h("Epop[48] netConn_projEI_ampa[979] = new NetCon(&v(0.5), syn_projEI_ampa[979], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 980: cell 49, seg 0 (0.5) [0.5 on Epop[49]] -> cell 0, seg 0 (0.5) [0.5 on Ipop[0]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[0] syn_projEI_ampa[980] = new ampa(0.5)")
        h("Epop[49] netConn_projEI_ampa[980] = new NetCon(&v(0.5), syn_projEI_ampa[980], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 981: cell 49, seg 0 (0.5) [0.5 on Epop[49]] -> cell 1, seg 0 (0.5) [0.5 on Ipop[1]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[1] syn_projEI_ampa[981] = new ampa(0.5)")
        h("Epop[49] netConn_projEI_ampa[981] = new NetCon(&v(0.5), syn_projEI_ampa[981], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 982: cell 49, seg 0 (0.5) [0.5 on Epop[49]] -> cell 2, seg 0 (0.5) [0.5 on Ipop[2]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[2] syn_projEI_ampa[982] = new ampa(0.5)")
        h("Epop[49] netConn_projEI_ampa[982] = new NetCon(&v(0.5), syn_projEI_ampa[982], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 983: cell 49, seg 0 (0.5) [0.5 on Epop[49]] -> cell 3, seg 0 (0.5) [0.5 on Ipop[3]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[3] syn_projEI_ampa[983] = new ampa(0.5)")
        h("Epop[49] netConn_projEI_ampa[983] = new NetCon(&v(0.5), syn_projEI_ampa[983], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 984: cell 49, seg 0 (0.5) [0.5 on Epop[49]] -> cell 4, seg 0 (0.5) [0.5 on Ipop[4]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[4] syn_projEI_ampa[984] = new ampa(0.5)")
        h("Epop[49] netConn_projEI_ampa[984] = new NetCon(&v(0.5), syn_projEI_ampa[984], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 985: cell 49, seg 0 (0.5) [0.5 on Epop[49]] -> cell 5, seg 0 (0.5) [0.5 on Ipop[5]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[5] syn_projEI_ampa[985] = new ampa(0.5)")
        h("Epop[49] netConn_projEI_ampa[985] = new NetCon(&v(0.5), syn_projEI_ampa[985], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 986: cell 49, seg 0 (0.5) [0.5 on Epop[49]] -> cell 6, seg 0 (0.5) [0.5 on Ipop[6]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[6] syn_projEI_ampa[986] = new ampa(0.5)")
        h("Epop[49] netConn_projEI_ampa[986] = new NetCon(&v(0.5), syn_projEI_ampa[986], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 987: cell 49, seg 0 (0.5) [0.5 on Epop[49]] -> cell 7, seg 0 (0.5) [0.5 on Ipop[7]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[7] syn_projEI_ampa[987] = new ampa(0.5)")
        h("Epop[49] netConn_projEI_ampa[987] = new NetCon(&v(0.5), syn_projEI_ampa[987], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 988: cell 49, seg 0 (0.5) [0.5 on Epop[49]] -> cell 8, seg 0 (0.5) [0.5 on Ipop[8]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[8] syn_projEI_ampa[988] = new ampa(0.5)")
        h("Epop[49] netConn_projEI_ampa[988] = new NetCon(&v(0.5), syn_projEI_ampa[988], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 989: cell 49, seg 0 (0.5) [0.5 on Epop[49]] -> cell 9, seg 0 (0.5) [0.5 on Ipop[9]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[9] syn_projEI_ampa[989] = new ampa(0.5)")
        h("Epop[49] netConn_projEI_ampa[989] = new NetCon(&v(0.5), syn_projEI_ampa[989], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 990: cell 49, seg 0 (0.5) [0.5 on Epop[49]] -> cell 10, seg 0 (0.5) [0.5 on Ipop[10]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[10] syn_projEI_ampa[990] = new ampa(0.5)")
        h("Epop[49] netConn_projEI_ampa[990] = new NetCon(&v(0.5), syn_projEI_ampa[990], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 991: cell 49, seg 0 (0.5) [0.5 on Epop[49]] -> cell 11, seg 0 (0.5) [0.5 on Ipop[11]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[11] syn_projEI_ampa[991] = new ampa(0.5)")
        h("Epop[49] netConn_projEI_ampa[991] = new NetCon(&v(0.5), syn_projEI_ampa[991], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 992: cell 49, seg 0 (0.5) [0.5 on Epop[49]] -> cell 12, seg 0 (0.5) [0.5 on Ipop[12]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[12] syn_projEI_ampa[992] = new ampa(0.5)")
        h("Epop[49] netConn_projEI_ampa[992] = new NetCon(&v(0.5), syn_projEI_ampa[992], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 993: cell 49, seg 0 (0.5) [0.5 on Epop[49]] -> cell 13, seg 0 (0.5) [0.5 on Ipop[13]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[13] syn_projEI_ampa[993] = new ampa(0.5)")
        h("Epop[49] netConn_projEI_ampa[993] = new NetCon(&v(0.5), syn_projEI_ampa[993], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 994: cell 49, seg 0 (0.5) [0.5 on Epop[49]] -> cell 14, seg 0 (0.5) [0.5 on Ipop[14]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[14] syn_projEI_ampa[994] = new ampa(0.5)")
        h("Epop[49] netConn_projEI_ampa[994] = new NetCon(&v(0.5), syn_projEI_ampa[994], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 995: cell 49, seg 0 (0.5) [0.5 on Epop[49]] -> cell 15, seg 0 (0.5) [0.5 on Ipop[15]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[15] syn_projEI_ampa[995] = new ampa(0.5)")
        h("Epop[49] netConn_projEI_ampa[995] = new NetCon(&v(0.5), syn_projEI_ampa[995], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 996: cell 49, seg 0 (0.5) [0.5 on Epop[49]] -> cell 16, seg 0 (0.5) [0.5 on Ipop[16]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[16] syn_projEI_ampa[996] = new ampa(0.5)")
        h("Epop[49] netConn_projEI_ampa[996] = new NetCon(&v(0.5), syn_projEI_ampa[996], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 997: cell 49, seg 0 (0.5) [0.5 on Epop[49]] -> cell 17, seg 0 (0.5) [0.5 on Ipop[17]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[17] syn_projEI_ampa[997] = new ampa(0.5)")
        h("Epop[49] netConn_projEI_ampa[997] = new NetCon(&v(0.5), syn_projEI_ampa[997], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 998: cell 49, seg 0 (0.5) [0.5 on Epop[49]] -> cell 18, seg 0 (0.5) [0.5 on Ipop[18]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[18] syn_projEI_ampa[998] = new ampa(0.5)")
        h("Epop[49] netConn_projEI_ampa[998] = new NetCon(&v(0.5), syn_projEI_ampa[998], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 999: cell 49, seg 0 (0.5) [0.5 on Epop[49]] -> cell 19, seg 0 (0.5) [0.5 on Ipop[19]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[19] syn_projEI_ampa[999] = new ampa(0.5)")
        h("Epop[49] netConn_projEI_ampa[999] = new NetCon(&v(0.5), syn_projEI_ampa[999], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1000: cell 50, seg 0 (0.5) [0.5 on Epop[50]] -> cell 0, seg 0 (0.5) [0.5 on Ipop[0]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[0] syn_projEI_ampa[1000] = new ampa(0.5)")
        h("Epop[50] netConn_projEI_ampa[1000] = new NetCon(&v(0.5), syn_projEI_ampa[1000], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1001: cell 50, seg 0 (0.5) [0.5 on Epop[50]] -> cell 1, seg 0 (0.5) [0.5 on Ipop[1]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[1] syn_projEI_ampa[1001] = new ampa(0.5)")
        h("Epop[50] netConn_projEI_ampa[1001] = new NetCon(&v(0.5), syn_projEI_ampa[1001], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1002: cell 50, seg 0 (0.5) [0.5 on Epop[50]] -> cell 2, seg 0 (0.5) [0.5 on Ipop[2]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[2] syn_projEI_ampa[1002] = new ampa(0.5)")
        h("Epop[50] netConn_projEI_ampa[1002] = new NetCon(&v(0.5), syn_projEI_ampa[1002], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1003: cell 50, seg 0 (0.5) [0.5 on Epop[50]] -> cell 3, seg 0 (0.5) [0.5 on Ipop[3]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[3] syn_projEI_ampa[1003] = new ampa(0.5)")
        h("Epop[50] netConn_projEI_ampa[1003] = new NetCon(&v(0.5), syn_projEI_ampa[1003], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1004: cell 50, seg 0 (0.5) [0.5 on Epop[50]] -> cell 4, seg 0 (0.5) [0.5 on Ipop[4]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[4] syn_projEI_ampa[1004] = new ampa(0.5)")
        h("Epop[50] netConn_projEI_ampa[1004] = new NetCon(&v(0.5), syn_projEI_ampa[1004], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1005: cell 50, seg 0 (0.5) [0.5 on Epop[50]] -> cell 5, seg 0 (0.5) [0.5 on Ipop[5]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[5] syn_projEI_ampa[1005] = new ampa(0.5)")
        h("Epop[50] netConn_projEI_ampa[1005] = new NetCon(&v(0.5), syn_projEI_ampa[1005], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1006: cell 50, seg 0 (0.5) [0.5 on Epop[50]] -> cell 6, seg 0 (0.5) [0.5 on Ipop[6]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[6] syn_projEI_ampa[1006] = new ampa(0.5)")
        h("Epop[50] netConn_projEI_ampa[1006] = new NetCon(&v(0.5), syn_projEI_ampa[1006], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1007: cell 50, seg 0 (0.5) [0.5 on Epop[50]] -> cell 7, seg 0 (0.5) [0.5 on Ipop[7]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[7] syn_projEI_ampa[1007] = new ampa(0.5)")
        h("Epop[50] netConn_projEI_ampa[1007] = new NetCon(&v(0.5), syn_projEI_ampa[1007], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1008: cell 50, seg 0 (0.5) [0.5 on Epop[50]] -> cell 8, seg 0 (0.5) [0.5 on Ipop[8]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[8] syn_projEI_ampa[1008] = new ampa(0.5)")
        h("Epop[50] netConn_projEI_ampa[1008] = new NetCon(&v(0.5), syn_projEI_ampa[1008], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1009: cell 50, seg 0 (0.5) [0.5 on Epop[50]] -> cell 9, seg 0 (0.5) [0.5 on Ipop[9]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[9] syn_projEI_ampa[1009] = new ampa(0.5)")
        h("Epop[50] netConn_projEI_ampa[1009] = new NetCon(&v(0.5), syn_projEI_ampa[1009], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1010: cell 50, seg 0 (0.5) [0.5 on Epop[50]] -> cell 10, seg 0 (0.5) [0.5 on Ipop[10]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[10] syn_projEI_ampa[1010] = new ampa(0.5)")
        h("Epop[50] netConn_projEI_ampa[1010] = new NetCon(&v(0.5), syn_projEI_ampa[1010], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1011: cell 50, seg 0 (0.5) [0.5 on Epop[50]] -> cell 11, seg 0 (0.5) [0.5 on Ipop[11]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[11] syn_projEI_ampa[1011] = new ampa(0.5)")
        h("Epop[50] netConn_projEI_ampa[1011] = new NetCon(&v(0.5), syn_projEI_ampa[1011], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1012: cell 50, seg 0 (0.5) [0.5 on Epop[50]] -> cell 12, seg 0 (0.5) [0.5 on Ipop[12]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[12] syn_projEI_ampa[1012] = new ampa(0.5)")
        h("Epop[50] netConn_projEI_ampa[1012] = new NetCon(&v(0.5), syn_projEI_ampa[1012], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1013: cell 50, seg 0 (0.5) [0.5 on Epop[50]] -> cell 13, seg 0 (0.5) [0.5 on Ipop[13]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[13] syn_projEI_ampa[1013] = new ampa(0.5)")
        h("Epop[50] netConn_projEI_ampa[1013] = new NetCon(&v(0.5), syn_projEI_ampa[1013], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1014: cell 50, seg 0 (0.5) [0.5 on Epop[50]] -> cell 14, seg 0 (0.5) [0.5 on Ipop[14]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[14] syn_projEI_ampa[1014] = new ampa(0.5)")
        h("Epop[50] netConn_projEI_ampa[1014] = new NetCon(&v(0.5), syn_projEI_ampa[1014], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1015: cell 50, seg 0 (0.5) [0.5 on Epop[50]] -> cell 15, seg 0 (0.5) [0.5 on Ipop[15]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[15] syn_projEI_ampa[1015] = new ampa(0.5)")
        h("Epop[50] netConn_projEI_ampa[1015] = new NetCon(&v(0.5), syn_projEI_ampa[1015], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1016: cell 50, seg 0 (0.5) [0.5 on Epop[50]] -> cell 16, seg 0 (0.5) [0.5 on Ipop[16]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[16] syn_projEI_ampa[1016] = new ampa(0.5)")
        h("Epop[50] netConn_projEI_ampa[1016] = new NetCon(&v(0.5), syn_projEI_ampa[1016], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1017: cell 50, seg 0 (0.5) [0.5 on Epop[50]] -> cell 17, seg 0 (0.5) [0.5 on Ipop[17]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[17] syn_projEI_ampa[1017] = new ampa(0.5)")
        h("Epop[50] netConn_projEI_ampa[1017] = new NetCon(&v(0.5), syn_projEI_ampa[1017], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1018: cell 50, seg 0 (0.5) [0.5 on Epop[50]] -> cell 18, seg 0 (0.5) [0.5 on Ipop[18]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[18] syn_projEI_ampa[1018] = new ampa(0.5)")
        h("Epop[50] netConn_projEI_ampa[1018] = new NetCon(&v(0.5), syn_projEI_ampa[1018], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1019: cell 50, seg 0 (0.5) [0.5 on Epop[50]] -> cell 19, seg 0 (0.5) [0.5 on Ipop[19]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[19] syn_projEI_ampa[1019] = new ampa(0.5)")
        h("Epop[50] netConn_projEI_ampa[1019] = new NetCon(&v(0.5), syn_projEI_ampa[1019], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1020: cell 51, seg 0 (0.5) [0.5 on Epop[51]] -> cell 0, seg 0 (0.5) [0.5 on Ipop[0]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[0] syn_projEI_ampa[1020] = new ampa(0.5)")
        h("Epop[51] netConn_projEI_ampa[1020] = new NetCon(&v(0.5), syn_projEI_ampa[1020], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1021: cell 51, seg 0 (0.5) [0.5 on Epop[51]] -> cell 1, seg 0 (0.5) [0.5 on Ipop[1]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[1] syn_projEI_ampa[1021] = new ampa(0.5)")
        h("Epop[51] netConn_projEI_ampa[1021] = new NetCon(&v(0.5), syn_projEI_ampa[1021], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1022: cell 51, seg 0 (0.5) [0.5 on Epop[51]] -> cell 2, seg 0 (0.5) [0.5 on Ipop[2]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[2] syn_projEI_ampa[1022] = new ampa(0.5)")
        h("Epop[51] netConn_projEI_ampa[1022] = new NetCon(&v(0.5), syn_projEI_ampa[1022], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1023: cell 51, seg 0 (0.5) [0.5 on Epop[51]] -> cell 3, seg 0 (0.5) [0.5 on Ipop[3]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[3] syn_projEI_ampa[1023] = new ampa(0.5)")
        h("Epop[51] netConn_projEI_ampa[1023] = new NetCon(&v(0.5), syn_projEI_ampa[1023], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1024: cell 51, seg 0 (0.5) [0.5 on Epop[51]] -> cell 4, seg 0 (0.5) [0.5 on Ipop[4]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[4] syn_projEI_ampa[1024] = new ampa(0.5)")
        h("Epop[51] netConn_projEI_ampa[1024] = new NetCon(&v(0.5), syn_projEI_ampa[1024], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1025: cell 51, seg 0 (0.5) [0.5 on Epop[51]] -> cell 5, seg 0 (0.5) [0.5 on Ipop[5]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[5] syn_projEI_ampa[1025] = new ampa(0.5)")
        h("Epop[51] netConn_projEI_ampa[1025] = new NetCon(&v(0.5), syn_projEI_ampa[1025], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1026: cell 51, seg 0 (0.5) [0.5 on Epop[51]] -> cell 6, seg 0 (0.5) [0.5 on Ipop[6]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[6] syn_projEI_ampa[1026] = new ampa(0.5)")
        h("Epop[51] netConn_projEI_ampa[1026] = new NetCon(&v(0.5), syn_projEI_ampa[1026], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1027: cell 51, seg 0 (0.5) [0.5 on Epop[51]] -> cell 7, seg 0 (0.5) [0.5 on Ipop[7]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[7] syn_projEI_ampa[1027] = new ampa(0.5)")
        h("Epop[51] netConn_projEI_ampa[1027] = new NetCon(&v(0.5), syn_projEI_ampa[1027], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1028: cell 51, seg 0 (0.5) [0.5 on Epop[51]] -> cell 8, seg 0 (0.5) [0.5 on Ipop[8]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[8] syn_projEI_ampa[1028] = new ampa(0.5)")
        h("Epop[51] netConn_projEI_ampa[1028] = new NetCon(&v(0.5), syn_projEI_ampa[1028], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1029: cell 51, seg 0 (0.5) [0.5 on Epop[51]] -> cell 9, seg 0 (0.5) [0.5 on Ipop[9]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[9] syn_projEI_ampa[1029] = new ampa(0.5)")
        h("Epop[51] netConn_projEI_ampa[1029] = new NetCon(&v(0.5), syn_projEI_ampa[1029], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1030: cell 51, seg 0 (0.5) [0.5 on Epop[51]] -> cell 10, seg 0 (0.5) [0.5 on Ipop[10]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[10] syn_projEI_ampa[1030] = new ampa(0.5)")
        h("Epop[51] netConn_projEI_ampa[1030] = new NetCon(&v(0.5), syn_projEI_ampa[1030], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1031: cell 51, seg 0 (0.5) [0.5 on Epop[51]] -> cell 11, seg 0 (0.5) [0.5 on Ipop[11]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[11] syn_projEI_ampa[1031] = new ampa(0.5)")
        h("Epop[51] netConn_projEI_ampa[1031] = new NetCon(&v(0.5), syn_projEI_ampa[1031], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1032: cell 51, seg 0 (0.5) [0.5 on Epop[51]] -> cell 12, seg 0 (0.5) [0.5 on Ipop[12]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[12] syn_projEI_ampa[1032] = new ampa(0.5)")
        h("Epop[51] netConn_projEI_ampa[1032] = new NetCon(&v(0.5), syn_projEI_ampa[1032], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1033: cell 51, seg 0 (0.5) [0.5 on Epop[51]] -> cell 13, seg 0 (0.5) [0.5 on Ipop[13]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[13] syn_projEI_ampa[1033] = new ampa(0.5)")
        h("Epop[51] netConn_projEI_ampa[1033] = new NetCon(&v(0.5), syn_projEI_ampa[1033], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1034: cell 51, seg 0 (0.5) [0.5 on Epop[51]] -> cell 14, seg 0 (0.5) [0.5 on Ipop[14]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[14] syn_projEI_ampa[1034] = new ampa(0.5)")
        h("Epop[51] netConn_projEI_ampa[1034] = new NetCon(&v(0.5), syn_projEI_ampa[1034], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1035: cell 51, seg 0 (0.5) [0.5 on Epop[51]] -> cell 15, seg 0 (0.5) [0.5 on Ipop[15]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[15] syn_projEI_ampa[1035] = new ampa(0.5)")
        h("Epop[51] netConn_projEI_ampa[1035] = new NetCon(&v(0.5), syn_projEI_ampa[1035], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1036: cell 51, seg 0 (0.5) [0.5 on Epop[51]] -> cell 16, seg 0 (0.5) [0.5 on Ipop[16]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[16] syn_projEI_ampa[1036] = new ampa(0.5)")
        h("Epop[51] netConn_projEI_ampa[1036] = new NetCon(&v(0.5), syn_projEI_ampa[1036], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1037: cell 51, seg 0 (0.5) [0.5 on Epop[51]] -> cell 17, seg 0 (0.5) [0.5 on Ipop[17]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[17] syn_projEI_ampa[1037] = new ampa(0.5)")
        h("Epop[51] netConn_projEI_ampa[1037] = new NetCon(&v(0.5), syn_projEI_ampa[1037], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1038: cell 51, seg 0 (0.5) [0.5 on Epop[51]] -> cell 18, seg 0 (0.5) [0.5 on Ipop[18]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[18] syn_projEI_ampa[1038] = new ampa(0.5)")
        h("Epop[51] netConn_projEI_ampa[1038] = new NetCon(&v(0.5), syn_projEI_ampa[1038], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1039: cell 51, seg 0 (0.5) [0.5 on Epop[51]] -> cell 19, seg 0 (0.5) [0.5 on Ipop[19]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[19] syn_projEI_ampa[1039] = new ampa(0.5)")
        h("Epop[51] netConn_projEI_ampa[1039] = new NetCon(&v(0.5), syn_projEI_ampa[1039], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1040: cell 52, seg 0 (0.5) [0.5 on Epop[52]] -> cell 0, seg 0 (0.5) [0.5 on Ipop[0]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[0] syn_projEI_ampa[1040] = new ampa(0.5)")
        h("Epop[52] netConn_projEI_ampa[1040] = new NetCon(&v(0.5), syn_projEI_ampa[1040], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1041: cell 52, seg 0 (0.5) [0.5 on Epop[52]] -> cell 1, seg 0 (0.5) [0.5 on Ipop[1]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[1] syn_projEI_ampa[1041] = new ampa(0.5)")
        h("Epop[52] netConn_projEI_ampa[1041] = new NetCon(&v(0.5), syn_projEI_ampa[1041], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1042: cell 52, seg 0 (0.5) [0.5 on Epop[52]] -> cell 2, seg 0 (0.5) [0.5 on Ipop[2]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[2] syn_projEI_ampa[1042] = new ampa(0.5)")
        h("Epop[52] netConn_projEI_ampa[1042] = new NetCon(&v(0.5), syn_projEI_ampa[1042], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1043: cell 52, seg 0 (0.5) [0.5 on Epop[52]] -> cell 3, seg 0 (0.5) [0.5 on Ipop[3]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[3] syn_projEI_ampa[1043] = new ampa(0.5)")
        h("Epop[52] netConn_projEI_ampa[1043] = new NetCon(&v(0.5), syn_projEI_ampa[1043], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1044: cell 52, seg 0 (0.5) [0.5 on Epop[52]] -> cell 4, seg 0 (0.5) [0.5 on Ipop[4]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[4] syn_projEI_ampa[1044] = new ampa(0.5)")
        h("Epop[52] netConn_projEI_ampa[1044] = new NetCon(&v(0.5), syn_projEI_ampa[1044], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1045: cell 52, seg 0 (0.5) [0.5 on Epop[52]] -> cell 5, seg 0 (0.5) [0.5 on Ipop[5]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[5] syn_projEI_ampa[1045] = new ampa(0.5)")
        h("Epop[52] netConn_projEI_ampa[1045] = new NetCon(&v(0.5), syn_projEI_ampa[1045], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1046: cell 52, seg 0 (0.5) [0.5 on Epop[52]] -> cell 6, seg 0 (0.5) [0.5 on Ipop[6]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[6] syn_projEI_ampa[1046] = new ampa(0.5)")
        h("Epop[52] netConn_projEI_ampa[1046] = new NetCon(&v(0.5), syn_projEI_ampa[1046], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1047: cell 52, seg 0 (0.5) [0.5 on Epop[52]] -> cell 7, seg 0 (0.5) [0.5 on Ipop[7]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[7] syn_projEI_ampa[1047] = new ampa(0.5)")
        h("Epop[52] netConn_projEI_ampa[1047] = new NetCon(&v(0.5), syn_projEI_ampa[1047], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1048: cell 52, seg 0 (0.5) [0.5 on Epop[52]] -> cell 8, seg 0 (0.5) [0.5 on Ipop[8]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[8] syn_projEI_ampa[1048] = new ampa(0.5)")
        h("Epop[52] netConn_projEI_ampa[1048] = new NetCon(&v(0.5), syn_projEI_ampa[1048], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1049: cell 52, seg 0 (0.5) [0.5 on Epop[52]] -> cell 9, seg 0 (0.5) [0.5 on Ipop[9]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[9] syn_projEI_ampa[1049] = new ampa(0.5)")
        h("Epop[52] netConn_projEI_ampa[1049] = new NetCon(&v(0.5), syn_projEI_ampa[1049], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1050: cell 52, seg 0 (0.5) [0.5 on Epop[52]] -> cell 10, seg 0 (0.5) [0.5 on Ipop[10]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[10] syn_projEI_ampa[1050] = new ampa(0.5)")
        h("Epop[52] netConn_projEI_ampa[1050] = new NetCon(&v(0.5), syn_projEI_ampa[1050], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1051: cell 52, seg 0 (0.5) [0.5 on Epop[52]] -> cell 11, seg 0 (0.5) [0.5 on Ipop[11]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[11] syn_projEI_ampa[1051] = new ampa(0.5)")
        h("Epop[52] netConn_projEI_ampa[1051] = new NetCon(&v(0.5), syn_projEI_ampa[1051], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1052: cell 52, seg 0 (0.5) [0.5 on Epop[52]] -> cell 12, seg 0 (0.5) [0.5 on Ipop[12]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[12] syn_projEI_ampa[1052] = new ampa(0.5)")
        h("Epop[52] netConn_projEI_ampa[1052] = new NetCon(&v(0.5), syn_projEI_ampa[1052], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1053: cell 52, seg 0 (0.5) [0.5 on Epop[52]] -> cell 13, seg 0 (0.5) [0.5 on Ipop[13]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[13] syn_projEI_ampa[1053] = new ampa(0.5)")
        h("Epop[52] netConn_projEI_ampa[1053] = new NetCon(&v(0.5), syn_projEI_ampa[1053], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1054: cell 52, seg 0 (0.5) [0.5 on Epop[52]] -> cell 14, seg 0 (0.5) [0.5 on Ipop[14]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[14] syn_projEI_ampa[1054] = new ampa(0.5)")
        h("Epop[52] netConn_projEI_ampa[1054] = new NetCon(&v(0.5), syn_projEI_ampa[1054], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1055: cell 52, seg 0 (0.5) [0.5 on Epop[52]] -> cell 15, seg 0 (0.5) [0.5 on Ipop[15]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[15] syn_projEI_ampa[1055] = new ampa(0.5)")
        h("Epop[52] netConn_projEI_ampa[1055] = new NetCon(&v(0.5), syn_projEI_ampa[1055], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1056: cell 52, seg 0 (0.5) [0.5 on Epop[52]] -> cell 16, seg 0 (0.5) [0.5 on Ipop[16]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[16] syn_projEI_ampa[1056] = new ampa(0.5)")
        h("Epop[52] netConn_projEI_ampa[1056] = new NetCon(&v(0.5), syn_projEI_ampa[1056], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1057: cell 52, seg 0 (0.5) [0.5 on Epop[52]] -> cell 17, seg 0 (0.5) [0.5 on Ipop[17]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[17] syn_projEI_ampa[1057] = new ampa(0.5)")
        h("Epop[52] netConn_projEI_ampa[1057] = new NetCon(&v(0.5), syn_projEI_ampa[1057], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1058: cell 52, seg 0 (0.5) [0.5 on Epop[52]] -> cell 18, seg 0 (0.5) [0.5 on Ipop[18]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[18] syn_projEI_ampa[1058] = new ampa(0.5)")
        h("Epop[52] netConn_projEI_ampa[1058] = new NetCon(&v(0.5), syn_projEI_ampa[1058], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1059: cell 52, seg 0 (0.5) [0.5 on Epop[52]] -> cell 19, seg 0 (0.5) [0.5 on Ipop[19]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[19] syn_projEI_ampa[1059] = new ampa(0.5)")
        h("Epop[52] netConn_projEI_ampa[1059] = new NetCon(&v(0.5), syn_projEI_ampa[1059], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1060: cell 53, seg 0 (0.5) [0.5 on Epop[53]] -> cell 0, seg 0 (0.5) [0.5 on Ipop[0]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[0] syn_projEI_ampa[1060] = new ampa(0.5)")
        h("Epop[53] netConn_projEI_ampa[1060] = new NetCon(&v(0.5), syn_projEI_ampa[1060], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1061: cell 53, seg 0 (0.5) [0.5 on Epop[53]] -> cell 1, seg 0 (0.5) [0.5 on Ipop[1]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[1] syn_projEI_ampa[1061] = new ampa(0.5)")
        h("Epop[53] netConn_projEI_ampa[1061] = new NetCon(&v(0.5), syn_projEI_ampa[1061], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1062: cell 53, seg 0 (0.5) [0.5 on Epop[53]] -> cell 2, seg 0 (0.5) [0.5 on Ipop[2]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[2] syn_projEI_ampa[1062] = new ampa(0.5)")
        h("Epop[53] netConn_projEI_ampa[1062] = new NetCon(&v(0.5), syn_projEI_ampa[1062], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1063: cell 53, seg 0 (0.5) [0.5 on Epop[53]] -> cell 3, seg 0 (0.5) [0.5 on Ipop[3]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[3] syn_projEI_ampa[1063] = new ampa(0.5)")
        h("Epop[53] netConn_projEI_ampa[1063] = new NetCon(&v(0.5), syn_projEI_ampa[1063], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1064: cell 53, seg 0 (0.5) [0.5 on Epop[53]] -> cell 4, seg 0 (0.5) [0.5 on Ipop[4]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[4] syn_projEI_ampa[1064] = new ampa(0.5)")
        h("Epop[53] netConn_projEI_ampa[1064] = new NetCon(&v(0.5), syn_projEI_ampa[1064], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1065: cell 53, seg 0 (0.5) [0.5 on Epop[53]] -> cell 5, seg 0 (0.5) [0.5 on Ipop[5]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[5] syn_projEI_ampa[1065] = new ampa(0.5)")
        h("Epop[53] netConn_projEI_ampa[1065] = new NetCon(&v(0.5), syn_projEI_ampa[1065], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1066: cell 53, seg 0 (0.5) [0.5 on Epop[53]] -> cell 6, seg 0 (0.5) [0.5 on Ipop[6]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[6] syn_projEI_ampa[1066] = new ampa(0.5)")
        h("Epop[53] netConn_projEI_ampa[1066] = new NetCon(&v(0.5), syn_projEI_ampa[1066], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1067: cell 53, seg 0 (0.5) [0.5 on Epop[53]] -> cell 7, seg 0 (0.5) [0.5 on Ipop[7]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[7] syn_projEI_ampa[1067] = new ampa(0.5)")
        h("Epop[53] netConn_projEI_ampa[1067] = new NetCon(&v(0.5), syn_projEI_ampa[1067], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1068: cell 53, seg 0 (0.5) [0.5 on Epop[53]] -> cell 8, seg 0 (0.5) [0.5 on Ipop[8]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[8] syn_projEI_ampa[1068] = new ampa(0.5)")
        h("Epop[53] netConn_projEI_ampa[1068] = new NetCon(&v(0.5), syn_projEI_ampa[1068], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1069: cell 53, seg 0 (0.5) [0.5 on Epop[53]] -> cell 9, seg 0 (0.5) [0.5 on Ipop[9]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[9] syn_projEI_ampa[1069] = new ampa(0.5)")
        h("Epop[53] netConn_projEI_ampa[1069] = new NetCon(&v(0.5), syn_projEI_ampa[1069], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1070: cell 53, seg 0 (0.5) [0.5 on Epop[53]] -> cell 10, seg 0 (0.5) [0.5 on Ipop[10]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[10] syn_projEI_ampa[1070] = new ampa(0.5)")
        h("Epop[53] netConn_projEI_ampa[1070] = new NetCon(&v(0.5), syn_projEI_ampa[1070], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1071: cell 53, seg 0 (0.5) [0.5 on Epop[53]] -> cell 11, seg 0 (0.5) [0.5 on Ipop[11]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[11] syn_projEI_ampa[1071] = new ampa(0.5)")
        h("Epop[53] netConn_projEI_ampa[1071] = new NetCon(&v(0.5), syn_projEI_ampa[1071], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1072: cell 53, seg 0 (0.5) [0.5 on Epop[53]] -> cell 12, seg 0 (0.5) [0.5 on Ipop[12]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[12] syn_projEI_ampa[1072] = new ampa(0.5)")
        h("Epop[53] netConn_projEI_ampa[1072] = new NetCon(&v(0.5), syn_projEI_ampa[1072], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1073: cell 53, seg 0 (0.5) [0.5 on Epop[53]] -> cell 13, seg 0 (0.5) [0.5 on Ipop[13]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[13] syn_projEI_ampa[1073] = new ampa(0.5)")
        h("Epop[53] netConn_projEI_ampa[1073] = new NetCon(&v(0.5), syn_projEI_ampa[1073], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1074: cell 53, seg 0 (0.5) [0.5 on Epop[53]] -> cell 14, seg 0 (0.5) [0.5 on Ipop[14]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[14] syn_projEI_ampa[1074] = new ampa(0.5)")
        h("Epop[53] netConn_projEI_ampa[1074] = new NetCon(&v(0.5), syn_projEI_ampa[1074], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1075: cell 53, seg 0 (0.5) [0.5 on Epop[53]] -> cell 15, seg 0 (0.5) [0.5 on Ipop[15]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[15] syn_projEI_ampa[1075] = new ampa(0.5)")
        h("Epop[53] netConn_projEI_ampa[1075] = new NetCon(&v(0.5), syn_projEI_ampa[1075], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1076: cell 53, seg 0 (0.5) [0.5 on Epop[53]] -> cell 16, seg 0 (0.5) [0.5 on Ipop[16]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[16] syn_projEI_ampa[1076] = new ampa(0.5)")
        h("Epop[53] netConn_projEI_ampa[1076] = new NetCon(&v(0.5), syn_projEI_ampa[1076], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1077: cell 53, seg 0 (0.5) [0.5 on Epop[53]] -> cell 17, seg 0 (0.5) [0.5 on Ipop[17]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[17] syn_projEI_ampa[1077] = new ampa(0.5)")
        h("Epop[53] netConn_projEI_ampa[1077] = new NetCon(&v(0.5), syn_projEI_ampa[1077], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1078: cell 53, seg 0 (0.5) [0.5 on Epop[53]] -> cell 18, seg 0 (0.5) [0.5 on Ipop[18]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[18] syn_projEI_ampa[1078] = new ampa(0.5)")
        h("Epop[53] netConn_projEI_ampa[1078] = new NetCon(&v(0.5), syn_projEI_ampa[1078], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1079: cell 53, seg 0 (0.5) [0.5 on Epop[53]] -> cell 19, seg 0 (0.5) [0.5 on Ipop[19]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[19] syn_projEI_ampa[1079] = new ampa(0.5)")
        h("Epop[53] netConn_projEI_ampa[1079] = new NetCon(&v(0.5), syn_projEI_ampa[1079], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1080: cell 54, seg 0 (0.5) [0.5 on Epop[54]] -> cell 0, seg 0 (0.5) [0.5 on Ipop[0]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[0] syn_projEI_ampa[1080] = new ampa(0.5)")
        h("Epop[54] netConn_projEI_ampa[1080] = new NetCon(&v(0.5), syn_projEI_ampa[1080], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1081: cell 54, seg 0 (0.5) [0.5 on Epop[54]] -> cell 1, seg 0 (0.5) [0.5 on Ipop[1]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[1] syn_projEI_ampa[1081] = new ampa(0.5)")
        h("Epop[54] netConn_projEI_ampa[1081] = new NetCon(&v(0.5), syn_projEI_ampa[1081], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1082: cell 54, seg 0 (0.5) [0.5 on Epop[54]] -> cell 2, seg 0 (0.5) [0.5 on Ipop[2]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[2] syn_projEI_ampa[1082] = new ampa(0.5)")
        h("Epop[54] netConn_projEI_ampa[1082] = new NetCon(&v(0.5), syn_projEI_ampa[1082], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1083: cell 54, seg 0 (0.5) [0.5 on Epop[54]] -> cell 3, seg 0 (0.5) [0.5 on Ipop[3]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[3] syn_projEI_ampa[1083] = new ampa(0.5)")
        h("Epop[54] netConn_projEI_ampa[1083] = new NetCon(&v(0.5), syn_projEI_ampa[1083], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1084: cell 54, seg 0 (0.5) [0.5 on Epop[54]] -> cell 4, seg 0 (0.5) [0.5 on Ipop[4]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[4] syn_projEI_ampa[1084] = new ampa(0.5)")
        h("Epop[54] netConn_projEI_ampa[1084] = new NetCon(&v(0.5), syn_projEI_ampa[1084], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1085: cell 54, seg 0 (0.5) [0.5 on Epop[54]] -> cell 5, seg 0 (0.5) [0.5 on Ipop[5]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[5] syn_projEI_ampa[1085] = new ampa(0.5)")
        h("Epop[54] netConn_projEI_ampa[1085] = new NetCon(&v(0.5), syn_projEI_ampa[1085], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1086: cell 54, seg 0 (0.5) [0.5 on Epop[54]] -> cell 6, seg 0 (0.5) [0.5 on Ipop[6]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[6] syn_projEI_ampa[1086] = new ampa(0.5)")
        h("Epop[54] netConn_projEI_ampa[1086] = new NetCon(&v(0.5), syn_projEI_ampa[1086], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1087: cell 54, seg 0 (0.5) [0.5 on Epop[54]] -> cell 7, seg 0 (0.5) [0.5 on Ipop[7]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[7] syn_projEI_ampa[1087] = new ampa(0.5)")
        h("Epop[54] netConn_projEI_ampa[1087] = new NetCon(&v(0.5), syn_projEI_ampa[1087], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1088: cell 54, seg 0 (0.5) [0.5 on Epop[54]] -> cell 8, seg 0 (0.5) [0.5 on Ipop[8]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[8] syn_projEI_ampa[1088] = new ampa(0.5)")
        h("Epop[54] netConn_projEI_ampa[1088] = new NetCon(&v(0.5), syn_projEI_ampa[1088], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1089: cell 54, seg 0 (0.5) [0.5 on Epop[54]] -> cell 9, seg 0 (0.5) [0.5 on Ipop[9]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[9] syn_projEI_ampa[1089] = new ampa(0.5)")
        h("Epop[54] netConn_projEI_ampa[1089] = new NetCon(&v(0.5), syn_projEI_ampa[1089], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1090: cell 54, seg 0 (0.5) [0.5 on Epop[54]] -> cell 10, seg 0 (0.5) [0.5 on Ipop[10]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[10] syn_projEI_ampa[1090] = new ampa(0.5)")
        h("Epop[54] netConn_projEI_ampa[1090] = new NetCon(&v(0.5), syn_projEI_ampa[1090], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1091: cell 54, seg 0 (0.5) [0.5 on Epop[54]] -> cell 11, seg 0 (0.5) [0.5 on Ipop[11]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[11] syn_projEI_ampa[1091] = new ampa(0.5)")
        h("Epop[54] netConn_projEI_ampa[1091] = new NetCon(&v(0.5), syn_projEI_ampa[1091], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1092: cell 54, seg 0 (0.5) [0.5 on Epop[54]] -> cell 12, seg 0 (0.5) [0.5 on Ipop[12]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[12] syn_projEI_ampa[1092] = new ampa(0.5)")
        h("Epop[54] netConn_projEI_ampa[1092] = new NetCon(&v(0.5), syn_projEI_ampa[1092], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1093: cell 54, seg 0 (0.5) [0.5 on Epop[54]] -> cell 13, seg 0 (0.5) [0.5 on Ipop[13]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[13] syn_projEI_ampa[1093] = new ampa(0.5)")
        h("Epop[54] netConn_projEI_ampa[1093] = new NetCon(&v(0.5), syn_projEI_ampa[1093], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1094: cell 54, seg 0 (0.5) [0.5 on Epop[54]] -> cell 14, seg 0 (0.5) [0.5 on Ipop[14]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[14] syn_projEI_ampa[1094] = new ampa(0.5)")
        h("Epop[54] netConn_projEI_ampa[1094] = new NetCon(&v(0.5), syn_projEI_ampa[1094], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1095: cell 54, seg 0 (0.5) [0.5 on Epop[54]] -> cell 15, seg 0 (0.5) [0.5 on Ipop[15]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[15] syn_projEI_ampa[1095] = new ampa(0.5)")
        h("Epop[54] netConn_projEI_ampa[1095] = new NetCon(&v(0.5), syn_projEI_ampa[1095], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1096: cell 54, seg 0 (0.5) [0.5 on Epop[54]] -> cell 16, seg 0 (0.5) [0.5 on Ipop[16]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[16] syn_projEI_ampa[1096] = new ampa(0.5)")
        h("Epop[54] netConn_projEI_ampa[1096] = new NetCon(&v(0.5), syn_projEI_ampa[1096], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1097: cell 54, seg 0 (0.5) [0.5 on Epop[54]] -> cell 17, seg 0 (0.5) [0.5 on Ipop[17]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[17] syn_projEI_ampa[1097] = new ampa(0.5)")
        h("Epop[54] netConn_projEI_ampa[1097] = new NetCon(&v(0.5), syn_projEI_ampa[1097], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1098: cell 54, seg 0 (0.5) [0.5 on Epop[54]] -> cell 18, seg 0 (0.5) [0.5 on Ipop[18]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[18] syn_projEI_ampa[1098] = new ampa(0.5)")
        h("Epop[54] netConn_projEI_ampa[1098] = new NetCon(&v(0.5), syn_projEI_ampa[1098], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1099: cell 54, seg 0 (0.5) [0.5 on Epop[54]] -> cell 19, seg 0 (0.5) [0.5 on Ipop[19]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[19] syn_projEI_ampa[1099] = new ampa(0.5)")
        h("Epop[54] netConn_projEI_ampa[1099] = new NetCon(&v(0.5), syn_projEI_ampa[1099], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1100: cell 55, seg 0 (0.5) [0.5 on Epop[55]] -> cell 0, seg 0 (0.5) [0.5 on Ipop[0]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[0] syn_projEI_ampa[1100] = new ampa(0.5)")
        h("Epop[55] netConn_projEI_ampa[1100] = new NetCon(&v(0.5), syn_projEI_ampa[1100], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1101: cell 55, seg 0 (0.5) [0.5 on Epop[55]] -> cell 1, seg 0 (0.5) [0.5 on Ipop[1]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[1] syn_projEI_ampa[1101] = new ampa(0.5)")
        h("Epop[55] netConn_projEI_ampa[1101] = new NetCon(&v(0.5), syn_projEI_ampa[1101], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1102: cell 55, seg 0 (0.5) [0.5 on Epop[55]] -> cell 2, seg 0 (0.5) [0.5 on Ipop[2]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[2] syn_projEI_ampa[1102] = new ampa(0.5)")
        h("Epop[55] netConn_projEI_ampa[1102] = new NetCon(&v(0.5), syn_projEI_ampa[1102], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1103: cell 55, seg 0 (0.5) [0.5 on Epop[55]] -> cell 3, seg 0 (0.5) [0.5 on Ipop[3]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[3] syn_projEI_ampa[1103] = new ampa(0.5)")
        h("Epop[55] netConn_projEI_ampa[1103] = new NetCon(&v(0.5), syn_projEI_ampa[1103], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1104: cell 55, seg 0 (0.5) [0.5 on Epop[55]] -> cell 4, seg 0 (0.5) [0.5 on Ipop[4]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[4] syn_projEI_ampa[1104] = new ampa(0.5)")
        h("Epop[55] netConn_projEI_ampa[1104] = new NetCon(&v(0.5), syn_projEI_ampa[1104], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1105: cell 55, seg 0 (0.5) [0.5 on Epop[55]] -> cell 5, seg 0 (0.5) [0.5 on Ipop[5]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[5] syn_projEI_ampa[1105] = new ampa(0.5)")
        h("Epop[55] netConn_projEI_ampa[1105] = new NetCon(&v(0.5), syn_projEI_ampa[1105], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1106: cell 55, seg 0 (0.5) [0.5 on Epop[55]] -> cell 6, seg 0 (0.5) [0.5 on Ipop[6]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[6] syn_projEI_ampa[1106] = new ampa(0.5)")
        h("Epop[55] netConn_projEI_ampa[1106] = new NetCon(&v(0.5), syn_projEI_ampa[1106], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1107: cell 55, seg 0 (0.5) [0.5 on Epop[55]] -> cell 7, seg 0 (0.5) [0.5 on Ipop[7]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[7] syn_projEI_ampa[1107] = new ampa(0.5)")
        h("Epop[55] netConn_projEI_ampa[1107] = new NetCon(&v(0.5), syn_projEI_ampa[1107], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1108: cell 55, seg 0 (0.5) [0.5 on Epop[55]] -> cell 8, seg 0 (0.5) [0.5 on Ipop[8]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[8] syn_projEI_ampa[1108] = new ampa(0.5)")
        h("Epop[55] netConn_projEI_ampa[1108] = new NetCon(&v(0.5), syn_projEI_ampa[1108], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1109: cell 55, seg 0 (0.5) [0.5 on Epop[55]] -> cell 9, seg 0 (0.5) [0.5 on Ipop[9]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[9] syn_projEI_ampa[1109] = new ampa(0.5)")
        h("Epop[55] netConn_projEI_ampa[1109] = new NetCon(&v(0.5), syn_projEI_ampa[1109], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1110: cell 55, seg 0 (0.5) [0.5 on Epop[55]] -> cell 10, seg 0 (0.5) [0.5 on Ipop[10]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[10] syn_projEI_ampa[1110] = new ampa(0.5)")
        h("Epop[55] netConn_projEI_ampa[1110] = new NetCon(&v(0.5), syn_projEI_ampa[1110], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1111: cell 55, seg 0 (0.5) [0.5 on Epop[55]] -> cell 11, seg 0 (0.5) [0.5 on Ipop[11]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[11] syn_projEI_ampa[1111] = new ampa(0.5)")
        h("Epop[55] netConn_projEI_ampa[1111] = new NetCon(&v(0.5), syn_projEI_ampa[1111], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1112: cell 55, seg 0 (0.5) [0.5 on Epop[55]] -> cell 12, seg 0 (0.5) [0.5 on Ipop[12]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[12] syn_projEI_ampa[1112] = new ampa(0.5)")
        h("Epop[55] netConn_projEI_ampa[1112] = new NetCon(&v(0.5), syn_projEI_ampa[1112], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1113: cell 55, seg 0 (0.5) [0.5 on Epop[55]] -> cell 13, seg 0 (0.5) [0.5 on Ipop[13]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[13] syn_projEI_ampa[1113] = new ampa(0.5)")
        h("Epop[55] netConn_projEI_ampa[1113] = new NetCon(&v(0.5), syn_projEI_ampa[1113], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1114: cell 55, seg 0 (0.5) [0.5 on Epop[55]] -> cell 14, seg 0 (0.5) [0.5 on Ipop[14]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[14] syn_projEI_ampa[1114] = new ampa(0.5)")
        h("Epop[55] netConn_projEI_ampa[1114] = new NetCon(&v(0.5), syn_projEI_ampa[1114], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1115: cell 55, seg 0 (0.5) [0.5 on Epop[55]] -> cell 15, seg 0 (0.5) [0.5 on Ipop[15]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[15] syn_projEI_ampa[1115] = new ampa(0.5)")
        h("Epop[55] netConn_projEI_ampa[1115] = new NetCon(&v(0.5), syn_projEI_ampa[1115], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1116: cell 55, seg 0 (0.5) [0.5 on Epop[55]] -> cell 16, seg 0 (0.5) [0.5 on Ipop[16]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[16] syn_projEI_ampa[1116] = new ampa(0.5)")
        h("Epop[55] netConn_projEI_ampa[1116] = new NetCon(&v(0.5), syn_projEI_ampa[1116], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1117: cell 55, seg 0 (0.5) [0.5 on Epop[55]] -> cell 17, seg 0 (0.5) [0.5 on Ipop[17]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[17] syn_projEI_ampa[1117] = new ampa(0.5)")
        h("Epop[55] netConn_projEI_ampa[1117] = new NetCon(&v(0.5), syn_projEI_ampa[1117], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1118: cell 55, seg 0 (0.5) [0.5 on Epop[55]] -> cell 18, seg 0 (0.5) [0.5 on Ipop[18]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[18] syn_projEI_ampa[1118] = new ampa(0.5)")
        h("Epop[55] netConn_projEI_ampa[1118] = new NetCon(&v(0.5), syn_projEI_ampa[1118], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1119: cell 55, seg 0 (0.5) [0.5 on Epop[55]] -> cell 19, seg 0 (0.5) [0.5 on Ipop[19]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[19] syn_projEI_ampa[1119] = new ampa(0.5)")
        h("Epop[55] netConn_projEI_ampa[1119] = new NetCon(&v(0.5), syn_projEI_ampa[1119], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1120: cell 56, seg 0 (0.5) [0.5 on Epop[56]] -> cell 0, seg 0 (0.5) [0.5 on Ipop[0]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[0] syn_projEI_ampa[1120] = new ampa(0.5)")
        h("Epop[56] netConn_projEI_ampa[1120] = new NetCon(&v(0.5), syn_projEI_ampa[1120], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1121: cell 56, seg 0 (0.5) [0.5 on Epop[56]] -> cell 1, seg 0 (0.5) [0.5 on Ipop[1]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[1] syn_projEI_ampa[1121] = new ampa(0.5)")
        h("Epop[56] netConn_projEI_ampa[1121] = new NetCon(&v(0.5), syn_projEI_ampa[1121], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1122: cell 56, seg 0 (0.5) [0.5 on Epop[56]] -> cell 2, seg 0 (0.5) [0.5 on Ipop[2]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[2] syn_projEI_ampa[1122] = new ampa(0.5)")
        h("Epop[56] netConn_projEI_ampa[1122] = new NetCon(&v(0.5), syn_projEI_ampa[1122], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1123: cell 56, seg 0 (0.5) [0.5 on Epop[56]] -> cell 3, seg 0 (0.5) [0.5 on Ipop[3]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[3] syn_projEI_ampa[1123] = new ampa(0.5)")
        h("Epop[56] netConn_projEI_ampa[1123] = new NetCon(&v(0.5), syn_projEI_ampa[1123], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1124: cell 56, seg 0 (0.5) [0.5 on Epop[56]] -> cell 4, seg 0 (0.5) [0.5 on Ipop[4]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[4] syn_projEI_ampa[1124] = new ampa(0.5)")
        h("Epop[56] netConn_projEI_ampa[1124] = new NetCon(&v(0.5), syn_projEI_ampa[1124], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1125: cell 56, seg 0 (0.5) [0.5 on Epop[56]] -> cell 5, seg 0 (0.5) [0.5 on Ipop[5]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[5] syn_projEI_ampa[1125] = new ampa(0.5)")
        h("Epop[56] netConn_projEI_ampa[1125] = new NetCon(&v(0.5), syn_projEI_ampa[1125], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1126: cell 56, seg 0 (0.5) [0.5 on Epop[56]] -> cell 6, seg 0 (0.5) [0.5 on Ipop[6]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[6] syn_projEI_ampa[1126] = new ampa(0.5)")
        h("Epop[56] netConn_projEI_ampa[1126] = new NetCon(&v(0.5), syn_projEI_ampa[1126], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1127: cell 56, seg 0 (0.5) [0.5 on Epop[56]] -> cell 7, seg 0 (0.5) [0.5 on Ipop[7]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[7] syn_projEI_ampa[1127] = new ampa(0.5)")
        h("Epop[56] netConn_projEI_ampa[1127] = new NetCon(&v(0.5), syn_projEI_ampa[1127], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1128: cell 56, seg 0 (0.5) [0.5 on Epop[56]] -> cell 8, seg 0 (0.5) [0.5 on Ipop[8]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[8] syn_projEI_ampa[1128] = new ampa(0.5)")
        h("Epop[56] netConn_projEI_ampa[1128] = new NetCon(&v(0.5), syn_projEI_ampa[1128], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1129: cell 56, seg 0 (0.5) [0.5 on Epop[56]] -> cell 9, seg 0 (0.5) [0.5 on Ipop[9]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[9] syn_projEI_ampa[1129] = new ampa(0.5)")
        h("Epop[56] netConn_projEI_ampa[1129] = new NetCon(&v(0.5), syn_projEI_ampa[1129], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1130: cell 56, seg 0 (0.5) [0.5 on Epop[56]] -> cell 10, seg 0 (0.5) [0.5 on Ipop[10]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[10] syn_projEI_ampa[1130] = new ampa(0.5)")
        h("Epop[56] netConn_projEI_ampa[1130] = new NetCon(&v(0.5), syn_projEI_ampa[1130], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1131: cell 56, seg 0 (0.5) [0.5 on Epop[56]] -> cell 11, seg 0 (0.5) [0.5 on Ipop[11]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[11] syn_projEI_ampa[1131] = new ampa(0.5)")
        h("Epop[56] netConn_projEI_ampa[1131] = new NetCon(&v(0.5), syn_projEI_ampa[1131], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1132: cell 56, seg 0 (0.5) [0.5 on Epop[56]] -> cell 12, seg 0 (0.5) [0.5 on Ipop[12]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[12] syn_projEI_ampa[1132] = new ampa(0.5)")
        h("Epop[56] netConn_projEI_ampa[1132] = new NetCon(&v(0.5), syn_projEI_ampa[1132], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1133: cell 56, seg 0 (0.5) [0.5 on Epop[56]] -> cell 13, seg 0 (0.5) [0.5 on Ipop[13]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[13] syn_projEI_ampa[1133] = new ampa(0.5)")
        h("Epop[56] netConn_projEI_ampa[1133] = new NetCon(&v(0.5), syn_projEI_ampa[1133], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1134: cell 56, seg 0 (0.5) [0.5 on Epop[56]] -> cell 14, seg 0 (0.5) [0.5 on Ipop[14]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[14] syn_projEI_ampa[1134] = new ampa(0.5)")
        h("Epop[56] netConn_projEI_ampa[1134] = new NetCon(&v(0.5), syn_projEI_ampa[1134], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1135: cell 56, seg 0 (0.5) [0.5 on Epop[56]] -> cell 15, seg 0 (0.5) [0.5 on Ipop[15]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[15] syn_projEI_ampa[1135] = new ampa(0.5)")
        h("Epop[56] netConn_projEI_ampa[1135] = new NetCon(&v(0.5), syn_projEI_ampa[1135], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1136: cell 56, seg 0 (0.5) [0.5 on Epop[56]] -> cell 16, seg 0 (0.5) [0.5 on Ipop[16]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[16] syn_projEI_ampa[1136] = new ampa(0.5)")
        h("Epop[56] netConn_projEI_ampa[1136] = new NetCon(&v(0.5), syn_projEI_ampa[1136], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1137: cell 56, seg 0 (0.5) [0.5 on Epop[56]] -> cell 17, seg 0 (0.5) [0.5 on Ipop[17]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[17] syn_projEI_ampa[1137] = new ampa(0.5)")
        h("Epop[56] netConn_projEI_ampa[1137] = new NetCon(&v(0.5), syn_projEI_ampa[1137], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1138: cell 56, seg 0 (0.5) [0.5 on Epop[56]] -> cell 18, seg 0 (0.5) [0.5 on Ipop[18]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[18] syn_projEI_ampa[1138] = new ampa(0.5)")
        h("Epop[56] netConn_projEI_ampa[1138] = new NetCon(&v(0.5), syn_projEI_ampa[1138], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1139: cell 56, seg 0 (0.5) [0.5 on Epop[56]] -> cell 19, seg 0 (0.5) [0.5 on Ipop[19]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[19] syn_projEI_ampa[1139] = new ampa(0.5)")
        h("Epop[56] netConn_projEI_ampa[1139] = new NetCon(&v(0.5), syn_projEI_ampa[1139], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1140: cell 57, seg 0 (0.5) [0.5 on Epop[57]] -> cell 0, seg 0 (0.5) [0.5 on Ipop[0]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[0] syn_projEI_ampa[1140] = new ampa(0.5)")
        h("Epop[57] netConn_projEI_ampa[1140] = new NetCon(&v(0.5), syn_projEI_ampa[1140], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1141: cell 57, seg 0 (0.5) [0.5 on Epop[57]] -> cell 1, seg 0 (0.5) [0.5 on Ipop[1]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[1] syn_projEI_ampa[1141] = new ampa(0.5)")
        h("Epop[57] netConn_projEI_ampa[1141] = new NetCon(&v(0.5), syn_projEI_ampa[1141], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1142: cell 57, seg 0 (0.5) [0.5 on Epop[57]] -> cell 2, seg 0 (0.5) [0.5 on Ipop[2]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[2] syn_projEI_ampa[1142] = new ampa(0.5)")
        h("Epop[57] netConn_projEI_ampa[1142] = new NetCon(&v(0.5), syn_projEI_ampa[1142], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1143: cell 57, seg 0 (0.5) [0.5 on Epop[57]] -> cell 3, seg 0 (0.5) [0.5 on Ipop[3]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[3] syn_projEI_ampa[1143] = new ampa(0.5)")
        h("Epop[57] netConn_projEI_ampa[1143] = new NetCon(&v(0.5), syn_projEI_ampa[1143], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1144: cell 57, seg 0 (0.5) [0.5 on Epop[57]] -> cell 4, seg 0 (0.5) [0.5 on Ipop[4]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[4] syn_projEI_ampa[1144] = new ampa(0.5)")
        h("Epop[57] netConn_projEI_ampa[1144] = new NetCon(&v(0.5), syn_projEI_ampa[1144], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1145: cell 57, seg 0 (0.5) [0.5 on Epop[57]] -> cell 5, seg 0 (0.5) [0.5 on Ipop[5]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[5] syn_projEI_ampa[1145] = new ampa(0.5)")
        h("Epop[57] netConn_projEI_ampa[1145] = new NetCon(&v(0.5), syn_projEI_ampa[1145], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1146: cell 57, seg 0 (0.5) [0.5 on Epop[57]] -> cell 6, seg 0 (0.5) [0.5 on Ipop[6]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[6] syn_projEI_ampa[1146] = new ampa(0.5)")
        h("Epop[57] netConn_projEI_ampa[1146] = new NetCon(&v(0.5), syn_projEI_ampa[1146], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1147: cell 57, seg 0 (0.5) [0.5 on Epop[57]] -> cell 7, seg 0 (0.5) [0.5 on Ipop[7]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[7] syn_projEI_ampa[1147] = new ampa(0.5)")
        h("Epop[57] netConn_projEI_ampa[1147] = new NetCon(&v(0.5), syn_projEI_ampa[1147], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1148: cell 57, seg 0 (0.5) [0.5 on Epop[57]] -> cell 8, seg 0 (0.5) [0.5 on Ipop[8]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[8] syn_projEI_ampa[1148] = new ampa(0.5)")
        h("Epop[57] netConn_projEI_ampa[1148] = new NetCon(&v(0.5), syn_projEI_ampa[1148], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1149: cell 57, seg 0 (0.5) [0.5 on Epop[57]] -> cell 9, seg 0 (0.5) [0.5 on Ipop[9]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[9] syn_projEI_ampa[1149] = new ampa(0.5)")
        h("Epop[57] netConn_projEI_ampa[1149] = new NetCon(&v(0.5), syn_projEI_ampa[1149], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1150: cell 57, seg 0 (0.5) [0.5 on Epop[57]] -> cell 10, seg 0 (0.5) [0.5 on Ipop[10]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[10] syn_projEI_ampa[1150] = new ampa(0.5)")
        h("Epop[57] netConn_projEI_ampa[1150] = new NetCon(&v(0.5), syn_projEI_ampa[1150], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1151: cell 57, seg 0 (0.5) [0.5 on Epop[57]] -> cell 11, seg 0 (0.5) [0.5 on Ipop[11]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[11] syn_projEI_ampa[1151] = new ampa(0.5)")
        h("Epop[57] netConn_projEI_ampa[1151] = new NetCon(&v(0.5), syn_projEI_ampa[1151], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1152: cell 57, seg 0 (0.5) [0.5 on Epop[57]] -> cell 12, seg 0 (0.5) [0.5 on Ipop[12]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[12] syn_projEI_ampa[1152] = new ampa(0.5)")
        h("Epop[57] netConn_projEI_ampa[1152] = new NetCon(&v(0.5), syn_projEI_ampa[1152], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1153: cell 57, seg 0 (0.5) [0.5 on Epop[57]] -> cell 13, seg 0 (0.5) [0.5 on Ipop[13]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[13] syn_projEI_ampa[1153] = new ampa(0.5)")
        h("Epop[57] netConn_projEI_ampa[1153] = new NetCon(&v(0.5), syn_projEI_ampa[1153], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1154: cell 57, seg 0 (0.5) [0.5 on Epop[57]] -> cell 14, seg 0 (0.5) [0.5 on Ipop[14]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[14] syn_projEI_ampa[1154] = new ampa(0.5)")
        h("Epop[57] netConn_projEI_ampa[1154] = new NetCon(&v(0.5), syn_projEI_ampa[1154], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1155: cell 57, seg 0 (0.5) [0.5 on Epop[57]] -> cell 15, seg 0 (0.5) [0.5 on Ipop[15]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[15] syn_projEI_ampa[1155] = new ampa(0.5)")
        h("Epop[57] netConn_projEI_ampa[1155] = new NetCon(&v(0.5), syn_projEI_ampa[1155], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1156: cell 57, seg 0 (0.5) [0.5 on Epop[57]] -> cell 16, seg 0 (0.5) [0.5 on Ipop[16]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[16] syn_projEI_ampa[1156] = new ampa(0.5)")
        h("Epop[57] netConn_projEI_ampa[1156] = new NetCon(&v(0.5), syn_projEI_ampa[1156], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1157: cell 57, seg 0 (0.5) [0.5 on Epop[57]] -> cell 17, seg 0 (0.5) [0.5 on Ipop[17]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[17] syn_projEI_ampa[1157] = new ampa(0.5)")
        h("Epop[57] netConn_projEI_ampa[1157] = new NetCon(&v(0.5), syn_projEI_ampa[1157], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1158: cell 57, seg 0 (0.5) [0.5 on Epop[57]] -> cell 18, seg 0 (0.5) [0.5 on Ipop[18]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[18] syn_projEI_ampa[1158] = new ampa(0.5)")
        h("Epop[57] netConn_projEI_ampa[1158] = new NetCon(&v(0.5), syn_projEI_ampa[1158], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1159: cell 57, seg 0 (0.5) [0.5 on Epop[57]] -> cell 19, seg 0 (0.5) [0.5 on Ipop[19]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[19] syn_projEI_ampa[1159] = new ampa(0.5)")
        h("Epop[57] netConn_projEI_ampa[1159] = new NetCon(&v(0.5), syn_projEI_ampa[1159], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1160: cell 58, seg 0 (0.5) [0.5 on Epop[58]] -> cell 0, seg 0 (0.5) [0.5 on Ipop[0]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[0] syn_projEI_ampa[1160] = new ampa(0.5)")
        h("Epop[58] netConn_projEI_ampa[1160] = new NetCon(&v(0.5), syn_projEI_ampa[1160], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1161: cell 58, seg 0 (0.5) [0.5 on Epop[58]] -> cell 1, seg 0 (0.5) [0.5 on Ipop[1]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[1] syn_projEI_ampa[1161] = new ampa(0.5)")
        h("Epop[58] netConn_projEI_ampa[1161] = new NetCon(&v(0.5), syn_projEI_ampa[1161], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1162: cell 58, seg 0 (0.5) [0.5 on Epop[58]] -> cell 2, seg 0 (0.5) [0.5 on Ipop[2]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[2] syn_projEI_ampa[1162] = new ampa(0.5)")
        h("Epop[58] netConn_projEI_ampa[1162] = new NetCon(&v(0.5), syn_projEI_ampa[1162], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1163: cell 58, seg 0 (0.5) [0.5 on Epop[58]] -> cell 3, seg 0 (0.5) [0.5 on Ipop[3]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[3] syn_projEI_ampa[1163] = new ampa(0.5)")
        h("Epop[58] netConn_projEI_ampa[1163] = new NetCon(&v(0.5), syn_projEI_ampa[1163], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1164: cell 58, seg 0 (0.5) [0.5 on Epop[58]] -> cell 4, seg 0 (0.5) [0.5 on Ipop[4]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[4] syn_projEI_ampa[1164] = new ampa(0.5)")
        h("Epop[58] netConn_projEI_ampa[1164] = new NetCon(&v(0.5), syn_projEI_ampa[1164], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1165: cell 58, seg 0 (0.5) [0.5 on Epop[58]] -> cell 5, seg 0 (0.5) [0.5 on Ipop[5]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[5] syn_projEI_ampa[1165] = new ampa(0.5)")
        h("Epop[58] netConn_projEI_ampa[1165] = new NetCon(&v(0.5), syn_projEI_ampa[1165], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1166: cell 58, seg 0 (0.5) [0.5 on Epop[58]] -> cell 6, seg 0 (0.5) [0.5 on Ipop[6]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[6] syn_projEI_ampa[1166] = new ampa(0.5)")
        h("Epop[58] netConn_projEI_ampa[1166] = new NetCon(&v(0.5), syn_projEI_ampa[1166], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1167: cell 58, seg 0 (0.5) [0.5 on Epop[58]] -> cell 7, seg 0 (0.5) [0.5 on Ipop[7]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[7] syn_projEI_ampa[1167] = new ampa(0.5)")
        h("Epop[58] netConn_projEI_ampa[1167] = new NetCon(&v(0.5), syn_projEI_ampa[1167], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1168: cell 58, seg 0 (0.5) [0.5 on Epop[58]] -> cell 8, seg 0 (0.5) [0.5 on Ipop[8]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[8] syn_projEI_ampa[1168] = new ampa(0.5)")
        h("Epop[58] netConn_projEI_ampa[1168] = new NetCon(&v(0.5), syn_projEI_ampa[1168], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1169: cell 58, seg 0 (0.5) [0.5 on Epop[58]] -> cell 9, seg 0 (0.5) [0.5 on Ipop[9]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[9] syn_projEI_ampa[1169] = new ampa(0.5)")
        h("Epop[58] netConn_projEI_ampa[1169] = new NetCon(&v(0.5), syn_projEI_ampa[1169], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1170: cell 58, seg 0 (0.5) [0.5 on Epop[58]] -> cell 10, seg 0 (0.5) [0.5 on Ipop[10]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[10] syn_projEI_ampa[1170] = new ampa(0.5)")
        h("Epop[58] netConn_projEI_ampa[1170] = new NetCon(&v(0.5), syn_projEI_ampa[1170], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1171: cell 58, seg 0 (0.5) [0.5 on Epop[58]] -> cell 11, seg 0 (0.5) [0.5 on Ipop[11]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[11] syn_projEI_ampa[1171] = new ampa(0.5)")
        h("Epop[58] netConn_projEI_ampa[1171] = new NetCon(&v(0.5), syn_projEI_ampa[1171], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1172: cell 58, seg 0 (0.5) [0.5 on Epop[58]] -> cell 12, seg 0 (0.5) [0.5 on Ipop[12]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[12] syn_projEI_ampa[1172] = new ampa(0.5)")
        h("Epop[58] netConn_projEI_ampa[1172] = new NetCon(&v(0.5), syn_projEI_ampa[1172], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1173: cell 58, seg 0 (0.5) [0.5 on Epop[58]] -> cell 13, seg 0 (0.5) [0.5 on Ipop[13]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[13] syn_projEI_ampa[1173] = new ampa(0.5)")
        h("Epop[58] netConn_projEI_ampa[1173] = new NetCon(&v(0.5), syn_projEI_ampa[1173], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1174: cell 58, seg 0 (0.5) [0.5 on Epop[58]] -> cell 14, seg 0 (0.5) [0.5 on Ipop[14]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[14] syn_projEI_ampa[1174] = new ampa(0.5)")
        h("Epop[58] netConn_projEI_ampa[1174] = new NetCon(&v(0.5), syn_projEI_ampa[1174], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1175: cell 58, seg 0 (0.5) [0.5 on Epop[58]] -> cell 15, seg 0 (0.5) [0.5 on Ipop[15]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[15] syn_projEI_ampa[1175] = new ampa(0.5)")
        h("Epop[58] netConn_projEI_ampa[1175] = new NetCon(&v(0.5), syn_projEI_ampa[1175], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1176: cell 58, seg 0 (0.5) [0.5 on Epop[58]] -> cell 16, seg 0 (0.5) [0.5 on Ipop[16]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[16] syn_projEI_ampa[1176] = new ampa(0.5)")
        h("Epop[58] netConn_projEI_ampa[1176] = new NetCon(&v(0.5), syn_projEI_ampa[1176], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1177: cell 58, seg 0 (0.5) [0.5 on Epop[58]] -> cell 17, seg 0 (0.5) [0.5 on Ipop[17]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[17] syn_projEI_ampa[1177] = new ampa(0.5)")
        h("Epop[58] netConn_projEI_ampa[1177] = new NetCon(&v(0.5), syn_projEI_ampa[1177], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1178: cell 58, seg 0 (0.5) [0.5 on Epop[58]] -> cell 18, seg 0 (0.5) [0.5 on Ipop[18]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[18] syn_projEI_ampa[1178] = new ampa(0.5)")
        h("Epop[58] netConn_projEI_ampa[1178] = new NetCon(&v(0.5), syn_projEI_ampa[1178], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1179: cell 58, seg 0 (0.5) [0.5 on Epop[58]] -> cell 19, seg 0 (0.5) [0.5 on Ipop[19]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[19] syn_projEI_ampa[1179] = new ampa(0.5)")
        h("Epop[58] netConn_projEI_ampa[1179] = new NetCon(&v(0.5), syn_projEI_ampa[1179], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1180: cell 59, seg 0 (0.5) [0.5 on Epop[59]] -> cell 0, seg 0 (0.5) [0.5 on Ipop[0]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[0] syn_projEI_ampa[1180] = new ampa(0.5)")
        h("Epop[59] netConn_projEI_ampa[1180] = new NetCon(&v(0.5), syn_projEI_ampa[1180], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1181: cell 59, seg 0 (0.5) [0.5 on Epop[59]] -> cell 1, seg 0 (0.5) [0.5 on Ipop[1]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[1] syn_projEI_ampa[1181] = new ampa(0.5)")
        h("Epop[59] netConn_projEI_ampa[1181] = new NetCon(&v(0.5), syn_projEI_ampa[1181], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1182: cell 59, seg 0 (0.5) [0.5 on Epop[59]] -> cell 2, seg 0 (0.5) [0.5 on Ipop[2]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[2] syn_projEI_ampa[1182] = new ampa(0.5)")
        h("Epop[59] netConn_projEI_ampa[1182] = new NetCon(&v(0.5), syn_projEI_ampa[1182], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1183: cell 59, seg 0 (0.5) [0.5 on Epop[59]] -> cell 3, seg 0 (0.5) [0.5 on Ipop[3]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[3] syn_projEI_ampa[1183] = new ampa(0.5)")
        h("Epop[59] netConn_projEI_ampa[1183] = new NetCon(&v(0.5), syn_projEI_ampa[1183], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1184: cell 59, seg 0 (0.5) [0.5 on Epop[59]] -> cell 4, seg 0 (0.5) [0.5 on Ipop[4]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[4] syn_projEI_ampa[1184] = new ampa(0.5)")
        h("Epop[59] netConn_projEI_ampa[1184] = new NetCon(&v(0.5), syn_projEI_ampa[1184], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1185: cell 59, seg 0 (0.5) [0.5 on Epop[59]] -> cell 5, seg 0 (0.5) [0.5 on Ipop[5]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[5] syn_projEI_ampa[1185] = new ampa(0.5)")
        h("Epop[59] netConn_projEI_ampa[1185] = new NetCon(&v(0.5), syn_projEI_ampa[1185], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1186: cell 59, seg 0 (0.5) [0.5 on Epop[59]] -> cell 6, seg 0 (0.5) [0.5 on Ipop[6]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[6] syn_projEI_ampa[1186] = new ampa(0.5)")
        h("Epop[59] netConn_projEI_ampa[1186] = new NetCon(&v(0.5), syn_projEI_ampa[1186], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1187: cell 59, seg 0 (0.5) [0.5 on Epop[59]] -> cell 7, seg 0 (0.5) [0.5 on Ipop[7]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[7] syn_projEI_ampa[1187] = new ampa(0.5)")
        h("Epop[59] netConn_projEI_ampa[1187] = new NetCon(&v(0.5), syn_projEI_ampa[1187], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1188: cell 59, seg 0 (0.5) [0.5 on Epop[59]] -> cell 8, seg 0 (0.5) [0.5 on Ipop[8]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[8] syn_projEI_ampa[1188] = new ampa(0.5)")
        h("Epop[59] netConn_projEI_ampa[1188] = new NetCon(&v(0.5), syn_projEI_ampa[1188], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1189: cell 59, seg 0 (0.5) [0.5 on Epop[59]] -> cell 9, seg 0 (0.5) [0.5 on Ipop[9]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[9] syn_projEI_ampa[1189] = new ampa(0.5)")
        h("Epop[59] netConn_projEI_ampa[1189] = new NetCon(&v(0.5), syn_projEI_ampa[1189], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1190: cell 59, seg 0 (0.5) [0.5 on Epop[59]] -> cell 10, seg 0 (0.5) [0.5 on Ipop[10]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[10] syn_projEI_ampa[1190] = new ampa(0.5)")
        h("Epop[59] netConn_projEI_ampa[1190] = new NetCon(&v(0.5), syn_projEI_ampa[1190], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1191: cell 59, seg 0 (0.5) [0.5 on Epop[59]] -> cell 11, seg 0 (0.5) [0.5 on Ipop[11]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[11] syn_projEI_ampa[1191] = new ampa(0.5)")
        h("Epop[59] netConn_projEI_ampa[1191] = new NetCon(&v(0.5), syn_projEI_ampa[1191], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1192: cell 59, seg 0 (0.5) [0.5 on Epop[59]] -> cell 12, seg 0 (0.5) [0.5 on Ipop[12]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[12] syn_projEI_ampa[1192] = new ampa(0.5)")
        h("Epop[59] netConn_projEI_ampa[1192] = new NetCon(&v(0.5), syn_projEI_ampa[1192], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1193: cell 59, seg 0 (0.5) [0.5 on Epop[59]] -> cell 13, seg 0 (0.5) [0.5 on Ipop[13]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[13] syn_projEI_ampa[1193] = new ampa(0.5)")
        h("Epop[59] netConn_projEI_ampa[1193] = new NetCon(&v(0.5), syn_projEI_ampa[1193], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1194: cell 59, seg 0 (0.5) [0.5 on Epop[59]] -> cell 14, seg 0 (0.5) [0.5 on Ipop[14]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[14] syn_projEI_ampa[1194] = new ampa(0.5)")
        h("Epop[59] netConn_projEI_ampa[1194] = new NetCon(&v(0.5), syn_projEI_ampa[1194], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1195: cell 59, seg 0 (0.5) [0.5 on Epop[59]] -> cell 15, seg 0 (0.5) [0.5 on Ipop[15]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[15] syn_projEI_ampa[1195] = new ampa(0.5)")
        h("Epop[59] netConn_projEI_ampa[1195] = new NetCon(&v(0.5), syn_projEI_ampa[1195], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1196: cell 59, seg 0 (0.5) [0.5 on Epop[59]] -> cell 16, seg 0 (0.5) [0.5 on Ipop[16]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[16] syn_projEI_ampa[1196] = new ampa(0.5)")
        h("Epop[59] netConn_projEI_ampa[1196] = new NetCon(&v(0.5), syn_projEI_ampa[1196], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1197: cell 59, seg 0 (0.5) [0.5 on Epop[59]] -> cell 17, seg 0 (0.5) [0.5 on Ipop[17]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[17] syn_projEI_ampa[1197] = new ampa(0.5)")
        h("Epop[59] netConn_projEI_ampa[1197] = new NetCon(&v(0.5), syn_projEI_ampa[1197], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1198: cell 59, seg 0 (0.5) [0.5 on Epop[59]] -> cell 18, seg 0 (0.5) [0.5 on Ipop[18]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[18] syn_projEI_ampa[1198] = new ampa(0.5)")
        h("Epop[59] netConn_projEI_ampa[1198] = new NetCon(&v(0.5), syn_projEI_ampa[1198], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1199: cell 59, seg 0 (0.5) [0.5 on Epop[59]] -> cell 19, seg 0 (0.5) [0.5 on Ipop[19]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[19] syn_projEI_ampa[1199] = new ampa(0.5)")
        h("Epop[59] netConn_projEI_ampa[1199] = new NetCon(&v(0.5), syn_projEI_ampa[1199], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1200: cell 60, seg 0 (0.5) [0.5 on Epop[60]] -> cell 0, seg 0 (0.5) [0.5 on Ipop[0]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[0] syn_projEI_ampa[1200] = new ampa(0.5)")
        h("Epop[60] netConn_projEI_ampa[1200] = new NetCon(&v(0.5), syn_projEI_ampa[1200], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1201: cell 60, seg 0 (0.5) [0.5 on Epop[60]] -> cell 1, seg 0 (0.5) [0.5 on Ipop[1]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[1] syn_projEI_ampa[1201] = new ampa(0.5)")
        h("Epop[60] netConn_projEI_ampa[1201] = new NetCon(&v(0.5), syn_projEI_ampa[1201], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1202: cell 60, seg 0 (0.5) [0.5 on Epop[60]] -> cell 2, seg 0 (0.5) [0.5 on Ipop[2]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[2] syn_projEI_ampa[1202] = new ampa(0.5)")
        h("Epop[60] netConn_projEI_ampa[1202] = new NetCon(&v(0.5), syn_projEI_ampa[1202], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1203: cell 60, seg 0 (0.5) [0.5 on Epop[60]] -> cell 3, seg 0 (0.5) [0.5 on Ipop[3]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[3] syn_projEI_ampa[1203] = new ampa(0.5)")
        h("Epop[60] netConn_projEI_ampa[1203] = new NetCon(&v(0.5), syn_projEI_ampa[1203], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1204: cell 60, seg 0 (0.5) [0.5 on Epop[60]] -> cell 4, seg 0 (0.5) [0.5 on Ipop[4]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[4] syn_projEI_ampa[1204] = new ampa(0.5)")
        h("Epop[60] netConn_projEI_ampa[1204] = new NetCon(&v(0.5), syn_projEI_ampa[1204], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1205: cell 60, seg 0 (0.5) [0.5 on Epop[60]] -> cell 5, seg 0 (0.5) [0.5 on Ipop[5]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[5] syn_projEI_ampa[1205] = new ampa(0.5)")
        h("Epop[60] netConn_projEI_ampa[1205] = new NetCon(&v(0.5), syn_projEI_ampa[1205], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1206: cell 60, seg 0 (0.5) [0.5 on Epop[60]] -> cell 6, seg 0 (0.5) [0.5 on Ipop[6]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[6] syn_projEI_ampa[1206] = new ampa(0.5)")
        h("Epop[60] netConn_projEI_ampa[1206] = new NetCon(&v(0.5), syn_projEI_ampa[1206], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1207: cell 60, seg 0 (0.5) [0.5 on Epop[60]] -> cell 7, seg 0 (0.5) [0.5 on Ipop[7]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[7] syn_projEI_ampa[1207] = new ampa(0.5)")
        h("Epop[60] netConn_projEI_ampa[1207] = new NetCon(&v(0.5), syn_projEI_ampa[1207], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1208: cell 60, seg 0 (0.5) [0.5 on Epop[60]] -> cell 8, seg 0 (0.5) [0.5 on Ipop[8]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[8] syn_projEI_ampa[1208] = new ampa(0.5)")
        h("Epop[60] netConn_projEI_ampa[1208] = new NetCon(&v(0.5), syn_projEI_ampa[1208], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1209: cell 60, seg 0 (0.5) [0.5 on Epop[60]] -> cell 9, seg 0 (0.5) [0.5 on Ipop[9]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[9] syn_projEI_ampa[1209] = new ampa(0.5)")
        h("Epop[60] netConn_projEI_ampa[1209] = new NetCon(&v(0.5), syn_projEI_ampa[1209], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1210: cell 60, seg 0 (0.5) [0.5 on Epop[60]] -> cell 10, seg 0 (0.5) [0.5 on Ipop[10]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[10] syn_projEI_ampa[1210] = new ampa(0.5)")
        h("Epop[60] netConn_projEI_ampa[1210] = new NetCon(&v(0.5), syn_projEI_ampa[1210], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1211: cell 60, seg 0 (0.5) [0.5 on Epop[60]] -> cell 11, seg 0 (0.5) [0.5 on Ipop[11]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[11] syn_projEI_ampa[1211] = new ampa(0.5)")
        h("Epop[60] netConn_projEI_ampa[1211] = new NetCon(&v(0.5), syn_projEI_ampa[1211], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1212: cell 60, seg 0 (0.5) [0.5 on Epop[60]] -> cell 12, seg 0 (0.5) [0.5 on Ipop[12]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[12] syn_projEI_ampa[1212] = new ampa(0.5)")
        h("Epop[60] netConn_projEI_ampa[1212] = new NetCon(&v(0.5), syn_projEI_ampa[1212], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1213: cell 60, seg 0 (0.5) [0.5 on Epop[60]] -> cell 13, seg 0 (0.5) [0.5 on Ipop[13]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[13] syn_projEI_ampa[1213] = new ampa(0.5)")
        h("Epop[60] netConn_projEI_ampa[1213] = new NetCon(&v(0.5), syn_projEI_ampa[1213], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1214: cell 60, seg 0 (0.5) [0.5 on Epop[60]] -> cell 14, seg 0 (0.5) [0.5 on Ipop[14]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[14] syn_projEI_ampa[1214] = new ampa(0.5)")
        h("Epop[60] netConn_projEI_ampa[1214] = new NetCon(&v(0.5), syn_projEI_ampa[1214], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1215: cell 60, seg 0 (0.5) [0.5 on Epop[60]] -> cell 15, seg 0 (0.5) [0.5 on Ipop[15]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[15] syn_projEI_ampa[1215] = new ampa(0.5)")
        h("Epop[60] netConn_projEI_ampa[1215] = new NetCon(&v(0.5), syn_projEI_ampa[1215], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1216: cell 60, seg 0 (0.5) [0.5 on Epop[60]] -> cell 16, seg 0 (0.5) [0.5 on Ipop[16]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[16] syn_projEI_ampa[1216] = new ampa(0.5)")
        h("Epop[60] netConn_projEI_ampa[1216] = new NetCon(&v(0.5), syn_projEI_ampa[1216], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1217: cell 60, seg 0 (0.5) [0.5 on Epop[60]] -> cell 17, seg 0 (0.5) [0.5 on Ipop[17]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[17] syn_projEI_ampa[1217] = new ampa(0.5)")
        h("Epop[60] netConn_projEI_ampa[1217] = new NetCon(&v(0.5), syn_projEI_ampa[1217], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1218: cell 60, seg 0 (0.5) [0.5 on Epop[60]] -> cell 18, seg 0 (0.5) [0.5 on Ipop[18]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[18] syn_projEI_ampa[1218] = new ampa(0.5)")
        h("Epop[60] netConn_projEI_ampa[1218] = new NetCon(&v(0.5), syn_projEI_ampa[1218], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1219: cell 60, seg 0 (0.5) [0.5 on Epop[60]] -> cell 19, seg 0 (0.5) [0.5 on Ipop[19]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[19] syn_projEI_ampa[1219] = new ampa(0.5)")
        h("Epop[60] netConn_projEI_ampa[1219] = new NetCon(&v(0.5), syn_projEI_ampa[1219], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1220: cell 61, seg 0 (0.5) [0.5 on Epop[61]] -> cell 0, seg 0 (0.5) [0.5 on Ipop[0]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[0] syn_projEI_ampa[1220] = new ampa(0.5)")
        h("Epop[61] netConn_projEI_ampa[1220] = new NetCon(&v(0.5), syn_projEI_ampa[1220], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1221: cell 61, seg 0 (0.5) [0.5 on Epop[61]] -> cell 1, seg 0 (0.5) [0.5 on Ipop[1]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[1] syn_projEI_ampa[1221] = new ampa(0.5)")
        h("Epop[61] netConn_projEI_ampa[1221] = new NetCon(&v(0.5), syn_projEI_ampa[1221], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1222: cell 61, seg 0 (0.5) [0.5 on Epop[61]] -> cell 2, seg 0 (0.5) [0.5 on Ipop[2]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[2] syn_projEI_ampa[1222] = new ampa(0.5)")
        h("Epop[61] netConn_projEI_ampa[1222] = new NetCon(&v(0.5), syn_projEI_ampa[1222], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1223: cell 61, seg 0 (0.5) [0.5 on Epop[61]] -> cell 3, seg 0 (0.5) [0.5 on Ipop[3]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[3] syn_projEI_ampa[1223] = new ampa(0.5)")
        h("Epop[61] netConn_projEI_ampa[1223] = new NetCon(&v(0.5), syn_projEI_ampa[1223], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1224: cell 61, seg 0 (0.5) [0.5 on Epop[61]] -> cell 4, seg 0 (0.5) [0.5 on Ipop[4]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[4] syn_projEI_ampa[1224] = new ampa(0.5)")
        h("Epop[61] netConn_projEI_ampa[1224] = new NetCon(&v(0.5), syn_projEI_ampa[1224], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1225: cell 61, seg 0 (0.5) [0.5 on Epop[61]] -> cell 5, seg 0 (0.5) [0.5 on Ipop[5]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[5] syn_projEI_ampa[1225] = new ampa(0.5)")
        h("Epop[61] netConn_projEI_ampa[1225] = new NetCon(&v(0.5), syn_projEI_ampa[1225], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1226: cell 61, seg 0 (0.5) [0.5 on Epop[61]] -> cell 6, seg 0 (0.5) [0.5 on Ipop[6]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[6] syn_projEI_ampa[1226] = new ampa(0.5)")
        h("Epop[61] netConn_projEI_ampa[1226] = new NetCon(&v(0.5), syn_projEI_ampa[1226], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1227: cell 61, seg 0 (0.5) [0.5 on Epop[61]] -> cell 7, seg 0 (0.5) [0.5 on Ipop[7]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[7] syn_projEI_ampa[1227] = new ampa(0.5)")
        h("Epop[61] netConn_projEI_ampa[1227] = new NetCon(&v(0.5), syn_projEI_ampa[1227], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1228: cell 61, seg 0 (0.5) [0.5 on Epop[61]] -> cell 8, seg 0 (0.5) [0.5 on Ipop[8]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[8] syn_projEI_ampa[1228] = new ampa(0.5)")
        h("Epop[61] netConn_projEI_ampa[1228] = new NetCon(&v(0.5), syn_projEI_ampa[1228], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1229: cell 61, seg 0 (0.5) [0.5 on Epop[61]] -> cell 9, seg 0 (0.5) [0.5 on Ipop[9]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[9] syn_projEI_ampa[1229] = new ampa(0.5)")
        h("Epop[61] netConn_projEI_ampa[1229] = new NetCon(&v(0.5), syn_projEI_ampa[1229], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1230: cell 61, seg 0 (0.5) [0.5 on Epop[61]] -> cell 10, seg 0 (0.5) [0.5 on Ipop[10]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[10] syn_projEI_ampa[1230] = new ampa(0.5)")
        h("Epop[61] netConn_projEI_ampa[1230] = new NetCon(&v(0.5), syn_projEI_ampa[1230], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1231: cell 61, seg 0 (0.5) [0.5 on Epop[61]] -> cell 11, seg 0 (0.5) [0.5 on Ipop[11]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[11] syn_projEI_ampa[1231] = new ampa(0.5)")
        h("Epop[61] netConn_projEI_ampa[1231] = new NetCon(&v(0.5), syn_projEI_ampa[1231], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1232: cell 61, seg 0 (0.5) [0.5 on Epop[61]] -> cell 12, seg 0 (0.5) [0.5 on Ipop[12]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[12] syn_projEI_ampa[1232] = new ampa(0.5)")
        h("Epop[61] netConn_projEI_ampa[1232] = new NetCon(&v(0.5), syn_projEI_ampa[1232], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1233: cell 61, seg 0 (0.5) [0.5 on Epop[61]] -> cell 13, seg 0 (0.5) [0.5 on Ipop[13]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[13] syn_projEI_ampa[1233] = new ampa(0.5)")
        h("Epop[61] netConn_projEI_ampa[1233] = new NetCon(&v(0.5), syn_projEI_ampa[1233], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1234: cell 61, seg 0 (0.5) [0.5 on Epop[61]] -> cell 14, seg 0 (0.5) [0.5 on Ipop[14]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[14] syn_projEI_ampa[1234] = new ampa(0.5)")
        h("Epop[61] netConn_projEI_ampa[1234] = new NetCon(&v(0.5), syn_projEI_ampa[1234], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1235: cell 61, seg 0 (0.5) [0.5 on Epop[61]] -> cell 15, seg 0 (0.5) [0.5 on Ipop[15]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[15] syn_projEI_ampa[1235] = new ampa(0.5)")
        h("Epop[61] netConn_projEI_ampa[1235] = new NetCon(&v(0.5), syn_projEI_ampa[1235], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1236: cell 61, seg 0 (0.5) [0.5 on Epop[61]] -> cell 16, seg 0 (0.5) [0.5 on Ipop[16]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[16] syn_projEI_ampa[1236] = new ampa(0.5)")
        h("Epop[61] netConn_projEI_ampa[1236] = new NetCon(&v(0.5), syn_projEI_ampa[1236], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1237: cell 61, seg 0 (0.5) [0.5 on Epop[61]] -> cell 17, seg 0 (0.5) [0.5 on Ipop[17]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[17] syn_projEI_ampa[1237] = new ampa(0.5)")
        h("Epop[61] netConn_projEI_ampa[1237] = new NetCon(&v(0.5), syn_projEI_ampa[1237], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1238: cell 61, seg 0 (0.5) [0.5 on Epop[61]] -> cell 18, seg 0 (0.5) [0.5 on Ipop[18]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[18] syn_projEI_ampa[1238] = new ampa(0.5)")
        h("Epop[61] netConn_projEI_ampa[1238] = new NetCon(&v(0.5), syn_projEI_ampa[1238], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1239: cell 61, seg 0 (0.5) [0.5 on Epop[61]] -> cell 19, seg 0 (0.5) [0.5 on Ipop[19]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[19] syn_projEI_ampa[1239] = new ampa(0.5)")
        h("Epop[61] netConn_projEI_ampa[1239] = new NetCon(&v(0.5), syn_projEI_ampa[1239], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1240: cell 62, seg 0 (0.5) [0.5 on Epop[62]] -> cell 0, seg 0 (0.5) [0.5 on Ipop[0]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[0] syn_projEI_ampa[1240] = new ampa(0.5)")
        h("Epop[62] netConn_projEI_ampa[1240] = new NetCon(&v(0.5), syn_projEI_ampa[1240], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1241: cell 62, seg 0 (0.5) [0.5 on Epop[62]] -> cell 1, seg 0 (0.5) [0.5 on Ipop[1]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[1] syn_projEI_ampa[1241] = new ampa(0.5)")
        h("Epop[62] netConn_projEI_ampa[1241] = new NetCon(&v(0.5), syn_projEI_ampa[1241], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1242: cell 62, seg 0 (0.5) [0.5 on Epop[62]] -> cell 2, seg 0 (0.5) [0.5 on Ipop[2]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[2] syn_projEI_ampa[1242] = new ampa(0.5)")
        h("Epop[62] netConn_projEI_ampa[1242] = new NetCon(&v(0.5), syn_projEI_ampa[1242], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1243: cell 62, seg 0 (0.5) [0.5 on Epop[62]] -> cell 3, seg 0 (0.5) [0.5 on Ipop[3]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[3] syn_projEI_ampa[1243] = new ampa(0.5)")
        h("Epop[62] netConn_projEI_ampa[1243] = new NetCon(&v(0.5), syn_projEI_ampa[1243], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1244: cell 62, seg 0 (0.5) [0.5 on Epop[62]] -> cell 4, seg 0 (0.5) [0.5 on Ipop[4]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[4] syn_projEI_ampa[1244] = new ampa(0.5)")
        h("Epop[62] netConn_projEI_ampa[1244] = new NetCon(&v(0.5), syn_projEI_ampa[1244], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1245: cell 62, seg 0 (0.5) [0.5 on Epop[62]] -> cell 5, seg 0 (0.5) [0.5 on Ipop[5]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[5] syn_projEI_ampa[1245] = new ampa(0.5)")
        h("Epop[62] netConn_projEI_ampa[1245] = new NetCon(&v(0.5), syn_projEI_ampa[1245], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1246: cell 62, seg 0 (0.5) [0.5 on Epop[62]] -> cell 6, seg 0 (0.5) [0.5 on Ipop[6]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[6] syn_projEI_ampa[1246] = new ampa(0.5)")
        h("Epop[62] netConn_projEI_ampa[1246] = new NetCon(&v(0.5), syn_projEI_ampa[1246], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1247: cell 62, seg 0 (0.5) [0.5 on Epop[62]] -> cell 7, seg 0 (0.5) [0.5 on Ipop[7]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[7] syn_projEI_ampa[1247] = new ampa(0.5)")
        h("Epop[62] netConn_projEI_ampa[1247] = new NetCon(&v(0.5), syn_projEI_ampa[1247], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1248: cell 62, seg 0 (0.5) [0.5 on Epop[62]] -> cell 8, seg 0 (0.5) [0.5 on Ipop[8]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[8] syn_projEI_ampa[1248] = new ampa(0.5)")
        h("Epop[62] netConn_projEI_ampa[1248] = new NetCon(&v(0.5), syn_projEI_ampa[1248], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1249: cell 62, seg 0 (0.5) [0.5 on Epop[62]] -> cell 9, seg 0 (0.5) [0.5 on Ipop[9]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[9] syn_projEI_ampa[1249] = new ampa(0.5)")
        h("Epop[62] netConn_projEI_ampa[1249] = new NetCon(&v(0.5), syn_projEI_ampa[1249], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1250: cell 62, seg 0 (0.5) [0.5 on Epop[62]] -> cell 10, seg 0 (0.5) [0.5 on Ipop[10]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[10] syn_projEI_ampa[1250] = new ampa(0.5)")
        h("Epop[62] netConn_projEI_ampa[1250] = new NetCon(&v(0.5), syn_projEI_ampa[1250], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1251: cell 62, seg 0 (0.5) [0.5 on Epop[62]] -> cell 11, seg 0 (0.5) [0.5 on Ipop[11]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[11] syn_projEI_ampa[1251] = new ampa(0.5)")
        h("Epop[62] netConn_projEI_ampa[1251] = new NetCon(&v(0.5), syn_projEI_ampa[1251], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1252: cell 62, seg 0 (0.5) [0.5 on Epop[62]] -> cell 12, seg 0 (0.5) [0.5 on Ipop[12]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[12] syn_projEI_ampa[1252] = new ampa(0.5)")
        h("Epop[62] netConn_projEI_ampa[1252] = new NetCon(&v(0.5), syn_projEI_ampa[1252], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1253: cell 62, seg 0 (0.5) [0.5 on Epop[62]] -> cell 13, seg 0 (0.5) [0.5 on Ipop[13]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[13] syn_projEI_ampa[1253] = new ampa(0.5)")
        h("Epop[62] netConn_projEI_ampa[1253] = new NetCon(&v(0.5), syn_projEI_ampa[1253], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1254: cell 62, seg 0 (0.5) [0.5 on Epop[62]] -> cell 14, seg 0 (0.5) [0.5 on Ipop[14]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[14] syn_projEI_ampa[1254] = new ampa(0.5)")
        h("Epop[62] netConn_projEI_ampa[1254] = new NetCon(&v(0.5), syn_projEI_ampa[1254], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1255: cell 62, seg 0 (0.5) [0.5 on Epop[62]] -> cell 15, seg 0 (0.5) [0.5 on Ipop[15]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[15] syn_projEI_ampa[1255] = new ampa(0.5)")
        h("Epop[62] netConn_projEI_ampa[1255] = new NetCon(&v(0.5), syn_projEI_ampa[1255], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1256: cell 62, seg 0 (0.5) [0.5 on Epop[62]] -> cell 16, seg 0 (0.5) [0.5 on Ipop[16]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[16] syn_projEI_ampa[1256] = new ampa(0.5)")
        h("Epop[62] netConn_projEI_ampa[1256] = new NetCon(&v(0.5), syn_projEI_ampa[1256], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1257: cell 62, seg 0 (0.5) [0.5 on Epop[62]] -> cell 17, seg 0 (0.5) [0.5 on Ipop[17]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[17] syn_projEI_ampa[1257] = new ampa(0.5)")
        h("Epop[62] netConn_projEI_ampa[1257] = new NetCon(&v(0.5), syn_projEI_ampa[1257], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1258: cell 62, seg 0 (0.5) [0.5 on Epop[62]] -> cell 18, seg 0 (0.5) [0.5 on Ipop[18]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[18] syn_projEI_ampa[1258] = new ampa(0.5)")
        h("Epop[62] netConn_projEI_ampa[1258] = new NetCon(&v(0.5), syn_projEI_ampa[1258], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1259: cell 62, seg 0 (0.5) [0.5 on Epop[62]] -> cell 19, seg 0 (0.5) [0.5 on Ipop[19]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[19] syn_projEI_ampa[1259] = new ampa(0.5)")
        h("Epop[62] netConn_projEI_ampa[1259] = new NetCon(&v(0.5), syn_projEI_ampa[1259], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1260: cell 63, seg 0 (0.5) [0.5 on Epop[63]] -> cell 0, seg 0 (0.5) [0.5 on Ipop[0]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[0] syn_projEI_ampa[1260] = new ampa(0.5)")
        h("Epop[63] netConn_projEI_ampa[1260] = new NetCon(&v(0.5), syn_projEI_ampa[1260], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1261: cell 63, seg 0 (0.5) [0.5 on Epop[63]] -> cell 1, seg 0 (0.5) [0.5 on Ipop[1]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[1] syn_projEI_ampa[1261] = new ampa(0.5)")
        h("Epop[63] netConn_projEI_ampa[1261] = new NetCon(&v(0.5), syn_projEI_ampa[1261], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1262: cell 63, seg 0 (0.5) [0.5 on Epop[63]] -> cell 2, seg 0 (0.5) [0.5 on Ipop[2]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[2] syn_projEI_ampa[1262] = new ampa(0.5)")
        h("Epop[63] netConn_projEI_ampa[1262] = new NetCon(&v(0.5), syn_projEI_ampa[1262], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1263: cell 63, seg 0 (0.5) [0.5 on Epop[63]] -> cell 3, seg 0 (0.5) [0.5 on Ipop[3]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[3] syn_projEI_ampa[1263] = new ampa(0.5)")
        h("Epop[63] netConn_projEI_ampa[1263] = new NetCon(&v(0.5), syn_projEI_ampa[1263], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1264: cell 63, seg 0 (0.5) [0.5 on Epop[63]] -> cell 4, seg 0 (0.5) [0.5 on Ipop[4]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[4] syn_projEI_ampa[1264] = new ampa(0.5)")
        h("Epop[63] netConn_projEI_ampa[1264] = new NetCon(&v(0.5), syn_projEI_ampa[1264], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1265: cell 63, seg 0 (0.5) [0.5 on Epop[63]] -> cell 5, seg 0 (0.5) [0.5 on Ipop[5]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[5] syn_projEI_ampa[1265] = new ampa(0.5)")
        h("Epop[63] netConn_projEI_ampa[1265] = new NetCon(&v(0.5), syn_projEI_ampa[1265], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1266: cell 63, seg 0 (0.5) [0.5 on Epop[63]] -> cell 6, seg 0 (0.5) [0.5 on Ipop[6]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[6] syn_projEI_ampa[1266] = new ampa(0.5)")
        h("Epop[63] netConn_projEI_ampa[1266] = new NetCon(&v(0.5), syn_projEI_ampa[1266], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1267: cell 63, seg 0 (0.5) [0.5 on Epop[63]] -> cell 7, seg 0 (0.5) [0.5 on Ipop[7]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[7] syn_projEI_ampa[1267] = new ampa(0.5)")
        h("Epop[63] netConn_projEI_ampa[1267] = new NetCon(&v(0.5), syn_projEI_ampa[1267], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1268: cell 63, seg 0 (0.5) [0.5 on Epop[63]] -> cell 8, seg 0 (0.5) [0.5 on Ipop[8]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[8] syn_projEI_ampa[1268] = new ampa(0.5)")
        h("Epop[63] netConn_projEI_ampa[1268] = new NetCon(&v(0.5), syn_projEI_ampa[1268], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1269: cell 63, seg 0 (0.5) [0.5 on Epop[63]] -> cell 9, seg 0 (0.5) [0.5 on Ipop[9]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[9] syn_projEI_ampa[1269] = new ampa(0.5)")
        h("Epop[63] netConn_projEI_ampa[1269] = new NetCon(&v(0.5), syn_projEI_ampa[1269], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1270: cell 63, seg 0 (0.5) [0.5 on Epop[63]] -> cell 10, seg 0 (0.5) [0.5 on Ipop[10]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[10] syn_projEI_ampa[1270] = new ampa(0.5)")
        h("Epop[63] netConn_projEI_ampa[1270] = new NetCon(&v(0.5), syn_projEI_ampa[1270], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1271: cell 63, seg 0 (0.5) [0.5 on Epop[63]] -> cell 11, seg 0 (0.5) [0.5 on Ipop[11]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[11] syn_projEI_ampa[1271] = new ampa(0.5)")
        h("Epop[63] netConn_projEI_ampa[1271] = new NetCon(&v(0.5), syn_projEI_ampa[1271], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1272: cell 63, seg 0 (0.5) [0.5 on Epop[63]] -> cell 12, seg 0 (0.5) [0.5 on Ipop[12]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[12] syn_projEI_ampa[1272] = new ampa(0.5)")
        h("Epop[63] netConn_projEI_ampa[1272] = new NetCon(&v(0.5), syn_projEI_ampa[1272], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1273: cell 63, seg 0 (0.5) [0.5 on Epop[63]] -> cell 13, seg 0 (0.5) [0.5 on Ipop[13]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[13] syn_projEI_ampa[1273] = new ampa(0.5)")
        h("Epop[63] netConn_projEI_ampa[1273] = new NetCon(&v(0.5), syn_projEI_ampa[1273], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1274: cell 63, seg 0 (0.5) [0.5 on Epop[63]] -> cell 14, seg 0 (0.5) [0.5 on Ipop[14]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[14] syn_projEI_ampa[1274] = new ampa(0.5)")
        h("Epop[63] netConn_projEI_ampa[1274] = new NetCon(&v(0.5), syn_projEI_ampa[1274], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1275: cell 63, seg 0 (0.5) [0.5 on Epop[63]] -> cell 15, seg 0 (0.5) [0.5 on Ipop[15]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[15] syn_projEI_ampa[1275] = new ampa(0.5)")
        h("Epop[63] netConn_projEI_ampa[1275] = new NetCon(&v(0.5), syn_projEI_ampa[1275], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1276: cell 63, seg 0 (0.5) [0.5 on Epop[63]] -> cell 16, seg 0 (0.5) [0.5 on Ipop[16]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[16] syn_projEI_ampa[1276] = new ampa(0.5)")
        h("Epop[63] netConn_projEI_ampa[1276] = new NetCon(&v(0.5), syn_projEI_ampa[1276], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1277: cell 63, seg 0 (0.5) [0.5 on Epop[63]] -> cell 17, seg 0 (0.5) [0.5 on Ipop[17]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[17] syn_projEI_ampa[1277] = new ampa(0.5)")
        h("Epop[63] netConn_projEI_ampa[1277] = new NetCon(&v(0.5), syn_projEI_ampa[1277], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1278: cell 63, seg 0 (0.5) [0.5 on Epop[63]] -> cell 18, seg 0 (0.5) [0.5 on Ipop[18]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[18] syn_projEI_ampa[1278] = new ampa(0.5)")
        h("Epop[63] netConn_projEI_ampa[1278] = new NetCon(&v(0.5), syn_projEI_ampa[1278], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1279: cell 63, seg 0 (0.5) [0.5 on Epop[63]] -> cell 19, seg 0 (0.5) [0.5 on Ipop[19]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[19] syn_projEI_ampa[1279] = new ampa(0.5)")
        h("Epop[63] netConn_projEI_ampa[1279] = new NetCon(&v(0.5), syn_projEI_ampa[1279], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1280: cell 64, seg 0 (0.5) [0.5 on Epop[64]] -> cell 0, seg 0 (0.5) [0.5 on Ipop[0]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[0] syn_projEI_ampa[1280] = new ampa(0.5)")
        h("Epop[64] netConn_projEI_ampa[1280] = new NetCon(&v(0.5), syn_projEI_ampa[1280], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1281: cell 64, seg 0 (0.5) [0.5 on Epop[64]] -> cell 1, seg 0 (0.5) [0.5 on Ipop[1]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[1] syn_projEI_ampa[1281] = new ampa(0.5)")
        h("Epop[64] netConn_projEI_ampa[1281] = new NetCon(&v(0.5), syn_projEI_ampa[1281], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1282: cell 64, seg 0 (0.5) [0.5 on Epop[64]] -> cell 2, seg 0 (0.5) [0.5 on Ipop[2]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[2] syn_projEI_ampa[1282] = new ampa(0.5)")
        h("Epop[64] netConn_projEI_ampa[1282] = new NetCon(&v(0.5), syn_projEI_ampa[1282], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1283: cell 64, seg 0 (0.5) [0.5 on Epop[64]] -> cell 3, seg 0 (0.5) [0.5 on Ipop[3]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[3] syn_projEI_ampa[1283] = new ampa(0.5)")
        h("Epop[64] netConn_projEI_ampa[1283] = new NetCon(&v(0.5), syn_projEI_ampa[1283], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1284: cell 64, seg 0 (0.5) [0.5 on Epop[64]] -> cell 4, seg 0 (0.5) [0.5 on Ipop[4]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[4] syn_projEI_ampa[1284] = new ampa(0.5)")
        h("Epop[64] netConn_projEI_ampa[1284] = new NetCon(&v(0.5), syn_projEI_ampa[1284], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1285: cell 64, seg 0 (0.5) [0.5 on Epop[64]] -> cell 5, seg 0 (0.5) [0.5 on Ipop[5]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[5] syn_projEI_ampa[1285] = new ampa(0.5)")
        h("Epop[64] netConn_projEI_ampa[1285] = new NetCon(&v(0.5), syn_projEI_ampa[1285], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1286: cell 64, seg 0 (0.5) [0.5 on Epop[64]] -> cell 6, seg 0 (0.5) [0.5 on Ipop[6]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[6] syn_projEI_ampa[1286] = new ampa(0.5)")
        h("Epop[64] netConn_projEI_ampa[1286] = new NetCon(&v(0.5), syn_projEI_ampa[1286], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1287: cell 64, seg 0 (0.5) [0.5 on Epop[64]] -> cell 7, seg 0 (0.5) [0.5 on Ipop[7]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[7] syn_projEI_ampa[1287] = new ampa(0.5)")
        h("Epop[64] netConn_projEI_ampa[1287] = new NetCon(&v(0.5), syn_projEI_ampa[1287], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1288: cell 64, seg 0 (0.5) [0.5 on Epop[64]] -> cell 8, seg 0 (0.5) [0.5 on Ipop[8]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[8] syn_projEI_ampa[1288] = new ampa(0.5)")
        h("Epop[64] netConn_projEI_ampa[1288] = new NetCon(&v(0.5), syn_projEI_ampa[1288], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1289: cell 64, seg 0 (0.5) [0.5 on Epop[64]] -> cell 9, seg 0 (0.5) [0.5 on Ipop[9]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[9] syn_projEI_ampa[1289] = new ampa(0.5)")
        h("Epop[64] netConn_projEI_ampa[1289] = new NetCon(&v(0.5), syn_projEI_ampa[1289], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1290: cell 64, seg 0 (0.5) [0.5 on Epop[64]] -> cell 10, seg 0 (0.5) [0.5 on Ipop[10]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[10] syn_projEI_ampa[1290] = new ampa(0.5)")
        h("Epop[64] netConn_projEI_ampa[1290] = new NetCon(&v(0.5), syn_projEI_ampa[1290], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1291: cell 64, seg 0 (0.5) [0.5 on Epop[64]] -> cell 11, seg 0 (0.5) [0.5 on Ipop[11]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[11] syn_projEI_ampa[1291] = new ampa(0.5)")
        h("Epop[64] netConn_projEI_ampa[1291] = new NetCon(&v(0.5), syn_projEI_ampa[1291], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1292: cell 64, seg 0 (0.5) [0.5 on Epop[64]] -> cell 12, seg 0 (0.5) [0.5 on Ipop[12]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[12] syn_projEI_ampa[1292] = new ampa(0.5)")
        h("Epop[64] netConn_projEI_ampa[1292] = new NetCon(&v(0.5), syn_projEI_ampa[1292], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1293: cell 64, seg 0 (0.5) [0.5 on Epop[64]] -> cell 13, seg 0 (0.5) [0.5 on Ipop[13]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[13] syn_projEI_ampa[1293] = new ampa(0.5)")
        h("Epop[64] netConn_projEI_ampa[1293] = new NetCon(&v(0.5), syn_projEI_ampa[1293], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1294: cell 64, seg 0 (0.5) [0.5 on Epop[64]] -> cell 14, seg 0 (0.5) [0.5 on Ipop[14]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[14] syn_projEI_ampa[1294] = new ampa(0.5)")
        h("Epop[64] netConn_projEI_ampa[1294] = new NetCon(&v(0.5), syn_projEI_ampa[1294], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1295: cell 64, seg 0 (0.5) [0.5 on Epop[64]] -> cell 15, seg 0 (0.5) [0.5 on Ipop[15]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[15] syn_projEI_ampa[1295] = new ampa(0.5)")
        h("Epop[64] netConn_projEI_ampa[1295] = new NetCon(&v(0.5), syn_projEI_ampa[1295], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1296: cell 64, seg 0 (0.5) [0.5 on Epop[64]] -> cell 16, seg 0 (0.5) [0.5 on Ipop[16]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[16] syn_projEI_ampa[1296] = new ampa(0.5)")
        h("Epop[64] netConn_projEI_ampa[1296] = new NetCon(&v(0.5), syn_projEI_ampa[1296], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1297: cell 64, seg 0 (0.5) [0.5 on Epop[64]] -> cell 17, seg 0 (0.5) [0.5 on Ipop[17]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[17] syn_projEI_ampa[1297] = new ampa(0.5)")
        h("Epop[64] netConn_projEI_ampa[1297] = new NetCon(&v(0.5), syn_projEI_ampa[1297], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1298: cell 64, seg 0 (0.5) [0.5 on Epop[64]] -> cell 18, seg 0 (0.5) [0.5 on Ipop[18]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[18] syn_projEI_ampa[1298] = new ampa(0.5)")
        h("Epop[64] netConn_projEI_ampa[1298] = new NetCon(&v(0.5), syn_projEI_ampa[1298], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1299: cell 64, seg 0 (0.5) [0.5 on Epop[64]] -> cell 19, seg 0 (0.5) [0.5 on Ipop[19]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[19] syn_projEI_ampa[1299] = new ampa(0.5)")
        h("Epop[64] netConn_projEI_ampa[1299] = new NetCon(&v(0.5), syn_projEI_ampa[1299], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1300: cell 65, seg 0 (0.5) [0.5 on Epop[65]] -> cell 0, seg 0 (0.5) [0.5 on Ipop[0]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[0] syn_projEI_ampa[1300] = new ampa(0.5)")
        h("Epop[65] netConn_projEI_ampa[1300] = new NetCon(&v(0.5), syn_projEI_ampa[1300], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1301: cell 65, seg 0 (0.5) [0.5 on Epop[65]] -> cell 1, seg 0 (0.5) [0.5 on Ipop[1]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[1] syn_projEI_ampa[1301] = new ampa(0.5)")
        h("Epop[65] netConn_projEI_ampa[1301] = new NetCon(&v(0.5), syn_projEI_ampa[1301], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1302: cell 65, seg 0 (0.5) [0.5 on Epop[65]] -> cell 2, seg 0 (0.5) [0.5 on Ipop[2]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[2] syn_projEI_ampa[1302] = new ampa(0.5)")
        h("Epop[65] netConn_projEI_ampa[1302] = new NetCon(&v(0.5), syn_projEI_ampa[1302], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1303: cell 65, seg 0 (0.5) [0.5 on Epop[65]] -> cell 3, seg 0 (0.5) [0.5 on Ipop[3]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[3] syn_projEI_ampa[1303] = new ampa(0.5)")
        h("Epop[65] netConn_projEI_ampa[1303] = new NetCon(&v(0.5), syn_projEI_ampa[1303], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1304: cell 65, seg 0 (0.5) [0.5 on Epop[65]] -> cell 4, seg 0 (0.5) [0.5 on Ipop[4]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[4] syn_projEI_ampa[1304] = new ampa(0.5)")
        h("Epop[65] netConn_projEI_ampa[1304] = new NetCon(&v(0.5), syn_projEI_ampa[1304], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1305: cell 65, seg 0 (0.5) [0.5 on Epop[65]] -> cell 5, seg 0 (0.5) [0.5 on Ipop[5]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[5] syn_projEI_ampa[1305] = new ampa(0.5)")
        h("Epop[65] netConn_projEI_ampa[1305] = new NetCon(&v(0.5), syn_projEI_ampa[1305], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1306: cell 65, seg 0 (0.5) [0.5 on Epop[65]] -> cell 6, seg 0 (0.5) [0.5 on Ipop[6]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[6] syn_projEI_ampa[1306] = new ampa(0.5)")
        h("Epop[65] netConn_projEI_ampa[1306] = new NetCon(&v(0.5), syn_projEI_ampa[1306], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1307: cell 65, seg 0 (0.5) [0.5 on Epop[65]] -> cell 7, seg 0 (0.5) [0.5 on Ipop[7]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[7] syn_projEI_ampa[1307] = new ampa(0.5)")
        h("Epop[65] netConn_projEI_ampa[1307] = new NetCon(&v(0.5), syn_projEI_ampa[1307], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1308: cell 65, seg 0 (0.5) [0.5 on Epop[65]] -> cell 8, seg 0 (0.5) [0.5 on Ipop[8]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[8] syn_projEI_ampa[1308] = new ampa(0.5)")
        h("Epop[65] netConn_projEI_ampa[1308] = new NetCon(&v(0.5), syn_projEI_ampa[1308], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1309: cell 65, seg 0 (0.5) [0.5 on Epop[65]] -> cell 9, seg 0 (0.5) [0.5 on Ipop[9]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[9] syn_projEI_ampa[1309] = new ampa(0.5)")
        h("Epop[65] netConn_projEI_ampa[1309] = new NetCon(&v(0.5), syn_projEI_ampa[1309], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1310: cell 65, seg 0 (0.5) [0.5 on Epop[65]] -> cell 10, seg 0 (0.5) [0.5 on Ipop[10]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[10] syn_projEI_ampa[1310] = new ampa(0.5)")
        h("Epop[65] netConn_projEI_ampa[1310] = new NetCon(&v(0.5), syn_projEI_ampa[1310], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1311: cell 65, seg 0 (0.5) [0.5 on Epop[65]] -> cell 11, seg 0 (0.5) [0.5 on Ipop[11]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[11] syn_projEI_ampa[1311] = new ampa(0.5)")
        h("Epop[65] netConn_projEI_ampa[1311] = new NetCon(&v(0.5), syn_projEI_ampa[1311], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1312: cell 65, seg 0 (0.5) [0.5 on Epop[65]] -> cell 12, seg 0 (0.5) [0.5 on Ipop[12]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[12] syn_projEI_ampa[1312] = new ampa(0.5)")
        h("Epop[65] netConn_projEI_ampa[1312] = new NetCon(&v(0.5), syn_projEI_ampa[1312], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1313: cell 65, seg 0 (0.5) [0.5 on Epop[65]] -> cell 13, seg 0 (0.5) [0.5 on Ipop[13]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[13] syn_projEI_ampa[1313] = new ampa(0.5)")
        h("Epop[65] netConn_projEI_ampa[1313] = new NetCon(&v(0.5), syn_projEI_ampa[1313], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1314: cell 65, seg 0 (0.5) [0.5 on Epop[65]] -> cell 14, seg 0 (0.5) [0.5 on Ipop[14]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[14] syn_projEI_ampa[1314] = new ampa(0.5)")
        h("Epop[65] netConn_projEI_ampa[1314] = new NetCon(&v(0.5), syn_projEI_ampa[1314], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1315: cell 65, seg 0 (0.5) [0.5 on Epop[65]] -> cell 15, seg 0 (0.5) [0.5 on Ipop[15]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[15] syn_projEI_ampa[1315] = new ampa(0.5)")
        h("Epop[65] netConn_projEI_ampa[1315] = new NetCon(&v(0.5), syn_projEI_ampa[1315], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1316: cell 65, seg 0 (0.5) [0.5 on Epop[65]] -> cell 16, seg 0 (0.5) [0.5 on Ipop[16]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[16] syn_projEI_ampa[1316] = new ampa(0.5)")
        h("Epop[65] netConn_projEI_ampa[1316] = new NetCon(&v(0.5), syn_projEI_ampa[1316], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1317: cell 65, seg 0 (0.5) [0.5 on Epop[65]] -> cell 17, seg 0 (0.5) [0.5 on Ipop[17]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[17] syn_projEI_ampa[1317] = new ampa(0.5)")
        h("Epop[65] netConn_projEI_ampa[1317] = new NetCon(&v(0.5), syn_projEI_ampa[1317], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1318: cell 65, seg 0 (0.5) [0.5 on Epop[65]] -> cell 18, seg 0 (0.5) [0.5 on Ipop[18]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[18] syn_projEI_ampa[1318] = new ampa(0.5)")
        h("Epop[65] netConn_projEI_ampa[1318] = new NetCon(&v(0.5), syn_projEI_ampa[1318], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1319: cell 65, seg 0 (0.5) [0.5 on Epop[65]] -> cell 19, seg 0 (0.5) [0.5 on Ipop[19]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[19] syn_projEI_ampa[1319] = new ampa(0.5)")
        h("Epop[65] netConn_projEI_ampa[1319] = new NetCon(&v(0.5), syn_projEI_ampa[1319], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1320: cell 66, seg 0 (0.5) [0.5 on Epop[66]] -> cell 0, seg 0 (0.5) [0.5 on Ipop[0]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[0] syn_projEI_ampa[1320] = new ampa(0.5)")
        h("Epop[66] netConn_projEI_ampa[1320] = new NetCon(&v(0.5), syn_projEI_ampa[1320], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1321: cell 66, seg 0 (0.5) [0.5 on Epop[66]] -> cell 1, seg 0 (0.5) [0.5 on Ipop[1]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[1] syn_projEI_ampa[1321] = new ampa(0.5)")
        h("Epop[66] netConn_projEI_ampa[1321] = new NetCon(&v(0.5), syn_projEI_ampa[1321], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1322: cell 66, seg 0 (0.5) [0.5 on Epop[66]] -> cell 2, seg 0 (0.5) [0.5 on Ipop[2]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[2] syn_projEI_ampa[1322] = new ampa(0.5)")
        h("Epop[66] netConn_projEI_ampa[1322] = new NetCon(&v(0.5), syn_projEI_ampa[1322], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1323: cell 66, seg 0 (0.5) [0.5 on Epop[66]] -> cell 3, seg 0 (0.5) [0.5 on Ipop[3]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[3] syn_projEI_ampa[1323] = new ampa(0.5)")
        h("Epop[66] netConn_projEI_ampa[1323] = new NetCon(&v(0.5), syn_projEI_ampa[1323], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1324: cell 66, seg 0 (0.5) [0.5 on Epop[66]] -> cell 4, seg 0 (0.5) [0.5 on Ipop[4]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[4] syn_projEI_ampa[1324] = new ampa(0.5)")
        h("Epop[66] netConn_projEI_ampa[1324] = new NetCon(&v(0.5), syn_projEI_ampa[1324], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1325: cell 66, seg 0 (0.5) [0.5 on Epop[66]] -> cell 5, seg 0 (0.5) [0.5 on Ipop[5]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[5] syn_projEI_ampa[1325] = new ampa(0.5)")
        h("Epop[66] netConn_projEI_ampa[1325] = new NetCon(&v(0.5), syn_projEI_ampa[1325], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1326: cell 66, seg 0 (0.5) [0.5 on Epop[66]] -> cell 6, seg 0 (0.5) [0.5 on Ipop[6]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[6] syn_projEI_ampa[1326] = new ampa(0.5)")
        h("Epop[66] netConn_projEI_ampa[1326] = new NetCon(&v(0.5), syn_projEI_ampa[1326], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1327: cell 66, seg 0 (0.5) [0.5 on Epop[66]] -> cell 7, seg 0 (0.5) [0.5 on Ipop[7]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[7] syn_projEI_ampa[1327] = new ampa(0.5)")
        h("Epop[66] netConn_projEI_ampa[1327] = new NetCon(&v(0.5), syn_projEI_ampa[1327], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1328: cell 66, seg 0 (0.5) [0.5 on Epop[66]] -> cell 8, seg 0 (0.5) [0.5 on Ipop[8]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[8] syn_projEI_ampa[1328] = new ampa(0.5)")
        h("Epop[66] netConn_projEI_ampa[1328] = new NetCon(&v(0.5), syn_projEI_ampa[1328], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1329: cell 66, seg 0 (0.5) [0.5 on Epop[66]] -> cell 9, seg 0 (0.5) [0.5 on Ipop[9]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[9] syn_projEI_ampa[1329] = new ampa(0.5)")
        h("Epop[66] netConn_projEI_ampa[1329] = new NetCon(&v(0.5), syn_projEI_ampa[1329], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1330: cell 66, seg 0 (0.5) [0.5 on Epop[66]] -> cell 10, seg 0 (0.5) [0.5 on Ipop[10]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[10] syn_projEI_ampa[1330] = new ampa(0.5)")
        h("Epop[66] netConn_projEI_ampa[1330] = new NetCon(&v(0.5), syn_projEI_ampa[1330], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1331: cell 66, seg 0 (0.5) [0.5 on Epop[66]] -> cell 11, seg 0 (0.5) [0.5 on Ipop[11]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[11] syn_projEI_ampa[1331] = new ampa(0.5)")
        h("Epop[66] netConn_projEI_ampa[1331] = new NetCon(&v(0.5), syn_projEI_ampa[1331], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1332: cell 66, seg 0 (0.5) [0.5 on Epop[66]] -> cell 12, seg 0 (0.5) [0.5 on Ipop[12]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[12] syn_projEI_ampa[1332] = new ampa(0.5)")
        h("Epop[66] netConn_projEI_ampa[1332] = new NetCon(&v(0.5), syn_projEI_ampa[1332], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1333: cell 66, seg 0 (0.5) [0.5 on Epop[66]] -> cell 13, seg 0 (0.5) [0.5 on Ipop[13]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[13] syn_projEI_ampa[1333] = new ampa(0.5)")
        h("Epop[66] netConn_projEI_ampa[1333] = new NetCon(&v(0.5), syn_projEI_ampa[1333], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1334: cell 66, seg 0 (0.5) [0.5 on Epop[66]] -> cell 14, seg 0 (0.5) [0.5 on Ipop[14]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[14] syn_projEI_ampa[1334] = new ampa(0.5)")
        h("Epop[66] netConn_projEI_ampa[1334] = new NetCon(&v(0.5), syn_projEI_ampa[1334], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1335: cell 66, seg 0 (0.5) [0.5 on Epop[66]] -> cell 15, seg 0 (0.5) [0.5 on Ipop[15]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[15] syn_projEI_ampa[1335] = new ampa(0.5)")
        h("Epop[66] netConn_projEI_ampa[1335] = new NetCon(&v(0.5), syn_projEI_ampa[1335], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1336: cell 66, seg 0 (0.5) [0.5 on Epop[66]] -> cell 16, seg 0 (0.5) [0.5 on Ipop[16]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[16] syn_projEI_ampa[1336] = new ampa(0.5)")
        h("Epop[66] netConn_projEI_ampa[1336] = new NetCon(&v(0.5), syn_projEI_ampa[1336], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1337: cell 66, seg 0 (0.5) [0.5 on Epop[66]] -> cell 17, seg 0 (0.5) [0.5 on Ipop[17]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[17] syn_projEI_ampa[1337] = new ampa(0.5)")
        h("Epop[66] netConn_projEI_ampa[1337] = new NetCon(&v(0.5), syn_projEI_ampa[1337], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1338: cell 66, seg 0 (0.5) [0.5 on Epop[66]] -> cell 18, seg 0 (0.5) [0.5 on Ipop[18]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[18] syn_projEI_ampa[1338] = new ampa(0.5)")
        h("Epop[66] netConn_projEI_ampa[1338] = new NetCon(&v(0.5), syn_projEI_ampa[1338], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1339: cell 66, seg 0 (0.5) [0.5 on Epop[66]] -> cell 19, seg 0 (0.5) [0.5 on Ipop[19]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[19] syn_projEI_ampa[1339] = new ampa(0.5)")
        h("Epop[66] netConn_projEI_ampa[1339] = new NetCon(&v(0.5), syn_projEI_ampa[1339], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1340: cell 67, seg 0 (0.5) [0.5 on Epop[67]] -> cell 0, seg 0 (0.5) [0.5 on Ipop[0]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[0] syn_projEI_ampa[1340] = new ampa(0.5)")
        h("Epop[67] netConn_projEI_ampa[1340] = new NetCon(&v(0.5), syn_projEI_ampa[1340], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1341: cell 67, seg 0 (0.5) [0.5 on Epop[67]] -> cell 1, seg 0 (0.5) [0.5 on Ipop[1]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[1] syn_projEI_ampa[1341] = new ampa(0.5)")
        h("Epop[67] netConn_projEI_ampa[1341] = new NetCon(&v(0.5), syn_projEI_ampa[1341], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1342: cell 67, seg 0 (0.5) [0.5 on Epop[67]] -> cell 2, seg 0 (0.5) [0.5 on Ipop[2]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[2] syn_projEI_ampa[1342] = new ampa(0.5)")
        h("Epop[67] netConn_projEI_ampa[1342] = new NetCon(&v(0.5), syn_projEI_ampa[1342], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1343: cell 67, seg 0 (0.5) [0.5 on Epop[67]] -> cell 3, seg 0 (0.5) [0.5 on Ipop[3]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[3] syn_projEI_ampa[1343] = new ampa(0.5)")
        h("Epop[67] netConn_projEI_ampa[1343] = new NetCon(&v(0.5), syn_projEI_ampa[1343], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1344: cell 67, seg 0 (0.5) [0.5 on Epop[67]] -> cell 4, seg 0 (0.5) [0.5 on Ipop[4]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[4] syn_projEI_ampa[1344] = new ampa(0.5)")
        h("Epop[67] netConn_projEI_ampa[1344] = new NetCon(&v(0.5), syn_projEI_ampa[1344], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1345: cell 67, seg 0 (0.5) [0.5 on Epop[67]] -> cell 5, seg 0 (0.5) [0.5 on Ipop[5]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[5] syn_projEI_ampa[1345] = new ampa(0.5)")
        h("Epop[67] netConn_projEI_ampa[1345] = new NetCon(&v(0.5), syn_projEI_ampa[1345], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1346: cell 67, seg 0 (0.5) [0.5 on Epop[67]] -> cell 6, seg 0 (0.5) [0.5 on Ipop[6]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[6] syn_projEI_ampa[1346] = new ampa(0.5)")
        h("Epop[67] netConn_projEI_ampa[1346] = new NetCon(&v(0.5), syn_projEI_ampa[1346], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1347: cell 67, seg 0 (0.5) [0.5 on Epop[67]] -> cell 7, seg 0 (0.5) [0.5 on Ipop[7]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[7] syn_projEI_ampa[1347] = new ampa(0.5)")
        h("Epop[67] netConn_projEI_ampa[1347] = new NetCon(&v(0.5), syn_projEI_ampa[1347], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1348: cell 67, seg 0 (0.5) [0.5 on Epop[67]] -> cell 8, seg 0 (0.5) [0.5 on Ipop[8]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[8] syn_projEI_ampa[1348] = new ampa(0.5)")
        h("Epop[67] netConn_projEI_ampa[1348] = new NetCon(&v(0.5), syn_projEI_ampa[1348], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1349: cell 67, seg 0 (0.5) [0.5 on Epop[67]] -> cell 9, seg 0 (0.5) [0.5 on Ipop[9]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[9] syn_projEI_ampa[1349] = new ampa(0.5)")
        h("Epop[67] netConn_projEI_ampa[1349] = new NetCon(&v(0.5), syn_projEI_ampa[1349], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1350: cell 67, seg 0 (0.5) [0.5 on Epop[67]] -> cell 10, seg 0 (0.5) [0.5 on Ipop[10]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[10] syn_projEI_ampa[1350] = new ampa(0.5)")
        h("Epop[67] netConn_projEI_ampa[1350] = new NetCon(&v(0.5), syn_projEI_ampa[1350], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1351: cell 67, seg 0 (0.5) [0.5 on Epop[67]] -> cell 11, seg 0 (0.5) [0.5 on Ipop[11]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[11] syn_projEI_ampa[1351] = new ampa(0.5)")
        h("Epop[67] netConn_projEI_ampa[1351] = new NetCon(&v(0.5), syn_projEI_ampa[1351], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1352: cell 67, seg 0 (0.5) [0.5 on Epop[67]] -> cell 12, seg 0 (0.5) [0.5 on Ipop[12]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[12] syn_projEI_ampa[1352] = new ampa(0.5)")
        h("Epop[67] netConn_projEI_ampa[1352] = new NetCon(&v(0.5), syn_projEI_ampa[1352], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1353: cell 67, seg 0 (0.5) [0.5 on Epop[67]] -> cell 13, seg 0 (0.5) [0.5 on Ipop[13]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[13] syn_projEI_ampa[1353] = new ampa(0.5)")
        h("Epop[67] netConn_projEI_ampa[1353] = new NetCon(&v(0.5), syn_projEI_ampa[1353], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1354: cell 67, seg 0 (0.5) [0.5 on Epop[67]] -> cell 14, seg 0 (0.5) [0.5 on Ipop[14]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[14] syn_projEI_ampa[1354] = new ampa(0.5)")
        h("Epop[67] netConn_projEI_ampa[1354] = new NetCon(&v(0.5), syn_projEI_ampa[1354], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1355: cell 67, seg 0 (0.5) [0.5 on Epop[67]] -> cell 15, seg 0 (0.5) [0.5 on Ipop[15]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[15] syn_projEI_ampa[1355] = new ampa(0.5)")
        h("Epop[67] netConn_projEI_ampa[1355] = new NetCon(&v(0.5), syn_projEI_ampa[1355], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1356: cell 67, seg 0 (0.5) [0.5 on Epop[67]] -> cell 16, seg 0 (0.5) [0.5 on Ipop[16]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[16] syn_projEI_ampa[1356] = new ampa(0.5)")
        h("Epop[67] netConn_projEI_ampa[1356] = new NetCon(&v(0.5), syn_projEI_ampa[1356], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1357: cell 67, seg 0 (0.5) [0.5 on Epop[67]] -> cell 17, seg 0 (0.5) [0.5 on Ipop[17]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[17] syn_projEI_ampa[1357] = new ampa(0.5)")
        h("Epop[67] netConn_projEI_ampa[1357] = new NetCon(&v(0.5), syn_projEI_ampa[1357], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1358: cell 67, seg 0 (0.5) [0.5 on Epop[67]] -> cell 18, seg 0 (0.5) [0.5 on Ipop[18]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[18] syn_projEI_ampa[1358] = new ampa(0.5)")
        h("Epop[67] netConn_projEI_ampa[1358] = new NetCon(&v(0.5), syn_projEI_ampa[1358], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1359: cell 67, seg 0 (0.5) [0.5 on Epop[67]] -> cell 19, seg 0 (0.5) [0.5 on Ipop[19]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[19] syn_projEI_ampa[1359] = new ampa(0.5)")
        h("Epop[67] netConn_projEI_ampa[1359] = new NetCon(&v(0.5), syn_projEI_ampa[1359], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1360: cell 68, seg 0 (0.5) [0.5 on Epop[68]] -> cell 0, seg 0 (0.5) [0.5 on Ipop[0]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[0] syn_projEI_ampa[1360] = new ampa(0.5)")
        h("Epop[68] netConn_projEI_ampa[1360] = new NetCon(&v(0.5), syn_projEI_ampa[1360], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1361: cell 68, seg 0 (0.5) [0.5 on Epop[68]] -> cell 1, seg 0 (0.5) [0.5 on Ipop[1]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[1] syn_projEI_ampa[1361] = new ampa(0.5)")
        h("Epop[68] netConn_projEI_ampa[1361] = new NetCon(&v(0.5), syn_projEI_ampa[1361], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1362: cell 68, seg 0 (0.5) [0.5 on Epop[68]] -> cell 2, seg 0 (0.5) [0.5 on Ipop[2]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[2] syn_projEI_ampa[1362] = new ampa(0.5)")
        h("Epop[68] netConn_projEI_ampa[1362] = new NetCon(&v(0.5), syn_projEI_ampa[1362], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1363: cell 68, seg 0 (0.5) [0.5 on Epop[68]] -> cell 3, seg 0 (0.5) [0.5 on Ipop[3]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[3] syn_projEI_ampa[1363] = new ampa(0.5)")
        h("Epop[68] netConn_projEI_ampa[1363] = new NetCon(&v(0.5), syn_projEI_ampa[1363], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1364: cell 68, seg 0 (0.5) [0.5 on Epop[68]] -> cell 4, seg 0 (0.5) [0.5 on Ipop[4]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[4] syn_projEI_ampa[1364] = new ampa(0.5)")
        h("Epop[68] netConn_projEI_ampa[1364] = new NetCon(&v(0.5), syn_projEI_ampa[1364], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1365: cell 68, seg 0 (0.5) [0.5 on Epop[68]] -> cell 5, seg 0 (0.5) [0.5 on Ipop[5]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[5] syn_projEI_ampa[1365] = new ampa(0.5)")
        h("Epop[68] netConn_projEI_ampa[1365] = new NetCon(&v(0.5), syn_projEI_ampa[1365], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1366: cell 68, seg 0 (0.5) [0.5 on Epop[68]] -> cell 6, seg 0 (0.5) [0.5 on Ipop[6]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[6] syn_projEI_ampa[1366] = new ampa(0.5)")
        h("Epop[68] netConn_projEI_ampa[1366] = new NetCon(&v(0.5), syn_projEI_ampa[1366], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1367: cell 68, seg 0 (0.5) [0.5 on Epop[68]] -> cell 7, seg 0 (0.5) [0.5 on Ipop[7]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[7] syn_projEI_ampa[1367] = new ampa(0.5)")
        h("Epop[68] netConn_projEI_ampa[1367] = new NetCon(&v(0.5), syn_projEI_ampa[1367], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1368: cell 68, seg 0 (0.5) [0.5 on Epop[68]] -> cell 8, seg 0 (0.5) [0.5 on Ipop[8]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[8] syn_projEI_ampa[1368] = new ampa(0.5)")
        h("Epop[68] netConn_projEI_ampa[1368] = new NetCon(&v(0.5), syn_projEI_ampa[1368], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1369: cell 68, seg 0 (0.5) [0.5 on Epop[68]] -> cell 9, seg 0 (0.5) [0.5 on Ipop[9]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[9] syn_projEI_ampa[1369] = new ampa(0.5)")
        h("Epop[68] netConn_projEI_ampa[1369] = new NetCon(&v(0.5), syn_projEI_ampa[1369], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1370: cell 68, seg 0 (0.5) [0.5 on Epop[68]] -> cell 10, seg 0 (0.5) [0.5 on Ipop[10]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[10] syn_projEI_ampa[1370] = new ampa(0.5)")
        h("Epop[68] netConn_projEI_ampa[1370] = new NetCon(&v(0.5), syn_projEI_ampa[1370], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1371: cell 68, seg 0 (0.5) [0.5 on Epop[68]] -> cell 11, seg 0 (0.5) [0.5 on Ipop[11]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[11] syn_projEI_ampa[1371] = new ampa(0.5)")
        h("Epop[68] netConn_projEI_ampa[1371] = new NetCon(&v(0.5), syn_projEI_ampa[1371], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1372: cell 68, seg 0 (0.5) [0.5 on Epop[68]] -> cell 12, seg 0 (0.5) [0.5 on Ipop[12]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[12] syn_projEI_ampa[1372] = new ampa(0.5)")
        h("Epop[68] netConn_projEI_ampa[1372] = new NetCon(&v(0.5), syn_projEI_ampa[1372], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1373: cell 68, seg 0 (0.5) [0.5 on Epop[68]] -> cell 13, seg 0 (0.5) [0.5 on Ipop[13]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[13] syn_projEI_ampa[1373] = new ampa(0.5)")
        h("Epop[68] netConn_projEI_ampa[1373] = new NetCon(&v(0.5), syn_projEI_ampa[1373], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1374: cell 68, seg 0 (0.5) [0.5 on Epop[68]] -> cell 14, seg 0 (0.5) [0.5 on Ipop[14]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[14] syn_projEI_ampa[1374] = new ampa(0.5)")
        h("Epop[68] netConn_projEI_ampa[1374] = new NetCon(&v(0.5), syn_projEI_ampa[1374], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1375: cell 68, seg 0 (0.5) [0.5 on Epop[68]] -> cell 15, seg 0 (0.5) [0.5 on Ipop[15]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[15] syn_projEI_ampa[1375] = new ampa(0.5)")
        h("Epop[68] netConn_projEI_ampa[1375] = new NetCon(&v(0.5), syn_projEI_ampa[1375], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1376: cell 68, seg 0 (0.5) [0.5 on Epop[68]] -> cell 16, seg 0 (0.5) [0.5 on Ipop[16]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[16] syn_projEI_ampa[1376] = new ampa(0.5)")
        h("Epop[68] netConn_projEI_ampa[1376] = new NetCon(&v(0.5), syn_projEI_ampa[1376], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1377: cell 68, seg 0 (0.5) [0.5 on Epop[68]] -> cell 17, seg 0 (0.5) [0.5 on Ipop[17]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[17] syn_projEI_ampa[1377] = new ampa(0.5)")
        h("Epop[68] netConn_projEI_ampa[1377] = new NetCon(&v(0.5), syn_projEI_ampa[1377], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1378: cell 68, seg 0 (0.5) [0.5 on Epop[68]] -> cell 18, seg 0 (0.5) [0.5 on Ipop[18]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[18] syn_projEI_ampa[1378] = new ampa(0.5)")
        h("Epop[68] netConn_projEI_ampa[1378] = new NetCon(&v(0.5), syn_projEI_ampa[1378], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1379: cell 68, seg 0 (0.5) [0.5 on Epop[68]] -> cell 19, seg 0 (0.5) [0.5 on Ipop[19]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[19] syn_projEI_ampa[1379] = new ampa(0.5)")
        h("Epop[68] netConn_projEI_ampa[1379] = new NetCon(&v(0.5), syn_projEI_ampa[1379], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1380: cell 69, seg 0 (0.5) [0.5 on Epop[69]] -> cell 0, seg 0 (0.5) [0.5 on Ipop[0]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[0] syn_projEI_ampa[1380] = new ampa(0.5)")
        h("Epop[69] netConn_projEI_ampa[1380] = new NetCon(&v(0.5), syn_projEI_ampa[1380], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1381: cell 69, seg 0 (0.5) [0.5 on Epop[69]] -> cell 1, seg 0 (0.5) [0.5 on Ipop[1]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[1] syn_projEI_ampa[1381] = new ampa(0.5)")
        h("Epop[69] netConn_projEI_ampa[1381] = new NetCon(&v(0.5), syn_projEI_ampa[1381], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1382: cell 69, seg 0 (0.5) [0.5 on Epop[69]] -> cell 2, seg 0 (0.5) [0.5 on Ipop[2]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[2] syn_projEI_ampa[1382] = new ampa(0.5)")
        h("Epop[69] netConn_projEI_ampa[1382] = new NetCon(&v(0.5), syn_projEI_ampa[1382], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1383: cell 69, seg 0 (0.5) [0.5 on Epop[69]] -> cell 3, seg 0 (0.5) [0.5 on Ipop[3]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[3] syn_projEI_ampa[1383] = new ampa(0.5)")
        h("Epop[69] netConn_projEI_ampa[1383] = new NetCon(&v(0.5), syn_projEI_ampa[1383], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1384: cell 69, seg 0 (0.5) [0.5 on Epop[69]] -> cell 4, seg 0 (0.5) [0.5 on Ipop[4]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[4] syn_projEI_ampa[1384] = new ampa(0.5)")
        h("Epop[69] netConn_projEI_ampa[1384] = new NetCon(&v(0.5), syn_projEI_ampa[1384], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1385: cell 69, seg 0 (0.5) [0.5 on Epop[69]] -> cell 5, seg 0 (0.5) [0.5 on Ipop[5]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[5] syn_projEI_ampa[1385] = new ampa(0.5)")
        h("Epop[69] netConn_projEI_ampa[1385] = new NetCon(&v(0.5), syn_projEI_ampa[1385], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1386: cell 69, seg 0 (0.5) [0.5 on Epop[69]] -> cell 6, seg 0 (0.5) [0.5 on Ipop[6]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[6] syn_projEI_ampa[1386] = new ampa(0.5)")
        h("Epop[69] netConn_projEI_ampa[1386] = new NetCon(&v(0.5), syn_projEI_ampa[1386], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1387: cell 69, seg 0 (0.5) [0.5 on Epop[69]] -> cell 7, seg 0 (0.5) [0.5 on Ipop[7]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[7] syn_projEI_ampa[1387] = new ampa(0.5)")
        h("Epop[69] netConn_projEI_ampa[1387] = new NetCon(&v(0.5), syn_projEI_ampa[1387], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1388: cell 69, seg 0 (0.5) [0.5 on Epop[69]] -> cell 8, seg 0 (0.5) [0.5 on Ipop[8]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[8] syn_projEI_ampa[1388] = new ampa(0.5)")
        h("Epop[69] netConn_projEI_ampa[1388] = new NetCon(&v(0.5), syn_projEI_ampa[1388], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1389: cell 69, seg 0 (0.5) [0.5 on Epop[69]] -> cell 9, seg 0 (0.5) [0.5 on Ipop[9]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[9] syn_projEI_ampa[1389] = new ampa(0.5)")
        h("Epop[69] netConn_projEI_ampa[1389] = new NetCon(&v(0.5), syn_projEI_ampa[1389], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1390: cell 69, seg 0 (0.5) [0.5 on Epop[69]] -> cell 10, seg 0 (0.5) [0.5 on Ipop[10]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[10] syn_projEI_ampa[1390] = new ampa(0.5)")
        h("Epop[69] netConn_projEI_ampa[1390] = new NetCon(&v(0.5), syn_projEI_ampa[1390], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1391: cell 69, seg 0 (0.5) [0.5 on Epop[69]] -> cell 11, seg 0 (0.5) [0.5 on Ipop[11]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[11] syn_projEI_ampa[1391] = new ampa(0.5)")
        h("Epop[69] netConn_projEI_ampa[1391] = new NetCon(&v(0.5), syn_projEI_ampa[1391], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1392: cell 69, seg 0 (0.5) [0.5 on Epop[69]] -> cell 12, seg 0 (0.5) [0.5 on Ipop[12]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[12] syn_projEI_ampa[1392] = new ampa(0.5)")
        h("Epop[69] netConn_projEI_ampa[1392] = new NetCon(&v(0.5), syn_projEI_ampa[1392], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1393: cell 69, seg 0 (0.5) [0.5 on Epop[69]] -> cell 13, seg 0 (0.5) [0.5 on Ipop[13]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[13] syn_projEI_ampa[1393] = new ampa(0.5)")
        h("Epop[69] netConn_projEI_ampa[1393] = new NetCon(&v(0.5), syn_projEI_ampa[1393], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1394: cell 69, seg 0 (0.5) [0.5 on Epop[69]] -> cell 14, seg 0 (0.5) [0.5 on Ipop[14]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[14] syn_projEI_ampa[1394] = new ampa(0.5)")
        h("Epop[69] netConn_projEI_ampa[1394] = new NetCon(&v(0.5), syn_projEI_ampa[1394], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1395: cell 69, seg 0 (0.5) [0.5 on Epop[69]] -> cell 15, seg 0 (0.5) [0.5 on Ipop[15]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[15] syn_projEI_ampa[1395] = new ampa(0.5)")
        h("Epop[69] netConn_projEI_ampa[1395] = new NetCon(&v(0.5), syn_projEI_ampa[1395], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1396: cell 69, seg 0 (0.5) [0.5 on Epop[69]] -> cell 16, seg 0 (0.5) [0.5 on Ipop[16]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[16] syn_projEI_ampa[1396] = new ampa(0.5)")
        h("Epop[69] netConn_projEI_ampa[1396] = new NetCon(&v(0.5), syn_projEI_ampa[1396], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1397: cell 69, seg 0 (0.5) [0.5 on Epop[69]] -> cell 17, seg 0 (0.5) [0.5 on Ipop[17]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[17] syn_projEI_ampa[1397] = new ampa(0.5)")
        h("Epop[69] netConn_projEI_ampa[1397] = new NetCon(&v(0.5), syn_projEI_ampa[1397], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1398: cell 69, seg 0 (0.5) [0.5 on Epop[69]] -> cell 18, seg 0 (0.5) [0.5 on Ipop[18]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[18] syn_projEI_ampa[1398] = new ampa(0.5)")
        h("Epop[69] netConn_projEI_ampa[1398] = new NetCon(&v(0.5), syn_projEI_ampa[1398], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1399: cell 69, seg 0 (0.5) [0.5 on Epop[69]] -> cell 19, seg 0 (0.5) [0.5 on Ipop[19]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[19] syn_projEI_ampa[1399] = new ampa(0.5)")
        h("Epop[69] netConn_projEI_ampa[1399] = new NetCon(&v(0.5), syn_projEI_ampa[1399], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1400: cell 70, seg 0 (0.5) [0.5 on Epop[70]] -> cell 0, seg 0 (0.5) [0.5 on Ipop[0]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[0] syn_projEI_ampa[1400] = new ampa(0.5)")
        h("Epop[70] netConn_projEI_ampa[1400] = new NetCon(&v(0.5), syn_projEI_ampa[1400], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1401: cell 70, seg 0 (0.5) [0.5 on Epop[70]] -> cell 1, seg 0 (0.5) [0.5 on Ipop[1]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[1] syn_projEI_ampa[1401] = new ampa(0.5)")
        h("Epop[70] netConn_projEI_ampa[1401] = new NetCon(&v(0.5), syn_projEI_ampa[1401], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1402: cell 70, seg 0 (0.5) [0.5 on Epop[70]] -> cell 2, seg 0 (0.5) [0.5 on Ipop[2]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[2] syn_projEI_ampa[1402] = new ampa(0.5)")
        h("Epop[70] netConn_projEI_ampa[1402] = new NetCon(&v(0.5), syn_projEI_ampa[1402], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1403: cell 70, seg 0 (0.5) [0.5 on Epop[70]] -> cell 3, seg 0 (0.5) [0.5 on Ipop[3]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[3] syn_projEI_ampa[1403] = new ampa(0.5)")
        h("Epop[70] netConn_projEI_ampa[1403] = new NetCon(&v(0.5), syn_projEI_ampa[1403], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1404: cell 70, seg 0 (0.5) [0.5 on Epop[70]] -> cell 4, seg 0 (0.5) [0.5 on Ipop[4]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[4] syn_projEI_ampa[1404] = new ampa(0.5)")
        h("Epop[70] netConn_projEI_ampa[1404] = new NetCon(&v(0.5), syn_projEI_ampa[1404], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1405: cell 70, seg 0 (0.5) [0.5 on Epop[70]] -> cell 5, seg 0 (0.5) [0.5 on Ipop[5]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[5] syn_projEI_ampa[1405] = new ampa(0.5)")
        h("Epop[70] netConn_projEI_ampa[1405] = new NetCon(&v(0.5), syn_projEI_ampa[1405], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1406: cell 70, seg 0 (0.5) [0.5 on Epop[70]] -> cell 6, seg 0 (0.5) [0.5 on Ipop[6]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[6] syn_projEI_ampa[1406] = new ampa(0.5)")
        h("Epop[70] netConn_projEI_ampa[1406] = new NetCon(&v(0.5), syn_projEI_ampa[1406], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1407: cell 70, seg 0 (0.5) [0.5 on Epop[70]] -> cell 7, seg 0 (0.5) [0.5 on Ipop[7]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[7] syn_projEI_ampa[1407] = new ampa(0.5)")
        h("Epop[70] netConn_projEI_ampa[1407] = new NetCon(&v(0.5), syn_projEI_ampa[1407], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1408: cell 70, seg 0 (0.5) [0.5 on Epop[70]] -> cell 8, seg 0 (0.5) [0.5 on Ipop[8]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[8] syn_projEI_ampa[1408] = new ampa(0.5)")
        h("Epop[70] netConn_projEI_ampa[1408] = new NetCon(&v(0.5), syn_projEI_ampa[1408], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1409: cell 70, seg 0 (0.5) [0.5 on Epop[70]] -> cell 9, seg 0 (0.5) [0.5 on Ipop[9]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[9] syn_projEI_ampa[1409] = new ampa(0.5)")
        h("Epop[70] netConn_projEI_ampa[1409] = new NetCon(&v(0.5), syn_projEI_ampa[1409], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1410: cell 70, seg 0 (0.5) [0.5 on Epop[70]] -> cell 10, seg 0 (0.5) [0.5 on Ipop[10]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[10] syn_projEI_ampa[1410] = new ampa(0.5)")
        h("Epop[70] netConn_projEI_ampa[1410] = new NetCon(&v(0.5), syn_projEI_ampa[1410], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1411: cell 70, seg 0 (0.5) [0.5 on Epop[70]] -> cell 11, seg 0 (0.5) [0.5 on Ipop[11]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[11] syn_projEI_ampa[1411] = new ampa(0.5)")
        h("Epop[70] netConn_projEI_ampa[1411] = new NetCon(&v(0.5), syn_projEI_ampa[1411], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1412: cell 70, seg 0 (0.5) [0.5 on Epop[70]] -> cell 12, seg 0 (0.5) [0.5 on Ipop[12]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[12] syn_projEI_ampa[1412] = new ampa(0.5)")
        h("Epop[70] netConn_projEI_ampa[1412] = new NetCon(&v(0.5), syn_projEI_ampa[1412], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1413: cell 70, seg 0 (0.5) [0.5 on Epop[70]] -> cell 13, seg 0 (0.5) [0.5 on Ipop[13]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[13] syn_projEI_ampa[1413] = new ampa(0.5)")
        h("Epop[70] netConn_projEI_ampa[1413] = new NetCon(&v(0.5), syn_projEI_ampa[1413], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1414: cell 70, seg 0 (0.5) [0.5 on Epop[70]] -> cell 14, seg 0 (0.5) [0.5 on Ipop[14]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[14] syn_projEI_ampa[1414] = new ampa(0.5)")
        h("Epop[70] netConn_projEI_ampa[1414] = new NetCon(&v(0.5), syn_projEI_ampa[1414], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1415: cell 70, seg 0 (0.5) [0.5 on Epop[70]] -> cell 15, seg 0 (0.5) [0.5 on Ipop[15]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[15] syn_projEI_ampa[1415] = new ampa(0.5)")
        h("Epop[70] netConn_projEI_ampa[1415] = new NetCon(&v(0.5), syn_projEI_ampa[1415], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1416: cell 70, seg 0 (0.5) [0.5 on Epop[70]] -> cell 16, seg 0 (0.5) [0.5 on Ipop[16]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[16] syn_projEI_ampa[1416] = new ampa(0.5)")
        h("Epop[70] netConn_projEI_ampa[1416] = new NetCon(&v(0.5), syn_projEI_ampa[1416], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1417: cell 70, seg 0 (0.5) [0.5 on Epop[70]] -> cell 17, seg 0 (0.5) [0.5 on Ipop[17]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[17] syn_projEI_ampa[1417] = new ampa(0.5)")
        h("Epop[70] netConn_projEI_ampa[1417] = new NetCon(&v(0.5), syn_projEI_ampa[1417], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1418: cell 70, seg 0 (0.5) [0.5 on Epop[70]] -> cell 18, seg 0 (0.5) [0.5 on Ipop[18]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[18] syn_projEI_ampa[1418] = new ampa(0.5)")
        h("Epop[70] netConn_projEI_ampa[1418] = new NetCon(&v(0.5), syn_projEI_ampa[1418], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1419: cell 70, seg 0 (0.5) [0.5 on Epop[70]] -> cell 19, seg 0 (0.5) [0.5 on Ipop[19]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[19] syn_projEI_ampa[1419] = new ampa(0.5)")
        h("Epop[70] netConn_projEI_ampa[1419] = new NetCon(&v(0.5), syn_projEI_ampa[1419], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1420: cell 71, seg 0 (0.5) [0.5 on Epop[71]] -> cell 0, seg 0 (0.5) [0.5 on Ipop[0]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[0] syn_projEI_ampa[1420] = new ampa(0.5)")
        h("Epop[71] netConn_projEI_ampa[1420] = new NetCon(&v(0.5), syn_projEI_ampa[1420], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1421: cell 71, seg 0 (0.5) [0.5 on Epop[71]] -> cell 1, seg 0 (0.5) [0.5 on Ipop[1]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[1] syn_projEI_ampa[1421] = new ampa(0.5)")
        h("Epop[71] netConn_projEI_ampa[1421] = new NetCon(&v(0.5), syn_projEI_ampa[1421], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1422: cell 71, seg 0 (0.5) [0.5 on Epop[71]] -> cell 2, seg 0 (0.5) [0.5 on Ipop[2]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[2] syn_projEI_ampa[1422] = new ampa(0.5)")
        h("Epop[71] netConn_projEI_ampa[1422] = new NetCon(&v(0.5), syn_projEI_ampa[1422], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1423: cell 71, seg 0 (0.5) [0.5 on Epop[71]] -> cell 3, seg 0 (0.5) [0.5 on Ipop[3]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[3] syn_projEI_ampa[1423] = new ampa(0.5)")
        h("Epop[71] netConn_projEI_ampa[1423] = new NetCon(&v(0.5), syn_projEI_ampa[1423], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1424: cell 71, seg 0 (0.5) [0.5 on Epop[71]] -> cell 4, seg 0 (0.5) [0.5 on Ipop[4]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[4] syn_projEI_ampa[1424] = new ampa(0.5)")
        h("Epop[71] netConn_projEI_ampa[1424] = new NetCon(&v(0.5), syn_projEI_ampa[1424], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1425: cell 71, seg 0 (0.5) [0.5 on Epop[71]] -> cell 5, seg 0 (0.5) [0.5 on Ipop[5]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[5] syn_projEI_ampa[1425] = new ampa(0.5)")
        h("Epop[71] netConn_projEI_ampa[1425] = new NetCon(&v(0.5), syn_projEI_ampa[1425], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1426: cell 71, seg 0 (0.5) [0.5 on Epop[71]] -> cell 6, seg 0 (0.5) [0.5 on Ipop[6]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[6] syn_projEI_ampa[1426] = new ampa(0.5)")
        h("Epop[71] netConn_projEI_ampa[1426] = new NetCon(&v(0.5), syn_projEI_ampa[1426], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1427: cell 71, seg 0 (0.5) [0.5 on Epop[71]] -> cell 7, seg 0 (0.5) [0.5 on Ipop[7]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[7] syn_projEI_ampa[1427] = new ampa(0.5)")
        h("Epop[71] netConn_projEI_ampa[1427] = new NetCon(&v(0.5), syn_projEI_ampa[1427], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1428: cell 71, seg 0 (0.5) [0.5 on Epop[71]] -> cell 8, seg 0 (0.5) [0.5 on Ipop[8]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[8] syn_projEI_ampa[1428] = new ampa(0.5)")
        h("Epop[71] netConn_projEI_ampa[1428] = new NetCon(&v(0.5), syn_projEI_ampa[1428], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1429: cell 71, seg 0 (0.5) [0.5 on Epop[71]] -> cell 9, seg 0 (0.5) [0.5 on Ipop[9]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[9] syn_projEI_ampa[1429] = new ampa(0.5)")
        h("Epop[71] netConn_projEI_ampa[1429] = new NetCon(&v(0.5), syn_projEI_ampa[1429], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1430: cell 71, seg 0 (0.5) [0.5 on Epop[71]] -> cell 10, seg 0 (0.5) [0.5 on Ipop[10]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[10] syn_projEI_ampa[1430] = new ampa(0.5)")
        h("Epop[71] netConn_projEI_ampa[1430] = new NetCon(&v(0.5), syn_projEI_ampa[1430], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1431: cell 71, seg 0 (0.5) [0.5 on Epop[71]] -> cell 11, seg 0 (0.5) [0.5 on Ipop[11]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[11] syn_projEI_ampa[1431] = new ampa(0.5)")
        h("Epop[71] netConn_projEI_ampa[1431] = new NetCon(&v(0.5), syn_projEI_ampa[1431], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1432: cell 71, seg 0 (0.5) [0.5 on Epop[71]] -> cell 12, seg 0 (0.5) [0.5 on Ipop[12]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[12] syn_projEI_ampa[1432] = new ampa(0.5)")
        h("Epop[71] netConn_projEI_ampa[1432] = new NetCon(&v(0.5), syn_projEI_ampa[1432], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1433: cell 71, seg 0 (0.5) [0.5 on Epop[71]] -> cell 13, seg 0 (0.5) [0.5 on Ipop[13]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[13] syn_projEI_ampa[1433] = new ampa(0.5)")
        h("Epop[71] netConn_projEI_ampa[1433] = new NetCon(&v(0.5), syn_projEI_ampa[1433], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1434: cell 71, seg 0 (0.5) [0.5 on Epop[71]] -> cell 14, seg 0 (0.5) [0.5 on Ipop[14]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[14] syn_projEI_ampa[1434] = new ampa(0.5)")
        h("Epop[71] netConn_projEI_ampa[1434] = new NetCon(&v(0.5), syn_projEI_ampa[1434], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1435: cell 71, seg 0 (0.5) [0.5 on Epop[71]] -> cell 15, seg 0 (0.5) [0.5 on Ipop[15]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[15] syn_projEI_ampa[1435] = new ampa(0.5)")
        h("Epop[71] netConn_projEI_ampa[1435] = new NetCon(&v(0.5), syn_projEI_ampa[1435], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1436: cell 71, seg 0 (0.5) [0.5 on Epop[71]] -> cell 16, seg 0 (0.5) [0.5 on Ipop[16]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[16] syn_projEI_ampa[1436] = new ampa(0.5)")
        h("Epop[71] netConn_projEI_ampa[1436] = new NetCon(&v(0.5), syn_projEI_ampa[1436], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1437: cell 71, seg 0 (0.5) [0.5 on Epop[71]] -> cell 17, seg 0 (0.5) [0.5 on Ipop[17]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[17] syn_projEI_ampa[1437] = new ampa(0.5)")
        h("Epop[71] netConn_projEI_ampa[1437] = new NetCon(&v(0.5), syn_projEI_ampa[1437], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1438: cell 71, seg 0 (0.5) [0.5 on Epop[71]] -> cell 18, seg 0 (0.5) [0.5 on Ipop[18]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[18] syn_projEI_ampa[1438] = new ampa(0.5)")
        h("Epop[71] netConn_projEI_ampa[1438] = new NetCon(&v(0.5), syn_projEI_ampa[1438], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1439: cell 71, seg 0 (0.5) [0.5 on Epop[71]] -> cell 19, seg 0 (0.5) [0.5 on Ipop[19]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[19] syn_projEI_ampa[1439] = new ampa(0.5)")
        h("Epop[71] netConn_projEI_ampa[1439] = new NetCon(&v(0.5), syn_projEI_ampa[1439], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1440: cell 72, seg 0 (0.5) [0.5 on Epop[72]] -> cell 0, seg 0 (0.5) [0.5 on Ipop[0]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[0] syn_projEI_ampa[1440] = new ampa(0.5)")
        h("Epop[72] netConn_projEI_ampa[1440] = new NetCon(&v(0.5), syn_projEI_ampa[1440], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1441: cell 72, seg 0 (0.5) [0.5 on Epop[72]] -> cell 1, seg 0 (0.5) [0.5 on Ipop[1]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[1] syn_projEI_ampa[1441] = new ampa(0.5)")
        h("Epop[72] netConn_projEI_ampa[1441] = new NetCon(&v(0.5), syn_projEI_ampa[1441], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1442: cell 72, seg 0 (0.5) [0.5 on Epop[72]] -> cell 2, seg 0 (0.5) [0.5 on Ipop[2]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[2] syn_projEI_ampa[1442] = new ampa(0.5)")
        h("Epop[72] netConn_projEI_ampa[1442] = new NetCon(&v(0.5), syn_projEI_ampa[1442], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1443: cell 72, seg 0 (0.5) [0.5 on Epop[72]] -> cell 3, seg 0 (0.5) [0.5 on Ipop[3]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[3] syn_projEI_ampa[1443] = new ampa(0.5)")
        h("Epop[72] netConn_projEI_ampa[1443] = new NetCon(&v(0.5), syn_projEI_ampa[1443], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1444: cell 72, seg 0 (0.5) [0.5 on Epop[72]] -> cell 4, seg 0 (0.5) [0.5 on Ipop[4]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[4] syn_projEI_ampa[1444] = new ampa(0.5)")
        h("Epop[72] netConn_projEI_ampa[1444] = new NetCon(&v(0.5), syn_projEI_ampa[1444], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1445: cell 72, seg 0 (0.5) [0.5 on Epop[72]] -> cell 5, seg 0 (0.5) [0.5 on Ipop[5]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[5] syn_projEI_ampa[1445] = new ampa(0.5)")
        h("Epop[72] netConn_projEI_ampa[1445] = new NetCon(&v(0.5), syn_projEI_ampa[1445], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1446: cell 72, seg 0 (0.5) [0.5 on Epop[72]] -> cell 6, seg 0 (0.5) [0.5 on Ipop[6]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[6] syn_projEI_ampa[1446] = new ampa(0.5)")
        h("Epop[72] netConn_projEI_ampa[1446] = new NetCon(&v(0.5), syn_projEI_ampa[1446], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1447: cell 72, seg 0 (0.5) [0.5 on Epop[72]] -> cell 7, seg 0 (0.5) [0.5 on Ipop[7]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[7] syn_projEI_ampa[1447] = new ampa(0.5)")
        h("Epop[72] netConn_projEI_ampa[1447] = new NetCon(&v(0.5), syn_projEI_ampa[1447], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1448: cell 72, seg 0 (0.5) [0.5 on Epop[72]] -> cell 8, seg 0 (0.5) [0.5 on Ipop[8]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[8] syn_projEI_ampa[1448] = new ampa(0.5)")
        h("Epop[72] netConn_projEI_ampa[1448] = new NetCon(&v(0.5), syn_projEI_ampa[1448], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1449: cell 72, seg 0 (0.5) [0.5 on Epop[72]] -> cell 9, seg 0 (0.5) [0.5 on Ipop[9]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[9] syn_projEI_ampa[1449] = new ampa(0.5)")
        h("Epop[72] netConn_projEI_ampa[1449] = new NetCon(&v(0.5), syn_projEI_ampa[1449], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1450: cell 72, seg 0 (0.5) [0.5 on Epop[72]] -> cell 10, seg 0 (0.5) [0.5 on Ipop[10]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[10] syn_projEI_ampa[1450] = new ampa(0.5)")
        h("Epop[72] netConn_projEI_ampa[1450] = new NetCon(&v(0.5), syn_projEI_ampa[1450], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1451: cell 72, seg 0 (0.5) [0.5 on Epop[72]] -> cell 11, seg 0 (0.5) [0.5 on Ipop[11]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[11] syn_projEI_ampa[1451] = new ampa(0.5)")
        h("Epop[72] netConn_projEI_ampa[1451] = new NetCon(&v(0.5), syn_projEI_ampa[1451], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1452: cell 72, seg 0 (0.5) [0.5 on Epop[72]] -> cell 12, seg 0 (0.5) [0.5 on Ipop[12]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[12] syn_projEI_ampa[1452] = new ampa(0.5)")
        h("Epop[72] netConn_projEI_ampa[1452] = new NetCon(&v(0.5), syn_projEI_ampa[1452], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1453: cell 72, seg 0 (0.5) [0.5 on Epop[72]] -> cell 13, seg 0 (0.5) [0.5 on Ipop[13]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[13] syn_projEI_ampa[1453] = new ampa(0.5)")
        h("Epop[72] netConn_projEI_ampa[1453] = new NetCon(&v(0.5), syn_projEI_ampa[1453], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1454: cell 72, seg 0 (0.5) [0.5 on Epop[72]] -> cell 14, seg 0 (0.5) [0.5 on Ipop[14]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[14] syn_projEI_ampa[1454] = new ampa(0.5)")
        h("Epop[72] netConn_projEI_ampa[1454] = new NetCon(&v(0.5), syn_projEI_ampa[1454], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1455: cell 72, seg 0 (0.5) [0.5 on Epop[72]] -> cell 15, seg 0 (0.5) [0.5 on Ipop[15]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[15] syn_projEI_ampa[1455] = new ampa(0.5)")
        h("Epop[72] netConn_projEI_ampa[1455] = new NetCon(&v(0.5), syn_projEI_ampa[1455], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1456: cell 72, seg 0 (0.5) [0.5 on Epop[72]] -> cell 16, seg 0 (0.5) [0.5 on Ipop[16]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[16] syn_projEI_ampa[1456] = new ampa(0.5)")
        h("Epop[72] netConn_projEI_ampa[1456] = new NetCon(&v(0.5), syn_projEI_ampa[1456], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1457: cell 72, seg 0 (0.5) [0.5 on Epop[72]] -> cell 17, seg 0 (0.5) [0.5 on Ipop[17]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[17] syn_projEI_ampa[1457] = new ampa(0.5)")
        h("Epop[72] netConn_projEI_ampa[1457] = new NetCon(&v(0.5), syn_projEI_ampa[1457], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1458: cell 72, seg 0 (0.5) [0.5 on Epop[72]] -> cell 18, seg 0 (0.5) [0.5 on Ipop[18]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[18] syn_projEI_ampa[1458] = new ampa(0.5)")
        h("Epop[72] netConn_projEI_ampa[1458] = new NetCon(&v(0.5), syn_projEI_ampa[1458], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1459: cell 72, seg 0 (0.5) [0.5 on Epop[72]] -> cell 19, seg 0 (0.5) [0.5 on Ipop[19]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[19] syn_projEI_ampa[1459] = new ampa(0.5)")
        h("Epop[72] netConn_projEI_ampa[1459] = new NetCon(&v(0.5), syn_projEI_ampa[1459], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1460: cell 73, seg 0 (0.5) [0.5 on Epop[73]] -> cell 0, seg 0 (0.5) [0.5 on Ipop[0]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[0] syn_projEI_ampa[1460] = new ampa(0.5)")
        h("Epop[73] netConn_projEI_ampa[1460] = new NetCon(&v(0.5), syn_projEI_ampa[1460], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1461: cell 73, seg 0 (0.5) [0.5 on Epop[73]] -> cell 1, seg 0 (0.5) [0.5 on Ipop[1]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[1] syn_projEI_ampa[1461] = new ampa(0.5)")
        h("Epop[73] netConn_projEI_ampa[1461] = new NetCon(&v(0.5), syn_projEI_ampa[1461], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1462: cell 73, seg 0 (0.5) [0.5 on Epop[73]] -> cell 2, seg 0 (0.5) [0.5 on Ipop[2]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[2] syn_projEI_ampa[1462] = new ampa(0.5)")
        h("Epop[73] netConn_projEI_ampa[1462] = new NetCon(&v(0.5), syn_projEI_ampa[1462], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1463: cell 73, seg 0 (0.5) [0.5 on Epop[73]] -> cell 3, seg 0 (0.5) [0.5 on Ipop[3]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[3] syn_projEI_ampa[1463] = new ampa(0.5)")
        h("Epop[73] netConn_projEI_ampa[1463] = new NetCon(&v(0.5), syn_projEI_ampa[1463], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1464: cell 73, seg 0 (0.5) [0.5 on Epop[73]] -> cell 4, seg 0 (0.5) [0.5 on Ipop[4]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[4] syn_projEI_ampa[1464] = new ampa(0.5)")
        h("Epop[73] netConn_projEI_ampa[1464] = new NetCon(&v(0.5), syn_projEI_ampa[1464], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1465: cell 73, seg 0 (0.5) [0.5 on Epop[73]] -> cell 5, seg 0 (0.5) [0.5 on Ipop[5]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[5] syn_projEI_ampa[1465] = new ampa(0.5)")
        h("Epop[73] netConn_projEI_ampa[1465] = new NetCon(&v(0.5), syn_projEI_ampa[1465], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1466: cell 73, seg 0 (0.5) [0.5 on Epop[73]] -> cell 6, seg 0 (0.5) [0.5 on Ipop[6]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[6] syn_projEI_ampa[1466] = new ampa(0.5)")
        h("Epop[73] netConn_projEI_ampa[1466] = new NetCon(&v(0.5), syn_projEI_ampa[1466], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1467: cell 73, seg 0 (0.5) [0.5 on Epop[73]] -> cell 7, seg 0 (0.5) [0.5 on Ipop[7]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[7] syn_projEI_ampa[1467] = new ampa(0.5)")
        h("Epop[73] netConn_projEI_ampa[1467] = new NetCon(&v(0.5), syn_projEI_ampa[1467], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1468: cell 73, seg 0 (0.5) [0.5 on Epop[73]] -> cell 8, seg 0 (0.5) [0.5 on Ipop[8]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[8] syn_projEI_ampa[1468] = new ampa(0.5)")
        h("Epop[73] netConn_projEI_ampa[1468] = new NetCon(&v(0.5), syn_projEI_ampa[1468], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1469: cell 73, seg 0 (0.5) [0.5 on Epop[73]] -> cell 9, seg 0 (0.5) [0.5 on Ipop[9]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[9] syn_projEI_ampa[1469] = new ampa(0.5)")
        h("Epop[73] netConn_projEI_ampa[1469] = new NetCon(&v(0.5), syn_projEI_ampa[1469], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1470: cell 73, seg 0 (0.5) [0.5 on Epop[73]] -> cell 10, seg 0 (0.5) [0.5 on Ipop[10]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[10] syn_projEI_ampa[1470] = new ampa(0.5)")
        h("Epop[73] netConn_projEI_ampa[1470] = new NetCon(&v(0.5), syn_projEI_ampa[1470], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1471: cell 73, seg 0 (0.5) [0.5 on Epop[73]] -> cell 11, seg 0 (0.5) [0.5 on Ipop[11]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[11] syn_projEI_ampa[1471] = new ampa(0.5)")
        h("Epop[73] netConn_projEI_ampa[1471] = new NetCon(&v(0.5), syn_projEI_ampa[1471], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1472: cell 73, seg 0 (0.5) [0.5 on Epop[73]] -> cell 12, seg 0 (0.5) [0.5 on Ipop[12]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[12] syn_projEI_ampa[1472] = new ampa(0.5)")
        h("Epop[73] netConn_projEI_ampa[1472] = new NetCon(&v(0.5), syn_projEI_ampa[1472], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1473: cell 73, seg 0 (0.5) [0.5 on Epop[73]] -> cell 13, seg 0 (0.5) [0.5 on Ipop[13]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[13] syn_projEI_ampa[1473] = new ampa(0.5)")
        h("Epop[73] netConn_projEI_ampa[1473] = new NetCon(&v(0.5), syn_projEI_ampa[1473], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1474: cell 73, seg 0 (0.5) [0.5 on Epop[73]] -> cell 14, seg 0 (0.5) [0.5 on Ipop[14]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[14] syn_projEI_ampa[1474] = new ampa(0.5)")
        h("Epop[73] netConn_projEI_ampa[1474] = new NetCon(&v(0.5), syn_projEI_ampa[1474], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1475: cell 73, seg 0 (0.5) [0.5 on Epop[73]] -> cell 15, seg 0 (0.5) [0.5 on Ipop[15]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[15] syn_projEI_ampa[1475] = new ampa(0.5)")
        h("Epop[73] netConn_projEI_ampa[1475] = new NetCon(&v(0.5), syn_projEI_ampa[1475], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1476: cell 73, seg 0 (0.5) [0.5 on Epop[73]] -> cell 16, seg 0 (0.5) [0.5 on Ipop[16]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[16] syn_projEI_ampa[1476] = new ampa(0.5)")
        h("Epop[73] netConn_projEI_ampa[1476] = new NetCon(&v(0.5), syn_projEI_ampa[1476], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1477: cell 73, seg 0 (0.5) [0.5 on Epop[73]] -> cell 17, seg 0 (0.5) [0.5 on Ipop[17]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[17] syn_projEI_ampa[1477] = new ampa(0.5)")
        h("Epop[73] netConn_projEI_ampa[1477] = new NetCon(&v(0.5), syn_projEI_ampa[1477], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1478: cell 73, seg 0 (0.5) [0.5 on Epop[73]] -> cell 18, seg 0 (0.5) [0.5 on Ipop[18]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[18] syn_projEI_ampa[1478] = new ampa(0.5)")
        h("Epop[73] netConn_projEI_ampa[1478] = new NetCon(&v(0.5), syn_projEI_ampa[1478], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1479: cell 73, seg 0 (0.5) [0.5 on Epop[73]] -> cell 19, seg 0 (0.5) [0.5 on Ipop[19]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[19] syn_projEI_ampa[1479] = new ampa(0.5)")
        h("Epop[73] netConn_projEI_ampa[1479] = new NetCon(&v(0.5), syn_projEI_ampa[1479], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1480: cell 74, seg 0 (0.5) [0.5 on Epop[74]] -> cell 0, seg 0 (0.5) [0.5 on Ipop[0]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[0] syn_projEI_ampa[1480] = new ampa(0.5)")
        h("Epop[74] netConn_projEI_ampa[1480] = new NetCon(&v(0.5), syn_projEI_ampa[1480], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1481: cell 74, seg 0 (0.5) [0.5 on Epop[74]] -> cell 1, seg 0 (0.5) [0.5 on Ipop[1]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[1] syn_projEI_ampa[1481] = new ampa(0.5)")
        h("Epop[74] netConn_projEI_ampa[1481] = new NetCon(&v(0.5), syn_projEI_ampa[1481], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1482: cell 74, seg 0 (0.5) [0.5 on Epop[74]] -> cell 2, seg 0 (0.5) [0.5 on Ipop[2]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[2] syn_projEI_ampa[1482] = new ampa(0.5)")
        h("Epop[74] netConn_projEI_ampa[1482] = new NetCon(&v(0.5), syn_projEI_ampa[1482], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1483: cell 74, seg 0 (0.5) [0.5 on Epop[74]] -> cell 3, seg 0 (0.5) [0.5 on Ipop[3]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[3] syn_projEI_ampa[1483] = new ampa(0.5)")
        h("Epop[74] netConn_projEI_ampa[1483] = new NetCon(&v(0.5), syn_projEI_ampa[1483], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1484: cell 74, seg 0 (0.5) [0.5 on Epop[74]] -> cell 4, seg 0 (0.5) [0.5 on Ipop[4]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[4] syn_projEI_ampa[1484] = new ampa(0.5)")
        h("Epop[74] netConn_projEI_ampa[1484] = new NetCon(&v(0.5), syn_projEI_ampa[1484], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1485: cell 74, seg 0 (0.5) [0.5 on Epop[74]] -> cell 5, seg 0 (0.5) [0.5 on Ipop[5]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[5] syn_projEI_ampa[1485] = new ampa(0.5)")
        h("Epop[74] netConn_projEI_ampa[1485] = new NetCon(&v(0.5), syn_projEI_ampa[1485], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1486: cell 74, seg 0 (0.5) [0.5 on Epop[74]] -> cell 6, seg 0 (0.5) [0.5 on Ipop[6]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[6] syn_projEI_ampa[1486] = new ampa(0.5)")
        h("Epop[74] netConn_projEI_ampa[1486] = new NetCon(&v(0.5), syn_projEI_ampa[1486], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1487: cell 74, seg 0 (0.5) [0.5 on Epop[74]] -> cell 7, seg 0 (0.5) [0.5 on Ipop[7]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[7] syn_projEI_ampa[1487] = new ampa(0.5)")
        h("Epop[74] netConn_projEI_ampa[1487] = new NetCon(&v(0.5), syn_projEI_ampa[1487], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1488: cell 74, seg 0 (0.5) [0.5 on Epop[74]] -> cell 8, seg 0 (0.5) [0.5 on Ipop[8]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[8] syn_projEI_ampa[1488] = new ampa(0.5)")
        h("Epop[74] netConn_projEI_ampa[1488] = new NetCon(&v(0.5), syn_projEI_ampa[1488], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1489: cell 74, seg 0 (0.5) [0.5 on Epop[74]] -> cell 9, seg 0 (0.5) [0.5 on Ipop[9]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[9] syn_projEI_ampa[1489] = new ampa(0.5)")
        h("Epop[74] netConn_projEI_ampa[1489] = new NetCon(&v(0.5), syn_projEI_ampa[1489], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1490: cell 74, seg 0 (0.5) [0.5 on Epop[74]] -> cell 10, seg 0 (0.5) [0.5 on Ipop[10]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[10] syn_projEI_ampa[1490] = new ampa(0.5)")
        h("Epop[74] netConn_projEI_ampa[1490] = new NetCon(&v(0.5), syn_projEI_ampa[1490], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1491: cell 74, seg 0 (0.5) [0.5 on Epop[74]] -> cell 11, seg 0 (0.5) [0.5 on Ipop[11]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[11] syn_projEI_ampa[1491] = new ampa(0.5)")
        h("Epop[74] netConn_projEI_ampa[1491] = new NetCon(&v(0.5), syn_projEI_ampa[1491], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1492: cell 74, seg 0 (0.5) [0.5 on Epop[74]] -> cell 12, seg 0 (0.5) [0.5 on Ipop[12]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[12] syn_projEI_ampa[1492] = new ampa(0.5)")
        h("Epop[74] netConn_projEI_ampa[1492] = new NetCon(&v(0.5), syn_projEI_ampa[1492], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1493: cell 74, seg 0 (0.5) [0.5 on Epop[74]] -> cell 13, seg 0 (0.5) [0.5 on Ipop[13]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[13] syn_projEI_ampa[1493] = new ampa(0.5)")
        h("Epop[74] netConn_projEI_ampa[1493] = new NetCon(&v(0.5), syn_projEI_ampa[1493], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1494: cell 74, seg 0 (0.5) [0.5 on Epop[74]] -> cell 14, seg 0 (0.5) [0.5 on Ipop[14]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[14] syn_projEI_ampa[1494] = new ampa(0.5)")
        h("Epop[74] netConn_projEI_ampa[1494] = new NetCon(&v(0.5), syn_projEI_ampa[1494], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1495: cell 74, seg 0 (0.5) [0.5 on Epop[74]] -> cell 15, seg 0 (0.5) [0.5 on Ipop[15]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[15] syn_projEI_ampa[1495] = new ampa(0.5)")
        h("Epop[74] netConn_projEI_ampa[1495] = new NetCon(&v(0.5), syn_projEI_ampa[1495], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1496: cell 74, seg 0 (0.5) [0.5 on Epop[74]] -> cell 16, seg 0 (0.5) [0.5 on Ipop[16]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[16] syn_projEI_ampa[1496] = new ampa(0.5)")
        h("Epop[74] netConn_projEI_ampa[1496] = new NetCon(&v(0.5), syn_projEI_ampa[1496], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1497: cell 74, seg 0 (0.5) [0.5 on Epop[74]] -> cell 17, seg 0 (0.5) [0.5 on Ipop[17]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[17] syn_projEI_ampa[1497] = new ampa(0.5)")
        h("Epop[74] netConn_projEI_ampa[1497] = new NetCon(&v(0.5), syn_projEI_ampa[1497], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1498: cell 74, seg 0 (0.5) [0.5 on Epop[74]] -> cell 18, seg 0 (0.5) [0.5 on Ipop[18]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[18] syn_projEI_ampa[1498] = new ampa(0.5)")
        h("Epop[74] netConn_projEI_ampa[1498] = new NetCon(&v(0.5), syn_projEI_ampa[1498], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1499: cell 74, seg 0 (0.5) [0.5 on Epop[74]] -> cell 19, seg 0 (0.5) [0.5 on Ipop[19]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[19] syn_projEI_ampa[1499] = new ampa(0.5)")
        h("Epop[74] netConn_projEI_ampa[1499] = new NetCon(&v(0.5), syn_projEI_ampa[1499], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1500: cell 75, seg 0 (0.5) [0.5 on Epop[75]] -> cell 0, seg 0 (0.5) [0.5 on Ipop[0]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[0] syn_projEI_ampa[1500] = new ampa(0.5)")
        h("Epop[75] netConn_projEI_ampa[1500] = new NetCon(&v(0.5), syn_projEI_ampa[1500], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1501: cell 75, seg 0 (0.5) [0.5 on Epop[75]] -> cell 1, seg 0 (0.5) [0.5 on Ipop[1]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[1] syn_projEI_ampa[1501] = new ampa(0.5)")
        h("Epop[75] netConn_projEI_ampa[1501] = new NetCon(&v(0.5), syn_projEI_ampa[1501], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1502: cell 75, seg 0 (0.5) [0.5 on Epop[75]] -> cell 2, seg 0 (0.5) [0.5 on Ipop[2]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[2] syn_projEI_ampa[1502] = new ampa(0.5)")
        h("Epop[75] netConn_projEI_ampa[1502] = new NetCon(&v(0.5), syn_projEI_ampa[1502], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1503: cell 75, seg 0 (0.5) [0.5 on Epop[75]] -> cell 3, seg 0 (0.5) [0.5 on Ipop[3]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[3] syn_projEI_ampa[1503] = new ampa(0.5)")
        h("Epop[75] netConn_projEI_ampa[1503] = new NetCon(&v(0.5), syn_projEI_ampa[1503], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1504: cell 75, seg 0 (0.5) [0.5 on Epop[75]] -> cell 4, seg 0 (0.5) [0.5 on Ipop[4]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[4] syn_projEI_ampa[1504] = new ampa(0.5)")
        h("Epop[75] netConn_projEI_ampa[1504] = new NetCon(&v(0.5), syn_projEI_ampa[1504], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1505: cell 75, seg 0 (0.5) [0.5 on Epop[75]] -> cell 5, seg 0 (0.5) [0.5 on Ipop[5]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[5] syn_projEI_ampa[1505] = new ampa(0.5)")
        h("Epop[75] netConn_projEI_ampa[1505] = new NetCon(&v(0.5), syn_projEI_ampa[1505], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1506: cell 75, seg 0 (0.5) [0.5 on Epop[75]] -> cell 6, seg 0 (0.5) [0.5 on Ipop[6]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[6] syn_projEI_ampa[1506] = new ampa(0.5)")
        h("Epop[75] netConn_projEI_ampa[1506] = new NetCon(&v(0.5), syn_projEI_ampa[1506], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1507: cell 75, seg 0 (0.5) [0.5 on Epop[75]] -> cell 7, seg 0 (0.5) [0.5 on Ipop[7]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[7] syn_projEI_ampa[1507] = new ampa(0.5)")
        h("Epop[75] netConn_projEI_ampa[1507] = new NetCon(&v(0.5), syn_projEI_ampa[1507], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1508: cell 75, seg 0 (0.5) [0.5 on Epop[75]] -> cell 8, seg 0 (0.5) [0.5 on Ipop[8]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[8] syn_projEI_ampa[1508] = new ampa(0.5)")
        h("Epop[75] netConn_projEI_ampa[1508] = new NetCon(&v(0.5), syn_projEI_ampa[1508], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1509: cell 75, seg 0 (0.5) [0.5 on Epop[75]] -> cell 9, seg 0 (0.5) [0.5 on Ipop[9]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[9] syn_projEI_ampa[1509] = new ampa(0.5)")
        h("Epop[75] netConn_projEI_ampa[1509] = new NetCon(&v(0.5), syn_projEI_ampa[1509], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1510: cell 75, seg 0 (0.5) [0.5 on Epop[75]] -> cell 10, seg 0 (0.5) [0.5 on Ipop[10]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[10] syn_projEI_ampa[1510] = new ampa(0.5)")
        h("Epop[75] netConn_projEI_ampa[1510] = new NetCon(&v(0.5), syn_projEI_ampa[1510], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1511: cell 75, seg 0 (0.5) [0.5 on Epop[75]] -> cell 11, seg 0 (0.5) [0.5 on Ipop[11]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[11] syn_projEI_ampa[1511] = new ampa(0.5)")
        h("Epop[75] netConn_projEI_ampa[1511] = new NetCon(&v(0.5), syn_projEI_ampa[1511], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1512: cell 75, seg 0 (0.5) [0.5 on Epop[75]] -> cell 12, seg 0 (0.5) [0.5 on Ipop[12]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[12] syn_projEI_ampa[1512] = new ampa(0.5)")
        h("Epop[75] netConn_projEI_ampa[1512] = new NetCon(&v(0.5), syn_projEI_ampa[1512], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1513: cell 75, seg 0 (0.5) [0.5 on Epop[75]] -> cell 13, seg 0 (0.5) [0.5 on Ipop[13]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[13] syn_projEI_ampa[1513] = new ampa(0.5)")
        h("Epop[75] netConn_projEI_ampa[1513] = new NetCon(&v(0.5), syn_projEI_ampa[1513], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1514: cell 75, seg 0 (0.5) [0.5 on Epop[75]] -> cell 14, seg 0 (0.5) [0.5 on Ipop[14]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[14] syn_projEI_ampa[1514] = new ampa(0.5)")
        h("Epop[75] netConn_projEI_ampa[1514] = new NetCon(&v(0.5), syn_projEI_ampa[1514], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1515: cell 75, seg 0 (0.5) [0.5 on Epop[75]] -> cell 15, seg 0 (0.5) [0.5 on Ipop[15]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[15] syn_projEI_ampa[1515] = new ampa(0.5)")
        h("Epop[75] netConn_projEI_ampa[1515] = new NetCon(&v(0.5), syn_projEI_ampa[1515], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1516: cell 75, seg 0 (0.5) [0.5 on Epop[75]] -> cell 16, seg 0 (0.5) [0.5 on Ipop[16]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[16] syn_projEI_ampa[1516] = new ampa(0.5)")
        h("Epop[75] netConn_projEI_ampa[1516] = new NetCon(&v(0.5), syn_projEI_ampa[1516], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1517: cell 75, seg 0 (0.5) [0.5 on Epop[75]] -> cell 17, seg 0 (0.5) [0.5 on Ipop[17]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[17] syn_projEI_ampa[1517] = new ampa(0.5)")
        h("Epop[75] netConn_projEI_ampa[1517] = new NetCon(&v(0.5), syn_projEI_ampa[1517], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1518: cell 75, seg 0 (0.5) [0.5 on Epop[75]] -> cell 18, seg 0 (0.5) [0.5 on Ipop[18]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[18] syn_projEI_ampa[1518] = new ampa(0.5)")
        h("Epop[75] netConn_projEI_ampa[1518] = new NetCon(&v(0.5), syn_projEI_ampa[1518], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1519: cell 75, seg 0 (0.5) [0.5 on Epop[75]] -> cell 19, seg 0 (0.5) [0.5 on Ipop[19]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[19] syn_projEI_ampa[1519] = new ampa(0.5)")
        h("Epop[75] netConn_projEI_ampa[1519] = new NetCon(&v(0.5), syn_projEI_ampa[1519], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1520: cell 76, seg 0 (0.5) [0.5 on Epop[76]] -> cell 0, seg 0 (0.5) [0.5 on Ipop[0]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[0] syn_projEI_ampa[1520] = new ampa(0.5)")
        h("Epop[76] netConn_projEI_ampa[1520] = new NetCon(&v(0.5), syn_projEI_ampa[1520], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1521: cell 76, seg 0 (0.5) [0.5 on Epop[76]] -> cell 1, seg 0 (0.5) [0.5 on Ipop[1]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[1] syn_projEI_ampa[1521] = new ampa(0.5)")
        h("Epop[76] netConn_projEI_ampa[1521] = new NetCon(&v(0.5), syn_projEI_ampa[1521], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1522: cell 76, seg 0 (0.5) [0.5 on Epop[76]] -> cell 2, seg 0 (0.5) [0.5 on Ipop[2]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[2] syn_projEI_ampa[1522] = new ampa(0.5)")
        h("Epop[76] netConn_projEI_ampa[1522] = new NetCon(&v(0.5), syn_projEI_ampa[1522], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1523: cell 76, seg 0 (0.5) [0.5 on Epop[76]] -> cell 3, seg 0 (0.5) [0.5 on Ipop[3]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[3] syn_projEI_ampa[1523] = new ampa(0.5)")
        h("Epop[76] netConn_projEI_ampa[1523] = new NetCon(&v(0.5), syn_projEI_ampa[1523], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1524: cell 76, seg 0 (0.5) [0.5 on Epop[76]] -> cell 4, seg 0 (0.5) [0.5 on Ipop[4]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[4] syn_projEI_ampa[1524] = new ampa(0.5)")
        h("Epop[76] netConn_projEI_ampa[1524] = new NetCon(&v(0.5), syn_projEI_ampa[1524], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1525: cell 76, seg 0 (0.5) [0.5 on Epop[76]] -> cell 5, seg 0 (0.5) [0.5 on Ipop[5]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[5] syn_projEI_ampa[1525] = new ampa(0.5)")
        h("Epop[76] netConn_projEI_ampa[1525] = new NetCon(&v(0.5), syn_projEI_ampa[1525], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1526: cell 76, seg 0 (0.5) [0.5 on Epop[76]] -> cell 6, seg 0 (0.5) [0.5 on Ipop[6]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[6] syn_projEI_ampa[1526] = new ampa(0.5)")
        h("Epop[76] netConn_projEI_ampa[1526] = new NetCon(&v(0.5), syn_projEI_ampa[1526], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1527: cell 76, seg 0 (0.5) [0.5 on Epop[76]] -> cell 7, seg 0 (0.5) [0.5 on Ipop[7]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[7] syn_projEI_ampa[1527] = new ampa(0.5)")
        h("Epop[76] netConn_projEI_ampa[1527] = new NetCon(&v(0.5), syn_projEI_ampa[1527], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1528: cell 76, seg 0 (0.5) [0.5 on Epop[76]] -> cell 8, seg 0 (0.5) [0.5 on Ipop[8]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[8] syn_projEI_ampa[1528] = new ampa(0.5)")
        h("Epop[76] netConn_projEI_ampa[1528] = new NetCon(&v(0.5), syn_projEI_ampa[1528], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1529: cell 76, seg 0 (0.5) [0.5 on Epop[76]] -> cell 9, seg 0 (0.5) [0.5 on Ipop[9]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[9] syn_projEI_ampa[1529] = new ampa(0.5)")
        h("Epop[76] netConn_projEI_ampa[1529] = new NetCon(&v(0.5), syn_projEI_ampa[1529], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1530: cell 76, seg 0 (0.5) [0.5 on Epop[76]] -> cell 10, seg 0 (0.5) [0.5 on Ipop[10]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[10] syn_projEI_ampa[1530] = new ampa(0.5)")
        h("Epop[76] netConn_projEI_ampa[1530] = new NetCon(&v(0.5), syn_projEI_ampa[1530], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1531: cell 76, seg 0 (0.5) [0.5 on Epop[76]] -> cell 11, seg 0 (0.5) [0.5 on Ipop[11]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[11] syn_projEI_ampa[1531] = new ampa(0.5)")
        h("Epop[76] netConn_projEI_ampa[1531] = new NetCon(&v(0.5), syn_projEI_ampa[1531], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1532: cell 76, seg 0 (0.5) [0.5 on Epop[76]] -> cell 12, seg 0 (0.5) [0.5 on Ipop[12]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[12] syn_projEI_ampa[1532] = new ampa(0.5)")
        h("Epop[76] netConn_projEI_ampa[1532] = new NetCon(&v(0.5), syn_projEI_ampa[1532], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1533: cell 76, seg 0 (0.5) [0.5 on Epop[76]] -> cell 13, seg 0 (0.5) [0.5 on Ipop[13]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[13] syn_projEI_ampa[1533] = new ampa(0.5)")
        h("Epop[76] netConn_projEI_ampa[1533] = new NetCon(&v(0.5), syn_projEI_ampa[1533], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1534: cell 76, seg 0 (0.5) [0.5 on Epop[76]] -> cell 14, seg 0 (0.5) [0.5 on Ipop[14]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[14] syn_projEI_ampa[1534] = new ampa(0.5)")
        h("Epop[76] netConn_projEI_ampa[1534] = new NetCon(&v(0.5), syn_projEI_ampa[1534], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1535: cell 76, seg 0 (0.5) [0.5 on Epop[76]] -> cell 15, seg 0 (0.5) [0.5 on Ipop[15]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[15] syn_projEI_ampa[1535] = new ampa(0.5)")
        h("Epop[76] netConn_projEI_ampa[1535] = new NetCon(&v(0.5), syn_projEI_ampa[1535], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1536: cell 76, seg 0 (0.5) [0.5 on Epop[76]] -> cell 16, seg 0 (0.5) [0.5 on Ipop[16]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[16] syn_projEI_ampa[1536] = new ampa(0.5)")
        h("Epop[76] netConn_projEI_ampa[1536] = new NetCon(&v(0.5), syn_projEI_ampa[1536], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1537: cell 76, seg 0 (0.5) [0.5 on Epop[76]] -> cell 17, seg 0 (0.5) [0.5 on Ipop[17]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[17] syn_projEI_ampa[1537] = new ampa(0.5)")
        h("Epop[76] netConn_projEI_ampa[1537] = new NetCon(&v(0.5), syn_projEI_ampa[1537], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1538: cell 76, seg 0 (0.5) [0.5 on Epop[76]] -> cell 18, seg 0 (0.5) [0.5 on Ipop[18]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[18] syn_projEI_ampa[1538] = new ampa(0.5)")
        h("Epop[76] netConn_projEI_ampa[1538] = new NetCon(&v(0.5), syn_projEI_ampa[1538], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1539: cell 76, seg 0 (0.5) [0.5 on Epop[76]] -> cell 19, seg 0 (0.5) [0.5 on Ipop[19]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[19] syn_projEI_ampa[1539] = new ampa(0.5)")
        h("Epop[76] netConn_projEI_ampa[1539] = new NetCon(&v(0.5), syn_projEI_ampa[1539], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1540: cell 77, seg 0 (0.5) [0.5 on Epop[77]] -> cell 0, seg 0 (0.5) [0.5 on Ipop[0]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[0] syn_projEI_ampa[1540] = new ampa(0.5)")
        h("Epop[77] netConn_projEI_ampa[1540] = new NetCon(&v(0.5), syn_projEI_ampa[1540], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1541: cell 77, seg 0 (0.5) [0.5 on Epop[77]] -> cell 1, seg 0 (0.5) [0.5 on Ipop[1]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[1] syn_projEI_ampa[1541] = new ampa(0.5)")
        h("Epop[77] netConn_projEI_ampa[1541] = new NetCon(&v(0.5), syn_projEI_ampa[1541], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1542: cell 77, seg 0 (0.5) [0.5 on Epop[77]] -> cell 2, seg 0 (0.5) [0.5 on Ipop[2]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[2] syn_projEI_ampa[1542] = new ampa(0.5)")
        h("Epop[77] netConn_projEI_ampa[1542] = new NetCon(&v(0.5), syn_projEI_ampa[1542], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1543: cell 77, seg 0 (0.5) [0.5 on Epop[77]] -> cell 3, seg 0 (0.5) [0.5 on Ipop[3]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[3] syn_projEI_ampa[1543] = new ampa(0.5)")
        h("Epop[77] netConn_projEI_ampa[1543] = new NetCon(&v(0.5), syn_projEI_ampa[1543], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1544: cell 77, seg 0 (0.5) [0.5 on Epop[77]] -> cell 4, seg 0 (0.5) [0.5 on Ipop[4]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[4] syn_projEI_ampa[1544] = new ampa(0.5)")
        h("Epop[77] netConn_projEI_ampa[1544] = new NetCon(&v(0.5), syn_projEI_ampa[1544], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1545: cell 77, seg 0 (0.5) [0.5 on Epop[77]] -> cell 5, seg 0 (0.5) [0.5 on Ipop[5]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[5] syn_projEI_ampa[1545] = new ampa(0.5)")
        h("Epop[77] netConn_projEI_ampa[1545] = new NetCon(&v(0.5), syn_projEI_ampa[1545], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1546: cell 77, seg 0 (0.5) [0.5 on Epop[77]] -> cell 6, seg 0 (0.5) [0.5 on Ipop[6]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[6] syn_projEI_ampa[1546] = new ampa(0.5)")
        h("Epop[77] netConn_projEI_ampa[1546] = new NetCon(&v(0.5), syn_projEI_ampa[1546], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1547: cell 77, seg 0 (0.5) [0.5 on Epop[77]] -> cell 7, seg 0 (0.5) [0.5 on Ipop[7]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[7] syn_projEI_ampa[1547] = new ampa(0.5)")
        h("Epop[77] netConn_projEI_ampa[1547] = new NetCon(&v(0.5), syn_projEI_ampa[1547], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1548: cell 77, seg 0 (0.5) [0.5 on Epop[77]] -> cell 8, seg 0 (0.5) [0.5 on Ipop[8]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[8] syn_projEI_ampa[1548] = new ampa(0.5)")
        h("Epop[77] netConn_projEI_ampa[1548] = new NetCon(&v(0.5), syn_projEI_ampa[1548], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1549: cell 77, seg 0 (0.5) [0.5 on Epop[77]] -> cell 9, seg 0 (0.5) [0.5 on Ipop[9]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[9] syn_projEI_ampa[1549] = new ampa(0.5)")
        h("Epop[77] netConn_projEI_ampa[1549] = new NetCon(&v(0.5), syn_projEI_ampa[1549], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1550: cell 77, seg 0 (0.5) [0.5 on Epop[77]] -> cell 10, seg 0 (0.5) [0.5 on Ipop[10]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[10] syn_projEI_ampa[1550] = new ampa(0.5)")
        h("Epop[77] netConn_projEI_ampa[1550] = new NetCon(&v(0.5), syn_projEI_ampa[1550], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1551: cell 77, seg 0 (0.5) [0.5 on Epop[77]] -> cell 11, seg 0 (0.5) [0.5 on Ipop[11]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[11] syn_projEI_ampa[1551] = new ampa(0.5)")
        h("Epop[77] netConn_projEI_ampa[1551] = new NetCon(&v(0.5), syn_projEI_ampa[1551], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1552: cell 77, seg 0 (0.5) [0.5 on Epop[77]] -> cell 12, seg 0 (0.5) [0.5 on Ipop[12]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[12] syn_projEI_ampa[1552] = new ampa(0.5)")
        h("Epop[77] netConn_projEI_ampa[1552] = new NetCon(&v(0.5), syn_projEI_ampa[1552], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1553: cell 77, seg 0 (0.5) [0.5 on Epop[77]] -> cell 13, seg 0 (0.5) [0.5 on Ipop[13]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[13] syn_projEI_ampa[1553] = new ampa(0.5)")
        h("Epop[77] netConn_projEI_ampa[1553] = new NetCon(&v(0.5), syn_projEI_ampa[1553], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1554: cell 77, seg 0 (0.5) [0.5 on Epop[77]] -> cell 14, seg 0 (0.5) [0.5 on Ipop[14]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[14] syn_projEI_ampa[1554] = new ampa(0.5)")
        h("Epop[77] netConn_projEI_ampa[1554] = new NetCon(&v(0.5), syn_projEI_ampa[1554], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1555: cell 77, seg 0 (0.5) [0.5 on Epop[77]] -> cell 15, seg 0 (0.5) [0.5 on Ipop[15]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[15] syn_projEI_ampa[1555] = new ampa(0.5)")
        h("Epop[77] netConn_projEI_ampa[1555] = new NetCon(&v(0.5), syn_projEI_ampa[1555], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1556: cell 77, seg 0 (0.5) [0.5 on Epop[77]] -> cell 16, seg 0 (0.5) [0.5 on Ipop[16]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[16] syn_projEI_ampa[1556] = new ampa(0.5)")
        h("Epop[77] netConn_projEI_ampa[1556] = new NetCon(&v(0.5), syn_projEI_ampa[1556], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1557: cell 77, seg 0 (0.5) [0.5 on Epop[77]] -> cell 17, seg 0 (0.5) [0.5 on Ipop[17]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[17] syn_projEI_ampa[1557] = new ampa(0.5)")
        h("Epop[77] netConn_projEI_ampa[1557] = new NetCon(&v(0.5), syn_projEI_ampa[1557], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1558: cell 77, seg 0 (0.5) [0.5 on Epop[77]] -> cell 18, seg 0 (0.5) [0.5 on Ipop[18]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[18] syn_projEI_ampa[1558] = new ampa(0.5)")
        h("Epop[77] netConn_projEI_ampa[1558] = new NetCon(&v(0.5), syn_projEI_ampa[1558], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1559: cell 77, seg 0 (0.5) [0.5 on Epop[77]] -> cell 19, seg 0 (0.5) [0.5 on Ipop[19]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[19] syn_projEI_ampa[1559] = new ampa(0.5)")
        h("Epop[77] netConn_projEI_ampa[1559] = new NetCon(&v(0.5), syn_projEI_ampa[1559], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1560: cell 78, seg 0 (0.5) [0.5 on Epop[78]] -> cell 0, seg 0 (0.5) [0.5 on Ipop[0]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[0] syn_projEI_ampa[1560] = new ampa(0.5)")
        h("Epop[78] netConn_projEI_ampa[1560] = new NetCon(&v(0.5), syn_projEI_ampa[1560], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1561: cell 78, seg 0 (0.5) [0.5 on Epop[78]] -> cell 1, seg 0 (0.5) [0.5 on Ipop[1]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[1] syn_projEI_ampa[1561] = new ampa(0.5)")
        h("Epop[78] netConn_projEI_ampa[1561] = new NetCon(&v(0.5), syn_projEI_ampa[1561], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1562: cell 78, seg 0 (0.5) [0.5 on Epop[78]] -> cell 2, seg 0 (0.5) [0.5 on Ipop[2]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[2] syn_projEI_ampa[1562] = new ampa(0.5)")
        h("Epop[78] netConn_projEI_ampa[1562] = new NetCon(&v(0.5), syn_projEI_ampa[1562], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1563: cell 78, seg 0 (0.5) [0.5 on Epop[78]] -> cell 3, seg 0 (0.5) [0.5 on Ipop[3]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[3] syn_projEI_ampa[1563] = new ampa(0.5)")
        h("Epop[78] netConn_projEI_ampa[1563] = new NetCon(&v(0.5), syn_projEI_ampa[1563], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1564: cell 78, seg 0 (0.5) [0.5 on Epop[78]] -> cell 4, seg 0 (0.5) [0.5 on Ipop[4]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[4] syn_projEI_ampa[1564] = new ampa(0.5)")
        h("Epop[78] netConn_projEI_ampa[1564] = new NetCon(&v(0.5), syn_projEI_ampa[1564], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1565: cell 78, seg 0 (0.5) [0.5 on Epop[78]] -> cell 5, seg 0 (0.5) [0.5 on Ipop[5]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[5] syn_projEI_ampa[1565] = new ampa(0.5)")
        h("Epop[78] netConn_projEI_ampa[1565] = new NetCon(&v(0.5), syn_projEI_ampa[1565], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1566: cell 78, seg 0 (0.5) [0.5 on Epop[78]] -> cell 6, seg 0 (0.5) [0.5 on Ipop[6]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[6] syn_projEI_ampa[1566] = new ampa(0.5)")
        h("Epop[78] netConn_projEI_ampa[1566] = new NetCon(&v(0.5), syn_projEI_ampa[1566], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1567: cell 78, seg 0 (0.5) [0.5 on Epop[78]] -> cell 7, seg 0 (0.5) [0.5 on Ipop[7]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[7] syn_projEI_ampa[1567] = new ampa(0.5)")
        h("Epop[78] netConn_projEI_ampa[1567] = new NetCon(&v(0.5), syn_projEI_ampa[1567], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1568: cell 78, seg 0 (0.5) [0.5 on Epop[78]] -> cell 8, seg 0 (0.5) [0.5 on Ipop[8]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[8] syn_projEI_ampa[1568] = new ampa(0.5)")
        h("Epop[78] netConn_projEI_ampa[1568] = new NetCon(&v(0.5), syn_projEI_ampa[1568], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1569: cell 78, seg 0 (0.5) [0.5 on Epop[78]] -> cell 9, seg 0 (0.5) [0.5 on Ipop[9]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[9] syn_projEI_ampa[1569] = new ampa(0.5)")
        h("Epop[78] netConn_projEI_ampa[1569] = new NetCon(&v(0.5), syn_projEI_ampa[1569], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1570: cell 78, seg 0 (0.5) [0.5 on Epop[78]] -> cell 10, seg 0 (0.5) [0.5 on Ipop[10]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[10] syn_projEI_ampa[1570] = new ampa(0.5)")
        h("Epop[78] netConn_projEI_ampa[1570] = new NetCon(&v(0.5), syn_projEI_ampa[1570], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1571: cell 78, seg 0 (0.5) [0.5 on Epop[78]] -> cell 11, seg 0 (0.5) [0.5 on Ipop[11]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[11] syn_projEI_ampa[1571] = new ampa(0.5)")
        h("Epop[78] netConn_projEI_ampa[1571] = new NetCon(&v(0.5), syn_projEI_ampa[1571], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1572: cell 78, seg 0 (0.5) [0.5 on Epop[78]] -> cell 12, seg 0 (0.5) [0.5 on Ipop[12]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[12] syn_projEI_ampa[1572] = new ampa(0.5)")
        h("Epop[78] netConn_projEI_ampa[1572] = new NetCon(&v(0.5), syn_projEI_ampa[1572], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1573: cell 78, seg 0 (0.5) [0.5 on Epop[78]] -> cell 13, seg 0 (0.5) [0.5 on Ipop[13]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[13] syn_projEI_ampa[1573] = new ampa(0.5)")
        h("Epop[78] netConn_projEI_ampa[1573] = new NetCon(&v(0.5), syn_projEI_ampa[1573], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1574: cell 78, seg 0 (0.5) [0.5 on Epop[78]] -> cell 14, seg 0 (0.5) [0.5 on Ipop[14]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[14] syn_projEI_ampa[1574] = new ampa(0.5)")
        h("Epop[78] netConn_projEI_ampa[1574] = new NetCon(&v(0.5), syn_projEI_ampa[1574], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1575: cell 78, seg 0 (0.5) [0.5 on Epop[78]] -> cell 15, seg 0 (0.5) [0.5 on Ipop[15]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[15] syn_projEI_ampa[1575] = new ampa(0.5)")
        h("Epop[78] netConn_projEI_ampa[1575] = new NetCon(&v(0.5), syn_projEI_ampa[1575], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1576: cell 78, seg 0 (0.5) [0.5 on Epop[78]] -> cell 16, seg 0 (0.5) [0.5 on Ipop[16]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[16] syn_projEI_ampa[1576] = new ampa(0.5)")
        h("Epop[78] netConn_projEI_ampa[1576] = new NetCon(&v(0.5), syn_projEI_ampa[1576], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1577: cell 78, seg 0 (0.5) [0.5 on Epop[78]] -> cell 17, seg 0 (0.5) [0.5 on Ipop[17]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[17] syn_projEI_ampa[1577] = new ampa(0.5)")
        h("Epop[78] netConn_projEI_ampa[1577] = new NetCon(&v(0.5), syn_projEI_ampa[1577], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1578: cell 78, seg 0 (0.5) [0.5 on Epop[78]] -> cell 18, seg 0 (0.5) [0.5 on Ipop[18]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[18] syn_projEI_ampa[1578] = new ampa(0.5)")
        h("Epop[78] netConn_projEI_ampa[1578] = new NetCon(&v(0.5), syn_projEI_ampa[1578], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1579: cell 78, seg 0 (0.5) [0.5 on Epop[78]] -> cell 19, seg 0 (0.5) [0.5 on Ipop[19]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[19] syn_projEI_ampa[1579] = new ampa(0.5)")
        h("Epop[78] netConn_projEI_ampa[1579] = new NetCon(&v(0.5), syn_projEI_ampa[1579], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1580: cell 79, seg 0 (0.5) [0.5 on Epop[79]] -> cell 0, seg 0 (0.5) [0.5 on Ipop[0]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[0] syn_projEI_ampa[1580] = new ampa(0.5)")
        h("Epop[79] netConn_projEI_ampa[1580] = new NetCon(&v(0.5), syn_projEI_ampa[1580], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1581: cell 79, seg 0 (0.5) [0.5 on Epop[79]] -> cell 1, seg 0 (0.5) [0.5 on Ipop[1]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[1] syn_projEI_ampa[1581] = new ampa(0.5)")
        h("Epop[79] netConn_projEI_ampa[1581] = new NetCon(&v(0.5), syn_projEI_ampa[1581], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1582: cell 79, seg 0 (0.5) [0.5 on Epop[79]] -> cell 2, seg 0 (0.5) [0.5 on Ipop[2]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[2] syn_projEI_ampa[1582] = new ampa(0.5)")
        h("Epop[79] netConn_projEI_ampa[1582] = new NetCon(&v(0.5), syn_projEI_ampa[1582], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1583: cell 79, seg 0 (0.5) [0.5 on Epop[79]] -> cell 3, seg 0 (0.5) [0.5 on Ipop[3]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[3] syn_projEI_ampa[1583] = new ampa(0.5)")
        h("Epop[79] netConn_projEI_ampa[1583] = new NetCon(&v(0.5), syn_projEI_ampa[1583], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1584: cell 79, seg 0 (0.5) [0.5 on Epop[79]] -> cell 4, seg 0 (0.5) [0.5 on Ipop[4]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[4] syn_projEI_ampa[1584] = new ampa(0.5)")
        h("Epop[79] netConn_projEI_ampa[1584] = new NetCon(&v(0.5), syn_projEI_ampa[1584], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1585: cell 79, seg 0 (0.5) [0.5 on Epop[79]] -> cell 5, seg 0 (0.5) [0.5 on Ipop[5]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[5] syn_projEI_ampa[1585] = new ampa(0.5)")
        h("Epop[79] netConn_projEI_ampa[1585] = new NetCon(&v(0.5), syn_projEI_ampa[1585], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1586: cell 79, seg 0 (0.5) [0.5 on Epop[79]] -> cell 6, seg 0 (0.5) [0.5 on Ipop[6]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[6] syn_projEI_ampa[1586] = new ampa(0.5)")
        h("Epop[79] netConn_projEI_ampa[1586] = new NetCon(&v(0.5), syn_projEI_ampa[1586], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1587: cell 79, seg 0 (0.5) [0.5 on Epop[79]] -> cell 7, seg 0 (0.5) [0.5 on Ipop[7]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[7] syn_projEI_ampa[1587] = new ampa(0.5)")
        h("Epop[79] netConn_projEI_ampa[1587] = new NetCon(&v(0.5), syn_projEI_ampa[1587], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1588: cell 79, seg 0 (0.5) [0.5 on Epop[79]] -> cell 8, seg 0 (0.5) [0.5 on Ipop[8]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[8] syn_projEI_ampa[1588] = new ampa(0.5)")
        h("Epop[79] netConn_projEI_ampa[1588] = new NetCon(&v(0.5), syn_projEI_ampa[1588], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1589: cell 79, seg 0 (0.5) [0.5 on Epop[79]] -> cell 9, seg 0 (0.5) [0.5 on Ipop[9]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[9] syn_projEI_ampa[1589] = new ampa(0.5)")
        h("Epop[79] netConn_projEI_ampa[1589] = new NetCon(&v(0.5), syn_projEI_ampa[1589], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1590: cell 79, seg 0 (0.5) [0.5 on Epop[79]] -> cell 10, seg 0 (0.5) [0.5 on Ipop[10]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[10] syn_projEI_ampa[1590] = new ampa(0.5)")
        h("Epop[79] netConn_projEI_ampa[1590] = new NetCon(&v(0.5), syn_projEI_ampa[1590], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1591: cell 79, seg 0 (0.5) [0.5 on Epop[79]] -> cell 11, seg 0 (0.5) [0.5 on Ipop[11]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[11] syn_projEI_ampa[1591] = new ampa(0.5)")
        h("Epop[79] netConn_projEI_ampa[1591] = new NetCon(&v(0.5), syn_projEI_ampa[1591], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1592: cell 79, seg 0 (0.5) [0.5 on Epop[79]] -> cell 12, seg 0 (0.5) [0.5 on Ipop[12]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[12] syn_projEI_ampa[1592] = new ampa(0.5)")
        h("Epop[79] netConn_projEI_ampa[1592] = new NetCon(&v(0.5), syn_projEI_ampa[1592], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1593: cell 79, seg 0 (0.5) [0.5 on Epop[79]] -> cell 13, seg 0 (0.5) [0.5 on Ipop[13]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[13] syn_projEI_ampa[1593] = new ampa(0.5)")
        h("Epop[79] netConn_projEI_ampa[1593] = new NetCon(&v(0.5), syn_projEI_ampa[1593], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1594: cell 79, seg 0 (0.5) [0.5 on Epop[79]] -> cell 14, seg 0 (0.5) [0.5 on Ipop[14]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[14] syn_projEI_ampa[1594] = new ampa(0.5)")
        h("Epop[79] netConn_projEI_ampa[1594] = new NetCon(&v(0.5), syn_projEI_ampa[1594], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1595: cell 79, seg 0 (0.5) [0.5 on Epop[79]] -> cell 15, seg 0 (0.5) [0.5 on Ipop[15]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[15] syn_projEI_ampa[1595] = new ampa(0.5)")
        h("Epop[79] netConn_projEI_ampa[1595] = new NetCon(&v(0.5), syn_projEI_ampa[1595], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1596: cell 79, seg 0 (0.5) [0.5 on Epop[79]] -> cell 16, seg 0 (0.5) [0.5 on Ipop[16]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[16] syn_projEI_ampa[1596] = new ampa(0.5)")
        h("Epop[79] netConn_projEI_ampa[1596] = new NetCon(&v(0.5), syn_projEI_ampa[1596], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1597: cell 79, seg 0 (0.5) [0.5 on Epop[79]] -> cell 17, seg 0 (0.5) [0.5 on Ipop[17]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[17] syn_projEI_ampa[1597] = new ampa(0.5)")
        h("Epop[79] netConn_projEI_ampa[1597] = new NetCon(&v(0.5), syn_projEI_ampa[1597], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1598: cell 79, seg 0 (0.5) [0.5 on Epop[79]] -> cell 18, seg 0 (0.5) [0.5 on Ipop[18]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[18] syn_projEI_ampa[1598] = new ampa(0.5)")
        h("Epop[79] netConn_projEI_ampa[1598] = new NetCon(&v(0.5), syn_projEI_ampa[1598], 20.0, 1.5, 4.1363508E-4)")  

        # Connection 1599: cell 79, seg 0 (0.5) [0.5 on Epop[79]] -> cell 19, seg 0 (0.5) [0.5 on Ipop[19]], weight: 4.1363508E-4, delay 1.5
        h("Ipop[19] syn_projEI_ampa[1599] = new ampa(0.5)")
        h("Epop[79] netConn_projEI_ampa[1599] = new NetCon(&v(0.5), syn_projEI_ampa[1599], 20.0, 1.5, 4.1363508E-4)")  

        # ######################   Projection: projIE
        print("Adding projection: projIE, from Ipop to Epop with synapse gaba, 1600 connection(s)")

        h("objectvar syn_projIE_gaba[1600]")

        h("objectvar netConn_projIE_gaba[1600]")

        # Connection 0: cell 0, seg 0 (0.5) [0.5 on Ipop[0]] -> cell 0, seg 0 (0.5) [0.5 on Epop[0]], weight: -0.0016545403, delay 1.5
        h("Epop[0] syn_projIE_gaba[0] = new gaba(0.5)")
        h("Ipop[0] netConn_projIE_gaba[0] = new NetCon(&v(0.5), syn_projIE_gaba[0], 20.0, 1.5, -0.0016545403)")  

        # Connection 1: cell 0, seg 0 (0.5) [0.5 on Ipop[0]] -> cell 1, seg 0 (0.5) [0.5 on Epop[1]], weight: -0.0016545403, delay 1.5
        h("Epop[1] syn_projIE_gaba[1] = new gaba(0.5)")
        h("Ipop[0] netConn_projIE_gaba[1] = new NetCon(&v(0.5), syn_projIE_gaba[1], 20.0, 1.5, -0.0016545403)")  

        # Connection 2: cell 0, seg 0 (0.5) [0.5 on Ipop[0]] -> cell 2, seg 0 (0.5) [0.5 on Epop[2]], weight: -0.0016545403, delay 1.5
        h("Epop[2] syn_projIE_gaba[2] = new gaba(0.5)")
        h("Ipop[0] netConn_projIE_gaba[2] = new NetCon(&v(0.5), syn_projIE_gaba[2], 20.0, 1.5, -0.0016545403)")  

        # Connection 3: cell 0, seg 0 (0.5) [0.5 on Ipop[0]] -> cell 3, seg 0 (0.5) [0.5 on Epop[3]], weight: -0.0016545403, delay 1.5
        h("Epop[3] syn_projIE_gaba[3] = new gaba(0.5)")
        h("Ipop[0] netConn_projIE_gaba[3] = new NetCon(&v(0.5), syn_projIE_gaba[3], 20.0, 1.5, -0.0016545403)")  

        # Connection 4: cell 0, seg 0 (0.5) [0.5 on Ipop[0]] -> cell 4, seg 0 (0.5) [0.5 on Epop[4]], weight: -0.0016545403, delay 1.5
        h("Epop[4] syn_projIE_gaba[4] = new gaba(0.5)")
        h("Ipop[0] netConn_projIE_gaba[4] = new NetCon(&v(0.5), syn_projIE_gaba[4], 20.0, 1.5, -0.0016545403)")  

        # Connection 5: cell 0, seg 0 (0.5) [0.5 on Ipop[0]] -> cell 5, seg 0 (0.5) [0.5 on Epop[5]], weight: -0.0016545403, delay 1.5
        h("Epop[5] syn_projIE_gaba[5] = new gaba(0.5)")
        h("Ipop[0] netConn_projIE_gaba[5] = new NetCon(&v(0.5), syn_projIE_gaba[5], 20.0, 1.5, -0.0016545403)")  

        # Connection 6: cell 0, seg 0 (0.5) [0.5 on Ipop[0]] -> cell 6, seg 0 (0.5) [0.5 on Epop[6]], weight: -0.0016545403, delay 1.5
        h("Epop[6] syn_projIE_gaba[6] = new gaba(0.5)")
        h("Ipop[0] netConn_projIE_gaba[6] = new NetCon(&v(0.5), syn_projIE_gaba[6], 20.0, 1.5, -0.0016545403)")  

        # Connection 7: cell 0, seg 0 (0.5) [0.5 on Ipop[0]] -> cell 7, seg 0 (0.5) [0.5 on Epop[7]], weight: -0.0016545403, delay 1.5
        h("Epop[7] syn_projIE_gaba[7] = new gaba(0.5)")
        h("Ipop[0] netConn_projIE_gaba[7] = new NetCon(&v(0.5), syn_projIE_gaba[7], 20.0, 1.5, -0.0016545403)")  

        # Connection 8: cell 0, seg 0 (0.5) [0.5 on Ipop[0]] -> cell 8, seg 0 (0.5) [0.5 on Epop[8]], weight: -0.0016545403, delay 1.5
        h("Epop[8] syn_projIE_gaba[8] = new gaba(0.5)")
        h("Ipop[0] netConn_projIE_gaba[8] = new NetCon(&v(0.5), syn_projIE_gaba[8], 20.0, 1.5, -0.0016545403)")  

        # Connection 9: cell 0, seg 0 (0.5) [0.5 on Ipop[0]] -> cell 9, seg 0 (0.5) [0.5 on Epop[9]], weight: -0.0016545403, delay 1.5
        h("Epop[9] syn_projIE_gaba[9] = new gaba(0.5)")
        h("Ipop[0] netConn_projIE_gaba[9] = new NetCon(&v(0.5), syn_projIE_gaba[9], 20.0, 1.5, -0.0016545403)")  

        # Connection 10: cell 0, seg 0 (0.5) [0.5 on Ipop[0]] -> cell 10, seg 0 (0.5) [0.5 on Epop[10]], weight: -0.0016545403, delay 1.5
        h("Epop[10] syn_projIE_gaba[10] = new gaba(0.5)")
        h("Ipop[0] netConn_projIE_gaba[10] = new NetCon(&v(0.5), syn_projIE_gaba[10], 20.0, 1.5, -0.0016545403)")  

        # Connection 11: cell 0, seg 0 (0.5) [0.5 on Ipop[0]] -> cell 11, seg 0 (0.5) [0.5 on Epop[11]], weight: -0.0016545403, delay 1.5
        h("Epop[11] syn_projIE_gaba[11] = new gaba(0.5)")
        h("Ipop[0] netConn_projIE_gaba[11] = new NetCon(&v(0.5), syn_projIE_gaba[11], 20.0, 1.5, -0.0016545403)")  

        # Connection 12: cell 0, seg 0 (0.5) [0.5 on Ipop[0]] -> cell 12, seg 0 (0.5) [0.5 on Epop[12]], weight: -0.0016545403, delay 1.5
        h("Epop[12] syn_projIE_gaba[12] = new gaba(0.5)")
        h("Ipop[0] netConn_projIE_gaba[12] = new NetCon(&v(0.5), syn_projIE_gaba[12], 20.0, 1.5, -0.0016545403)")  

        # Connection 13: cell 0, seg 0 (0.5) [0.5 on Ipop[0]] -> cell 13, seg 0 (0.5) [0.5 on Epop[13]], weight: -0.0016545403, delay 1.5
        h("Epop[13] syn_projIE_gaba[13] = new gaba(0.5)")
        h("Ipop[0] netConn_projIE_gaba[13] = new NetCon(&v(0.5), syn_projIE_gaba[13], 20.0, 1.5, -0.0016545403)")  

        # Connection 14: cell 0, seg 0 (0.5) [0.5 on Ipop[0]] -> cell 14, seg 0 (0.5) [0.5 on Epop[14]], weight: -0.0016545403, delay 1.5
        h("Epop[14] syn_projIE_gaba[14] = new gaba(0.5)")
        h("Ipop[0] netConn_projIE_gaba[14] = new NetCon(&v(0.5), syn_projIE_gaba[14], 20.0, 1.5, -0.0016545403)")  

        # Connection 15: cell 0, seg 0 (0.5) [0.5 on Ipop[0]] -> cell 15, seg 0 (0.5) [0.5 on Epop[15]], weight: -0.0016545403, delay 1.5
        h("Epop[15] syn_projIE_gaba[15] = new gaba(0.5)")
        h("Ipop[0] netConn_projIE_gaba[15] = new NetCon(&v(0.5), syn_projIE_gaba[15], 20.0, 1.5, -0.0016545403)")  

        # Connection 16: cell 0, seg 0 (0.5) [0.5 on Ipop[0]] -> cell 16, seg 0 (0.5) [0.5 on Epop[16]], weight: -0.0016545403, delay 1.5
        h("Epop[16] syn_projIE_gaba[16] = new gaba(0.5)")
        h("Ipop[0] netConn_projIE_gaba[16] = new NetCon(&v(0.5), syn_projIE_gaba[16], 20.0, 1.5, -0.0016545403)")  

        # Connection 17: cell 0, seg 0 (0.5) [0.5 on Ipop[0]] -> cell 17, seg 0 (0.5) [0.5 on Epop[17]], weight: -0.0016545403, delay 1.5
        h("Epop[17] syn_projIE_gaba[17] = new gaba(0.5)")
        h("Ipop[0] netConn_projIE_gaba[17] = new NetCon(&v(0.5), syn_projIE_gaba[17], 20.0, 1.5, -0.0016545403)")  

        # Connection 18: cell 0, seg 0 (0.5) [0.5 on Ipop[0]] -> cell 18, seg 0 (0.5) [0.5 on Epop[18]], weight: -0.0016545403, delay 1.5
        h("Epop[18] syn_projIE_gaba[18] = new gaba(0.5)")
        h("Ipop[0] netConn_projIE_gaba[18] = new NetCon(&v(0.5), syn_projIE_gaba[18], 20.0, 1.5, -0.0016545403)")  

        # Connection 19: cell 0, seg 0 (0.5) [0.5 on Ipop[0]] -> cell 19, seg 0 (0.5) [0.5 on Epop[19]], weight: -0.0016545403, delay 1.5
        h("Epop[19] syn_projIE_gaba[19] = new gaba(0.5)")
        h("Ipop[0] netConn_projIE_gaba[19] = new NetCon(&v(0.5), syn_projIE_gaba[19], 20.0, 1.5, -0.0016545403)")  

        # Connection 20: cell 0, seg 0 (0.5) [0.5 on Ipop[0]] -> cell 20, seg 0 (0.5) [0.5 on Epop[20]], weight: -0.0016545403, delay 1.5
        h("Epop[20] syn_projIE_gaba[20] = new gaba(0.5)")
        h("Ipop[0] netConn_projIE_gaba[20] = new NetCon(&v(0.5), syn_projIE_gaba[20], 20.0, 1.5, -0.0016545403)")  

        # Connection 21: cell 0, seg 0 (0.5) [0.5 on Ipop[0]] -> cell 21, seg 0 (0.5) [0.5 on Epop[21]], weight: -0.0016545403, delay 1.5
        h("Epop[21] syn_projIE_gaba[21] = new gaba(0.5)")
        h("Ipop[0] netConn_projIE_gaba[21] = new NetCon(&v(0.5), syn_projIE_gaba[21], 20.0, 1.5, -0.0016545403)")  

        # Connection 22: cell 0, seg 0 (0.5) [0.5 on Ipop[0]] -> cell 22, seg 0 (0.5) [0.5 on Epop[22]], weight: -0.0016545403, delay 1.5
        h("Epop[22] syn_projIE_gaba[22] = new gaba(0.5)")
        h("Ipop[0] netConn_projIE_gaba[22] = new NetCon(&v(0.5), syn_projIE_gaba[22], 20.0, 1.5, -0.0016545403)")  

        # Connection 23: cell 0, seg 0 (0.5) [0.5 on Ipop[0]] -> cell 23, seg 0 (0.5) [0.5 on Epop[23]], weight: -0.0016545403, delay 1.5
        h("Epop[23] syn_projIE_gaba[23] = new gaba(0.5)")
        h("Ipop[0] netConn_projIE_gaba[23] = new NetCon(&v(0.5), syn_projIE_gaba[23], 20.0, 1.5, -0.0016545403)")  

        # Connection 24: cell 0, seg 0 (0.5) [0.5 on Ipop[0]] -> cell 24, seg 0 (0.5) [0.5 on Epop[24]], weight: -0.0016545403, delay 1.5
        h("Epop[24] syn_projIE_gaba[24] = new gaba(0.5)")
        h("Ipop[0] netConn_projIE_gaba[24] = new NetCon(&v(0.5), syn_projIE_gaba[24], 20.0, 1.5, -0.0016545403)")  

        # Connection 25: cell 0, seg 0 (0.5) [0.5 on Ipop[0]] -> cell 25, seg 0 (0.5) [0.5 on Epop[25]], weight: -0.0016545403, delay 1.5
        h("Epop[25] syn_projIE_gaba[25] = new gaba(0.5)")
        h("Ipop[0] netConn_projIE_gaba[25] = new NetCon(&v(0.5), syn_projIE_gaba[25], 20.0, 1.5, -0.0016545403)")  

        # Connection 26: cell 0, seg 0 (0.5) [0.5 on Ipop[0]] -> cell 26, seg 0 (0.5) [0.5 on Epop[26]], weight: -0.0016545403, delay 1.5
        h("Epop[26] syn_projIE_gaba[26] = new gaba(0.5)")
        h("Ipop[0] netConn_projIE_gaba[26] = new NetCon(&v(0.5), syn_projIE_gaba[26], 20.0, 1.5, -0.0016545403)")  

        # Connection 27: cell 0, seg 0 (0.5) [0.5 on Ipop[0]] -> cell 27, seg 0 (0.5) [0.5 on Epop[27]], weight: -0.0016545403, delay 1.5
        h("Epop[27] syn_projIE_gaba[27] = new gaba(0.5)")
        h("Ipop[0] netConn_projIE_gaba[27] = new NetCon(&v(0.5), syn_projIE_gaba[27], 20.0, 1.5, -0.0016545403)")  

        # Connection 28: cell 0, seg 0 (0.5) [0.5 on Ipop[0]] -> cell 28, seg 0 (0.5) [0.5 on Epop[28]], weight: -0.0016545403, delay 1.5
        h("Epop[28] syn_projIE_gaba[28] = new gaba(0.5)")
        h("Ipop[0] netConn_projIE_gaba[28] = new NetCon(&v(0.5), syn_projIE_gaba[28], 20.0, 1.5, -0.0016545403)")  

        # Connection 29: cell 0, seg 0 (0.5) [0.5 on Ipop[0]] -> cell 29, seg 0 (0.5) [0.5 on Epop[29]], weight: -0.0016545403, delay 1.5
        h("Epop[29] syn_projIE_gaba[29] = new gaba(0.5)")
        h("Ipop[0] netConn_projIE_gaba[29] = new NetCon(&v(0.5), syn_projIE_gaba[29], 20.0, 1.5, -0.0016545403)")  

        # Connection 30: cell 0, seg 0 (0.5) [0.5 on Ipop[0]] -> cell 30, seg 0 (0.5) [0.5 on Epop[30]], weight: -0.0016545403, delay 1.5
        h("Epop[30] syn_projIE_gaba[30] = new gaba(0.5)")
        h("Ipop[0] netConn_projIE_gaba[30] = new NetCon(&v(0.5), syn_projIE_gaba[30], 20.0, 1.5, -0.0016545403)")  

        # Connection 31: cell 0, seg 0 (0.5) [0.5 on Ipop[0]] -> cell 31, seg 0 (0.5) [0.5 on Epop[31]], weight: -0.0016545403, delay 1.5
        h("Epop[31] syn_projIE_gaba[31] = new gaba(0.5)")
        h("Ipop[0] netConn_projIE_gaba[31] = new NetCon(&v(0.5), syn_projIE_gaba[31], 20.0, 1.5, -0.0016545403)")  

        # Connection 32: cell 0, seg 0 (0.5) [0.5 on Ipop[0]] -> cell 32, seg 0 (0.5) [0.5 on Epop[32]], weight: -0.0016545403, delay 1.5
        h("Epop[32] syn_projIE_gaba[32] = new gaba(0.5)")
        h("Ipop[0] netConn_projIE_gaba[32] = new NetCon(&v(0.5), syn_projIE_gaba[32], 20.0, 1.5, -0.0016545403)")  

        # Connection 33: cell 0, seg 0 (0.5) [0.5 on Ipop[0]] -> cell 33, seg 0 (0.5) [0.5 on Epop[33]], weight: -0.0016545403, delay 1.5
        h("Epop[33] syn_projIE_gaba[33] = new gaba(0.5)")
        h("Ipop[0] netConn_projIE_gaba[33] = new NetCon(&v(0.5), syn_projIE_gaba[33], 20.0, 1.5, -0.0016545403)")  

        # Connection 34: cell 0, seg 0 (0.5) [0.5 on Ipop[0]] -> cell 34, seg 0 (0.5) [0.5 on Epop[34]], weight: -0.0016545403, delay 1.5
        h("Epop[34] syn_projIE_gaba[34] = new gaba(0.5)")
        h("Ipop[0] netConn_projIE_gaba[34] = new NetCon(&v(0.5), syn_projIE_gaba[34], 20.0, 1.5, -0.0016545403)")  

        # Connection 35: cell 0, seg 0 (0.5) [0.5 on Ipop[0]] -> cell 35, seg 0 (0.5) [0.5 on Epop[35]], weight: -0.0016545403, delay 1.5
        h("Epop[35] syn_projIE_gaba[35] = new gaba(0.5)")
        h("Ipop[0] netConn_projIE_gaba[35] = new NetCon(&v(0.5), syn_projIE_gaba[35], 20.0, 1.5, -0.0016545403)")  

        # Connection 36: cell 0, seg 0 (0.5) [0.5 on Ipop[0]] -> cell 36, seg 0 (0.5) [0.5 on Epop[36]], weight: -0.0016545403, delay 1.5
        h("Epop[36] syn_projIE_gaba[36] = new gaba(0.5)")
        h("Ipop[0] netConn_projIE_gaba[36] = new NetCon(&v(0.5), syn_projIE_gaba[36], 20.0, 1.5, -0.0016545403)")  

        # Connection 37: cell 0, seg 0 (0.5) [0.5 on Ipop[0]] -> cell 37, seg 0 (0.5) [0.5 on Epop[37]], weight: -0.0016545403, delay 1.5
        h("Epop[37] syn_projIE_gaba[37] = new gaba(0.5)")
        h("Ipop[0] netConn_projIE_gaba[37] = new NetCon(&v(0.5), syn_projIE_gaba[37], 20.0, 1.5, -0.0016545403)")  

        # Connection 38: cell 0, seg 0 (0.5) [0.5 on Ipop[0]] -> cell 38, seg 0 (0.5) [0.5 on Epop[38]], weight: -0.0016545403, delay 1.5
        h("Epop[38] syn_projIE_gaba[38] = new gaba(0.5)")
        h("Ipop[0] netConn_projIE_gaba[38] = new NetCon(&v(0.5), syn_projIE_gaba[38], 20.0, 1.5, -0.0016545403)")  

        # Connection 39: cell 0, seg 0 (0.5) [0.5 on Ipop[0]] -> cell 39, seg 0 (0.5) [0.5 on Epop[39]], weight: -0.0016545403, delay 1.5
        h("Epop[39] syn_projIE_gaba[39] = new gaba(0.5)")
        h("Ipop[0] netConn_projIE_gaba[39] = new NetCon(&v(0.5), syn_projIE_gaba[39], 20.0, 1.5, -0.0016545403)")  

        # Connection 40: cell 0, seg 0 (0.5) [0.5 on Ipop[0]] -> cell 40, seg 0 (0.5) [0.5 on Epop[40]], weight: -0.0016545403, delay 1.5
        h("Epop[40] syn_projIE_gaba[40] = new gaba(0.5)")
        h("Ipop[0] netConn_projIE_gaba[40] = new NetCon(&v(0.5), syn_projIE_gaba[40], 20.0, 1.5, -0.0016545403)")  

        # Connection 41: cell 0, seg 0 (0.5) [0.5 on Ipop[0]] -> cell 41, seg 0 (0.5) [0.5 on Epop[41]], weight: -0.0016545403, delay 1.5
        h("Epop[41] syn_projIE_gaba[41] = new gaba(0.5)")
        h("Ipop[0] netConn_projIE_gaba[41] = new NetCon(&v(0.5), syn_projIE_gaba[41], 20.0, 1.5, -0.0016545403)")  

        # Connection 42: cell 0, seg 0 (0.5) [0.5 on Ipop[0]] -> cell 42, seg 0 (0.5) [0.5 on Epop[42]], weight: -0.0016545403, delay 1.5
        h("Epop[42] syn_projIE_gaba[42] = new gaba(0.5)")
        h("Ipop[0] netConn_projIE_gaba[42] = new NetCon(&v(0.5), syn_projIE_gaba[42], 20.0, 1.5, -0.0016545403)")  

        # Connection 43: cell 0, seg 0 (0.5) [0.5 on Ipop[0]] -> cell 43, seg 0 (0.5) [0.5 on Epop[43]], weight: -0.0016545403, delay 1.5
        h("Epop[43] syn_projIE_gaba[43] = new gaba(0.5)")
        h("Ipop[0] netConn_projIE_gaba[43] = new NetCon(&v(0.5), syn_projIE_gaba[43], 20.0, 1.5, -0.0016545403)")  

        # Connection 44: cell 0, seg 0 (0.5) [0.5 on Ipop[0]] -> cell 44, seg 0 (0.5) [0.5 on Epop[44]], weight: -0.0016545403, delay 1.5
        h("Epop[44] syn_projIE_gaba[44] = new gaba(0.5)")
        h("Ipop[0] netConn_projIE_gaba[44] = new NetCon(&v(0.5), syn_projIE_gaba[44], 20.0, 1.5, -0.0016545403)")  

        # Connection 45: cell 0, seg 0 (0.5) [0.5 on Ipop[0]] -> cell 45, seg 0 (0.5) [0.5 on Epop[45]], weight: -0.0016545403, delay 1.5
        h("Epop[45] syn_projIE_gaba[45] = new gaba(0.5)")
        h("Ipop[0] netConn_projIE_gaba[45] = new NetCon(&v(0.5), syn_projIE_gaba[45], 20.0, 1.5, -0.0016545403)")  

        # Connection 46: cell 0, seg 0 (0.5) [0.5 on Ipop[0]] -> cell 46, seg 0 (0.5) [0.5 on Epop[46]], weight: -0.0016545403, delay 1.5
        h("Epop[46] syn_projIE_gaba[46] = new gaba(0.5)")
        h("Ipop[0] netConn_projIE_gaba[46] = new NetCon(&v(0.5), syn_projIE_gaba[46], 20.0, 1.5, -0.0016545403)")  

        # Connection 47: cell 0, seg 0 (0.5) [0.5 on Ipop[0]] -> cell 47, seg 0 (0.5) [0.5 on Epop[47]], weight: -0.0016545403, delay 1.5
        h("Epop[47] syn_projIE_gaba[47] = new gaba(0.5)")
        h("Ipop[0] netConn_projIE_gaba[47] = new NetCon(&v(0.5), syn_projIE_gaba[47], 20.0, 1.5, -0.0016545403)")  

        # Connection 48: cell 0, seg 0 (0.5) [0.5 on Ipop[0]] -> cell 48, seg 0 (0.5) [0.5 on Epop[48]], weight: -0.0016545403, delay 1.5
        h("Epop[48] syn_projIE_gaba[48] = new gaba(0.5)")
        h("Ipop[0] netConn_projIE_gaba[48] = new NetCon(&v(0.5), syn_projIE_gaba[48], 20.0, 1.5, -0.0016545403)")  

        # Connection 49: cell 0, seg 0 (0.5) [0.5 on Ipop[0]] -> cell 49, seg 0 (0.5) [0.5 on Epop[49]], weight: -0.0016545403, delay 1.5
        h("Epop[49] syn_projIE_gaba[49] = new gaba(0.5)")
        h("Ipop[0] netConn_projIE_gaba[49] = new NetCon(&v(0.5), syn_projIE_gaba[49], 20.0, 1.5, -0.0016545403)")  

        # Connection 50: cell 0, seg 0 (0.5) [0.5 on Ipop[0]] -> cell 50, seg 0 (0.5) [0.5 on Epop[50]], weight: -0.0016545403, delay 1.5
        h("Epop[50] syn_projIE_gaba[50] = new gaba(0.5)")
        h("Ipop[0] netConn_projIE_gaba[50] = new NetCon(&v(0.5), syn_projIE_gaba[50], 20.0, 1.5, -0.0016545403)")  

        # Connection 51: cell 0, seg 0 (0.5) [0.5 on Ipop[0]] -> cell 51, seg 0 (0.5) [0.5 on Epop[51]], weight: -0.0016545403, delay 1.5
        h("Epop[51] syn_projIE_gaba[51] = new gaba(0.5)")
        h("Ipop[0] netConn_projIE_gaba[51] = new NetCon(&v(0.5), syn_projIE_gaba[51], 20.0, 1.5, -0.0016545403)")  

        # Connection 52: cell 0, seg 0 (0.5) [0.5 on Ipop[0]] -> cell 52, seg 0 (0.5) [0.5 on Epop[52]], weight: -0.0016545403, delay 1.5
        h("Epop[52] syn_projIE_gaba[52] = new gaba(0.5)")
        h("Ipop[0] netConn_projIE_gaba[52] = new NetCon(&v(0.5), syn_projIE_gaba[52], 20.0, 1.5, -0.0016545403)")  

        # Connection 53: cell 0, seg 0 (0.5) [0.5 on Ipop[0]] -> cell 53, seg 0 (0.5) [0.5 on Epop[53]], weight: -0.0016545403, delay 1.5
        h("Epop[53] syn_projIE_gaba[53] = new gaba(0.5)")
        h("Ipop[0] netConn_projIE_gaba[53] = new NetCon(&v(0.5), syn_projIE_gaba[53], 20.0, 1.5, -0.0016545403)")  

        # Connection 54: cell 0, seg 0 (0.5) [0.5 on Ipop[0]] -> cell 54, seg 0 (0.5) [0.5 on Epop[54]], weight: -0.0016545403, delay 1.5
        h("Epop[54] syn_projIE_gaba[54] = new gaba(0.5)")
        h("Ipop[0] netConn_projIE_gaba[54] = new NetCon(&v(0.5), syn_projIE_gaba[54], 20.0, 1.5, -0.0016545403)")  

        # Connection 55: cell 0, seg 0 (0.5) [0.5 on Ipop[0]] -> cell 55, seg 0 (0.5) [0.5 on Epop[55]], weight: -0.0016545403, delay 1.5
        h("Epop[55] syn_projIE_gaba[55] = new gaba(0.5)")
        h("Ipop[0] netConn_projIE_gaba[55] = new NetCon(&v(0.5), syn_projIE_gaba[55], 20.0, 1.5, -0.0016545403)")  

        # Connection 56: cell 0, seg 0 (0.5) [0.5 on Ipop[0]] -> cell 56, seg 0 (0.5) [0.5 on Epop[56]], weight: -0.0016545403, delay 1.5
        h("Epop[56] syn_projIE_gaba[56] = new gaba(0.5)")
        h("Ipop[0] netConn_projIE_gaba[56] = new NetCon(&v(0.5), syn_projIE_gaba[56], 20.0, 1.5, -0.0016545403)")  

        # Connection 57: cell 0, seg 0 (0.5) [0.5 on Ipop[0]] -> cell 57, seg 0 (0.5) [0.5 on Epop[57]], weight: -0.0016545403, delay 1.5
        h("Epop[57] syn_projIE_gaba[57] = new gaba(0.5)")
        h("Ipop[0] netConn_projIE_gaba[57] = new NetCon(&v(0.5), syn_projIE_gaba[57], 20.0, 1.5, -0.0016545403)")  

        # Connection 58: cell 0, seg 0 (0.5) [0.5 on Ipop[0]] -> cell 58, seg 0 (0.5) [0.5 on Epop[58]], weight: -0.0016545403, delay 1.5
        h("Epop[58] syn_projIE_gaba[58] = new gaba(0.5)")
        h("Ipop[0] netConn_projIE_gaba[58] = new NetCon(&v(0.5), syn_projIE_gaba[58], 20.0, 1.5, -0.0016545403)")  

        # Connection 59: cell 0, seg 0 (0.5) [0.5 on Ipop[0]] -> cell 59, seg 0 (0.5) [0.5 on Epop[59]], weight: -0.0016545403, delay 1.5
        h("Epop[59] syn_projIE_gaba[59] = new gaba(0.5)")
        h("Ipop[0] netConn_projIE_gaba[59] = new NetCon(&v(0.5), syn_projIE_gaba[59], 20.0, 1.5, -0.0016545403)")  

        # Connection 60: cell 0, seg 0 (0.5) [0.5 on Ipop[0]] -> cell 60, seg 0 (0.5) [0.5 on Epop[60]], weight: -0.0016545403, delay 1.5
        h("Epop[60] syn_projIE_gaba[60] = new gaba(0.5)")
        h("Ipop[0] netConn_projIE_gaba[60] = new NetCon(&v(0.5), syn_projIE_gaba[60], 20.0, 1.5, -0.0016545403)")  

        # Connection 61: cell 0, seg 0 (0.5) [0.5 on Ipop[0]] -> cell 61, seg 0 (0.5) [0.5 on Epop[61]], weight: -0.0016545403, delay 1.5
        h("Epop[61] syn_projIE_gaba[61] = new gaba(0.5)")
        h("Ipop[0] netConn_projIE_gaba[61] = new NetCon(&v(0.5), syn_projIE_gaba[61], 20.0, 1.5, -0.0016545403)")  

        # Connection 62: cell 0, seg 0 (0.5) [0.5 on Ipop[0]] -> cell 62, seg 0 (0.5) [0.5 on Epop[62]], weight: -0.0016545403, delay 1.5
        h("Epop[62] syn_projIE_gaba[62] = new gaba(0.5)")
        h("Ipop[0] netConn_projIE_gaba[62] = new NetCon(&v(0.5), syn_projIE_gaba[62], 20.0, 1.5, -0.0016545403)")  

        # Connection 63: cell 0, seg 0 (0.5) [0.5 on Ipop[0]] -> cell 63, seg 0 (0.5) [0.5 on Epop[63]], weight: -0.0016545403, delay 1.5
        h("Epop[63] syn_projIE_gaba[63] = new gaba(0.5)")
        h("Ipop[0] netConn_projIE_gaba[63] = new NetCon(&v(0.5), syn_projIE_gaba[63], 20.0, 1.5, -0.0016545403)")  

        # Connection 64: cell 0, seg 0 (0.5) [0.5 on Ipop[0]] -> cell 64, seg 0 (0.5) [0.5 on Epop[64]], weight: -0.0016545403, delay 1.5
        h("Epop[64] syn_projIE_gaba[64] = new gaba(0.5)")
        h("Ipop[0] netConn_projIE_gaba[64] = new NetCon(&v(0.5), syn_projIE_gaba[64], 20.0, 1.5, -0.0016545403)")  

        # Connection 65: cell 0, seg 0 (0.5) [0.5 on Ipop[0]] -> cell 65, seg 0 (0.5) [0.5 on Epop[65]], weight: -0.0016545403, delay 1.5
        h("Epop[65] syn_projIE_gaba[65] = new gaba(0.5)")
        h("Ipop[0] netConn_projIE_gaba[65] = new NetCon(&v(0.5), syn_projIE_gaba[65], 20.0, 1.5, -0.0016545403)")  

        # Connection 66: cell 0, seg 0 (0.5) [0.5 on Ipop[0]] -> cell 66, seg 0 (0.5) [0.5 on Epop[66]], weight: -0.0016545403, delay 1.5
        h("Epop[66] syn_projIE_gaba[66] = new gaba(0.5)")
        h("Ipop[0] netConn_projIE_gaba[66] = new NetCon(&v(0.5), syn_projIE_gaba[66], 20.0, 1.5, -0.0016545403)")  

        # Connection 67: cell 0, seg 0 (0.5) [0.5 on Ipop[0]] -> cell 67, seg 0 (0.5) [0.5 on Epop[67]], weight: -0.0016545403, delay 1.5
        h("Epop[67] syn_projIE_gaba[67] = new gaba(0.5)")
        h("Ipop[0] netConn_projIE_gaba[67] = new NetCon(&v(0.5), syn_projIE_gaba[67], 20.0, 1.5, -0.0016545403)")  

        # Connection 68: cell 0, seg 0 (0.5) [0.5 on Ipop[0]] -> cell 68, seg 0 (0.5) [0.5 on Epop[68]], weight: -0.0016545403, delay 1.5
        h("Epop[68] syn_projIE_gaba[68] = new gaba(0.5)")
        h("Ipop[0] netConn_projIE_gaba[68] = new NetCon(&v(0.5), syn_projIE_gaba[68], 20.0, 1.5, -0.0016545403)")  

        # Connection 69: cell 0, seg 0 (0.5) [0.5 on Ipop[0]] -> cell 69, seg 0 (0.5) [0.5 on Epop[69]], weight: -0.0016545403, delay 1.5
        h("Epop[69] syn_projIE_gaba[69] = new gaba(0.5)")
        h("Ipop[0] netConn_projIE_gaba[69] = new NetCon(&v(0.5), syn_projIE_gaba[69], 20.0, 1.5, -0.0016545403)")  

        # Connection 70: cell 0, seg 0 (0.5) [0.5 on Ipop[0]] -> cell 70, seg 0 (0.5) [0.5 on Epop[70]], weight: -0.0016545403, delay 1.5
        h("Epop[70] syn_projIE_gaba[70] = new gaba(0.5)")
        h("Ipop[0] netConn_projIE_gaba[70] = new NetCon(&v(0.5), syn_projIE_gaba[70], 20.0, 1.5, -0.0016545403)")  

        # Connection 71: cell 0, seg 0 (0.5) [0.5 on Ipop[0]] -> cell 71, seg 0 (0.5) [0.5 on Epop[71]], weight: -0.0016545403, delay 1.5
        h("Epop[71] syn_projIE_gaba[71] = new gaba(0.5)")
        h("Ipop[0] netConn_projIE_gaba[71] = new NetCon(&v(0.5), syn_projIE_gaba[71], 20.0, 1.5, -0.0016545403)")  

        # Connection 72: cell 0, seg 0 (0.5) [0.5 on Ipop[0]] -> cell 72, seg 0 (0.5) [0.5 on Epop[72]], weight: -0.0016545403, delay 1.5
        h("Epop[72] syn_projIE_gaba[72] = new gaba(0.5)")
        h("Ipop[0] netConn_projIE_gaba[72] = new NetCon(&v(0.5), syn_projIE_gaba[72], 20.0, 1.5, -0.0016545403)")  

        # Connection 73: cell 0, seg 0 (0.5) [0.5 on Ipop[0]] -> cell 73, seg 0 (0.5) [0.5 on Epop[73]], weight: -0.0016545403, delay 1.5
        h("Epop[73] syn_projIE_gaba[73] = new gaba(0.5)")
        h("Ipop[0] netConn_projIE_gaba[73] = new NetCon(&v(0.5), syn_projIE_gaba[73], 20.0, 1.5, -0.0016545403)")  

        # Connection 74: cell 0, seg 0 (0.5) [0.5 on Ipop[0]] -> cell 74, seg 0 (0.5) [0.5 on Epop[74]], weight: -0.0016545403, delay 1.5
        h("Epop[74] syn_projIE_gaba[74] = new gaba(0.5)")
        h("Ipop[0] netConn_projIE_gaba[74] = new NetCon(&v(0.5), syn_projIE_gaba[74], 20.0, 1.5, -0.0016545403)")  

        # Connection 75: cell 0, seg 0 (0.5) [0.5 on Ipop[0]] -> cell 75, seg 0 (0.5) [0.5 on Epop[75]], weight: -0.0016545403, delay 1.5
        h("Epop[75] syn_projIE_gaba[75] = new gaba(0.5)")
        h("Ipop[0] netConn_projIE_gaba[75] = new NetCon(&v(0.5), syn_projIE_gaba[75], 20.0, 1.5, -0.0016545403)")  

        # Connection 76: cell 0, seg 0 (0.5) [0.5 on Ipop[0]] -> cell 76, seg 0 (0.5) [0.5 on Epop[76]], weight: -0.0016545403, delay 1.5
        h("Epop[76] syn_projIE_gaba[76] = new gaba(0.5)")
        h("Ipop[0] netConn_projIE_gaba[76] = new NetCon(&v(0.5), syn_projIE_gaba[76], 20.0, 1.5, -0.0016545403)")  

        # Connection 77: cell 0, seg 0 (0.5) [0.5 on Ipop[0]] -> cell 77, seg 0 (0.5) [0.5 on Epop[77]], weight: -0.0016545403, delay 1.5
        h("Epop[77] syn_projIE_gaba[77] = new gaba(0.5)")
        h("Ipop[0] netConn_projIE_gaba[77] = new NetCon(&v(0.5), syn_projIE_gaba[77], 20.0, 1.5, -0.0016545403)")  

        # Connection 78: cell 0, seg 0 (0.5) [0.5 on Ipop[0]] -> cell 78, seg 0 (0.5) [0.5 on Epop[78]], weight: -0.0016545403, delay 1.5
        h("Epop[78] syn_projIE_gaba[78] = new gaba(0.5)")
        h("Ipop[0] netConn_projIE_gaba[78] = new NetCon(&v(0.5), syn_projIE_gaba[78], 20.0, 1.5, -0.0016545403)")  

        # Connection 79: cell 0, seg 0 (0.5) [0.5 on Ipop[0]] -> cell 79, seg 0 (0.5) [0.5 on Epop[79]], weight: -0.0016545403, delay 1.5
        h("Epop[79] syn_projIE_gaba[79] = new gaba(0.5)")
        h("Ipop[0] netConn_projIE_gaba[79] = new NetCon(&v(0.5), syn_projIE_gaba[79], 20.0, 1.5, -0.0016545403)")  

        # Connection 80: cell 1, seg 0 (0.5) [0.5 on Ipop[1]] -> cell 0, seg 0 (0.5) [0.5 on Epop[0]], weight: -0.0016545403, delay 1.5
        h("Epop[0] syn_projIE_gaba[80] = new gaba(0.5)")
        h("Ipop[1] netConn_projIE_gaba[80] = new NetCon(&v(0.5), syn_projIE_gaba[80], 20.0, 1.5, -0.0016545403)")  

        # Connection 81: cell 1, seg 0 (0.5) [0.5 on Ipop[1]] -> cell 1, seg 0 (0.5) [0.5 on Epop[1]], weight: -0.0016545403, delay 1.5
        h("Epop[1] syn_projIE_gaba[81] = new gaba(0.5)")
        h("Ipop[1] netConn_projIE_gaba[81] = new NetCon(&v(0.5), syn_projIE_gaba[81], 20.0, 1.5, -0.0016545403)")  

        # Connection 82: cell 1, seg 0 (0.5) [0.5 on Ipop[1]] -> cell 2, seg 0 (0.5) [0.5 on Epop[2]], weight: -0.0016545403, delay 1.5
        h("Epop[2] syn_projIE_gaba[82] = new gaba(0.5)")
        h("Ipop[1] netConn_projIE_gaba[82] = new NetCon(&v(0.5), syn_projIE_gaba[82], 20.0, 1.5, -0.0016545403)")  

        # Connection 83: cell 1, seg 0 (0.5) [0.5 on Ipop[1]] -> cell 3, seg 0 (0.5) [0.5 on Epop[3]], weight: -0.0016545403, delay 1.5
        h("Epop[3] syn_projIE_gaba[83] = new gaba(0.5)")
        h("Ipop[1] netConn_projIE_gaba[83] = new NetCon(&v(0.5), syn_projIE_gaba[83], 20.0, 1.5, -0.0016545403)")  

        # Connection 84: cell 1, seg 0 (0.5) [0.5 on Ipop[1]] -> cell 4, seg 0 (0.5) [0.5 on Epop[4]], weight: -0.0016545403, delay 1.5
        h("Epop[4] syn_projIE_gaba[84] = new gaba(0.5)")
        h("Ipop[1] netConn_projIE_gaba[84] = new NetCon(&v(0.5), syn_projIE_gaba[84], 20.0, 1.5, -0.0016545403)")  

        # Connection 85: cell 1, seg 0 (0.5) [0.5 on Ipop[1]] -> cell 5, seg 0 (0.5) [0.5 on Epop[5]], weight: -0.0016545403, delay 1.5
        h("Epop[5] syn_projIE_gaba[85] = new gaba(0.5)")
        h("Ipop[1] netConn_projIE_gaba[85] = new NetCon(&v(0.5), syn_projIE_gaba[85], 20.0, 1.5, -0.0016545403)")  

        # Connection 86: cell 1, seg 0 (0.5) [0.5 on Ipop[1]] -> cell 6, seg 0 (0.5) [0.5 on Epop[6]], weight: -0.0016545403, delay 1.5
        h("Epop[6] syn_projIE_gaba[86] = new gaba(0.5)")
        h("Ipop[1] netConn_projIE_gaba[86] = new NetCon(&v(0.5), syn_projIE_gaba[86], 20.0, 1.5, -0.0016545403)")  

        # Connection 87: cell 1, seg 0 (0.5) [0.5 on Ipop[1]] -> cell 7, seg 0 (0.5) [0.5 on Epop[7]], weight: -0.0016545403, delay 1.5
        h("Epop[7] syn_projIE_gaba[87] = new gaba(0.5)")
        h("Ipop[1] netConn_projIE_gaba[87] = new NetCon(&v(0.5), syn_projIE_gaba[87], 20.0, 1.5, -0.0016545403)")  

        # Connection 88: cell 1, seg 0 (0.5) [0.5 on Ipop[1]] -> cell 8, seg 0 (0.5) [0.5 on Epop[8]], weight: -0.0016545403, delay 1.5
        h("Epop[8] syn_projIE_gaba[88] = new gaba(0.5)")
        h("Ipop[1] netConn_projIE_gaba[88] = new NetCon(&v(0.5), syn_projIE_gaba[88], 20.0, 1.5, -0.0016545403)")  

        # Connection 89: cell 1, seg 0 (0.5) [0.5 on Ipop[1]] -> cell 9, seg 0 (0.5) [0.5 on Epop[9]], weight: -0.0016545403, delay 1.5
        h("Epop[9] syn_projIE_gaba[89] = new gaba(0.5)")
        h("Ipop[1] netConn_projIE_gaba[89] = new NetCon(&v(0.5), syn_projIE_gaba[89], 20.0, 1.5, -0.0016545403)")  

        # Connection 90: cell 1, seg 0 (0.5) [0.5 on Ipop[1]] -> cell 10, seg 0 (0.5) [0.5 on Epop[10]], weight: -0.0016545403, delay 1.5
        h("Epop[10] syn_projIE_gaba[90] = new gaba(0.5)")
        h("Ipop[1] netConn_projIE_gaba[90] = new NetCon(&v(0.5), syn_projIE_gaba[90], 20.0, 1.5, -0.0016545403)")  

        # Connection 91: cell 1, seg 0 (0.5) [0.5 on Ipop[1]] -> cell 11, seg 0 (0.5) [0.5 on Epop[11]], weight: -0.0016545403, delay 1.5
        h("Epop[11] syn_projIE_gaba[91] = new gaba(0.5)")
        h("Ipop[1] netConn_projIE_gaba[91] = new NetCon(&v(0.5), syn_projIE_gaba[91], 20.0, 1.5, -0.0016545403)")  

        # Connection 92: cell 1, seg 0 (0.5) [0.5 on Ipop[1]] -> cell 12, seg 0 (0.5) [0.5 on Epop[12]], weight: -0.0016545403, delay 1.5
        h("Epop[12] syn_projIE_gaba[92] = new gaba(0.5)")
        h("Ipop[1] netConn_projIE_gaba[92] = new NetCon(&v(0.5), syn_projIE_gaba[92], 20.0, 1.5, -0.0016545403)")  

        # Connection 93: cell 1, seg 0 (0.5) [0.5 on Ipop[1]] -> cell 13, seg 0 (0.5) [0.5 on Epop[13]], weight: -0.0016545403, delay 1.5
        h("Epop[13] syn_projIE_gaba[93] = new gaba(0.5)")
        h("Ipop[1] netConn_projIE_gaba[93] = new NetCon(&v(0.5), syn_projIE_gaba[93], 20.0, 1.5, -0.0016545403)")  

        # Connection 94: cell 1, seg 0 (0.5) [0.5 on Ipop[1]] -> cell 14, seg 0 (0.5) [0.5 on Epop[14]], weight: -0.0016545403, delay 1.5
        h("Epop[14] syn_projIE_gaba[94] = new gaba(0.5)")
        h("Ipop[1] netConn_projIE_gaba[94] = new NetCon(&v(0.5), syn_projIE_gaba[94], 20.0, 1.5, -0.0016545403)")  

        # Connection 95: cell 1, seg 0 (0.5) [0.5 on Ipop[1]] -> cell 15, seg 0 (0.5) [0.5 on Epop[15]], weight: -0.0016545403, delay 1.5
        h("Epop[15] syn_projIE_gaba[95] = new gaba(0.5)")
        h("Ipop[1] netConn_projIE_gaba[95] = new NetCon(&v(0.5), syn_projIE_gaba[95], 20.0, 1.5, -0.0016545403)")  

        # Connection 96: cell 1, seg 0 (0.5) [0.5 on Ipop[1]] -> cell 16, seg 0 (0.5) [0.5 on Epop[16]], weight: -0.0016545403, delay 1.5
        h("Epop[16] syn_projIE_gaba[96] = new gaba(0.5)")
        h("Ipop[1] netConn_projIE_gaba[96] = new NetCon(&v(0.5), syn_projIE_gaba[96], 20.0, 1.5, -0.0016545403)")  

        # Connection 97: cell 1, seg 0 (0.5) [0.5 on Ipop[1]] -> cell 17, seg 0 (0.5) [0.5 on Epop[17]], weight: -0.0016545403, delay 1.5
        h("Epop[17] syn_projIE_gaba[97] = new gaba(0.5)")
        h("Ipop[1] netConn_projIE_gaba[97] = new NetCon(&v(0.5), syn_projIE_gaba[97], 20.0, 1.5, -0.0016545403)")  

        # Connection 98: cell 1, seg 0 (0.5) [0.5 on Ipop[1]] -> cell 18, seg 0 (0.5) [0.5 on Epop[18]], weight: -0.0016545403, delay 1.5
        h("Epop[18] syn_projIE_gaba[98] = new gaba(0.5)")
        h("Ipop[1] netConn_projIE_gaba[98] = new NetCon(&v(0.5), syn_projIE_gaba[98], 20.0, 1.5, -0.0016545403)")  

        # Connection 99: cell 1, seg 0 (0.5) [0.5 on Ipop[1]] -> cell 19, seg 0 (0.5) [0.5 on Epop[19]], weight: -0.0016545403, delay 1.5
        h("Epop[19] syn_projIE_gaba[99] = new gaba(0.5)")
        h("Ipop[1] netConn_projIE_gaba[99] = new NetCon(&v(0.5), syn_projIE_gaba[99], 20.0, 1.5, -0.0016545403)")  

        # Connection 100: cell 1, seg 0 (0.5) [0.5 on Ipop[1]] -> cell 20, seg 0 (0.5) [0.5 on Epop[20]], weight: -0.0016545403, delay 1.5
        h("Epop[20] syn_projIE_gaba[100] = new gaba(0.5)")
        h("Ipop[1] netConn_projIE_gaba[100] = new NetCon(&v(0.5), syn_projIE_gaba[100], 20.0, 1.5, -0.0016545403)")  

        # Connection 101: cell 1, seg 0 (0.5) [0.5 on Ipop[1]] -> cell 21, seg 0 (0.5) [0.5 on Epop[21]], weight: -0.0016545403, delay 1.5
        h("Epop[21] syn_projIE_gaba[101] = new gaba(0.5)")
        h("Ipop[1] netConn_projIE_gaba[101] = new NetCon(&v(0.5), syn_projIE_gaba[101], 20.0, 1.5, -0.0016545403)")  

        # Connection 102: cell 1, seg 0 (0.5) [0.5 on Ipop[1]] -> cell 22, seg 0 (0.5) [0.5 on Epop[22]], weight: -0.0016545403, delay 1.5
        h("Epop[22] syn_projIE_gaba[102] = new gaba(0.5)")
        h("Ipop[1] netConn_projIE_gaba[102] = new NetCon(&v(0.5), syn_projIE_gaba[102], 20.0, 1.5, -0.0016545403)")  

        # Connection 103: cell 1, seg 0 (0.5) [0.5 on Ipop[1]] -> cell 23, seg 0 (0.5) [0.5 on Epop[23]], weight: -0.0016545403, delay 1.5
        h("Epop[23] syn_projIE_gaba[103] = new gaba(0.5)")
        h("Ipop[1] netConn_projIE_gaba[103] = new NetCon(&v(0.5), syn_projIE_gaba[103], 20.0, 1.5, -0.0016545403)")  

        # Connection 104: cell 1, seg 0 (0.5) [0.5 on Ipop[1]] -> cell 24, seg 0 (0.5) [0.5 on Epop[24]], weight: -0.0016545403, delay 1.5
        h("Epop[24] syn_projIE_gaba[104] = new gaba(0.5)")
        h("Ipop[1] netConn_projIE_gaba[104] = new NetCon(&v(0.5), syn_projIE_gaba[104], 20.0, 1.5, -0.0016545403)")  

        # Connection 105: cell 1, seg 0 (0.5) [0.5 on Ipop[1]] -> cell 25, seg 0 (0.5) [0.5 on Epop[25]], weight: -0.0016545403, delay 1.5
        h("Epop[25] syn_projIE_gaba[105] = new gaba(0.5)")
        h("Ipop[1] netConn_projIE_gaba[105] = new NetCon(&v(0.5), syn_projIE_gaba[105], 20.0, 1.5, -0.0016545403)")  

        # Connection 106: cell 1, seg 0 (0.5) [0.5 on Ipop[1]] -> cell 26, seg 0 (0.5) [0.5 on Epop[26]], weight: -0.0016545403, delay 1.5
        h("Epop[26] syn_projIE_gaba[106] = new gaba(0.5)")
        h("Ipop[1] netConn_projIE_gaba[106] = new NetCon(&v(0.5), syn_projIE_gaba[106], 20.0, 1.5, -0.0016545403)")  

        # Connection 107: cell 1, seg 0 (0.5) [0.5 on Ipop[1]] -> cell 27, seg 0 (0.5) [0.5 on Epop[27]], weight: -0.0016545403, delay 1.5
        h("Epop[27] syn_projIE_gaba[107] = new gaba(0.5)")
        h("Ipop[1] netConn_projIE_gaba[107] = new NetCon(&v(0.5), syn_projIE_gaba[107], 20.0, 1.5, -0.0016545403)")  

        # Connection 108: cell 1, seg 0 (0.5) [0.5 on Ipop[1]] -> cell 28, seg 0 (0.5) [0.5 on Epop[28]], weight: -0.0016545403, delay 1.5
        h("Epop[28] syn_projIE_gaba[108] = new gaba(0.5)")
        h("Ipop[1] netConn_projIE_gaba[108] = new NetCon(&v(0.5), syn_projIE_gaba[108], 20.0, 1.5, -0.0016545403)")  

        # Connection 109: cell 1, seg 0 (0.5) [0.5 on Ipop[1]] -> cell 29, seg 0 (0.5) [0.5 on Epop[29]], weight: -0.0016545403, delay 1.5
        h("Epop[29] syn_projIE_gaba[109] = new gaba(0.5)")
        h("Ipop[1] netConn_projIE_gaba[109] = new NetCon(&v(0.5), syn_projIE_gaba[109], 20.0, 1.5, -0.0016545403)")  

        # Connection 110: cell 1, seg 0 (0.5) [0.5 on Ipop[1]] -> cell 30, seg 0 (0.5) [0.5 on Epop[30]], weight: -0.0016545403, delay 1.5
        h("Epop[30] syn_projIE_gaba[110] = new gaba(0.5)")
        h("Ipop[1] netConn_projIE_gaba[110] = new NetCon(&v(0.5), syn_projIE_gaba[110], 20.0, 1.5, -0.0016545403)")  

        # Connection 111: cell 1, seg 0 (0.5) [0.5 on Ipop[1]] -> cell 31, seg 0 (0.5) [0.5 on Epop[31]], weight: -0.0016545403, delay 1.5
        h("Epop[31] syn_projIE_gaba[111] = new gaba(0.5)")
        h("Ipop[1] netConn_projIE_gaba[111] = new NetCon(&v(0.5), syn_projIE_gaba[111], 20.0, 1.5, -0.0016545403)")  

        # Connection 112: cell 1, seg 0 (0.5) [0.5 on Ipop[1]] -> cell 32, seg 0 (0.5) [0.5 on Epop[32]], weight: -0.0016545403, delay 1.5
        h("Epop[32] syn_projIE_gaba[112] = new gaba(0.5)")
        h("Ipop[1] netConn_projIE_gaba[112] = new NetCon(&v(0.5), syn_projIE_gaba[112], 20.0, 1.5, -0.0016545403)")  

        # Connection 113: cell 1, seg 0 (0.5) [0.5 on Ipop[1]] -> cell 33, seg 0 (0.5) [0.5 on Epop[33]], weight: -0.0016545403, delay 1.5
        h("Epop[33] syn_projIE_gaba[113] = new gaba(0.5)")
        h("Ipop[1] netConn_projIE_gaba[113] = new NetCon(&v(0.5), syn_projIE_gaba[113], 20.0, 1.5, -0.0016545403)")  

        # Connection 114: cell 1, seg 0 (0.5) [0.5 on Ipop[1]] -> cell 34, seg 0 (0.5) [0.5 on Epop[34]], weight: -0.0016545403, delay 1.5
        h("Epop[34] syn_projIE_gaba[114] = new gaba(0.5)")
        h("Ipop[1] netConn_projIE_gaba[114] = new NetCon(&v(0.5), syn_projIE_gaba[114], 20.0, 1.5, -0.0016545403)")  

        # Connection 115: cell 1, seg 0 (0.5) [0.5 on Ipop[1]] -> cell 35, seg 0 (0.5) [0.5 on Epop[35]], weight: -0.0016545403, delay 1.5
        h("Epop[35] syn_projIE_gaba[115] = new gaba(0.5)")
        h("Ipop[1] netConn_projIE_gaba[115] = new NetCon(&v(0.5), syn_projIE_gaba[115], 20.0, 1.5, -0.0016545403)")  

        # Connection 116: cell 1, seg 0 (0.5) [0.5 on Ipop[1]] -> cell 36, seg 0 (0.5) [0.5 on Epop[36]], weight: -0.0016545403, delay 1.5
        h("Epop[36] syn_projIE_gaba[116] = new gaba(0.5)")
        h("Ipop[1] netConn_projIE_gaba[116] = new NetCon(&v(0.5), syn_projIE_gaba[116], 20.0, 1.5, -0.0016545403)")  

        # Connection 117: cell 1, seg 0 (0.5) [0.5 on Ipop[1]] -> cell 37, seg 0 (0.5) [0.5 on Epop[37]], weight: -0.0016545403, delay 1.5
        h("Epop[37] syn_projIE_gaba[117] = new gaba(0.5)")
        h("Ipop[1] netConn_projIE_gaba[117] = new NetCon(&v(0.5), syn_projIE_gaba[117], 20.0, 1.5, -0.0016545403)")  

        # Connection 118: cell 1, seg 0 (0.5) [0.5 on Ipop[1]] -> cell 38, seg 0 (0.5) [0.5 on Epop[38]], weight: -0.0016545403, delay 1.5
        h("Epop[38] syn_projIE_gaba[118] = new gaba(0.5)")
        h("Ipop[1] netConn_projIE_gaba[118] = new NetCon(&v(0.5), syn_projIE_gaba[118], 20.0, 1.5, -0.0016545403)")  

        # Connection 119: cell 1, seg 0 (0.5) [0.5 on Ipop[1]] -> cell 39, seg 0 (0.5) [0.5 on Epop[39]], weight: -0.0016545403, delay 1.5
        h("Epop[39] syn_projIE_gaba[119] = new gaba(0.5)")
        h("Ipop[1] netConn_projIE_gaba[119] = new NetCon(&v(0.5), syn_projIE_gaba[119], 20.0, 1.5, -0.0016545403)")  

        # Connection 120: cell 1, seg 0 (0.5) [0.5 on Ipop[1]] -> cell 40, seg 0 (0.5) [0.5 on Epop[40]], weight: -0.0016545403, delay 1.5
        h("Epop[40] syn_projIE_gaba[120] = new gaba(0.5)")
        h("Ipop[1] netConn_projIE_gaba[120] = new NetCon(&v(0.5), syn_projIE_gaba[120], 20.0, 1.5, -0.0016545403)")  

        # Connection 121: cell 1, seg 0 (0.5) [0.5 on Ipop[1]] -> cell 41, seg 0 (0.5) [0.5 on Epop[41]], weight: -0.0016545403, delay 1.5
        h("Epop[41] syn_projIE_gaba[121] = new gaba(0.5)")
        h("Ipop[1] netConn_projIE_gaba[121] = new NetCon(&v(0.5), syn_projIE_gaba[121], 20.0, 1.5, -0.0016545403)")  

        # Connection 122: cell 1, seg 0 (0.5) [0.5 on Ipop[1]] -> cell 42, seg 0 (0.5) [0.5 on Epop[42]], weight: -0.0016545403, delay 1.5
        h("Epop[42] syn_projIE_gaba[122] = new gaba(0.5)")
        h("Ipop[1] netConn_projIE_gaba[122] = new NetCon(&v(0.5), syn_projIE_gaba[122], 20.0, 1.5, -0.0016545403)")  

        # Connection 123: cell 1, seg 0 (0.5) [0.5 on Ipop[1]] -> cell 43, seg 0 (0.5) [0.5 on Epop[43]], weight: -0.0016545403, delay 1.5
        h("Epop[43] syn_projIE_gaba[123] = new gaba(0.5)")
        h("Ipop[1] netConn_projIE_gaba[123] = new NetCon(&v(0.5), syn_projIE_gaba[123], 20.0, 1.5, -0.0016545403)")  

        # Connection 124: cell 1, seg 0 (0.5) [0.5 on Ipop[1]] -> cell 44, seg 0 (0.5) [0.5 on Epop[44]], weight: -0.0016545403, delay 1.5
        h("Epop[44] syn_projIE_gaba[124] = new gaba(0.5)")
        h("Ipop[1] netConn_projIE_gaba[124] = new NetCon(&v(0.5), syn_projIE_gaba[124], 20.0, 1.5, -0.0016545403)")  

        # Connection 125: cell 1, seg 0 (0.5) [0.5 on Ipop[1]] -> cell 45, seg 0 (0.5) [0.5 on Epop[45]], weight: -0.0016545403, delay 1.5
        h("Epop[45] syn_projIE_gaba[125] = new gaba(0.5)")
        h("Ipop[1] netConn_projIE_gaba[125] = new NetCon(&v(0.5), syn_projIE_gaba[125], 20.0, 1.5, -0.0016545403)")  

        # Connection 126: cell 1, seg 0 (0.5) [0.5 on Ipop[1]] -> cell 46, seg 0 (0.5) [0.5 on Epop[46]], weight: -0.0016545403, delay 1.5
        h("Epop[46] syn_projIE_gaba[126] = new gaba(0.5)")
        h("Ipop[1] netConn_projIE_gaba[126] = new NetCon(&v(0.5), syn_projIE_gaba[126], 20.0, 1.5, -0.0016545403)")  

        # Connection 127: cell 1, seg 0 (0.5) [0.5 on Ipop[1]] -> cell 47, seg 0 (0.5) [0.5 on Epop[47]], weight: -0.0016545403, delay 1.5
        h("Epop[47] syn_projIE_gaba[127] = new gaba(0.5)")
        h("Ipop[1] netConn_projIE_gaba[127] = new NetCon(&v(0.5), syn_projIE_gaba[127], 20.0, 1.5, -0.0016545403)")  

        # Connection 128: cell 1, seg 0 (0.5) [0.5 on Ipop[1]] -> cell 48, seg 0 (0.5) [0.5 on Epop[48]], weight: -0.0016545403, delay 1.5
        h("Epop[48] syn_projIE_gaba[128] = new gaba(0.5)")
        h("Ipop[1] netConn_projIE_gaba[128] = new NetCon(&v(0.5), syn_projIE_gaba[128], 20.0, 1.5, -0.0016545403)")  

        # Connection 129: cell 1, seg 0 (0.5) [0.5 on Ipop[1]] -> cell 49, seg 0 (0.5) [0.5 on Epop[49]], weight: -0.0016545403, delay 1.5
        h("Epop[49] syn_projIE_gaba[129] = new gaba(0.5)")
        h("Ipop[1] netConn_projIE_gaba[129] = new NetCon(&v(0.5), syn_projIE_gaba[129], 20.0, 1.5, -0.0016545403)")  

        # Connection 130: cell 1, seg 0 (0.5) [0.5 on Ipop[1]] -> cell 50, seg 0 (0.5) [0.5 on Epop[50]], weight: -0.0016545403, delay 1.5
        h("Epop[50] syn_projIE_gaba[130] = new gaba(0.5)")
        h("Ipop[1] netConn_projIE_gaba[130] = new NetCon(&v(0.5), syn_projIE_gaba[130], 20.0, 1.5, -0.0016545403)")  

        # Connection 131: cell 1, seg 0 (0.5) [0.5 on Ipop[1]] -> cell 51, seg 0 (0.5) [0.5 on Epop[51]], weight: -0.0016545403, delay 1.5
        h("Epop[51] syn_projIE_gaba[131] = new gaba(0.5)")
        h("Ipop[1] netConn_projIE_gaba[131] = new NetCon(&v(0.5), syn_projIE_gaba[131], 20.0, 1.5, -0.0016545403)")  

        # Connection 132: cell 1, seg 0 (0.5) [0.5 on Ipop[1]] -> cell 52, seg 0 (0.5) [0.5 on Epop[52]], weight: -0.0016545403, delay 1.5
        h("Epop[52] syn_projIE_gaba[132] = new gaba(0.5)")
        h("Ipop[1] netConn_projIE_gaba[132] = new NetCon(&v(0.5), syn_projIE_gaba[132], 20.0, 1.5, -0.0016545403)")  

        # Connection 133: cell 1, seg 0 (0.5) [0.5 on Ipop[1]] -> cell 53, seg 0 (0.5) [0.5 on Epop[53]], weight: -0.0016545403, delay 1.5
        h("Epop[53] syn_projIE_gaba[133] = new gaba(0.5)")
        h("Ipop[1] netConn_projIE_gaba[133] = new NetCon(&v(0.5), syn_projIE_gaba[133], 20.0, 1.5, -0.0016545403)")  

        # Connection 134: cell 1, seg 0 (0.5) [0.5 on Ipop[1]] -> cell 54, seg 0 (0.5) [0.5 on Epop[54]], weight: -0.0016545403, delay 1.5
        h("Epop[54] syn_projIE_gaba[134] = new gaba(0.5)")
        h("Ipop[1] netConn_projIE_gaba[134] = new NetCon(&v(0.5), syn_projIE_gaba[134], 20.0, 1.5, -0.0016545403)")  

        # Connection 135: cell 1, seg 0 (0.5) [0.5 on Ipop[1]] -> cell 55, seg 0 (0.5) [0.5 on Epop[55]], weight: -0.0016545403, delay 1.5
        h("Epop[55] syn_projIE_gaba[135] = new gaba(0.5)")
        h("Ipop[1] netConn_projIE_gaba[135] = new NetCon(&v(0.5), syn_projIE_gaba[135], 20.0, 1.5, -0.0016545403)")  

        # Connection 136: cell 1, seg 0 (0.5) [0.5 on Ipop[1]] -> cell 56, seg 0 (0.5) [0.5 on Epop[56]], weight: -0.0016545403, delay 1.5
        h("Epop[56] syn_projIE_gaba[136] = new gaba(0.5)")
        h("Ipop[1] netConn_projIE_gaba[136] = new NetCon(&v(0.5), syn_projIE_gaba[136], 20.0, 1.5, -0.0016545403)")  

        # Connection 137: cell 1, seg 0 (0.5) [0.5 on Ipop[1]] -> cell 57, seg 0 (0.5) [0.5 on Epop[57]], weight: -0.0016545403, delay 1.5
        h("Epop[57] syn_projIE_gaba[137] = new gaba(0.5)")
        h("Ipop[1] netConn_projIE_gaba[137] = new NetCon(&v(0.5), syn_projIE_gaba[137], 20.0, 1.5, -0.0016545403)")  

        # Connection 138: cell 1, seg 0 (0.5) [0.5 on Ipop[1]] -> cell 58, seg 0 (0.5) [0.5 on Epop[58]], weight: -0.0016545403, delay 1.5
        h("Epop[58] syn_projIE_gaba[138] = new gaba(0.5)")
        h("Ipop[1] netConn_projIE_gaba[138] = new NetCon(&v(0.5), syn_projIE_gaba[138], 20.0, 1.5, -0.0016545403)")  

        # Connection 139: cell 1, seg 0 (0.5) [0.5 on Ipop[1]] -> cell 59, seg 0 (0.5) [0.5 on Epop[59]], weight: -0.0016545403, delay 1.5
        h("Epop[59] syn_projIE_gaba[139] = new gaba(0.5)")
        h("Ipop[1] netConn_projIE_gaba[139] = new NetCon(&v(0.5), syn_projIE_gaba[139], 20.0, 1.5, -0.0016545403)")  

        # Connection 140: cell 1, seg 0 (0.5) [0.5 on Ipop[1]] -> cell 60, seg 0 (0.5) [0.5 on Epop[60]], weight: -0.0016545403, delay 1.5
        h("Epop[60] syn_projIE_gaba[140] = new gaba(0.5)")
        h("Ipop[1] netConn_projIE_gaba[140] = new NetCon(&v(0.5), syn_projIE_gaba[140], 20.0, 1.5, -0.0016545403)")  

        # Connection 141: cell 1, seg 0 (0.5) [0.5 on Ipop[1]] -> cell 61, seg 0 (0.5) [0.5 on Epop[61]], weight: -0.0016545403, delay 1.5
        h("Epop[61] syn_projIE_gaba[141] = new gaba(0.5)")
        h("Ipop[1] netConn_projIE_gaba[141] = new NetCon(&v(0.5), syn_projIE_gaba[141], 20.0, 1.5, -0.0016545403)")  

        # Connection 142: cell 1, seg 0 (0.5) [0.5 on Ipop[1]] -> cell 62, seg 0 (0.5) [0.5 on Epop[62]], weight: -0.0016545403, delay 1.5
        h("Epop[62] syn_projIE_gaba[142] = new gaba(0.5)")
        h("Ipop[1] netConn_projIE_gaba[142] = new NetCon(&v(0.5), syn_projIE_gaba[142], 20.0, 1.5, -0.0016545403)")  

        # Connection 143: cell 1, seg 0 (0.5) [0.5 on Ipop[1]] -> cell 63, seg 0 (0.5) [0.5 on Epop[63]], weight: -0.0016545403, delay 1.5
        h("Epop[63] syn_projIE_gaba[143] = new gaba(0.5)")
        h("Ipop[1] netConn_projIE_gaba[143] = new NetCon(&v(0.5), syn_projIE_gaba[143], 20.0, 1.5, -0.0016545403)")  

        # Connection 144: cell 1, seg 0 (0.5) [0.5 on Ipop[1]] -> cell 64, seg 0 (0.5) [0.5 on Epop[64]], weight: -0.0016545403, delay 1.5
        h("Epop[64] syn_projIE_gaba[144] = new gaba(0.5)")
        h("Ipop[1] netConn_projIE_gaba[144] = new NetCon(&v(0.5), syn_projIE_gaba[144], 20.0, 1.5, -0.0016545403)")  

        # Connection 145: cell 1, seg 0 (0.5) [0.5 on Ipop[1]] -> cell 65, seg 0 (0.5) [0.5 on Epop[65]], weight: -0.0016545403, delay 1.5
        h("Epop[65] syn_projIE_gaba[145] = new gaba(0.5)")
        h("Ipop[1] netConn_projIE_gaba[145] = new NetCon(&v(0.5), syn_projIE_gaba[145], 20.0, 1.5, -0.0016545403)")  

        # Connection 146: cell 1, seg 0 (0.5) [0.5 on Ipop[1]] -> cell 66, seg 0 (0.5) [0.5 on Epop[66]], weight: -0.0016545403, delay 1.5
        h("Epop[66] syn_projIE_gaba[146] = new gaba(0.5)")
        h("Ipop[1] netConn_projIE_gaba[146] = new NetCon(&v(0.5), syn_projIE_gaba[146], 20.0, 1.5, -0.0016545403)")  

        # Connection 147: cell 1, seg 0 (0.5) [0.5 on Ipop[1]] -> cell 67, seg 0 (0.5) [0.5 on Epop[67]], weight: -0.0016545403, delay 1.5
        h("Epop[67] syn_projIE_gaba[147] = new gaba(0.5)")
        h("Ipop[1] netConn_projIE_gaba[147] = new NetCon(&v(0.5), syn_projIE_gaba[147], 20.0, 1.5, -0.0016545403)")  

        # Connection 148: cell 1, seg 0 (0.5) [0.5 on Ipop[1]] -> cell 68, seg 0 (0.5) [0.5 on Epop[68]], weight: -0.0016545403, delay 1.5
        h("Epop[68] syn_projIE_gaba[148] = new gaba(0.5)")
        h("Ipop[1] netConn_projIE_gaba[148] = new NetCon(&v(0.5), syn_projIE_gaba[148], 20.0, 1.5, -0.0016545403)")  

        # Connection 149: cell 1, seg 0 (0.5) [0.5 on Ipop[1]] -> cell 69, seg 0 (0.5) [0.5 on Epop[69]], weight: -0.0016545403, delay 1.5
        h("Epop[69] syn_projIE_gaba[149] = new gaba(0.5)")
        h("Ipop[1] netConn_projIE_gaba[149] = new NetCon(&v(0.5), syn_projIE_gaba[149], 20.0, 1.5, -0.0016545403)")  

        # Connection 150: cell 1, seg 0 (0.5) [0.5 on Ipop[1]] -> cell 70, seg 0 (0.5) [0.5 on Epop[70]], weight: -0.0016545403, delay 1.5
        h("Epop[70] syn_projIE_gaba[150] = new gaba(0.5)")
        h("Ipop[1] netConn_projIE_gaba[150] = new NetCon(&v(0.5), syn_projIE_gaba[150], 20.0, 1.5, -0.0016545403)")  

        # Connection 151: cell 1, seg 0 (0.5) [0.5 on Ipop[1]] -> cell 71, seg 0 (0.5) [0.5 on Epop[71]], weight: -0.0016545403, delay 1.5
        h("Epop[71] syn_projIE_gaba[151] = new gaba(0.5)")
        h("Ipop[1] netConn_projIE_gaba[151] = new NetCon(&v(0.5), syn_projIE_gaba[151], 20.0, 1.5, -0.0016545403)")  

        # Connection 152: cell 1, seg 0 (0.5) [0.5 on Ipop[1]] -> cell 72, seg 0 (0.5) [0.5 on Epop[72]], weight: -0.0016545403, delay 1.5
        h("Epop[72] syn_projIE_gaba[152] = new gaba(0.5)")
        h("Ipop[1] netConn_projIE_gaba[152] = new NetCon(&v(0.5), syn_projIE_gaba[152], 20.0, 1.5, -0.0016545403)")  

        # Connection 153: cell 1, seg 0 (0.5) [0.5 on Ipop[1]] -> cell 73, seg 0 (0.5) [0.5 on Epop[73]], weight: -0.0016545403, delay 1.5
        h("Epop[73] syn_projIE_gaba[153] = new gaba(0.5)")
        h("Ipop[1] netConn_projIE_gaba[153] = new NetCon(&v(0.5), syn_projIE_gaba[153], 20.0, 1.5, -0.0016545403)")  

        # Connection 154: cell 1, seg 0 (0.5) [0.5 on Ipop[1]] -> cell 74, seg 0 (0.5) [0.5 on Epop[74]], weight: -0.0016545403, delay 1.5
        h("Epop[74] syn_projIE_gaba[154] = new gaba(0.5)")
        h("Ipop[1] netConn_projIE_gaba[154] = new NetCon(&v(0.5), syn_projIE_gaba[154], 20.0, 1.5, -0.0016545403)")  

        # Connection 155: cell 1, seg 0 (0.5) [0.5 on Ipop[1]] -> cell 75, seg 0 (0.5) [0.5 on Epop[75]], weight: -0.0016545403, delay 1.5
        h("Epop[75] syn_projIE_gaba[155] = new gaba(0.5)")
        h("Ipop[1] netConn_projIE_gaba[155] = new NetCon(&v(0.5), syn_projIE_gaba[155], 20.0, 1.5, -0.0016545403)")  

        # Connection 156: cell 1, seg 0 (0.5) [0.5 on Ipop[1]] -> cell 76, seg 0 (0.5) [0.5 on Epop[76]], weight: -0.0016545403, delay 1.5
        h("Epop[76] syn_projIE_gaba[156] = new gaba(0.5)")
        h("Ipop[1] netConn_projIE_gaba[156] = new NetCon(&v(0.5), syn_projIE_gaba[156], 20.0, 1.5, -0.0016545403)")  

        # Connection 157: cell 1, seg 0 (0.5) [0.5 on Ipop[1]] -> cell 77, seg 0 (0.5) [0.5 on Epop[77]], weight: -0.0016545403, delay 1.5
        h("Epop[77] syn_projIE_gaba[157] = new gaba(0.5)")
        h("Ipop[1] netConn_projIE_gaba[157] = new NetCon(&v(0.5), syn_projIE_gaba[157], 20.0, 1.5, -0.0016545403)")  

        # Connection 158: cell 1, seg 0 (0.5) [0.5 on Ipop[1]] -> cell 78, seg 0 (0.5) [0.5 on Epop[78]], weight: -0.0016545403, delay 1.5
        h("Epop[78] syn_projIE_gaba[158] = new gaba(0.5)")
        h("Ipop[1] netConn_projIE_gaba[158] = new NetCon(&v(0.5), syn_projIE_gaba[158], 20.0, 1.5, -0.0016545403)")  

        # Connection 159: cell 1, seg 0 (0.5) [0.5 on Ipop[1]] -> cell 79, seg 0 (0.5) [0.5 on Epop[79]], weight: -0.0016545403, delay 1.5
        h("Epop[79] syn_projIE_gaba[159] = new gaba(0.5)")
        h("Ipop[1] netConn_projIE_gaba[159] = new NetCon(&v(0.5), syn_projIE_gaba[159], 20.0, 1.5, -0.0016545403)")  

        # Connection 160: cell 2, seg 0 (0.5) [0.5 on Ipop[2]] -> cell 0, seg 0 (0.5) [0.5 on Epop[0]], weight: -0.0016545403, delay 1.5
        h("Epop[0] syn_projIE_gaba[160] = new gaba(0.5)")
        h("Ipop[2] netConn_projIE_gaba[160] = new NetCon(&v(0.5), syn_projIE_gaba[160], 20.0, 1.5, -0.0016545403)")  

        # Connection 161: cell 2, seg 0 (0.5) [0.5 on Ipop[2]] -> cell 1, seg 0 (0.5) [0.5 on Epop[1]], weight: -0.0016545403, delay 1.5
        h("Epop[1] syn_projIE_gaba[161] = new gaba(0.5)")
        h("Ipop[2] netConn_projIE_gaba[161] = new NetCon(&v(0.5), syn_projIE_gaba[161], 20.0, 1.5, -0.0016545403)")  

        # Connection 162: cell 2, seg 0 (0.5) [0.5 on Ipop[2]] -> cell 2, seg 0 (0.5) [0.5 on Epop[2]], weight: -0.0016545403, delay 1.5
        h("Epop[2] syn_projIE_gaba[162] = new gaba(0.5)")
        h("Ipop[2] netConn_projIE_gaba[162] = new NetCon(&v(0.5), syn_projIE_gaba[162], 20.0, 1.5, -0.0016545403)")  

        # Connection 163: cell 2, seg 0 (0.5) [0.5 on Ipop[2]] -> cell 3, seg 0 (0.5) [0.5 on Epop[3]], weight: -0.0016545403, delay 1.5
        h("Epop[3] syn_projIE_gaba[163] = new gaba(0.5)")
        h("Ipop[2] netConn_projIE_gaba[163] = new NetCon(&v(0.5), syn_projIE_gaba[163], 20.0, 1.5, -0.0016545403)")  

        # Connection 164: cell 2, seg 0 (0.5) [0.5 on Ipop[2]] -> cell 4, seg 0 (0.5) [0.5 on Epop[4]], weight: -0.0016545403, delay 1.5
        h("Epop[4] syn_projIE_gaba[164] = new gaba(0.5)")
        h("Ipop[2] netConn_projIE_gaba[164] = new NetCon(&v(0.5), syn_projIE_gaba[164], 20.0, 1.5, -0.0016545403)")  

        # Connection 165: cell 2, seg 0 (0.5) [0.5 on Ipop[2]] -> cell 5, seg 0 (0.5) [0.5 on Epop[5]], weight: -0.0016545403, delay 1.5
        h("Epop[5] syn_projIE_gaba[165] = new gaba(0.5)")
        h("Ipop[2] netConn_projIE_gaba[165] = new NetCon(&v(0.5), syn_projIE_gaba[165], 20.0, 1.5, -0.0016545403)")  

        # Connection 166: cell 2, seg 0 (0.5) [0.5 on Ipop[2]] -> cell 6, seg 0 (0.5) [0.5 on Epop[6]], weight: -0.0016545403, delay 1.5
        h("Epop[6] syn_projIE_gaba[166] = new gaba(0.5)")
        h("Ipop[2] netConn_projIE_gaba[166] = new NetCon(&v(0.5), syn_projIE_gaba[166], 20.0, 1.5, -0.0016545403)")  

        # Connection 167: cell 2, seg 0 (0.5) [0.5 on Ipop[2]] -> cell 7, seg 0 (0.5) [0.5 on Epop[7]], weight: -0.0016545403, delay 1.5
        h("Epop[7] syn_projIE_gaba[167] = new gaba(0.5)")
        h("Ipop[2] netConn_projIE_gaba[167] = new NetCon(&v(0.5), syn_projIE_gaba[167], 20.0, 1.5, -0.0016545403)")  

        # Connection 168: cell 2, seg 0 (0.5) [0.5 on Ipop[2]] -> cell 8, seg 0 (0.5) [0.5 on Epop[8]], weight: -0.0016545403, delay 1.5
        h("Epop[8] syn_projIE_gaba[168] = new gaba(0.5)")
        h("Ipop[2] netConn_projIE_gaba[168] = new NetCon(&v(0.5), syn_projIE_gaba[168], 20.0, 1.5, -0.0016545403)")  

        # Connection 169: cell 2, seg 0 (0.5) [0.5 on Ipop[2]] -> cell 9, seg 0 (0.5) [0.5 on Epop[9]], weight: -0.0016545403, delay 1.5
        h("Epop[9] syn_projIE_gaba[169] = new gaba(0.5)")
        h("Ipop[2] netConn_projIE_gaba[169] = new NetCon(&v(0.5), syn_projIE_gaba[169], 20.0, 1.5, -0.0016545403)")  

        # Connection 170: cell 2, seg 0 (0.5) [0.5 on Ipop[2]] -> cell 10, seg 0 (0.5) [0.5 on Epop[10]], weight: -0.0016545403, delay 1.5
        h("Epop[10] syn_projIE_gaba[170] = new gaba(0.5)")
        h("Ipop[2] netConn_projIE_gaba[170] = new NetCon(&v(0.5), syn_projIE_gaba[170], 20.0, 1.5, -0.0016545403)")  

        # Connection 171: cell 2, seg 0 (0.5) [0.5 on Ipop[2]] -> cell 11, seg 0 (0.5) [0.5 on Epop[11]], weight: -0.0016545403, delay 1.5
        h("Epop[11] syn_projIE_gaba[171] = new gaba(0.5)")
        h("Ipop[2] netConn_projIE_gaba[171] = new NetCon(&v(0.5), syn_projIE_gaba[171], 20.0, 1.5, -0.0016545403)")  

        # Connection 172: cell 2, seg 0 (0.5) [0.5 on Ipop[2]] -> cell 12, seg 0 (0.5) [0.5 on Epop[12]], weight: -0.0016545403, delay 1.5
        h("Epop[12] syn_projIE_gaba[172] = new gaba(0.5)")
        h("Ipop[2] netConn_projIE_gaba[172] = new NetCon(&v(0.5), syn_projIE_gaba[172], 20.0, 1.5, -0.0016545403)")  

        # Connection 173: cell 2, seg 0 (0.5) [0.5 on Ipop[2]] -> cell 13, seg 0 (0.5) [0.5 on Epop[13]], weight: -0.0016545403, delay 1.5
        h("Epop[13] syn_projIE_gaba[173] = new gaba(0.5)")
        h("Ipop[2] netConn_projIE_gaba[173] = new NetCon(&v(0.5), syn_projIE_gaba[173], 20.0, 1.5, -0.0016545403)")  

        # Connection 174: cell 2, seg 0 (0.5) [0.5 on Ipop[2]] -> cell 14, seg 0 (0.5) [0.5 on Epop[14]], weight: -0.0016545403, delay 1.5
        h("Epop[14] syn_projIE_gaba[174] = new gaba(0.5)")
        h("Ipop[2] netConn_projIE_gaba[174] = new NetCon(&v(0.5), syn_projIE_gaba[174], 20.0, 1.5, -0.0016545403)")  

        # Connection 175: cell 2, seg 0 (0.5) [0.5 on Ipop[2]] -> cell 15, seg 0 (0.5) [0.5 on Epop[15]], weight: -0.0016545403, delay 1.5
        h("Epop[15] syn_projIE_gaba[175] = new gaba(0.5)")
        h("Ipop[2] netConn_projIE_gaba[175] = new NetCon(&v(0.5), syn_projIE_gaba[175], 20.0, 1.5, -0.0016545403)")  

        # Connection 176: cell 2, seg 0 (0.5) [0.5 on Ipop[2]] -> cell 16, seg 0 (0.5) [0.5 on Epop[16]], weight: -0.0016545403, delay 1.5
        h("Epop[16] syn_projIE_gaba[176] = new gaba(0.5)")
        h("Ipop[2] netConn_projIE_gaba[176] = new NetCon(&v(0.5), syn_projIE_gaba[176], 20.0, 1.5, -0.0016545403)")  

        # Connection 177: cell 2, seg 0 (0.5) [0.5 on Ipop[2]] -> cell 17, seg 0 (0.5) [0.5 on Epop[17]], weight: -0.0016545403, delay 1.5
        h("Epop[17] syn_projIE_gaba[177] = new gaba(0.5)")
        h("Ipop[2] netConn_projIE_gaba[177] = new NetCon(&v(0.5), syn_projIE_gaba[177], 20.0, 1.5, -0.0016545403)")  

        # Connection 178: cell 2, seg 0 (0.5) [0.5 on Ipop[2]] -> cell 18, seg 0 (0.5) [0.5 on Epop[18]], weight: -0.0016545403, delay 1.5
        h("Epop[18] syn_projIE_gaba[178] = new gaba(0.5)")
        h("Ipop[2] netConn_projIE_gaba[178] = new NetCon(&v(0.5), syn_projIE_gaba[178], 20.0, 1.5, -0.0016545403)")  

        # Connection 179: cell 2, seg 0 (0.5) [0.5 on Ipop[2]] -> cell 19, seg 0 (0.5) [0.5 on Epop[19]], weight: -0.0016545403, delay 1.5
        h("Epop[19] syn_projIE_gaba[179] = new gaba(0.5)")
        h("Ipop[2] netConn_projIE_gaba[179] = new NetCon(&v(0.5), syn_projIE_gaba[179], 20.0, 1.5, -0.0016545403)")  

        # Connection 180: cell 2, seg 0 (0.5) [0.5 on Ipop[2]] -> cell 20, seg 0 (0.5) [0.5 on Epop[20]], weight: -0.0016545403, delay 1.5
        h("Epop[20] syn_projIE_gaba[180] = new gaba(0.5)")
        h("Ipop[2] netConn_projIE_gaba[180] = new NetCon(&v(0.5), syn_projIE_gaba[180], 20.0, 1.5, -0.0016545403)")  

        # Connection 181: cell 2, seg 0 (0.5) [0.5 on Ipop[2]] -> cell 21, seg 0 (0.5) [0.5 on Epop[21]], weight: -0.0016545403, delay 1.5
        h("Epop[21] syn_projIE_gaba[181] = new gaba(0.5)")
        h("Ipop[2] netConn_projIE_gaba[181] = new NetCon(&v(0.5), syn_projIE_gaba[181], 20.0, 1.5, -0.0016545403)")  

        # Connection 182: cell 2, seg 0 (0.5) [0.5 on Ipop[2]] -> cell 22, seg 0 (0.5) [0.5 on Epop[22]], weight: -0.0016545403, delay 1.5
        h("Epop[22] syn_projIE_gaba[182] = new gaba(0.5)")
        h("Ipop[2] netConn_projIE_gaba[182] = new NetCon(&v(0.5), syn_projIE_gaba[182], 20.0, 1.5, -0.0016545403)")  

        # Connection 183: cell 2, seg 0 (0.5) [0.5 on Ipop[2]] -> cell 23, seg 0 (0.5) [0.5 on Epop[23]], weight: -0.0016545403, delay 1.5
        h("Epop[23] syn_projIE_gaba[183] = new gaba(0.5)")
        h("Ipop[2] netConn_projIE_gaba[183] = new NetCon(&v(0.5), syn_projIE_gaba[183], 20.0, 1.5, -0.0016545403)")  

        # Connection 184: cell 2, seg 0 (0.5) [0.5 on Ipop[2]] -> cell 24, seg 0 (0.5) [0.5 on Epop[24]], weight: -0.0016545403, delay 1.5
        h("Epop[24] syn_projIE_gaba[184] = new gaba(0.5)")
        h("Ipop[2] netConn_projIE_gaba[184] = new NetCon(&v(0.5), syn_projIE_gaba[184], 20.0, 1.5, -0.0016545403)")  

        # Connection 185: cell 2, seg 0 (0.5) [0.5 on Ipop[2]] -> cell 25, seg 0 (0.5) [0.5 on Epop[25]], weight: -0.0016545403, delay 1.5
        h("Epop[25] syn_projIE_gaba[185] = new gaba(0.5)")
        h("Ipop[2] netConn_projIE_gaba[185] = new NetCon(&v(0.5), syn_projIE_gaba[185], 20.0, 1.5, -0.0016545403)")  

        # Connection 186: cell 2, seg 0 (0.5) [0.5 on Ipop[2]] -> cell 26, seg 0 (0.5) [0.5 on Epop[26]], weight: -0.0016545403, delay 1.5
        h("Epop[26] syn_projIE_gaba[186] = new gaba(0.5)")
        h("Ipop[2] netConn_projIE_gaba[186] = new NetCon(&v(0.5), syn_projIE_gaba[186], 20.0, 1.5, -0.0016545403)")  

        # Connection 187: cell 2, seg 0 (0.5) [0.5 on Ipop[2]] -> cell 27, seg 0 (0.5) [0.5 on Epop[27]], weight: -0.0016545403, delay 1.5
        h("Epop[27] syn_projIE_gaba[187] = new gaba(0.5)")
        h("Ipop[2] netConn_projIE_gaba[187] = new NetCon(&v(0.5), syn_projIE_gaba[187], 20.0, 1.5, -0.0016545403)")  

        # Connection 188: cell 2, seg 0 (0.5) [0.5 on Ipop[2]] -> cell 28, seg 0 (0.5) [0.5 on Epop[28]], weight: -0.0016545403, delay 1.5
        h("Epop[28] syn_projIE_gaba[188] = new gaba(0.5)")
        h("Ipop[2] netConn_projIE_gaba[188] = new NetCon(&v(0.5), syn_projIE_gaba[188], 20.0, 1.5, -0.0016545403)")  

        # Connection 189: cell 2, seg 0 (0.5) [0.5 on Ipop[2]] -> cell 29, seg 0 (0.5) [0.5 on Epop[29]], weight: -0.0016545403, delay 1.5
        h("Epop[29] syn_projIE_gaba[189] = new gaba(0.5)")
        h("Ipop[2] netConn_projIE_gaba[189] = new NetCon(&v(0.5), syn_projIE_gaba[189], 20.0, 1.5, -0.0016545403)")  

        # Connection 190: cell 2, seg 0 (0.5) [0.5 on Ipop[2]] -> cell 30, seg 0 (0.5) [0.5 on Epop[30]], weight: -0.0016545403, delay 1.5
        h("Epop[30] syn_projIE_gaba[190] = new gaba(0.5)")
        h("Ipop[2] netConn_projIE_gaba[190] = new NetCon(&v(0.5), syn_projIE_gaba[190], 20.0, 1.5, -0.0016545403)")  

        # Connection 191: cell 2, seg 0 (0.5) [0.5 on Ipop[2]] -> cell 31, seg 0 (0.5) [0.5 on Epop[31]], weight: -0.0016545403, delay 1.5
        h("Epop[31] syn_projIE_gaba[191] = new gaba(0.5)")
        h("Ipop[2] netConn_projIE_gaba[191] = new NetCon(&v(0.5), syn_projIE_gaba[191], 20.0, 1.5, -0.0016545403)")  

        # Connection 192: cell 2, seg 0 (0.5) [0.5 on Ipop[2]] -> cell 32, seg 0 (0.5) [0.5 on Epop[32]], weight: -0.0016545403, delay 1.5
        h("Epop[32] syn_projIE_gaba[192] = new gaba(0.5)")
        h("Ipop[2] netConn_projIE_gaba[192] = new NetCon(&v(0.5), syn_projIE_gaba[192], 20.0, 1.5, -0.0016545403)")  

        # Connection 193: cell 2, seg 0 (0.5) [0.5 on Ipop[2]] -> cell 33, seg 0 (0.5) [0.5 on Epop[33]], weight: -0.0016545403, delay 1.5
        h("Epop[33] syn_projIE_gaba[193] = new gaba(0.5)")
        h("Ipop[2] netConn_projIE_gaba[193] = new NetCon(&v(0.5), syn_projIE_gaba[193], 20.0, 1.5, -0.0016545403)")  

        # Connection 194: cell 2, seg 0 (0.5) [0.5 on Ipop[2]] -> cell 34, seg 0 (0.5) [0.5 on Epop[34]], weight: -0.0016545403, delay 1.5
        h("Epop[34] syn_projIE_gaba[194] = new gaba(0.5)")
        h("Ipop[2] netConn_projIE_gaba[194] = new NetCon(&v(0.5), syn_projIE_gaba[194], 20.0, 1.5, -0.0016545403)")  

        # Connection 195: cell 2, seg 0 (0.5) [0.5 on Ipop[2]] -> cell 35, seg 0 (0.5) [0.5 on Epop[35]], weight: -0.0016545403, delay 1.5
        h("Epop[35] syn_projIE_gaba[195] = new gaba(0.5)")
        h("Ipop[2] netConn_projIE_gaba[195] = new NetCon(&v(0.5), syn_projIE_gaba[195], 20.0, 1.5, -0.0016545403)")  

        # Connection 196: cell 2, seg 0 (0.5) [0.5 on Ipop[2]] -> cell 36, seg 0 (0.5) [0.5 on Epop[36]], weight: -0.0016545403, delay 1.5
        h("Epop[36] syn_projIE_gaba[196] = new gaba(0.5)")
        h("Ipop[2] netConn_projIE_gaba[196] = new NetCon(&v(0.5), syn_projIE_gaba[196], 20.0, 1.5, -0.0016545403)")  

        # Connection 197: cell 2, seg 0 (0.5) [0.5 on Ipop[2]] -> cell 37, seg 0 (0.5) [0.5 on Epop[37]], weight: -0.0016545403, delay 1.5
        h("Epop[37] syn_projIE_gaba[197] = new gaba(0.5)")
        h("Ipop[2] netConn_projIE_gaba[197] = new NetCon(&v(0.5), syn_projIE_gaba[197], 20.0, 1.5, -0.0016545403)")  

        # Connection 198: cell 2, seg 0 (0.5) [0.5 on Ipop[2]] -> cell 38, seg 0 (0.5) [0.5 on Epop[38]], weight: -0.0016545403, delay 1.5
        h("Epop[38] syn_projIE_gaba[198] = new gaba(0.5)")
        h("Ipop[2] netConn_projIE_gaba[198] = new NetCon(&v(0.5), syn_projIE_gaba[198], 20.0, 1.5, -0.0016545403)")  

        # Connection 199: cell 2, seg 0 (0.5) [0.5 on Ipop[2]] -> cell 39, seg 0 (0.5) [0.5 on Epop[39]], weight: -0.0016545403, delay 1.5
        h("Epop[39] syn_projIE_gaba[199] = new gaba(0.5)")
        h("Ipop[2] netConn_projIE_gaba[199] = new NetCon(&v(0.5), syn_projIE_gaba[199], 20.0, 1.5, -0.0016545403)")  

        # Connection 200: cell 2, seg 0 (0.5) [0.5 on Ipop[2]] -> cell 40, seg 0 (0.5) [0.5 on Epop[40]], weight: -0.0016545403, delay 1.5
        h("Epop[40] syn_projIE_gaba[200] = new gaba(0.5)")
        h("Ipop[2] netConn_projIE_gaba[200] = new NetCon(&v(0.5), syn_projIE_gaba[200], 20.0, 1.5, -0.0016545403)")  

        # Connection 201: cell 2, seg 0 (0.5) [0.5 on Ipop[2]] -> cell 41, seg 0 (0.5) [0.5 on Epop[41]], weight: -0.0016545403, delay 1.5
        h("Epop[41] syn_projIE_gaba[201] = new gaba(0.5)")
        h("Ipop[2] netConn_projIE_gaba[201] = new NetCon(&v(0.5), syn_projIE_gaba[201], 20.0, 1.5, -0.0016545403)")  

        # Connection 202: cell 2, seg 0 (0.5) [0.5 on Ipop[2]] -> cell 42, seg 0 (0.5) [0.5 on Epop[42]], weight: -0.0016545403, delay 1.5
        h("Epop[42] syn_projIE_gaba[202] = new gaba(0.5)")
        h("Ipop[2] netConn_projIE_gaba[202] = new NetCon(&v(0.5), syn_projIE_gaba[202], 20.0, 1.5, -0.0016545403)")  

        # Connection 203: cell 2, seg 0 (0.5) [0.5 on Ipop[2]] -> cell 43, seg 0 (0.5) [0.5 on Epop[43]], weight: -0.0016545403, delay 1.5
        h("Epop[43] syn_projIE_gaba[203] = new gaba(0.5)")
        h("Ipop[2] netConn_projIE_gaba[203] = new NetCon(&v(0.5), syn_projIE_gaba[203], 20.0, 1.5, -0.0016545403)")  

        # Connection 204: cell 2, seg 0 (0.5) [0.5 on Ipop[2]] -> cell 44, seg 0 (0.5) [0.5 on Epop[44]], weight: -0.0016545403, delay 1.5
        h("Epop[44] syn_projIE_gaba[204] = new gaba(0.5)")
        h("Ipop[2] netConn_projIE_gaba[204] = new NetCon(&v(0.5), syn_projIE_gaba[204], 20.0, 1.5, -0.0016545403)")  

        # Connection 205: cell 2, seg 0 (0.5) [0.5 on Ipop[2]] -> cell 45, seg 0 (0.5) [0.5 on Epop[45]], weight: -0.0016545403, delay 1.5
        h("Epop[45] syn_projIE_gaba[205] = new gaba(0.5)")
        h("Ipop[2] netConn_projIE_gaba[205] = new NetCon(&v(0.5), syn_projIE_gaba[205], 20.0, 1.5, -0.0016545403)")  

        # Connection 206: cell 2, seg 0 (0.5) [0.5 on Ipop[2]] -> cell 46, seg 0 (0.5) [0.5 on Epop[46]], weight: -0.0016545403, delay 1.5
        h("Epop[46] syn_projIE_gaba[206] = new gaba(0.5)")
        h("Ipop[2] netConn_projIE_gaba[206] = new NetCon(&v(0.5), syn_projIE_gaba[206], 20.0, 1.5, -0.0016545403)")  

        # Connection 207: cell 2, seg 0 (0.5) [0.5 on Ipop[2]] -> cell 47, seg 0 (0.5) [0.5 on Epop[47]], weight: -0.0016545403, delay 1.5
        h("Epop[47] syn_projIE_gaba[207] = new gaba(0.5)")
        h("Ipop[2] netConn_projIE_gaba[207] = new NetCon(&v(0.5), syn_projIE_gaba[207], 20.0, 1.5, -0.0016545403)")  

        # Connection 208: cell 2, seg 0 (0.5) [0.5 on Ipop[2]] -> cell 48, seg 0 (0.5) [0.5 on Epop[48]], weight: -0.0016545403, delay 1.5
        h("Epop[48] syn_projIE_gaba[208] = new gaba(0.5)")
        h("Ipop[2] netConn_projIE_gaba[208] = new NetCon(&v(0.5), syn_projIE_gaba[208], 20.0, 1.5, -0.0016545403)")  

        # Connection 209: cell 2, seg 0 (0.5) [0.5 on Ipop[2]] -> cell 49, seg 0 (0.5) [0.5 on Epop[49]], weight: -0.0016545403, delay 1.5
        h("Epop[49] syn_projIE_gaba[209] = new gaba(0.5)")
        h("Ipop[2] netConn_projIE_gaba[209] = new NetCon(&v(0.5), syn_projIE_gaba[209], 20.0, 1.5, -0.0016545403)")  

        # Connection 210: cell 2, seg 0 (0.5) [0.5 on Ipop[2]] -> cell 50, seg 0 (0.5) [0.5 on Epop[50]], weight: -0.0016545403, delay 1.5
        h("Epop[50] syn_projIE_gaba[210] = new gaba(0.5)")
        h("Ipop[2] netConn_projIE_gaba[210] = new NetCon(&v(0.5), syn_projIE_gaba[210], 20.0, 1.5, -0.0016545403)")  

        # Connection 211: cell 2, seg 0 (0.5) [0.5 on Ipop[2]] -> cell 51, seg 0 (0.5) [0.5 on Epop[51]], weight: -0.0016545403, delay 1.5
        h("Epop[51] syn_projIE_gaba[211] = new gaba(0.5)")
        h("Ipop[2] netConn_projIE_gaba[211] = new NetCon(&v(0.5), syn_projIE_gaba[211], 20.0, 1.5, -0.0016545403)")  

        # Connection 212: cell 2, seg 0 (0.5) [0.5 on Ipop[2]] -> cell 52, seg 0 (0.5) [0.5 on Epop[52]], weight: -0.0016545403, delay 1.5
        h("Epop[52] syn_projIE_gaba[212] = new gaba(0.5)")
        h("Ipop[2] netConn_projIE_gaba[212] = new NetCon(&v(0.5), syn_projIE_gaba[212], 20.0, 1.5, -0.0016545403)")  

        # Connection 213: cell 2, seg 0 (0.5) [0.5 on Ipop[2]] -> cell 53, seg 0 (0.5) [0.5 on Epop[53]], weight: -0.0016545403, delay 1.5
        h("Epop[53] syn_projIE_gaba[213] = new gaba(0.5)")
        h("Ipop[2] netConn_projIE_gaba[213] = new NetCon(&v(0.5), syn_projIE_gaba[213], 20.0, 1.5, -0.0016545403)")  

        # Connection 214: cell 2, seg 0 (0.5) [0.5 on Ipop[2]] -> cell 54, seg 0 (0.5) [0.5 on Epop[54]], weight: -0.0016545403, delay 1.5
        h("Epop[54] syn_projIE_gaba[214] = new gaba(0.5)")
        h("Ipop[2] netConn_projIE_gaba[214] = new NetCon(&v(0.5), syn_projIE_gaba[214], 20.0, 1.5, -0.0016545403)")  

        # Connection 215: cell 2, seg 0 (0.5) [0.5 on Ipop[2]] -> cell 55, seg 0 (0.5) [0.5 on Epop[55]], weight: -0.0016545403, delay 1.5
        h("Epop[55] syn_projIE_gaba[215] = new gaba(0.5)")
        h("Ipop[2] netConn_projIE_gaba[215] = new NetCon(&v(0.5), syn_projIE_gaba[215], 20.0, 1.5, -0.0016545403)")  

        # Connection 216: cell 2, seg 0 (0.5) [0.5 on Ipop[2]] -> cell 56, seg 0 (0.5) [0.5 on Epop[56]], weight: -0.0016545403, delay 1.5
        h("Epop[56] syn_projIE_gaba[216] = new gaba(0.5)")
        h("Ipop[2] netConn_projIE_gaba[216] = new NetCon(&v(0.5), syn_projIE_gaba[216], 20.0, 1.5, -0.0016545403)")  

        # Connection 217: cell 2, seg 0 (0.5) [0.5 on Ipop[2]] -> cell 57, seg 0 (0.5) [0.5 on Epop[57]], weight: -0.0016545403, delay 1.5
        h("Epop[57] syn_projIE_gaba[217] = new gaba(0.5)")
        h("Ipop[2] netConn_projIE_gaba[217] = new NetCon(&v(0.5), syn_projIE_gaba[217], 20.0, 1.5, -0.0016545403)")  

        # Connection 218: cell 2, seg 0 (0.5) [0.5 on Ipop[2]] -> cell 58, seg 0 (0.5) [0.5 on Epop[58]], weight: -0.0016545403, delay 1.5
        h("Epop[58] syn_projIE_gaba[218] = new gaba(0.5)")
        h("Ipop[2] netConn_projIE_gaba[218] = new NetCon(&v(0.5), syn_projIE_gaba[218], 20.0, 1.5, -0.0016545403)")  

        # Connection 219: cell 2, seg 0 (0.5) [0.5 on Ipop[2]] -> cell 59, seg 0 (0.5) [0.5 on Epop[59]], weight: -0.0016545403, delay 1.5
        h("Epop[59] syn_projIE_gaba[219] = new gaba(0.5)")
        h("Ipop[2] netConn_projIE_gaba[219] = new NetCon(&v(0.5), syn_projIE_gaba[219], 20.0, 1.5, -0.0016545403)")  

        # Connection 220: cell 2, seg 0 (0.5) [0.5 on Ipop[2]] -> cell 60, seg 0 (0.5) [0.5 on Epop[60]], weight: -0.0016545403, delay 1.5
        h("Epop[60] syn_projIE_gaba[220] = new gaba(0.5)")
        h("Ipop[2] netConn_projIE_gaba[220] = new NetCon(&v(0.5), syn_projIE_gaba[220], 20.0, 1.5, -0.0016545403)")  

        # Connection 221: cell 2, seg 0 (0.5) [0.5 on Ipop[2]] -> cell 61, seg 0 (0.5) [0.5 on Epop[61]], weight: -0.0016545403, delay 1.5
        h("Epop[61] syn_projIE_gaba[221] = new gaba(0.5)")
        h("Ipop[2] netConn_projIE_gaba[221] = new NetCon(&v(0.5), syn_projIE_gaba[221], 20.0, 1.5, -0.0016545403)")  

        # Connection 222: cell 2, seg 0 (0.5) [0.5 on Ipop[2]] -> cell 62, seg 0 (0.5) [0.5 on Epop[62]], weight: -0.0016545403, delay 1.5
        h("Epop[62] syn_projIE_gaba[222] = new gaba(0.5)")
        h("Ipop[2] netConn_projIE_gaba[222] = new NetCon(&v(0.5), syn_projIE_gaba[222], 20.0, 1.5, -0.0016545403)")  

        # Connection 223: cell 2, seg 0 (0.5) [0.5 on Ipop[2]] -> cell 63, seg 0 (0.5) [0.5 on Epop[63]], weight: -0.0016545403, delay 1.5
        h("Epop[63] syn_projIE_gaba[223] = new gaba(0.5)")
        h("Ipop[2] netConn_projIE_gaba[223] = new NetCon(&v(0.5), syn_projIE_gaba[223], 20.0, 1.5, -0.0016545403)")  

        # Connection 224: cell 2, seg 0 (0.5) [0.5 on Ipop[2]] -> cell 64, seg 0 (0.5) [0.5 on Epop[64]], weight: -0.0016545403, delay 1.5
        h("Epop[64] syn_projIE_gaba[224] = new gaba(0.5)")
        h("Ipop[2] netConn_projIE_gaba[224] = new NetCon(&v(0.5), syn_projIE_gaba[224], 20.0, 1.5, -0.0016545403)")  

        # Connection 225: cell 2, seg 0 (0.5) [0.5 on Ipop[2]] -> cell 65, seg 0 (0.5) [0.5 on Epop[65]], weight: -0.0016545403, delay 1.5
        h("Epop[65] syn_projIE_gaba[225] = new gaba(0.5)")
        h("Ipop[2] netConn_projIE_gaba[225] = new NetCon(&v(0.5), syn_projIE_gaba[225], 20.0, 1.5, -0.0016545403)")  

        # Connection 226: cell 2, seg 0 (0.5) [0.5 on Ipop[2]] -> cell 66, seg 0 (0.5) [0.5 on Epop[66]], weight: -0.0016545403, delay 1.5
        h("Epop[66] syn_projIE_gaba[226] = new gaba(0.5)")
        h("Ipop[2] netConn_projIE_gaba[226] = new NetCon(&v(0.5), syn_projIE_gaba[226], 20.0, 1.5, -0.0016545403)")  

        # Connection 227: cell 2, seg 0 (0.5) [0.5 on Ipop[2]] -> cell 67, seg 0 (0.5) [0.5 on Epop[67]], weight: -0.0016545403, delay 1.5
        h("Epop[67] syn_projIE_gaba[227] = new gaba(0.5)")
        h("Ipop[2] netConn_projIE_gaba[227] = new NetCon(&v(0.5), syn_projIE_gaba[227], 20.0, 1.5, -0.0016545403)")  

        # Connection 228: cell 2, seg 0 (0.5) [0.5 on Ipop[2]] -> cell 68, seg 0 (0.5) [0.5 on Epop[68]], weight: -0.0016545403, delay 1.5
        h("Epop[68] syn_projIE_gaba[228] = new gaba(0.5)")
        h("Ipop[2] netConn_projIE_gaba[228] = new NetCon(&v(0.5), syn_projIE_gaba[228], 20.0, 1.5, -0.0016545403)")  

        # Connection 229: cell 2, seg 0 (0.5) [0.5 on Ipop[2]] -> cell 69, seg 0 (0.5) [0.5 on Epop[69]], weight: -0.0016545403, delay 1.5
        h("Epop[69] syn_projIE_gaba[229] = new gaba(0.5)")
        h("Ipop[2] netConn_projIE_gaba[229] = new NetCon(&v(0.5), syn_projIE_gaba[229], 20.0, 1.5, -0.0016545403)")  

        # Connection 230: cell 2, seg 0 (0.5) [0.5 on Ipop[2]] -> cell 70, seg 0 (0.5) [0.5 on Epop[70]], weight: -0.0016545403, delay 1.5
        h("Epop[70] syn_projIE_gaba[230] = new gaba(0.5)")
        h("Ipop[2] netConn_projIE_gaba[230] = new NetCon(&v(0.5), syn_projIE_gaba[230], 20.0, 1.5, -0.0016545403)")  

        # Connection 231: cell 2, seg 0 (0.5) [0.5 on Ipop[2]] -> cell 71, seg 0 (0.5) [0.5 on Epop[71]], weight: -0.0016545403, delay 1.5
        h("Epop[71] syn_projIE_gaba[231] = new gaba(0.5)")
        h("Ipop[2] netConn_projIE_gaba[231] = new NetCon(&v(0.5), syn_projIE_gaba[231], 20.0, 1.5, -0.0016545403)")  

        # Connection 232: cell 2, seg 0 (0.5) [0.5 on Ipop[2]] -> cell 72, seg 0 (0.5) [0.5 on Epop[72]], weight: -0.0016545403, delay 1.5
        h("Epop[72] syn_projIE_gaba[232] = new gaba(0.5)")
        h("Ipop[2] netConn_projIE_gaba[232] = new NetCon(&v(0.5), syn_projIE_gaba[232], 20.0, 1.5, -0.0016545403)")  

        # Connection 233: cell 2, seg 0 (0.5) [0.5 on Ipop[2]] -> cell 73, seg 0 (0.5) [0.5 on Epop[73]], weight: -0.0016545403, delay 1.5
        h("Epop[73] syn_projIE_gaba[233] = new gaba(0.5)")
        h("Ipop[2] netConn_projIE_gaba[233] = new NetCon(&v(0.5), syn_projIE_gaba[233], 20.0, 1.5, -0.0016545403)")  

        # Connection 234: cell 2, seg 0 (0.5) [0.5 on Ipop[2]] -> cell 74, seg 0 (0.5) [0.5 on Epop[74]], weight: -0.0016545403, delay 1.5
        h("Epop[74] syn_projIE_gaba[234] = new gaba(0.5)")
        h("Ipop[2] netConn_projIE_gaba[234] = new NetCon(&v(0.5), syn_projIE_gaba[234], 20.0, 1.5, -0.0016545403)")  

        # Connection 235: cell 2, seg 0 (0.5) [0.5 on Ipop[2]] -> cell 75, seg 0 (0.5) [0.5 on Epop[75]], weight: -0.0016545403, delay 1.5
        h("Epop[75] syn_projIE_gaba[235] = new gaba(0.5)")
        h("Ipop[2] netConn_projIE_gaba[235] = new NetCon(&v(0.5), syn_projIE_gaba[235], 20.0, 1.5, -0.0016545403)")  

        # Connection 236: cell 2, seg 0 (0.5) [0.5 on Ipop[2]] -> cell 76, seg 0 (0.5) [0.5 on Epop[76]], weight: -0.0016545403, delay 1.5
        h("Epop[76] syn_projIE_gaba[236] = new gaba(0.5)")
        h("Ipop[2] netConn_projIE_gaba[236] = new NetCon(&v(0.5), syn_projIE_gaba[236], 20.0, 1.5, -0.0016545403)")  

        # Connection 237: cell 2, seg 0 (0.5) [0.5 on Ipop[2]] -> cell 77, seg 0 (0.5) [0.5 on Epop[77]], weight: -0.0016545403, delay 1.5
        h("Epop[77] syn_projIE_gaba[237] = new gaba(0.5)")
        h("Ipop[2] netConn_projIE_gaba[237] = new NetCon(&v(0.5), syn_projIE_gaba[237], 20.0, 1.5, -0.0016545403)")  

        # Connection 238: cell 2, seg 0 (0.5) [0.5 on Ipop[2]] -> cell 78, seg 0 (0.5) [0.5 on Epop[78]], weight: -0.0016545403, delay 1.5
        h("Epop[78] syn_projIE_gaba[238] = new gaba(0.5)")
        h("Ipop[2] netConn_projIE_gaba[238] = new NetCon(&v(0.5), syn_projIE_gaba[238], 20.0, 1.5, -0.0016545403)")  

        # Connection 239: cell 2, seg 0 (0.5) [0.5 on Ipop[2]] -> cell 79, seg 0 (0.5) [0.5 on Epop[79]], weight: -0.0016545403, delay 1.5
        h("Epop[79] syn_projIE_gaba[239] = new gaba(0.5)")
        h("Ipop[2] netConn_projIE_gaba[239] = new NetCon(&v(0.5), syn_projIE_gaba[239], 20.0, 1.5, -0.0016545403)")  

        # Connection 240: cell 3, seg 0 (0.5) [0.5 on Ipop[3]] -> cell 0, seg 0 (0.5) [0.5 on Epop[0]], weight: -0.0016545403, delay 1.5
        h("Epop[0] syn_projIE_gaba[240] = new gaba(0.5)")
        h("Ipop[3] netConn_projIE_gaba[240] = new NetCon(&v(0.5), syn_projIE_gaba[240], 20.0, 1.5, -0.0016545403)")  

        # Connection 241: cell 3, seg 0 (0.5) [0.5 on Ipop[3]] -> cell 1, seg 0 (0.5) [0.5 on Epop[1]], weight: -0.0016545403, delay 1.5
        h("Epop[1] syn_projIE_gaba[241] = new gaba(0.5)")
        h("Ipop[3] netConn_projIE_gaba[241] = new NetCon(&v(0.5), syn_projIE_gaba[241], 20.0, 1.5, -0.0016545403)")  

        # Connection 242: cell 3, seg 0 (0.5) [0.5 on Ipop[3]] -> cell 2, seg 0 (0.5) [0.5 on Epop[2]], weight: -0.0016545403, delay 1.5
        h("Epop[2] syn_projIE_gaba[242] = new gaba(0.5)")
        h("Ipop[3] netConn_projIE_gaba[242] = new NetCon(&v(0.5), syn_projIE_gaba[242], 20.0, 1.5, -0.0016545403)")  

        # Connection 243: cell 3, seg 0 (0.5) [0.5 on Ipop[3]] -> cell 3, seg 0 (0.5) [0.5 on Epop[3]], weight: -0.0016545403, delay 1.5
        h("Epop[3] syn_projIE_gaba[243] = new gaba(0.5)")
        h("Ipop[3] netConn_projIE_gaba[243] = new NetCon(&v(0.5), syn_projIE_gaba[243], 20.0, 1.5, -0.0016545403)")  

        # Connection 244: cell 3, seg 0 (0.5) [0.5 on Ipop[3]] -> cell 4, seg 0 (0.5) [0.5 on Epop[4]], weight: -0.0016545403, delay 1.5
        h("Epop[4] syn_projIE_gaba[244] = new gaba(0.5)")
        h("Ipop[3] netConn_projIE_gaba[244] = new NetCon(&v(0.5), syn_projIE_gaba[244], 20.0, 1.5, -0.0016545403)")  

        # Connection 245: cell 3, seg 0 (0.5) [0.5 on Ipop[3]] -> cell 5, seg 0 (0.5) [0.5 on Epop[5]], weight: -0.0016545403, delay 1.5
        h("Epop[5] syn_projIE_gaba[245] = new gaba(0.5)")
        h("Ipop[3] netConn_projIE_gaba[245] = new NetCon(&v(0.5), syn_projIE_gaba[245], 20.0, 1.5, -0.0016545403)")  

        # Connection 246: cell 3, seg 0 (0.5) [0.5 on Ipop[3]] -> cell 6, seg 0 (0.5) [0.5 on Epop[6]], weight: -0.0016545403, delay 1.5
        h("Epop[6] syn_projIE_gaba[246] = new gaba(0.5)")
        h("Ipop[3] netConn_projIE_gaba[246] = new NetCon(&v(0.5), syn_projIE_gaba[246], 20.0, 1.5, -0.0016545403)")  

        # Connection 247: cell 3, seg 0 (0.5) [0.5 on Ipop[3]] -> cell 7, seg 0 (0.5) [0.5 on Epop[7]], weight: -0.0016545403, delay 1.5
        h("Epop[7] syn_projIE_gaba[247] = new gaba(0.5)")
        h("Ipop[3] netConn_projIE_gaba[247] = new NetCon(&v(0.5), syn_projIE_gaba[247], 20.0, 1.5, -0.0016545403)")  

        # Connection 248: cell 3, seg 0 (0.5) [0.5 on Ipop[3]] -> cell 8, seg 0 (0.5) [0.5 on Epop[8]], weight: -0.0016545403, delay 1.5
        h("Epop[8] syn_projIE_gaba[248] = new gaba(0.5)")
        h("Ipop[3] netConn_projIE_gaba[248] = new NetCon(&v(0.5), syn_projIE_gaba[248], 20.0, 1.5, -0.0016545403)")  

        # Connection 249: cell 3, seg 0 (0.5) [0.5 on Ipop[3]] -> cell 9, seg 0 (0.5) [0.5 on Epop[9]], weight: -0.0016545403, delay 1.5
        h("Epop[9] syn_projIE_gaba[249] = new gaba(0.5)")
        h("Ipop[3] netConn_projIE_gaba[249] = new NetCon(&v(0.5), syn_projIE_gaba[249], 20.0, 1.5, -0.0016545403)")  

        # Connection 250: cell 3, seg 0 (0.5) [0.5 on Ipop[3]] -> cell 10, seg 0 (0.5) [0.5 on Epop[10]], weight: -0.0016545403, delay 1.5
        h("Epop[10] syn_projIE_gaba[250] = new gaba(0.5)")
        h("Ipop[3] netConn_projIE_gaba[250] = new NetCon(&v(0.5), syn_projIE_gaba[250], 20.0, 1.5, -0.0016545403)")  

        # Connection 251: cell 3, seg 0 (0.5) [0.5 on Ipop[3]] -> cell 11, seg 0 (0.5) [0.5 on Epop[11]], weight: -0.0016545403, delay 1.5
        h("Epop[11] syn_projIE_gaba[251] = new gaba(0.5)")
        h("Ipop[3] netConn_projIE_gaba[251] = new NetCon(&v(0.5), syn_projIE_gaba[251], 20.0, 1.5, -0.0016545403)")  

        # Connection 252: cell 3, seg 0 (0.5) [0.5 on Ipop[3]] -> cell 12, seg 0 (0.5) [0.5 on Epop[12]], weight: -0.0016545403, delay 1.5
        h("Epop[12] syn_projIE_gaba[252] = new gaba(0.5)")
        h("Ipop[3] netConn_projIE_gaba[252] = new NetCon(&v(0.5), syn_projIE_gaba[252], 20.0, 1.5, -0.0016545403)")  

        # Connection 253: cell 3, seg 0 (0.5) [0.5 on Ipop[3]] -> cell 13, seg 0 (0.5) [0.5 on Epop[13]], weight: -0.0016545403, delay 1.5
        h("Epop[13] syn_projIE_gaba[253] = new gaba(0.5)")
        h("Ipop[3] netConn_projIE_gaba[253] = new NetCon(&v(0.5), syn_projIE_gaba[253], 20.0, 1.5, -0.0016545403)")  

        # Connection 254: cell 3, seg 0 (0.5) [0.5 on Ipop[3]] -> cell 14, seg 0 (0.5) [0.5 on Epop[14]], weight: -0.0016545403, delay 1.5
        h("Epop[14] syn_projIE_gaba[254] = new gaba(0.5)")
        h("Ipop[3] netConn_projIE_gaba[254] = new NetCon(&v(0.5), syn_projIE_gaba[254], 20.0, 1.5, -0.0016545403)")  

        # Connection 255: cell 3, seg 0 (0.5) [0.5 on Ipop[3]] -> cell 15, seg 0 (0.5) [0.5 on Epop[15]], weight: -0.0016545403, delay 1.5
        h("Epop[15] syn_projIE_gaba[255] = new gaba(0.5)")
        h("Ipop[3] netConn_projIE_gaba[255] = new NetCon(&v(0.5), syn_projIE_gaba[255], 20.0, 1.5, -0.0016545403)")  

        # Connection 256: cell 3, seg 0 (0.5) [0.5 on Ipop[3]] -> cell 16, seg 0 (0.5) [0.5 on Epop[16]], weight: -0.0016545403, delay 1.5
        h("Epop[16] syn_projIE_gaba[256] = new gaba(0.5)")
        h("Ipop[3] netConn_projIE_gaba[256] = new NetCon(&v(0.5), syn_projIE_gaba[256], 20.0, 1.5, -0.0016545403)")  

        # Connection 257: cell 3, seg 0 (0.5) [0.5 on Ipop[3]] -> cell 17, seg 0 (0.5) [0.5 on Epop[17]], weight: -0.0016545403, delay 1.5
        h("Epop[17] syn_projIE_gaba[257] = new gaba(0.5)")
        h("Ipop[3] netConn_projIE_gaba[257] = new NetCon(&v(0.5), syn_projIE_gaba[257], 20.0, 1.5, -0.0016545403)")  

        # Connection 258: cell 3, seg 0 (0.5) [0.5 on Ipop[3]] -> cell 18, seg 0 (0.5) [0.5 on Epop[18]], weight: -0.0016545403, delay 1.5
        h("Epop[18] syn_projIE_gaba[258] = new gaba(0.5)")
        h("Ipop[3] netConn_projIE_gaba[258] = new NetCon(&v(0.5), syn_projIE_gaba[258], 20.0, 1.5, -0.0016545403)")  

        # Connection 259: cell 3, seg 0 (0.5) [0.5 on Ipop[3]] -> cell 19, seg 0 (0.5) [0.5 on Epop[19]], weight: -0.0016545403, delay 1.5
        h("Epop[19] syn_projIE_gaba[259] = new gaba(0.5)")
        h("Ipop[3] netConn_projIE_gaba[259] = new NetCon(&v(0.5), syn_projIE_gaba[259], 20.0, 1.5, -0.0016545403)")  

        # Connection 260: cell 3, seg 0 (0.5) [0.5 on Ipop[3]] -> cell 20, seg 0 (0.5) [0.5 on Epop[20]], weight: -0.0016545403, delay 1.5
        h("Epop[20] syn_projIE_gaba[260] = new gaba(0.5)")
        h("Ipop[3] netConn_projIE_gaba[260] = new NetCon(&v(0.5), syn_projIE_gaba[260], 20.0, 1.5, -0.0016545403)")  

        # Connection 261: cell 3, seg 0 (0.5) [0.5 on Ipop[3]] -> cell 21, seg 0 (0.5) [0.5 on Epop[21]], weight: -0.0016545403, delay 1.5
        h("Epop[21] syn_projIE_gaba[261] = new gaba(0.5)")
        h("Ipop[3] netConn_projIE_gaba[261] = new NetCon(&v(0.5), syn_projIE_gaba[261], 20.0, 1.5, -0.0016545403)")  

        # Connection 262: cell 3, seg 0 (0.5) [0.5 on Ipop[3]] -> cell 22, seg 0 (0.5) [0.5 on Epop[22]], weight: -0.0016545403, delay 1.5
        h("Epop[22] syn_projIE_gaba[262] = new gaba(0.5)")
        h("Ipop[3] netConn_projIE_gaba[262] = new NetCon(&v(0.5), syn_projIE_gaba[262], 20.0, 1.5, -0.0016545403)")  

        # Connection 263: cell 3, seg 0 (0.5) [0.5 on Ipop[3]] -> cell 23, seg 0 (0.5) [0.5 on Epop[23]], weight: -0.0016545403, delay 1.5
        h("Epop[23] syn_projIE_gaba[263] = new gaba(0.5)")
        h("Ipop[3] netConn_projIE_gaba[263] = new NetCon(&v(0.5), syn_projIE_gaba[263], 20.0, 1.5, -0.0016545403)")  

        # Connection 264: cell 3, seg 0 (0.5) [0.5 on Ipop[3]] -> cell 24, seg 0 (0.5) [0.5 on Epop[24]], weight: -0.0016545403, delay 1.5
        h("Epop[24] syn_projIE_gaba[264] = new gaba(0.5)")
        h("Ipop[3] netConn_projIE_gaba[264] = new NetCon(&v(0.5), syn_projIE_gaba[264], 20.0, 1.5, -0.0016545403)")  

        # Connection 265: cell 3, seg 0 (0.5) [0.5 on Ipop[3]] -> cell 25, seg 0 (0.5) [0.5 on Epop[25]], weight: -0.0016545403, delay 1.5
        h("Epop[25] syn_projIE_gaba[265] = new gaba(0.5)")
        h("Ipop[3] netConn_projIE_gaba[265] = new NetCon(&v(0.5), syn_projIE_gaba[265], 20.0, 1.5, -0.0016545403)")  

        # Connection 266: cell 3, seg 0 (0.5) [0.5 on Ipop[3]] -> cell 26, seg 0 (0.5) [0.5 on Epop[26]], weight: -0.0016545403, delay 1.5
        h("Epop[26] syn_projIE_gaba[266] = new gaba(0.5)")
        h("Ipop[3] netConn_projIE_gaba[266] = new NetCon(&v(0.5), syn_projIE_gaba[266], 20.0, 1.5, -0.0016545403)")  

        # Connection 267: cell 3, seg 0 (0.5) [0.5 on Ipop[3]] -> cell 27, seg 0 (0.5) [0.5 on Epop[27]], weight: -0.0016545403, delay 1.5
        h("Epop[27] syn_projIE_gaba[267] = new gaba(0.5)")
        h("Ipop[3] netConn_projIE_gaba[267] = new NetCon(&v(0.5), syn_projIE_gaba[267], 20.0, 1.5, -0.0016545403)")  

        # Connection 268: cell 3, seg 0 (0.5) [0.5 on Ipop[3]] -> cell 28, seg 0 (0.5) [0.5 on Epop[28]], weight: -0.0016545403, delay 1.5
        h("Epop[28] syn_projIE_gaba[268] = new gaba(0.5)")
        h("Ipop[3] netConn_projIE_gaba[268] = new NetCon(&v(0.5), syn_projIE_gaba[268], 20.0, 1.5, -0.0016545403)")  

        # Connection 269: cell 3, seg 0 (0.5) [0.5 on Ipop[3]] -> cell 29, seg 0 (0.5) [0.5 on Epop[29]], weight: -0.0016545403, delay 1.5
        h("Epop[29] syn_projIE_gaba[269] = new gaba(0.5)")
        h("Ipop[3] netConn_projIE_gaba[269] = new NetCon(&v(0.5), syn_projIE_gaba[269], 20.0, 1.5, -0.0016545403)")  

        # Connection 270: cell 3, seg 0 (0.5) [0.5 on Ipop[3]] -> cell 30, seg 0 (0.5) [0.5 on Epop[30]], weight: -0.0016545403, delay 1.5
        h("Epop[30] syn_projIE_gaba[270] = new gaba(0.5)")
        h("Ipop[3] netConn_projIE_gaba[270] = new NetCon(&v(0.5), syn_projIE_gaba[270], 20.0, 1.5, -0.0016545403)")  

        # Connection 271: cell 3, seg 0 (0.5) [0.5 on Ipop[3]] -> cell 31, seg 0 (0.5) [0.5 on Epop[31]], weight: -0.0016545403, delay 1.5
        h("Epop[31] syn_projIE_gaba[271] = new gaba(0.5)")
        h("Ipop[3] netConn_projIE_gaba[271] = new NetCon(&v(0.5), syn_projIE_gaba[271], 20.0, 1.5, -0.0016545403)")  

        # Connection 272: cell 3, seg 0 (0.5) [0.5 on Ipop[3]] -> cell 32, seg 0 (0.5) [0.5 on Epop[32]], weight: -0.0016545403, delay 1.5
        h("Epop[32] syn_projIE_gaba[272] = new gaba(0.5)")
        h("Ipop[3] netConn_projIE_gaba[272] = new NetCon(&v(0.5), syn_projIE_gaba[272], 20.0, 1.5, -0.0016545403)")  

        # Connection 273: cell 3, seg 0 (0.5) [0.5 on Ipop[3]] -> cell 33, seg 0 (0.5) [0.5 on Epop[33]], weight: -0.0016545403, delay 1.5
        h("Epop[33] syn_projIE_gaba[273] = new gaba(0.5)")
        h("Ipop[3] netConn_projIE_gaba[273] = new NetCon(&v(0.5), syn_projIE_gaba[273], 20.0, 1.5, -0.0016545403)")  

        # Connection 274: cell 3, seg 0 (0.5) [0.5 on Ipop[3]] -> cell 34, seg 0 (0.5) [0.5 on Epop[34]], weight: -0.0016545403, delay 1.5
        h("Epop[34] syn_projIE_gaba[274] = new gaba(0.5)")
        h("Ipop[3] netConn_projIE_gaba[274] = new NetCon(&v(0.5), syn_projIE_gaba[274], 20.0, 1.5, -0.0016545403)")  

        # Connection 275: cell 3, seg 0 (0.5) [0.5 on Ipop[3]] -> cell 35, seg 0 (0.5) [0.5 on Epop[35]], weight: -0.0016545403, delay 1.5
        h("Epop[35] syn_projIE_gaba[275] = new gaba(0.5)")
        h("Ipop[3] netConn_projIE_gaba[275] = new NetCon(&v(0.5), syn_projIE_gaba[275], 20.0, 1.5, -0.0016545403)")  

        # Connection 276: cell 3, seg 0 (0.5) [0.5 on Ipop[3]] -> cell 36, seg 0 (0.5) [0.5 on Epop[36]], weight: -0.0016545403, delay 1.5
        h("Epop[36] syn_projIE_gaba[276] = new gaba(0.5)")
        h("Ipop[3] netConn_projIE_gaba[276] = new NetCon(&v(0.5), syn_projIE_gaba[276], 20.0, 1.5, -0.0016545403)")  

        # Connection 277: cell 3, seg 0 (0.5) [0.5 on Ipop[3]] -> cell 37, seg 0 (0.5) [0.5 on Epop[37]], weight: -0.0016545403, delay 1.5
        h("Epop[37] syn_projIE_gaba[277] = new gaba(0.5)")
        h("Ipop[3] netConn_projIE_gaba[277] = new NetCon(&v(0.5), syn_projIE_gaba[277], 20.0, 1.5, -0.0016545403)")  

        # Connection 278: cell 3, seg 0 (0.5) [0.5 on Ipop[3]] -> cell 38, seg 0 (0.5) [0.5 on Epop[38]], weight: -0.0016545403, delay 1.5
        h("Epop[38] syn_projIE_gaba[278] = new gaba(0.5)")
        h("Ipop[3] netConn_projIE_gaba[278] = new NetCon(&v(0.5), syn_projIE_gaba[278], 20.0, 1.5, -0.0016545403)")  

        # Connection 279: cell 3, seg 0 (0.5) [0.5 on Ipop[3]] -> cell 39, seg 0 (0.5) [0.5 on Epop[39]], weight: -0.0016545403, delay 1.5
        h("Epop[39] syn_projIE_gaba[279] = new gaba(0.5)")
        h("Ipop[3] netConn_projIE_gaba[279] = new NetCon(&v(0.5), syn_projIE_gaba[279], 20.0, 1.5, -0.0016545403)")  

        # Connection 280: cell 3, seg 0 (0.5) [0.5 on Ipop[3]] -> cell 40, seg 0 (0.5) [0.5 on Epop[40]], weight: -0.0016545403, delay 1.5
        h("Epop[40] syn_projIE_gaba[280] = new gaba(0.5)")
        h("Ipop[3] netConn_projIE_gaba[280] = new NetCon(&v(0.5), syn_projIE_gaba[280], 20.0, 1.5, -0.0016545403)")  

        # Connection 281: cell 3, seg 0 (0.5) [0.5 on Ipop[3]] -> cell 41, seg 0 (0.5) [0.5 on Epop[41]], weight: -0.0016545403, delay 1.5
        h("Epop[41] syn_projIE_gaba[281] = new gaba(0.5)")
        h("Ipop[3] netConn_projIE_gaba[281] = new NetCon(&v(0.5), syn_projIE_gaba[281], 20.0, 1.5, -0.0016545403)")  

        # Connection 282: cell 3, seg 0 (0.5) [0.5 on Ipop[3]] -> cell 42, seg 0 (0.5) [0.5 on Epop[42]], weight: -0.0016545403, delay 1.5
        h("Epop[42] syn_projIE_gaba[282] = new gaba(0.5)")
        h("Ipop[3] netConn_projIE_gaba[282] = new NetCon(&v(0.5), syn_projIE_gaba[282], 20.0, 1.5, -0.0016545403)")  

        # Connection 283: cell 3, seg 0 (0.5) [0.5 on Ipop[3]] -> cell 43, seg 0 (0.5) [0.5 on Epop[43]], weight: -0.0016545403, delay 1.5
        h("Epop[43] syn_projIE_gaba[283] = new gaba(0.5)")
        h("Ipop[3] netConn_projIE_gaba[283] = new NetCon(&v(0.5), syn_projIE_gaba[283], 20.0, 1.5, -0.0016545403)")  

        # Connection 284: cell 3, seg 0 (0.5) [0.5 on Ipop[3]] -> cell 44, seg 0 (0.5) [0.5 on Epop[44]], weight: -0.0016545403, delay 1.5
        h("Epop[44] syn_projIE_gaba[284] = new gaba(0.5)")
        h("Ipop[3] netConn_projIE_gaba[284] = new NetCon(&v(0.5), syn_projIE_gaba[284], 20.0, 1.5, -0.0016545403)")  

        # Connection 285: cell 3, seg 0 (0.5) [0.5 on Ipop[3]] -> cell 45, seg 0 (0.5) [0.5 on Epop[45]], weight: -0.0016545403, delay 1.5
        h("Epop[45] syn_projIE_gaba[285] = new gaba(0.5)")
        h("Ipop[3] netConn_projIE_gaba[285] = new NetCon(&v(0.5), syn_projIE_gaba[285], 20.0, 1.5, -0.0016545403)")  

        # Connection 286: cell 3, seg 0 (0.5) [0.5 on Ipop[3]] -> cell 46, seg 0 (0.5) [0.5 on Epop[46]], weight: -0.0016545403, delay 1.5
        h("Epop[46] syn_projIE_gaba[286] = new gaba(0.5)")
        h("Ipop[3] netConn_projIE_gaba[286] = new NetCon(&v(0.5), syn_projIE_gaba[286], 20.0, 1.5, -0.0016545403)")  

        # Connection 287: cell 3, seg 0 (0.5) [0.5 on Ipop[3]] -> cell 47, seg 0 (0.5) [0.5 on Epop[47]], weight: -0.0016545403, delay 1.5
        h("Epop[47] syn_projIE_gaba[287] = new gaba(0.5)")
        h("Ipop[3] netConn_projIE_gaba[287] = new NetCon(&v(0.5), syn_projIE_gaba[287], 20.0, 1.5, -0.0016545403)")  

        # Connection 288: cell 3, seg 0 (0.5) [0.5 on Ipop[3]] -> cell 48, seg 0 (0.5) [0.5 on Epop[48]], weight: -0.0016545403, delay 1.5
        h("Epop[48] syn_projIE_gaba[288] = new gaba(0.5)")
        h("Ipop[3] netConn_projIE_gaba[288] = new NetCon(&v(0.5), syn_projIE_gaba[288], 20.0, 1.5, -0.0016545403)")  

        # Connection 289: cell 3, seg 0 (0.5) [0.5 on Ipop[3]] -> cell 49, seg 0 (0.5) [0.5 on Epop[49]], weight: -0.0016545403, delay 1.5
        h("Epop[49] syn_projIE_gaba[289] = new gaba(0.5)")
        h("Ipop[3] netConn_projIE_gaba[289] = new NetCon(&v(0.5), syn_projIE_gaba[289], 20.0, 1.5, -0.0016545403)")  

        # Connection 290: cell 3, seg 0 (0.5) [0.5 on Ipop[3]] -> cell 50, seg 0 (0.5) [0.5 on Epop[50]], weight: -0.0016545403, delay 1.5
        h("Epop[50] syn_projIE_gaba[290] = new gaba(0.5)")
        h("Ipop[3] netConn_projIE_gaba[290] = new NetCon(&v(0.5), syn_projIE_gaba[290], 20.0, 1.5, -0.0016545403)")  

        # Connection 291: cell 3, seg 0 (0.5) [0.5 on Ipop[3]] -> cell 51, seg 0 (0.5) [0.5 on Epop[51]], weight: -0.0016545403, delay 1.5
        h("Epop[51] syn_projIE_gaba[291] = new gaba(0.5)")
        h("Ipop[3] netConn_projIE_gaba[291] = new NetCon(&v(0.5), syn_projIE_gaba[291], 20.0, 1.5, -0.0016545403)")  

        # Connection 292: cell 3, seg 0 (0.5) [0.5 on Ipop[3]] -> cell 52, seg 0 (0.5) [0.5 on Epop[52]], weight: -0.0016545403, delay 1.5
        h("Epop[52] syn_projIE_gaba[292] = new gaba(0.5)")
        h("Ipop[3] netConn_projIE_gaba[292] = new NetCon(&v(0.5), syn_projIE_gaba[292], 20.0, 1.5, -0.0016545403)")  

        # Connection 293: cell 3, seg 0 (0.5) [0.5 on Ipop[3]] -> cell 53, seg 0 (0.5) [0.5 on Epop[53]], weight: -0.0016545403, delay 1.5
        h("Epop[53] syn_projIE_gaba[293] = new gaba(0.5)")
        h("Ipop[3] netConn_projIE_gaba[293] = new NetCon(&v(0.5), syn_projIE_gaba[293], 20.0, 1.5, -0.0016545403)")  

        # Connection 294: cell 3, seg 0 (0.5) [0.5 on Ipop[3]] -> cell 54, seg 0 (0.5) [0.5 on Epop[54]], weight: -0.0016545403, delay 1.5
        h("Epop[54] syn_projIE_gaba[294] = new gaba(0.5)")
        h("Ipop[3] netConn_projIE_gaba[294] = new NetCon(&v(0.5), syn_projIE_gaba[294], 20.0, 1.5, -0.0016545403)")  

        # Connection 295: cell 3, seg 0 (0.5) [0.5 on Ipop[3]] -> cell 55, seg 0 (0.5) [0.5 on Epop[55]], weight: -0.0016545403, delay 1.5
        h("Epop[55] syn_projIE_gaba[295] = new gaba(0.5)")
        h("Ipop[3] netConn_projIE_gaba[295] = new NetCon(&v(0.5), syn_projIE_gaba[295], 20.0, 1.5, -0.0016545403)")  

        # Connection 296: cell 3, seg 0 (0.5) [0.5 on Ipop[3]] -> cell 56, seg 0 (0.5) [0.5 on Epop[56]], weight: -0.0016545403, delay 1.5
        h("Epop[56] syn_projIE_gaba[296] = new gaba(0.5)")
        h("Ipop[3] netConn_projIE_gaba[296] = new NetCon(&v(0.5), syn_projIE_gaba[296], 20.0, 1.5, -0.0016545403)")  

        # Connection 297: cell 3, seg 0 (0.5) [0.5 on Ipop[3]] -> cell 57, seg 0 (0.5) [0.5 on Epop[57]], weight: -0.0016545403, delay 1.5
        h("Epop[57] syn_projIE_gaba[297] = new gaba(0.5)")
        h("Ipop[3] netConn_projIE_gaba[297] = new NetCon(&v(0.5), syn_projIE_gaba[297], 20.0, 1.5, -0.0016545403)")  

        # Connection 298: cell 3, seg 0 (0.5) [0.5 on Ipop[3]] -> cell 58, seg 0 (0.5) [0.5 on Epop[58]], weight: -0.0016545403, delay 1.5
        h("Epop[58] syn_projIE_gaba[298] = new gaba(0.5)")
        h("Ipop[3] netConn_projIE_gaba[298] = new NetCon(&v(0.5), syn_projIE_gaba[298], 20.0, 1.5, -0.0016545403)")  

        # Connection 299: cell 3, seg 0 (0.5) [0.5 on Ipop[3]] -> cell 59, seg 0 (0.5) [0.5 on Epop[59]], weight: -0.0016545403, delay 1.5
        h("Epop[59] syn_projIE_gaba[299] = new gaba(0.5)")
        h("Ipop[3] netConn_projIE_gaba[299] = new NetCon(&v(0.5), syn_projIE_gaba[299], 20.0, 1.5, -0.0016545403)")  

        # Connection 300: cell 3, seg 0 (0.5) [0.5 on Ipop[3]] -> cell 60, seg 0 (0.5) [0.5 on Epop[60]], weight: -0.0016545403, delay 1.5
        h("Epop[60] syn_projIE_gaba[300] = new gaba(0.5)")
        h("Ipop[3] netConn_projIE_gaba[300] = new NetCon(&v(0.5), syn_projIE_gaba[300], 20.0, 1.5, -0.0016545403)")  

        # Connection 301: cell 3, seg 0 (0.5) [0.5 on Ipop[3]] -> cell 61, seg 0 (0.5) [0.5 on Epop[61]], weight: -0.0016545403, delay 1.5
        h("Epop[61] syn_projIE_gaba[301] = new gaba(0.5)")
        h("Ipop[3] netConn_projIE_gaba[301] = new NetCon(&v(0.5), syn_projIE_gaba[301], 20.0, 1.5, -0.0016545403)")  

        # Connection 302: cell 3, seg 0 (0.5) [0.5 on Ipop[3]] -> cell 62, seg 0 (0.5) [0.5 on Epop[62]], weight: -0.0016545403, delay 1.5
        h("Epop[62] syn_projIE_gaba[302] = new gaba(0.5)")
        h("Ipop[3] netConn_projIE_gaba[302] = new NetCon(&v(0.5), syn_projIE_gaba[302], 20.0, 1.5, -0.0016545403)")  

        # Connection 303: cell 3, seg 0 (0.5) [0.5 on Ipop[3]] -> cell 63, seg 0 (0.5) [0.5 on Epop[63]], weight: -0.0016545403, delay 1.5
        h("Epop[63] syn_projIE_gaba[303] = new gaba(0.5)")
        h("Ipop[3] netConn_projIE_gaba[303] = new NetCon(&v(0.5), syn_projIE_gaba[303], 20.0, 1.5, -0.0016545403)")  

        # Connection 304: cell 3, seg 0 (0.5) [0.5 on Ipop[3]] -> cell 64, seg 0 (0.5) [0.5 on Epop[64]], weight: -0.0016545403, delay 1.5
        h("Epop[64] syn_projIE_gaba[304] = new gaba(0.5)")
        h("Ipop[3] netConn_projIE_gaba[304] = new NetCon(&v(0.5), syn_projIE_gaba[304], 20.0, 1.5, -0.0016545403)")  

        # Connection 305: cell 3, seg 0 (0.5) [0.5 on Ipop[3]] -> cell 65, seg 0 (0.5) [0.5 on Epop[65]], weight: -0.0016545403, delay 1.5
        h("Epop[65] syn_projIE_gaba[305] = new gaba(0.5)")
        h("Ipop[3] netConn_projIE_gaba[305] = new NetCon(&v(0.5), syn_projIE_gaba[305], 20.0, 1.5, -0.0016545403)")  

        # Connection 306: cell 3, seg 0 (0.5) [0.5 on Ipop[3]] -> cell 66, seg 0 (0.5) [0.5 on Epop[66]], weight: -0.0016545403, delay 1.5
        h("Epop[66] syn_projIE_gaba[306] = new gaba(0.5)")
        h("Ipop[3] netConn_projIE_gaba[306] = new NetCon(&v(0.5), syn_projIE_gaba[306], 20.0, 1.5, -0.0016545403)")  

        # Connection 307: cell 3, seg 0 (0.5) [0.5 on Ipop[3]] -> cell 67, seg 0 (0.5) [0.5 on Epop[67]], weight: -0.0016545403, delay 1.5
        h("Epop[67] syn_projIE_gaba[307] = new gaba(0.5)")
        h("Ipop[3] netConn_projIE_gaba[307] = new NetCon(&v(0.5), syn_projIE_gaba[307], 20.0, 1.5, -0.0016545403)")  

        # Connection 308: cell 3, seg 0 (0.5) [0.5 on Ipop[3]] -> cell 68, seg 0 (0.5) [0.5 on Epop[68]], weight: -0.0016545403, delay 1.5
        h("Epop[68] syn_projIE_gaba[308] = new gaba(0.5)")
        h("Ipop[3] netConn_projIE_gaba[308] = new NetCon(&v(0.5), syn_projIE_gaba[308], 20.0, 1.5, -0.0016545403)")  

        # Connection 309: cell 3, seg 0 (0.5) [0.5 on Ipop[3]] -> cell 69, seg 0 (0.5) [0.5 on Epop[69]], weight: -0.0016545403, delay 1.5
        h("Epop[69] syn_projIE_gaba[309] = new gaba(0.5)")
        h("Ipop[3] netConn_projIE_gaba[309] = new NetCon(&v(0.5), syn_projIE_gaba[309], 20.0, 1.5, -0.0016545403)")  

        # Connection 310: cell 3, seg 0 (0.5) [0.5 on Ipop[3]] -> cell 70, seg 0 (0.5) [0.5 on Epop[70]], weight: -0.0016545403, delay 1.5
        h("Epop[70] syn_projIE_gaba[310] = new gaba(0.5)")
        h("Ipop[3] netConn_projIE_gaba[310] = new NetCon(&v(0.5), syn_projIE_gaba[310], 20.0, 1.5, -0.0016545403)")  

        # Connection 311: cell 3, seg 0 (0.5) [0.5 on Ipop[3]] -> cell 71, seg 0 (0.5) [0.5 on Epop[71]], weight: -0.0016545403, delay 1.5
        h("Epop[71] syn_projIE_gaba[311] = new gaba(0.5)")
        h("Ipop[3] netConn_projIE_gaba[311] = new NetCon(&v(0.5), syn_projIE_gaba[311], 20.0, 1.5, -0.0016545403)")  

        # Connection 312: cell 3, seg 0 (0.5) [0.5 on Ipop[3]] -> cell 72, seg 0 (0.5) [0.5 on Epop[72]], weight: -0.0016545403, delay 1.5
        h("Epop[72] syn_projIE_gaba[312] = new gaba(0.5)")
        h("Ipop[3] netConn_projIE_gaba[312] = new NetCon(&v(0.5), syn_projIE_gaba[312], 20.0, 1.5, -0.0016545403)")  

        # Connection 313: cell 3, seg 0 (0.5) [0.5 on Ipop[3]] -> cell 73, seg 0 (0.5) [0.5 on Epop[73]], weight: -0.0016545403, delay 1.5
        h("Epop[73] syn_projIE_gaba[313] = new gaba(0.5)")
        h("Ipop[3] netConn_projIE_gaba[313] = new NetCon(&v(0.5), syn_projIE_gaba[313], 20.0, 1.5, -0.0016545403)")  

        # Connection 314: cell 3, seg 0 (0.5) [0.5 on Ipop[3]] -> cell 74, seg 0 (0.5) [0.5 on Epop[74]], weight: -0.0016545403, delay 1.5
        h("Epop[74] syn_projIE_gaba[314] = new gaba(0.5)")
        h("Ipop[3] netConn_projIE_gaba[314] = new NetCon(&v(0.5), syn_projIE_gaba[314], 20.0, 1.5, -0.0016545403)")  

        # Connection 315: cell 3, seg 0 (0.5) [0.5 on Ipop[3]] -> cell 75, seg 0 (0.5) [0.5 on Epop[75]], weight: -0.0016545403, delay 1.5
        h("Epop[75] syn_projIE_gaba[315] = new gaba(0.5)")
        h("Ipop[3] netConn_projIE_gaba[315] = new NetCon(&v(0.5), syn_projIE_gaba[315], 20.0, 1.5, -0.0016545403)")  

        # Connection 316: cell 3, seg 0 (0.5) [0.5 on Ipop[3]] -> cell 76, seg 0 (0.5) [0.5 on Epop[76]], weight: -0.0016545403, delay 1.5
        h("Epop[76] syn_projIE_gaba[316] = new gaba(0.5)")
        h("Ipop[3] netConn_projIE_gaba[316] = new NetCon(&v(0.5), syn_projIE_gaba[316], 20.0, 1.5, -0.0016545403)")  

        # Connection 317: cell 3, seg 0 (0.5) [0.5 on Ipop[3]] -> cell 77, seg 0 (0.5) [0.5 on Epop[77]], weight: -0.0016545403, delay 1.5
        h("Epop[77] syn_projIE_gaba[317] = new gaba(0.5)")
        h("Ipop[3] netConn_projIE_gaba[317] = new NetCon(&v(0.5), syn_projIE_gaba[317], 20.0, 1.5, -0.0016545403)")  

        # Connection 318: cell 3, seg 0 (0.5) [0.5 on Ipop[3]] -> cell 78, seg 0 (0.5) [0.5 on Epop[78]], weight: -0.0016545403, delay 1.5
        h("Epop[78] syn_projIE_gaba[318] = new gaba(0.5)")
        h("Ipop[3] netConn_projIE_gaba[318] = new NetCon(&v(0.5), syn_projIE_gaba[318], 20.0, 1.5, -0.0016545403)")  

        # Connection 319: cell 3, seg 0 (0.5) [0.5 on Ipop[3]] -> cell 79, seg 0 (0.5) [0.5 on Epop[79]], weight: -0.0016545403, delay 1.5
        h("Epop[79] syn_projIE_gaba[319] = new gaba(0.5)")
        h("Ipop[3] netConn_projIE_gaba[319] = new NetCon(&v(0.5), syn_projIE_gaba[319], 20.0, 1.5, -0.0016545403)")  

        # Connection 320: cell 4, seg 0 (0.5) [0.5 on Ipop[4]] -> cell 0, seg 0 (0.5) [0.5 on Epop[0]], weight: -0.0016545403, delay 1.5
        h("Epop[0] syn_projIE_gaba[320] = new gaba(0.5)")
        h("Ipop[4] netConn_projIE_gaba[320] = new NetCon(&v(0.5), syn_projIE_gaba[320], 20.0, 1.5, -0.0016545403)")  

        # Connection 321: cell 4, seg 0 (0.5) [0.5 on Ipop[4]] -> cell 1, seg 0 (0.5) [0.5 on Epop[1]], weight: -0.0016545403, delay 1.5
        h("Epop[1] syn_projIE_gaba[321] = new gaba(0.5)")
        h("Ipop[4] netConn_projIE_gaba[321] = new NetCon(&v(0.5), syn_projIE_gaba[321], 20.0, 1.5, -0.0016545403)")  

        # Connection 322: cell 4, seg 0 (0.5) [0.5 on Ipop[4]] -> cell 2, seg 0 (0.5) [0.5 on Epop[2]], weight: -0.0016545403, delay 1.5
        h("Epop[2] syn_projIE_gaba[322] = new gaba(0.5)")
        h("Ipop[4] netConn_projIE_gaba[322] = new NetCon(&v(0.5), syn_projIE_gaba[322], 20.0, 1.5, -0.0016545403)")  

        # Connection 323: cell 4, seg 0 (0.5) [0.5 on Ipop[4]] -> cell 3, seg 0 (0.5) [0.5 on Epop[3]], weight: -0.0016545403, delay 1.5
        h("Epop[3] syn_projIE_gaba[323] = new gaba(0.5)")
        h("Ipop[4] netConn_projIE_gaba[323] = new NetCon(&v(0.5), syn_projIE_gaba[323], 20.0, 1.5, -0.0016545403)")  

        # Connection 324: cell 4, seg 0 (0.5) [0.5 on Ipop[4]] -> cell 4, seg 0 (0.5) [0.5 on Epop[4]], weight: -0.0016545403, delay 1.5
        h("Epop[4] syn_projIE_gaba[324] = new gaba(0.5)")
        h("Ipop[4] netConn_projIE_gaba[324] = new NetCon(&v(0.5), syn_projIE_gaba[324], 20.0, 1.5, -0.0016545403)")  

        # Connection 325: cell 4, seg 0 (0.5) [0.5 on Ipop[4]] -> cell 5, seg 0 (0.5) [0.5 on Epop[5]], weight: -0.0016545403, delay 1.5
        h("Epop[5] syn_projIE_gaba[325] = new gaba(0.5)")
        h("Ipop[4] netConn_projIE_gaba[325] = new NetCon(&v(0.5), syn_projIE_gaba[325], 20.0, 1.5, -0.0016545403)")  

        # Connection 326: cell 4, seg 0 (0.5) [0.5 on Ipop[4]] -> cell 6, seg 0 (0.5) [0.5 on Epop[6]], weight: -0.0016545403, delay 1.5
        h("Epop[6] syn_projIE_gaba[326] = new gaba(0.5)")
        h("Ipop[4] netConn_projIE_gaba[326] = new NetCon(&v(0.5), syn_projIE_gaba[326], 20.0, 1.5, -0.0016545403)")  

        # Connection 327: cell 4, seg 0 (0.5) [0.5 on Ipop[4]] -> cell 7, seg 0 (0.5) [0.5 on Epop[7]], weight: -0.0016545403, delay 1.5
        h("Epop[7] syn_projIE_gaba[327] = new gaba(0.5)")
        h("Ipop[4] netConn_projIE_gaba[327] = new NetCon(&v(0.5), syn_projIE_gaba[327], 20.0, 1.5, -0.0016545403)")  

        # Connection 328: cell 4, seg 0 (0.5) [0.5 on Ipop[4]] -> cell 8, seg 0 (0.5) [0.5 on Epop[8]], weight: -0.0016545403, delay 1.5
        h("Epop[8] syn_projIE_gaba[328] = new gaba(0.5)")
        h("Ipop[4] netConn_projIE_gaba[328] = new NetCon(&v(0.5), syn_projIE_gaba[328], 20.0, 1.5, -0.0016545403)")  

        # Connection 329: cell 4, seg 0 (0.5) [0.5 on Ipop[4]] -> cell 9, seg 0 (0.5) [0.5 on Epop[9]], weight: -0.0016545403, delay 1.5
        h("Epop[9] syn_projIE_gaba[329] = new gaba(0.5)")
        h("Ipop[4] netConn_projIE_gaba[329] = new NetCon(&v(0.5), syn_projIE_gaba[329], 20.0, 1.5, -0.0016545403)")  

        # Connection 330: cell 4, seg 0 (0.5) [0.5 on Ipop[4]] -> cell 10, seg 0 (0.5) [0.5 on Epop[10]], weight: -0.0016545403, delay 1.5
        h("Epop[10] syn_projIE_gaba[330] = new gaba(0.5)")
        h("Ipop[4] netConn_projIE_gaba[330] = new NetCon(&v(0.5), syn_projIE_gaba[330], 20.0, 1.5, -0.0016545403)")  

        # Connection 331: cell 4, seg 0 (0.5) [0.5 on Ipop[4]] -> cell 11, seg 0 (0.5) [0.5 on Epop[11]], weight: -0.0016545403, delay 1.5
        h("Epop[11] syn_projIE_gaba[331] = new gaba(0.5)")
        h("Ipop[4] netConn_projIE_gaba[331] = new NetCon(&v(0.5), syn_projIE_gaba[331], 20.0, 1.5, -0.0016545403)")  

        # Connection 332: cell 4, seg 0 (0.5) [0.5 on Ipop[4]] -> cell 12, seg 0 (0.5) [0.5 on Epop[12]], weight: -0.0016545403, delay 1.5
        h("Epop[12] syn_projIE_gaba[332] = new gaba(0.5)")
        h("Ipop[4] netConn_projIE_gaba[332] = new NetCon(&v(0.5), syn_projIE_gaba[332], 20.0, 1.5, -0.0016545403)")  

        # Connection 333: cell 4, seg 0 (0.5) [0.5 on Ipop[4]] -> cell 13, seg 0 (0.5) [0.5 on Epop[13]], weight: -0.0016545403, delay 1.5
        h("Epop[13] syn_projIE_gaba[333] = new gaba(0.5)")
        h("Ipop[4] netConn_projIE_gaba[333] = new NetCon(&v(0.5), syn_projIE_gaba[333], 20.0, 1.5, -0.0016545403)")  

        # Connection 334: cell 4, seg 0 (0.5) [0.5 on Ipop[4]] -> cell 14, seg 0 (0.5) [0.5 on Epop[14]], weight: -0.0016545403, delay 1.5
        h("Epop[14] syn_projIE_gaba[334] = new gaba(0.5)")
        h("Ipop[4] netConn_projIE_gaba[334] = new NetCon(&v(0.5), syn_projIE_gaba[334], 20.0, 1.5, -0.0016545403)")  

        # Connection 335: cell 4, seg 0 (0.5) [0.5 on Ipop[4]] -> cell 15, seg 0 (0.5) [0.5 on Epop[15]], weight: -0.0016545403, delay 1.5
        h("Epop[15] syn_projIE_gaba[335] = new gaba(0.5)")
        h("Ipop[4] netConn_projIE_gaba[335] = new NetCon(&v(0.5), syn_projIE_gaba[335], 20.0, 1.5, -0.0016545403)")  

        # Connection 336: cell 4, seg 0 (0.5) [0.5 on Ipop[4]] -> cell 16, seg 0 (0.5) [0.5 on Epop[16]], weight: -0.0016545403, delay 1.5
        h("Epop[16] syn_projIE_gaba[336] = new gaba(0.5)")
        h("Ipop[4] netConn_projIE_gaba[336] = new NetCon(&v(0.5), syn_projIE_gaba[336], 20.0, 1.5, -0.0016545403)")  

        # Connection 337: cell 4, seg 0 (0.5) [0.5 on Ipop[4]] -> cell 17, seg 0 (0.5) [0.5 on Epop[17]], weight: -0.0016545403, delay 1.5
        h("Epop[17] syn_projIE_gaba[337] = new gaba(0.5)")
        h("Ipop[4] netConn_projIE_gaba[337] = new NetCon(&v(0.5), syn_projIE_gaba[337], 20.0, 1.5, -0.0016545403)")  

        # Connection 338: cell 4, seg 0 (0.5) [0.5 on Ipop[4]] -> cell 18, seg 0 (0.5) [0.5 on Epop[18]], weight: -0.0016545403, delay 1.5
        h("Epop[18] syn_projIE_gaba[338] = new gaba(0.5)")
        h("Ipop[4] netConn_projIE_gaba[338] = new NetCon(&v(0.5), syn_projIE_gaba[338], 20.0, 1.5, -0.0016545403)")  

        # Connection 339: cell 4, seg 0 (0.5) [0.5 on Ipop[4]] -> cell 19, seg 0 (0.5) [0.5 on Epop[19]], weight: -0.0016545403, delay 1.5
        h("Epop[19] syn_projIE_gaba[339] = new gaba(0.5)")
        h("Ipop[4] netConn_projIE_gaba[339] = new NetCon(&v(0.5), syn_projIE_gaba[339], 20.0, 1.5, -0.0016545403)")  

        # Connection 340: cell 4, seg 0 (0.5) [0.5 on Ipop[4]] -> cell 20, seg 0 (0.5) [0.5 on Epop[20]], weight: -0.0016545403, delay 1.5
        h("Epop[20] syn_projIE_gaba[340] = new gaba(0.5)")
        h("Ipop[4] netConn_projIE_gaba[340] = new NetCon(&v(0.5), syn_projIE_gaba[340], 20.0, 1.5, -0.0016545403)")  

        # Connection 341: cell 4, seg 0 (0.5) [0.5 on Ipop[4]] -> cell 21, seg 0 (0.5) [0.5 on Epop[21]], weight: -0.0016545403, delay 1.5
        h("Epop[21] syn_projIE_gaba[341] = new gaba(0.5)")
        h("Ipop[4] netConn_projIE_gaba[341] = new NetCon(&v(0.5), syn_projIE_gaba[341], 20.0, 1.5, -0.0016545403)")  

        # Connection 342: cell 4, seg 0 (0.5) [0.5 on Ipop[4]] -> cell 22, seg 0 (0.5) [0.5 on Epop[22]], weight: -0.0016545403, delay 1.5
        h("Epop[22] syn_projIE_gaba[342] = new gaba(0.5)")
        h("Ipop[4] netConn_projIE_gaba[342] = new NetCon(&v(0.5), syn_projIE_gaba[342], 20.0, 1.5, -0.0016545403)")  

        # Connection 343: cell 4, seg 0 (0.5) [0.5 on Ipop[4]] -> cell 23, seg 0 (0.5) [0.5 on Epop[23]], weight: -0.0016545403, delay 1.5
        h("Epop[23] syn_projIE_gaba[343] = new gaba(0.5)")
        h("Ipop[4] netConn_projIE_gaba[343] = new NetCon(&v(0.5), syn_projIE_gaba[343], 20.0, 1.5, -0.0016545403)")  

        # Connection 344: cell 4, seg 0 (0.5) [0.5 on Ipop[4]] -> cell 24, seg 0 (0.5) [0.5 on Epop[24]], weight: -0.0016545403, delay 1.5
        h("Epop[24] syn_projIE_gaba[344] = new gaba(0.5)")
        h("Ipop[4] netConn_projIE_gaba[344] = new NetCon(&v(0.5), syn_projIE_gaba[344], 20.0, 1.5, -0.0016545403)")  

        # Connection 345: cell 4, seg 0 (0.5) [0.5 on Ipop[4]] -> cell 25, seg 0 (0.5) [0.5 on Epop[25]], weight: -0.0016545403, delay 1.5
        h("Epop[25] syn_projIE_gaba[345] = new gaba(0.5)")
        h("Ipop[4] netConn_projIE_gaba[345] = new NetCon(&v(0.5), syn_projIE_gaba[345], 20.0, 1.5, -0.0016545403)")  

        # Connection 346: cell 4, seg 0 (0.5) [0.5 on Ipop[4]] -> cell 26, seg 0 (0.5) [0.5 on Epop[26]], weight: -0.0016545403, delay 1.5
        h("Epop[26] syn_projIE_gaba[346] = new gaba(0.5)")
        h("Ipop[4] netConn_projIE_gaba[346] = new NetCon(&v(0.5), syn_projIE_gaba[346], 20.0, 1.5, -0.0016545403)")  

        # Connection 347: cell 4, seg 0 (0.5) [0.5 on Ipop[4]] -> cell 27, seg 0 (0.5) [0.5 on Epop[27]], weight: -0.0016545403, delay 1.5
        h("Epop[27] syn_projIE_gaba[347] = new gaba(0.5)")
        h("Ipop[4] netConn_projIE_gaba[347] = new NetCon(&v(0.5), syn_projIE_gaba[347], 20.0, 1.5, -0.0016545403)")  

        # Connection 348: cell 4, seg 0 (0.5) [0.5 on Ipop[4]] -> cell 28, seg 0 (0.5) [0.5 on Epop[28]], weight: -0.0016545403, delay 1.5
        h("Epop[28] syn_projIE_gaba[348] = new gaba(0.5)")
        h("Ipop[4] netConn_projIE_gaba[348] = new NetCon(&v(0.5), syn_projIE_gaba[348], 20.0, 1.5, -0.0016545403)")  

        # Connection 349: cell 4, seg 0 (0.5) [0.5 on Ipop[4]] -> cell 29, seg 0 (0.5) [0.5 on Epop[29]], weight: -0.0016545403, delay 1.5
        h("Epop[29] syn_projIE_gaba[349] = new gaba(0.5)")
        h("Ipop[4] netConn_projIE_gaba[349] = new NetCon(&v(0.5), syn_projIE_gaba[349], 20.0, 1.5, -0.0016545403)")  

        # Connection 350: cell 4, seg 0 (0.5) [0.5 on Ipop[4]] -> cell 30, seg 0 (0.5) [0.5 on Epop[30]], weight: -0.0016545403, delay 1.5
        h("Epop[30] syn_projIE_gaba[350] = new gaba(0.5)")
        h("Ipop[4] netConn_projIE_gaba[350] = new NetCon(&v(0.5), syn_projIE_gaba[350], 20.0, 1.5, -0.0016545403)")  

        # Connection 351: cell 4, seg 0 (0.5) [0.5 on Ipop[4]] -> cell 31, seg 0 (0.5) [0.5 on Epop[31]], weight: -0.0016545403, delay 1.5
        h("Epop[31] syn_projIE_gaba[351] = new gaba(0.5)")
        h("Ipop[4] netConn_projIE_gaba[351] = new NetCon(&v(0.5), syn_projIE_gaba[351], 20.0, 1.5, -0.0016545403)")  

        # Connection 352: cell 4, seg 0 (0.5) [0.5 on Ipop[4]] -> cell 32, seg 0 (0.5) [0.5 on Epop[32]], weight: -0.0016545403, delay 1.5
        h("Epop[32] syn_projIE_gaba[352] = new gaba(0.5)")
        h("Ipop[4] netConn_projIE_gaba[352] = new NetCon(&v(0.5), syn_projIE_gaba[352], 20.0, 1.5, -0.0016545403)")  

        # Connection 353: cell 4, seg 0 (0.5) [0.5 on Ipop[4]] -> cell 33, seg 0 (0.5) [0.5 on Epop[33]], weight: -0.0016545403, delay 1.5
        h("Epop[33] syn_projIE_gaba[353] = new gaba(0.5)")
        h("Ipop[4] netConn_projIE_gaba[353] = new NetCon(&v(0.5), syn_projIE_gaba[353], 20.0, 1.5, -0.0016545403)")  

        # Connection 354: cell 4, seg 0 (0.5) [0.5 on Ipop[4]] -> cell 34, seg 0 (0.5) [0.5 on Epop[34]], weight: -0.0016545403, delay 1.5
        h("Epop[34] syn_projIE_gaba[354] = new gaba(0.5)")
        h("Ipop[4] netConn_projIE_gaba[354] = new NetCon(&v(0.5), syn_projIE_gaba[354], 20.0, 1.5, -0.0016545403)")  

        # Connection 355: cell 4, seg 0 (0.5) [0.5 on Ipop[4]] -> cell 35, seg 0 (0.5) [0.5 on Epop[35]], weight: -0.0016545403, delay 1.5
        h("Epop[35] syn_projIE_gaba[355] = new gaba(0.5)")
        h("Ipop[4] netConn_projIE_gaba[355] = new NetCon(&v(0.5), syn_projIE_gaba[355], 20.0, 1.5, -0.0016545403)")  

        # Connection 356: cell 4, seg 0 (0.5) [0.5 on Ipop[4]] -> cell 36, seg 0 (0.5) [0.5 on Epop[36]], weight: -0.0016545403, delay 1.5
        h("Epop[36] syn_projIE_gaba[356] = new gaba(0.5)")
        h("Ipop[4] netConn_projIE_gaba[356] = new NetCon(&v(0.5), syn_projIE_gaba[356], 20.0, 1.5, -0.0016545403)")  

        # Connection 357: cell 4, seg 0 (0.5) [0.5 on Ipop[4]] -> cell 37, seg 0 (0.5) [0.5 on Epop[37]], weight: -0.0016545403, delay 1.5
        h("Epop[37] syn_projIE_gaba[357] = new gaba(0.5)")
        h("Ipop[4] netConn_projIE_gaba[357] = new NetCon(&v(0.5), syn_projIE_gaba[357], 20.0, 1.5, -0.0016545403)")  

        # Connection 358: cell 4, seg 0 (0.5) [0.5 on Ipop[4]] -> cell 38, seg 0 (0.5) [0.5 on Epop[38]], weight: -0.0016545403, delay 1.5
        h("Epop[38] syn_projIE_gaba[358] = new gaba(0.5)")
        h("Ipop[4] netConn_projIE_gaba[358] = new NetCon(&v(0.5), syn_projIE_gaba[358], 20.0, 1.5, -0.0016545403)")  

        # Connection 359: cell 4, seg 0 (0.5) [0.5 on Ipop[4]] -> cell 39, seg 0 (0.5) [0.5 on Epop[39]], weight: -0.0016545403, delay 1.5
        h("Epop[39] syn_projIE_gaba[359] = new gaba(0.5)")
        h("Ipop[4] netConn_projIE_gaba[359] = new NetCon(&v(0.5), syn_projIE_gaba[359], 20.0, 1.5, -0.0016545403)")  

        # Connection 360: cell 4, seg 0 (0.5) [0.5 on Ipop[4]] -> cell 40, seg 0 (0.5) [0.5 on Epop[40]], weight: -0.0016545403, delay 1.5
        h("Epop[40] syn_projIE_gaba[360] = new gaba(0.5)")
        h("Ipop[4] netConn_projIE_gaba[360] = new NetCon(&v(0.5), syn_projIE_gaba[360], 20.0, 1.5, -0.0016545403)")  

        # Connection 361: cell 4, seg 0 (0.5) [0.5 on Ipop[4]] -> cell 41, seg 0 (0.5) [0.5 on Epop[41]], weight: -0.0016545403, delay 1.5
        h("Epop[41] syn_projIE_gaba[361] = new gaba(0.5)")
        h("Ipop[4] netConn_projIE_gaba[361] = new NetCon(&v(0.5), syn_projIE_gaba[361], 20.0, 1.5, -0.0016545403)")  

        # Connection 362: cell 4, seg 0 (0.5) [0.5 on Ipop[4]] -> cell 42, seg 0 (0.5) [0.5 on Epop[42]], weight: -0.0016545403, delay 1.5
        h("Epop[42] syn_projIE_gaba[362] = new gaba(0.5)")
        h("Ipop[4] netConn_projIE_gaba[362] = new NetCon(&v(0.5), syn_projIE_gaba[362], 20.0, 1.5, -0.0016545403)")  

        # Connection 363: cell 4, seg 0 (0.5) [0.5 on Ipop[4]] -> cell 43, seg 0 (0.5) [0.5 on Epop[43]], weight: -0.0016545403, delay 1.5
        h("Epop[43] syn_projIE_gaba[363] = new gaba(0.5)")
        h("Ipop[4] netConn_projIE_gaba[363] = new NetCon(&v(0.5), syn_projIE_gaba[363], 20.0, 1.5, -0.0016545403)")  

        # Connection 364: cell 4, seg 0 (0.5) [0.5 on Ipop[4]] -> cell 44, seg 0 (0.5) [0.5 on Epop[44]], weight: -0.0016545403, delay 1.5
        h("Epop[44] syn_projIE_gaba[364] = new gaba(0.5)")
        h("Ipop[4] netConn_projIE_gaba[364] = new NetCon(&v(0.5), syn_projIE_gaba[364], 20.0, 1.5, -0.0016545403)")  

        # Connection 365: cell 4, seg 0 (0.5) [0.5 on Ipop[4]] -> cell 45, seg 0 (0.5) [0.5 on Epop[45]], weight: -0.0016545403, delay 1.5
        h("Epop[45] syn_projIE_gaba[365] = new gaba(0.5)")
        h("Ipop[4] netConn_projIE_gaba[365] = new NetCon(&v(0.5), syn_projIE_gaba[365], 20.0, 1.5, -0.0016545403)")  

        # Connection 366: cell 4, seg 0 (0.5) [0.5 on Ipop[4]] -> cell 46, seg 0 (0.5) [0.5 on Epop[46]], weight: -0.0016545403, delay 1.5
        h("Epop[46] syn_projIE_gaba[366] = new gaba(0.5)")
        h("Ipop[4] netConn_projIE_gaba[366] = new NetCon(&v(0.5), syn_projIE_gaba[366], 20.0, 1.5, -0.0016545403)")  

        # Connection 367: cell 4, seg 0 (0.5) [0.5 on Ipop[4]] -> cell 47, seg 0 (0.5) [0.5 on Epop[47]], weight: -0.0016545403, delay 1.5
        h("Epop[47] syn_projIE_gaba[367] = new gaba(0.5)")
        h("Ipop[4] netConn_projIE_gaba[367] = new NetCon(&v(0.5), syn_projIE_gaba[367], 20.0, 1.5, -0.0016545403)")  

        # Connection 368: cell 4, seg 0 (0.5) [0.5 on Ipop[4]] -> cell 48, seg 0 (0.5) [0.5 on Epop[48]], weight: -0.0016545403, delay 1.5
        h("Epop[48] syn_projIE_gaba[368] = new gaba(0.5)")
        h("Ipop[4] netConn_projIE_gaba[368] = new NetCon(&v(0.5), syn_projIE_gaba[368], 20.0, 1.5, -0.0016545403)")  

        # Connection 369: cell 4, seg 0 (0.5) [0.5 on Ipop[4]] -> cell 49, seg 0 (0.5) [0.5 on Epop[49]], weight: -0.0016545403, delay 1.5
        h("Epop[49] syn_projIE_gaba[369] = new gaba(0.5)")
        h("Ipop[4] netConn_projIE_gaba[369] = new NetCon(&v(0.5), syn_projIE_gaba[369], 20.0, 1.5, -0.0016545403)")  

        # Connection 370: cell 4, seg 0 (0.5) [0.5 on Ipop[4]] -> cell 50, seg 0 (0.5) [0.5 on Epop[50]], weight: -0.0016545403, delay 1.5
        h("Epop[50] syn_projIE_gaba[370] = new gaba(0.5)")
        h("Ipop[4] netConn_projIE_gaba[370] = new NetCon(&v(0.5), syn_projIE_gaba[370], 20.0, 1.5, -0.0016545403)")  

        # Connection 371: cell 4, seg 0 (0.5) [0.5 on Ipop[4]] -> cell 51, seg 0 (0.5) [0.5 on Epop[51]], weight: -0.0016545403, delay 1.5
        h("Epop[51] syn_projIE_gaba[371] = new gaba(0.5)")
        h("Ipop[4] netConn_projIE_gaba[371] = new NetCon(&v(0.5), syn_projIE_gaba[371], 20.0, 1.5, -0.0016545403)")  

        # Connection 372: cell 4, seg 0 (0.5) [0.5 on Ipop[4]] -> cell 52, seg 0 (0.5) [0.5 on Epop[52]], weight: -0.0016545403, delay 1.5
        h("Epop[52] syn_projIE_gaba[372] = new gaba(0.5)")
        h("Ipop[4] netConn_projIE_gaba[372] = new NetCon(&v(0.5), syn_projIE_gaba[372], 20.0, 1.5, -0.0016545403)")  

        # Connection 373: cell 4, seg 0 (0.5) [0.5 on Ipop[4]] -> cell 53, seg 0 (0.5) [0.5 on Epop[53]], weight: -0.0016545403, delay 1.5
        h("Epop[53] syn_projIE_gaba[373] = new gaba(0.5)")
        h("Ipop[4] netConn_projIE_gaba[373] = new NetCon(&v(0.5), syn_projIE_gaba[373], 20.0, 1.5, -0.0016545403)")  

        # Connection 374: cell 4, seg 0 (0.5) [0.5 on Ipop[4]] -> cell 54, seg 0 (0.5) [0.5 on Epop[54]], weight: -0.0016545403, delay 1.5
        h("Epop[54] syn_projIE_gaba[374] = new gaba(0.5)")
        h("Ipop[4] netConn_projIE_gaba[374] = new NetCon(&v(0.5), syn_projIE_gaba[374], 20.0, 1.5, -0.0016545403)")  

        # Connection 375: cell 4, seg 0 (0.5) [0.5 on Ipop[4]] -> cell 55, seg 0 (0.5) [0.5 on Epop[55]], weight: -0.0016545403, delay 1.5
        h("Epop[55] syn_projIE_gaba[375] = new gaba(0.5)")
        h("Ipop[4] netConn_projIE_gaba[375] = new NetCon(&v(0.5), syn_projIE_gaba[375], 20.0, 1.5, -0.0016545403)")  

        # Connection 376: cell 4, seg 0 (0.5) [0.5 on Ipop[4]] -> cell 56, seg 0 (0.5) [0.5 on Epop[56]], weight: -0.0016545403, delay 1.5
        h("Epop[56] syn_projIE_gaba[376] = new gaba(0.5)")
        h("Ipop[4] netConn_projIE_gaba[376] = new NetCon(&v(0.5), syn_projIE_gaba[376], 20.0, 1.5, -0.0016545403)")  

        # Connection 377: cell 4, seg 0 (0.5) [0.5 on Ipop[4]] -> cell 57, seg 0 (0.5) [0.5 on Epop[57]], weight: -0.0016545403, delay 1.5
        h("Epop[57] syn_projIE_gaba[377] = new gaba(0.5)")
        h("Ipop[4] netConn_projIE_gaba[377] = new NetCon(&v(0.5), syn_projIE_gaba[377], 20.0, 1.5, -0.0016545403)")  

        # Connection 378: cell 4, seg 0 (0.5) [0.5 on Ipop[4]] -> cell 58, seg 0 (0.5) [0.5 on Epop[58]], weight: -0.0016545403, delay 1.5
        h("Epop[58] syn_projIE_gaba[378] = new gaba(0.5)")
        h("Ipop[4] netConn_projIE_gaba[378] = new NetCon(&v(0.5), syn_projIE_gaba[378], 20.0, 1.5, -0.0016545403)")  

        # Connection 379: cell 4, seg 0 (0.5) [0.5 on Ipop[4]] -> cell 59, seg 0 (0.5) [0.5 on Epop[59]], weight: -0.0016545403, delay 1.5
        h("Epop[59] syn_projIE_gaba[379] = new gaba(0.5)")
        h("Ipop[4] netConn_projIE_gaba[379] = new NetCon(&v(0.5), syn_projIE_gaba[379], 20.0, 1.5, -0.0016545403)")  

        # Connection 380: cell 4, seg 0 (0.5) [0.5 on Ipop[4]] -> cell 60, seg 0 (0.5) [0.5 on Epop[60]], weight: -0.0016545403, delay 1.5
        h("Epop[60] syn_projIE_gaba[380] = new gaba(0.5)")
        h("Ipop[4] netConn_projIE_gaba[380] = new NetCon(&v(0.5), syn_projIE_gaba[380], 20.0, 1.5, -0.0016545403)")  

        # Connection 381: cell 4, seg 0 (0.5) [0.5 on Ipop[4]] -> cell 61, seg 0 (0.5) [0.5 on Epop[61]], weight: -0.0016545403, delay 1.5
        h("Epop[61] syn_projIE_gaba[381] = new gaba(0.5)")
        h("Ipop[4] netConn_projIE_gaba[381] = new NetCon(&v(0.5), syn_projIE_gaba[381], 20.0, 1.5, -0.0016545403)")  

        # Connection 382: cell 4, seg 0 (0.5) [0.5 on Ipop[4]] -> cell 62, seg 0 (0.5) [0.5 on Epop[62]], weight: -0.0016545403, delay 1.5
        h("Epop[62] syn_projIE_gaba[382] = new gaba(0.5)")
        h("Ipop[4] netConn_projIE_gaba[382] = new NetCon(&v(0.5), syn_projIE_gaba[382], 20.0, 1.5, -0.0016545403)")  

        # Connection 383: cell 4, seg 0 (0.5) [0.5 on Ipop[4]] -> cell 63, seg 0 (0.5) [0.5 on Epop[63]], weight: -0.0016545403, delay 1.5
        h("Epop[63] syn_projIE_gaba[383] = new gaba(0.5)")
        h("Ipop[4] netConn_projIE_gaba[383] = new NetCon(&v(0.5), syn_projIE_gaba[383], 20.0, 1.5, -0.0016545403)")  

        # Connection 384: cell 4, seg 0 (0.5) [0.5 on Ipop[4]] -> cell 64, seg 0 (0.5) [0.5 on Epop[64]], weight: -0.0016545403, delay 1.5
        h("Epop[64] syn_projIE_gaba[384] = new gaba(0.5)")
        h("Ipop[4] netConn_projIE_gaba[384] = new NetCon(&v(0.5), syn_projIE_gaba[384], 20.0, 1.5, -0.0016545403)")  

        # Connection 385: cell 4, seg 0 (0.5) [0.5 on Ipop[4]] -> cell 65, seg 0 (0.5) [0.5 on Epop[65]], weight: -0.0016545403, delay 1.5
        h("Epop[65] syn_projIE_gaba[385] = new gaba(0.5)")
        h("Ipop[4] netConn_projIE_gaba[385] = new NetCon(&v(0.5), syn_projIE_gaba[385], 20.0, 1.5, -0.0016545403)")  

        # Connection 386: cell 4, seg 0 (0.5) [0.5 on Ipop[4]] -> cell 66, seg 0 (0.5) [0.5 on Epop[66]], weight: -0.0016545403, delay 1.5
        h("Epop[66] syn_projIE_gaba[386] = new gaba(0.5)")
        h("Ipop[4] netConn_projIE_gaba[386] = new NetCon(&v(0.5), syn_projIE_gaba[386], 20.0, 1.5, -0.0016545403)")  

        # Connection 387: cell 4, seg 0 (0.5) [0.5 on Ipop[4]] -> cell 67, seg 0 (0.5) [0.5 on Epop[67]], weight: -0.0016545403, delay 1.5
        h("Epop[67] syn_projIE_gaba[387] = new gaba(0.5)")
        h("Ipop[4] netConn_projIE_gaba[387] = new NetCon(&v(0.5), syn_projIE_gaba[387], 20.0, 1.5, -0.0016545403)")  

        # Connection 388: cell 4, seg 0 (0.5) [0.5 on Ipop[4]] -> cell 68, seg 0 (0.5) [0.5 on Epop[68]], weight: -0.0016545403, delay 1.5
        h("Epop[68] syn_projIE_gaba[388] = new gaba(0.5)")
        h("Ipop[4] netConn_projIE_gaba[388] = new NetCon(&v(0.5), syn_projIE_gaba[388], 20.0, 1.5, -0.0016545403)")  

        # Connection 389: cell 4, seg 0 (0.5) [0.5 on Ipop[4]] -> cell 69, seg 0 (0.5) [0.5 on Epop[69]], weight: -0.0016545403, delay 1.5
        h("Epop[69] syn_projIE_gaba[389] = new gaba(0.5)")
        h("Ipop[4] netConn_projIE_gaba[389] = new NetCon(&v(0.5), syn_projIE_gaba[389], 20.0, 1.5, -0.0016545403)")  

        # Connection 390: cell 4, seg 0 (0.5) [0.5 on Ipop[4]] -> cell 70, seg 0 (0.5) [0.5 on Epop[70]], weight: -0.0016545403, delay 1.5
        h("Epop[70] syn_projIE_gaba[390] = new gaba(0.5)")
        h("Ipop[4] netConn_projIE_gaba[390] = new NetCon(&v(0.5), syn_projIE_gaba[390], 20.0, 1.5, -0.0016545403)")  

        # Connection 391: cell 4, seg 0 (0.5) [0.5 on Ipop[4]] -> cell 71, seg 0 (0.5) [0.5 on Epop[71]], weight: -0.0016545403, delay 1.5
        h("Epop[71] syn_projIE_gaba[391] = new gaba(0.5)")
        h("Ipop[4] netConn_projIE_gaba[391] = new NetCon(&v(0.5), syn_projIE_gaba[391], 20.0, 1.5, -0.0016545403)")  

        # Connection 392: cell 4, seg 0 (0.5) [0.5 on Ipop[4]] -> cell 72, seg 0 (0.5) [0.5 on Epop[72]], weight: -0.0016545403, delay 1.5
        h("Epop[72] syn_projIE_gaba[392] = new gaba(0.5)")
        h("Ipop[4] netConn_projIE_gaba[392] = new NetCon(&v(0.5), syn_projIE_gaba[392], 20.0, 1.5, -0.0016545403)")  

        # Connection 393: cell 4, seg 0 (0.5) [0.5 on Ipop[4]] -> cell 73, seg 0 (0.5) [0.5 on Epop[73]], weight: -0.0016545403, delay 1.5
        h("Epop[73] syn_projIE_gaba[393] = new gaba(0.5)")
        h("Ipop[4] netConn_projIE_gaba[393] = new NetCon(&v(0.5), syn_projIE_gaba[393], 20.0, 1.5, -0.0016545403)")  

        # Connection 394: cell 4, seg 0 (0.5) [0.5 on Ipop[4]] -> cell 74, seg 0 (0.5) [0.5 on Epop[74]], weight: -0.0016545403, delay 1.5
        h("Epop[74] syn_projIE_gaba[394] = new gaba(0.5)")
        h("Ipop[4] netConn_projIE_gaba[394] = new NetCon(&v(0.5), syn_projIE_gaba[394], 20.0, 1.5, -0.0016545403)")  

        # Connection 395: cell 4, seg 0 (0.5) [0.5 on Ipop[4]] -> cell 75, seg 0 (0.5) [0.5 on Epop[75]], weight: -0.0016545403, delay 1.5
        h("Epop[75] syn_projIE_gaba[395] = new gaba(0.5)")
        h("Ipop[4] netConn_projIE_gaba[395] = new NetCon(&v(0.5), syn_projIE_gaba[395], 20.0, 1.5, -0.0016545403)")  

        # Connection 396: cell 4, seg 0 (0.5) [0.5 on Ipop[4]] -> cell 76, seg 0 (0.5) [0.5 on Epop[76]], weight: -0.0016545403, delay 1.5
        h("Epop[76] syn_projIE_gaba[396] = new gaba(0.5)")
        h("Ipop[4] netConn_projIE_gaba[396] = new NetCon(&v(0.5), syn_projIE_gaba[396], 20.0, 1.5, -0.0016545403)")  

        # Connection 397: cell 4, seg 0 (0.5) [0.5 on Ipop[4]] -> cell 77, seg 0 (0.5) [0.5 on Epop[77]], weight: -0.0016545403, delay 1.5
        h("Epop[77] syn_projIE_gaba[397] = new gaba(0.5)")
        h("Ipop[4] netConn_projIE_gaba[397] = new NetCon(&v(0.5), syn_projIE_gaba[397], 20.0, 1.5, -0.0016545403)")  

        # Connection 398: cell 4, seg 0 (0.5) [0.5 on Ipop[4]] -> cell 78, seg 0 (0.5) [0.5 on Epop[78]], weight: -0.0016545403, delay 1.5
        h("Epop[78] syn_projIE_gaba[398] = new gaba(0.5)")
        h("Ipop[4] netConn_projIE_gaba[398] = new NetCon(&v(0.5), syn_projIE_gaba[398], 20.0, 1.5, -0.0016545403)")  

        # Connection 399: cell 4, seg 0 (0.5) [0.5 on Ipop[4]] -> cell 79, seg 0 (0.5) [0.5 on Epop[79]], weight: -0.0016545403, delay 1.5
        h("Epop[79] syn_projIE_gaba[399] = new gaba(0.5)")
        h("Ipop[4] netConn_projIE_gaba[399] = new NetCon(&v(0.5), syn_projIE_gaba[399], 20.0, 1.5, -0.0016545403)")  

        # Connection 400: cell 5, seg 0 (0.5) [0.5 on Ipop[5]] -> cell 0, seg 0 (0.5) [0.5 on Epop[0]], weight: -0.0016545403, delay 1.5
        h("Epop[0] syn_projIE_gaba[400] = new gaba(0.5)")
        h("Ipop[5] netConn_projIE_gaba[400] = new NetCon(&v(0.5), syn_projIE_gaba[400], 20.0, 1.5, -0.0016545403)")  

        # Connection 401: cell 5, seg 0 (0.5) [0.5 on Ipop[5]] -> cell 1, seg 0 (0.5) [0.5 on Epop[1]], weight: -0.0016545403, delay 1.5
        h("Epop[1] syn_projIE_gaba[401] = new gaba(0.5)")
        h("Ipop[5] netConn_projIE_gaba[401] = new NetCon(&v(0.5), syn_projIE_gaba[401], 20.0, 1.5, -0.0016545403)")  

        # Connection 402: cell 5, seg 0 (0.5) [0.5 on Ipop[5]] -> cell 2, seg 0 (0.5) [0.5 on Epop[2]], weight: -0.0016545403, delay 1.5
        h("Epop[2] syn_projIE_gaba[402] = new gaba(0.5)")
        h("Ipop[5] netConn_projIE_gaba[402] = new NetCon(&v(0.5), syn_projIE_gaba[402], 20.0, 1.5, -0.0016545403)")  

        # Connection 403: cell 5, seg 0 (0.5) [0.5 on Ipop[5]] -> cell 3, seg 0 (0.5) [0.5 on Epop[3]], weight: -0.0016545403, delay 1.5
        h("Epop[3] syn_projIE_gaba[403] = new gaba(0.5)")
        h("Ipop[5] netConn_projIE_gaba[403] = new NetCon(&v(0.5), syn_projIE_gaba[403], 20.0, 1.5, -0.0016545403)")  

        # Connection 404: cell 5, seg 0 (0.5) [0.5 on Ipop[5]] -> cell 4, seg 0 (0.5) [0.5 on Epop[4]], weight: -0.0016545403, delay 1.5
        h("Epop[4] syn_projIE_gaba[404] = new gaba(0.5)")
        h("Ipop[5] netConn_projIE_gaba[404] = new NetCon(&v(0.5), syn_projIE_gaba[404], 20.0, 1.5, -0.0016545403)")  

        # Connection 405: cell 5, seg 0 (0.5) [0.5 on Ipop[5]] -> cell 5, seg 0 (0.5) [0.5 on Epop[5]], weight: -0.0016545403, delay 1.5
        h("Epop[5] syn_projIE_gaba[405] = new gaba(0.5)")
        h("Ipop[5] netConn_projIE_gaba[405] = new NetCon(&v(0.5), syn_projIE_gaba[405], 20.0, 1.5, -0.0016545403)")  

        # Connection 406: cell 5, seg 0 (0.5) [0.5 on Ipop[5]] -> cell 6, seg 0 (0.5) [0.5 on Epop[6]], weight: -0.0016545403, delay 1.5
        h("Epop[6] syn_projIE_gaba[406] = new gaba(0.5)")
        h("Ipop[5] netConn_projIE_gaba[406] = new NetCon(&v(0.5), syn_projIE_gaba[406], 20.0, 1.5, -0.0016545403)")  

        # Connection 407: cell 5, seg 0 (0.5) [0.5 on Ipop[5]] -> cell 7, seg 0 (0.5) [0.5 on Epop[7]], weight: -0.0016545403, delay 1.5
        h("Epop[7] syn_projIE_gaba[407] = new gaba(0.5)")
        h("Ipop[5] netConn_projIE_gaba[407] = new NetCon(&v(0.5), syn_projIE_gaba[407], 20.0, 1.5, -0.0016545403)")  

        # Connection 408: cell 5, seg 0 (0.5) [0.5 on Ipop[5]] -> cell 8, seg 0 (0.5) [0.5 on Epop[8]], weight: -0.0016545403, delay 1.5
        h("Epop[8] syn_projIE_gaba[408] = new gaba(0.5)")
        h("Ipop[5] netConn_projIE_gaba[408] = new NetCon(&v(0.5), syn_projIE_gaba[408], 20.0, 1.5, -0.0016545403)")  

        # Connection 409: cell 5, seg 0 (0.5) [0.5 on Ipop[5]] -> cell 9, seg 0 (0.5) [0.5 on Epop[9]], weight: -0.0016545403, delay 1.5
        h("Epop[9] syn_projIE_gaba[409] = new gaba(0.5)")
        h("Ipop[5] netConn_projIE_gaba[409] = new NetCon(&v(0.5), syn_projIE_gaba[409], 20.0, 1.5, -0.0016545403)")  

        # Connection 410: cell 5, seg 0 (0.5) [0.5 on Ipop[5]] -> cell 10, seg 0 (0.5) [0.5 on Epop[10]], weight: -0.0016545403, delay 1.5
        h("Epop[10] syn_projIE_gaba[410] = new gaba(0.5)")
        h("Ipop[5] netConn_projIE_gaba[410] = new NetCon(&v(0.5), syn_projIE_gaba[410], 20.0, 1.5, -0.0016545403)")  

        # Connection 411: cell 5, seg 0 (0.5) [0.5 on Ipop[5]] -> cell 11, seg 0 (0.5) [0.5 on Epop[11]], weight: -0.0016545403, delay 1.5
        h("Epop[11] syn_projIE_gaba[411] = new gaba(0.5)")
        h("Ipop[5] netConn_projIE_gaba[411] = new NetCon(&v(0.5), syn_projIE_gaba[411], 20.0, 1.5, -0.0016545403)")  

        # Connection 412: cell 5, seg 0 (0.5) [0.5 on Ipop[5]] -> cell 12, seg 0 (0.5) [0.5 on Epop[12]], weight: -0.0016545403, delay 1.5
        h("Epop[12] syn_projIE_gaba[412] = new gaba(0.5)")
        h("Ipop[5] netConn_projIE_gaba[412] = new NetCon(&v(0.5), syn_projIE_gaba[412], 20.0, 1.5, -0.0016545403)")  

        # Connection 413: cell 5, seg 0 (0.5) [0.5 on Ipop[5]] -> cell 13, seg 0 (0.5) [0.5 on Epop[13]], weight: -0.0016545403, delay 1.5
        h("Epop[13] syn_projIE_gaba[413] = new gaba(0.5)")
        h("Ipop[5] netConn_projIE_gaba[413] = new NetCon(&v(0.5), syn_projIE_gaba[413], 20.0, 1.5, -0.0016545403)")  

        # Connection 414: cell 5, seg 0 (0.5) [0.5 on Ipop[5]] -> cell 14, seg 0 (0.5) [0.5 on Epop[14]], weight: -0.0016545403, delay 1.5
        h("Epop[14] syn_projIE_gaba[414] = new gaba(0.5)")
        h("Ipop[5] netConn_projIE_gaba[414] = new NetCon(&v(0.5), syn_projIE_gaba[414], 20.0, 1.5, -0.0016545403)")  

        # Connection 415: cell 5, seg 0 (0.5) [0.5 on Ipop[5]] -> cell 15, seg 0 (0.5) [0.5 on Epop[15]], weight: -0.0016545403, delay 1.5
        h("Epop[15] syn_projIE_gaba[415] = new gaba(0.5)")
        h("Ipop[5] netConn_projIE_gaba[415] = new NetCon(&v(0.5), syn_projIE_gaba[415], 20.0, 1.5, -0.0016545403)")  

        # Connection 416: cell 5, seg 0 (0.5) [0.5 on Ipop[5]] -> cell 16, seg 0 (0.5) [0.5 on Epop[16]], weight: -0.0016545403, delay 1.5
        h("Epop[16] syn_projIE_gaba[416] = new gaba(0.5)")
        h("Ipop[5] netConn_projIE_gaba[416] = new NetCon(&v(0.5), syn_projIE_gaba[416], 20.0, 1.5, -0.0016545403)")  

        # Connection 417: cell 5, seg 0 (0.5) [0.5 on Ipop[5]] -> cell 17, seg 0 (0.5) [0.5 on Epop[17]], weight: -0.0016545403, delay 1.5
        h("Epop[17] syn_projIE_gaba[417] = new gaba(0.5)")
        h("Ipop[5] netConn_projIE_gaba[417] = new NetCon(&v(0.5), syn_projIE_gaba[417], 20.0, 1.5, -0.0016545403)")  

        # Connection 418: cell 5, seg 0 (0.5) [0.5 on Ipop[5]] -> cell 18, seg 0 (0.5) [0.5 on Epop[18]], weight: -0.0016545403, delay 1.5
        h("Epop[18] syn_projIE_gaba[418] = new gaba(0.5)")
        h("Ipop[5] netConn_projIE_gaba[418] = new NetCon(&v(0.5), syn_projIE_gaba[418], 20.0, 1.5, -0.0016545403)")  

        # Connection 419: cell 5, seg 0 (0.5) [0.5 on Ipop[5]] -> cell 19, seg 0 (0.5) [0.5 on Epop[19]], weight: -0.0016545403, delay 1.5
        h("Epop[19] syn_projIE_gaba[419] = new gaba(0.5)")
        h("Ipop[5] netConn_projIE_gaba[419] = new NetCon(&v(0.5), syn_projIE_gaba[419], 20.0, 1.5, -0.0016545403)")  

        # Connection 420: cell 5, seg 0 (0.5) [0.5 on Ipop[5]] -> cell 20, seg 0 (0.5) [0.5 on Epop[20]], weight: -0.0016545403, delay 1.5
        h("Epop[20] syn_projIE_gaba[420] = new gaba(0.5)")
        h("Ipop[5] netConn_projIE_gaba[420] = new NetCon(&v(0.5), syn_projIE_gaba[420], 20.0, 1.5, -0.0016545403)")  

        # Connection 421: cell 5, seg 0 (0.5) [0.5 on Ipop[5]] -> cell 21, seg 0 (0.5) [0.5 on Epop[21]], weight: -0.0016545403, delay 1.5
        h("Epop[21] syn_projIE_gaba[421] = new gaba(0.5)")
        h("Ipop[5] netConn_projIE_gaba[421] = new NetCon(&v(0.5), syn_projIE_gaba[421], 20.0, 1.5, -0.0016545403)")  

        # Connection 422: cell 5, seg 0 (0.5) [0.5 on Ipop[5]] -> cell 22, seg 0 (0.5) [0.5 on Epop[22]], weight: -0.0016545403, delay 1.5
        h("Epop[22] syn_projIE_gaba[422] = new gaba(0.5)")
        h("Ipop[5] netConn_projIE_gaba[422] = new NetCon(&v(0.5), syn_projIE_gaba[422], 20.0, 1.5, -0.0016545403)")  

        # Connection 423: cell 5, seg 0 (0.5) [0.5 on Ipop[5]] -> cell 23, seg 0 (0.5) [0.5 on Epop[23]], weight: -0.0016545403, delay 1.5
        h("Epop[23] syn_projIE_gaba[423] = new gaba(0.5)")
        h("Ipop[5] netConn_projIE_gaba[423] = new NetCon(&v(0.5), syn_projIE_gaba[423], 20.0, 1.5, -0.0016545403)")  

        # Connection 424: cell 5, seg 0 (0.5) [0.5 on Ipop[5]] -> cell 24, seg 0 (0.5) [0.5 on Epop[24]], weight: -0.0016545403, delay 1.5
        h("Epop[24] syn_projIE_gaba[424] = new gaba(0.5)")
        h("Ipop[5] netConn_projIE_gaba[424] = new NetCon(&v(0.5), syn_projIE_gaba[424], 20.0, 1.5, -0.0016545403)")  

        # Connection 425: cell 5, seg 0 (0.5) [0.5 on Ipop[5]] -> cell 25, seg 0 (0.5) [0.5 on Epop[25]], weight: -0.0016545403, delay 1.5
        h("Epop[25] syn_projIE_gaba[425] = new gaba(0.5)")
        h("Ipop[5] netConn_projIE_gaba[425] = new NetCon(&v(0.5), syn_projIE_gaba[425], 20.0, 1.5, -0.0016545403)")  

        # Connection 426: cell 5, seg 0 (0.5) [0.5 on Ipop[5]] -> cell 26, seg 0 (0.5) [0.5 on Epop[26]], weight: -0.0016545403, delay 1.5
        h("Epop[26] syn_projIE_gaba[426] = new gaba(0.5)")
        h("Ipop[5] netConn_projIE_gaba[426] = new NetCon(&v(0.5), syn_projIE_gaba[426], 20.0, 1.5, -0.0016545403)")  

        # Connection 427: cell 5, seg 0 (0.5) [0.5 on Ipop[5]] -> cell 27, seg 0 (0.5) [0.5 on Epop[27]], weight: -0.0016545403, delay 1.5
        h("Epop[27] syn_projIE_gaba[427] = new gaba(0.5)")
        h("Ipop[5] netConn_projIE_gaba[427] = new NetCon(&v(0.5), syn_projIE_gaba[427], 20.0, 1.5, -0.0016545403)")  

        # Connection 428: cell 5, seg 0 (0.5) [0.5 on Ipop[5]] -> cell 28, seg 0 (0.5) [0.5 on Epop[28]], weight: -0.0016545403, delay 1.5
        h("Epop[28] syn_projIE_gaba[428] = new gaba(0.5)")
        h("Ipop[5] netConn_projIE_gaba[428] = new NetCon(&v(0.5), syn_projIE_gaba[428], 20.0, 1.5, -0.0016545403)")  

        # Connection 429: cell 5, seg 0 (0.5) [0.5 on Ipop[5]] -> cell 29, seg 0 (0.5) [0.5 on Epop[29]], weight: -0.0016545403, delay 1.5
        h("Epop[29] syn_projIE_gaba[429] = new gaba(0.5)")
        h("Ipop[5] netConn_projIE_gaba[429] = new NetCon(&v(0.5), syn_projIE_gaba[429], 20.0, 1.5, -0.0016545403)")  

        # Connection 430: cell 5, seg 0 (0.5) [0.5 on Ipop[5]] -> cell 30, seg 0 (0.5) [0.5 on Epop[30]], weight: -0.0016545403, delay 1.5
        h("Epop[30] syn_projIE_gaba[430] = new gaba(0.5)")
        h("Ipop[5] netConn_projIE_gaba[430] = new NetCon(&v(0.5), syn_projIE_gaba[430], 20.0, 1.5, -0.0016545403)")  

        # Connection 431: cell 5, seg 0 (0.5) [0.5 on Ipop[5]] -> cell 31, seg 0 (0.5) [0.5 on Epop[31]], weight: -0.0016545403, delay 1.5
        h("Epop[31] syn_projIE_gaba[431] = new gaba(0.5)")
        h("Ipop[5] netConn_projIE_gaba[431] = new NetCon(&v(0.5), syn_projIE_gaba[431], 20.0, 1.5, -0.0016545403)")  

        # Connection 432: cell 5, seg 0 (0.5) [0.5 on Ipop[5]] -> cell 32, seg 0 (0.5) [0.5 on Epop[32]], weight: -0.0016545403, delay 1.5
        h("Epop[32] syn_projIE_gaba[432] = new gaba(0.5)")
        h("Ipop[5] netConn_projIE_gaba[432] = new NetCon(&v(0.5), syn_projIE_gaba[432], 20.0, 1.5, -0.0016545403)")  

        # Connection 433: cell 5, seg 0 (0.5) [0.5 on Ipop[5]] -> cell 33, seg 0 (0.5) [0.5 on Epop[33]], weight: -0.0016545403, delay 1.5
        h("Epop[33] syn_projIE_gaba[433] = new gaba(0.5)")
        h("Ipop[5] netConn_projIE_gaba[433] = new NetCon(&v(0.5), syn_projIE_gaba[433], 20.0, 1.5, -0.0016545403)")  

        # Connection 434: cell 5, seg 0 (0.5) [0.5 on Ipop[5]] -> cell 34, seg 0 (0.5) [0.5 on Epop[34]], weight: -0.0016545403, delay 1.5
        h("Epop[34] syn_projIE_gaba[434] = new gaba(0.5)")
        h("Ipop[5] netConn_projIE_gaba[434] = new NetCon(&v(0.5), syn_projIE_gaba[434], 20.0, 1.5, -0.0016545403)")  

        # Connection 435: cell 5, seg 0 (0.5) [0.5 on Ipop[5]] -> cell 35, seg 0 (0.5) [0.5 on Epop[35]], weight: -0.0016545403, delay 1.5
        h("Epop[35] syn_projIE_gaba[435] = new gaba(0.5)")
        h("Ipop[5] netConn_projIE_gaba[435] = new NetCon(&v(0.5), syn_projIE_gaba[435], 20.0, 1.5, -0.0016545403)")  

        # Connection 436: cell 5, seg 0 (0.5) [0.5 on Ipop[5]] -> cell 36, seg 0 (0.5) [0.5 on Epop[36]], weight: -0.0016545403, delay 1.5
        h("Epop[36] syn_projIE_gaba[436] = new gaba(0.5)")
        h("Ipop[5] netConn_projIE_gaba[436] = new NetCon(&v(0.5), syn_projIE_gaba[436], 20.0, 1.5, -0.0016545403)")  

        # Connection 437: cell 5, seg 0 (0.5) [0.5 on Ipop[5]] -> cell 37, seg 0 (0.5) [0.5 on Epop[37]], weight: -0.0016545403, delay 1.5
        h("Epop[37] syn_projIE_gaba[437] = new gaba(0.5)")
        h("Ipop[5] netConn_projIE_gaba[437] = new NetCon(&v(0.5), syn_projIE_gaba[437], 20.0, 1.5, -0.0016545403)")  

        # Connection 438: cell 5, seg 0 (0.5) [0.5 on Ipop[5]] -> cell 38, seg 0 (0.5) [0.5 on Epop[38]], weight: -0.0016545403, delay 1.5
        h("Epop[38] syn_projIE_gaba[438] = new gaba(0.5)")
        h("Ipop[5] netConn_projIE_gaba[438] = new NetCon(&v(0.5), syn_projIE_gaba[438], 20.0, 1.5, -0.0016545403)")  

        # Connection 439: cell 5, seg 0 (0.5) [0.5 on Ipop[5]] -> cell 39, seg 0 (0.5) [0.5 on Epop[39]], weight: -0.0016545403, delay 1.5
        h("Epop[39] syn_projIE_gaba[439] = new gaba(0.5)")
        h("Ipop[5] netConn_projIE_gaba[439] = new NetCon(&v(0.5), syn_projIE_gaba[439], 20.0, 1.5, -0.0016545403)")  

        # Connection 440: cell 5, seg 0 (0.5) [0.5 on Ipop[5]] -> cell 40, seg 0 (0.5) [0.5 on Epop[40]], weight: -0.0016545403, delay 1.5
        h("Epop[40] syn_projIE_gaba[440] = new gaba(0.5)")
        h("Ipop[5] netConn_projIE_gaba[440] = new NetCon(&v(0.5), syn_projIE_gaba[440], 20.0, 1.5, -0.0016545403)")  

        # Connection 441: cell 5, seg 0 (0.5) [0.5 on Ipop[5]] -> cell 41, seg 0 (0.5) [0.5 on Epop[41]], weight: -0.0016545403, delay 1.5
        h("Epop[41] syn_projIE_gaba[441] = new gaba(0.5)")
        h("Ipop[5] netConn_projIE_gaba[441] = new NetCon(&v(0.5), syn_projIE_gaba[441], 20.0, 1.5, -0.0016545403)")  

        # Connection 442: cell 5, seg 0 (0.5) [0.5 on Ipop[5]] -> cell 42, seg 0 (0.5) [0.5 on Epop[42]], weight: -0.0016545403, delay 1.5
        h("Epop[42] syn_projIE_gaba[442] = new gaba(0.5)")
        h("Ipop[5] netConn_projIE_gaba[442] = new NetCon(&v(0.5), syn_projIE_gaba[442], 20.0, 1.5, -0.0016545403)")  

        # Connection 443: cell 5, seg 0 (0.5) [0.5 on Ipop[5]] -> cell 43, seg 0 (0.5) [0.5 on Epop[43]], weight: -0.0016545403, delay 1.5
        h("Epop[43] syn_projIE_gaba[443] = new gaba(0.5)")
        h("Ipop[5] netConn_projIE_gaba[443] = new NetCon(&v(0.5), syn_projIE_gaba[443], 20.0, 1.5, -0.0016545403)")  

        # Connection 444: cell 5, seg 0 (0.5) [0.5 on Ipop[5]] -> cell 44, seg 0 (0.5) [0.5 on Epop[44]], weight: -0.0016545403, delay 1.5
        h("Epop[44] syn_projIE_gaba[444] = new gaba(0.5)")
        h("Ipop[5] netConn_projIE_gaba[444] = new NetCon(&v(0.5), syn_projIE_gaba[444], 20.0, 1.5, -0.0016545403)")  

        # Connection 445: cell 5, seg 0 (0.5) [0.5 on Ipop[5]] -> cell 45, seg 0 (0.5) [0.5 on Epop[45]], weight: -0.0016545403, delay 1.5
        h("Epop[45] syn_projIE_gaba[445] = new gaba(0.5)")
        h("Ipop[5] netConn_projIE_gaba[445] = new NetCon(&v(0.5), syn_projIE_gaba[445], 20.0, 1.5, -0.0016545403)")  

        # Connection 446: cell 5, seg 0 (0.5) [0.5 on Ipop[5]] -> cell 46, seg 0 (0.5) [0.5 on Epop[46]], weight: -0.0016545403, delay 1.5
        h("Epop[46] syn_projIE_gaba[446] = new gaba(0.5)")
        h("Ipop[5] netConn_projIE_gaba[446] = new NetCon(&v(0.5), syn_projIE_gaba[446], 20.0, 1.5, -0.0016545403)")  

        # Connection 447: cell 5, seg 0 (0.5) [0.5 on Ipop[5]] -> cell 47, seg 0 (0.5) [0.5 on Epop[47]], weight: -0.0016545403, delay 1.5
        h("Epop[47] syn_projIE_gaba[447] = new gaba(0.5)")
        h("Ipop[5] netConn_projIE_gaba[447] = new NetCon(&v(0.5), syn_projIE_gaba[447], 20.0, 1.5, -0.0016545403)")  

        # Connection 448: cell 5, seg 0 (0.5) [0.5 on Ipop[5]] -> cell 48, seg 0 (0.5) [0.5 on Epop[48]], weight: -0.0016545403, delay 1.5
        h("Epop[48] syn_projIE_gaba[448] = new gaba(0.5)")
        h("Ipop[5] netConn_projIE_gaba[448] = new NetCon(&v(0.5), syn_projIE_gaba[448], 20.0, 1.5, -0.0016545403)")  

        # Connection 449: cell 5, seg 0 (0.5) [0.5 on Ipop[5]] -> cell 49, seg 0 (0.5) [0.5 on Epop[49]], weight: -0.0016545403, delay 1.5
        h("Epop[49] syn_projIE_gaba[449] = new gaba(0.5)")
        h("Ipop[5] netConn_projIE_gaba[449] = new NetCon(&v(0.5), syn_projIE_gaba[449], 20.0, 1.5, -0.0016545403)")  

        # Connection 450: cell 5, seg 0 (0.5) [0.5 on Ipop[5]] -> cell 50, seg 0 (0.5) [0.5 on Epop[50]], weight: -0.0016545403, delay 1.5
        h("Epop[50] syn_projIE_gaba[450] = new gaba(0.5)")
        h("Ipop[5] netConn_projIE_gaba[450] = new NetCon(&v(0.5), syn_projIE_gaba[450], 20.0, 1.5, -0.0016545403)")  

        # Connection 451: cell 5, seg 0 (0.5) [0.5 on Ipop[5]] -> cell 51, seg 0 (0.5) [0.5 on Epop[51]], weight: -0.0016545403, delay 1.5
        h("Epop[51] syn_projIE_gaba[451] = new gaba(0.5)")
        h("Ipop[5] netConn_projIE_gaba[451] = new NetCon(&v(0.5), syn_projIE_gaba[451], 20.0, 1.5, -0.0016545403)")  

        # Connection 452: cell 5, seg 0 (0.5) [0.5 on Ipop[5]] -> cell 52, seg 0 (0.5) [0.5 on Epop[52]], weight: -0.0016545403, delay 1.5
        h("Epop[52] syn_projIE_gaba[452] = new gaba(0.5)")
        h("Ipop[5] netConn_projIE_gaba[452] = new NetCon(&v(0.5), syn_projIE_gaba[452], 20.0, 1.5, -0.0016545403)")  

        # Connection 453: cell 5, seg 0 (0.5) [0.5 on Ipop[5]] -> cell 53, seg 0 (0.5) [0.5 on Epop[53]], weight: -0.0016545403, delay 1.5
        h("Epop[53] syn_projIE_gaba[453] = new gaba(0.5)")
        h("Ipop[5] netConn_projIE_gaba[453] = new NetCon(&v(0.5), syn_projIE_gaba[453], 20.0, 1.5, -0.0016545403)")  

        # Connection 454: cell 5, seg 0 (0.5) [0.5 on Ipop[5]] -> cell 54, seg 0 (0.5) [0.5 on Epop[54]], weight: -0.0016545403, delay 1.5
        h("Epop[54] syn_projIE_gaba[454] = new gaba(0.5)")
        h("Ipop[5] netConn_projIE_gaba[454] = new NetCon(&v(0.5), syn_projIE_gaba[454], 20.0, 1.5, -0.0016545403)")  

        # Connection 455: cell 5, seg 0 (0.5) [0.5 on Ipop[5]] -> cell 55, seg 0 (0.5) [0.5 on Epop[55]], weight: -0.0016545403, delay 1.5
        h("Epop[55] syn_projIE_gaba[455] = new gaba(0.5)")
        h("Ipop[5] netConn_projIE_gaba[455] = new NetCon(&v(0.5), syn_projIE_gaba[455], 20.0, 1.5, -0.0016545403)")  

        # Connection 456: cell 5, seg 0 (0.5) [0.5 on Ipop[5]] -> cell 56, seg 0 (0.5) [0.5 on Epop[56]], weight: -0.0016545403, delay 1.5
        h("Epop[56] syn_projIE_gaba[456] = new gaba(0.5)")
        h("Ipop[5] netConn_projIE_gaba[456] = new NetCon(&v(0.5), syn_projIE_gaba[456], 20.0, 1.5, -0.0016545403)")  

        # Connection 457: cell 5, seg 0 (0.5) [0.5 on Ipop[5]] -> cell 57, seg 0 (0.5) [0.5 on Epop[57]], weight: -0.0016545403, delay 1.5
        h("Epop[57] syn_projIE_gaba[457] = new gaba(0.5)")
        h("Ipop[5] netConn_projIE_gaba[457] = new NetCon(&v(0.5), syn_projIE_gaba[457], 20.0, 1.5, -0.0016545403)")  

        # Connection 458: cell 5, seg 0 (0.5) [0.5 on Ipop[5]] -> cell 58, seg 0 (0.5) [0.5 on Epop[58]], weight: -0.0016545403, delay 1.5
        h("Epop[58] syn_projIE_gaba[458] = new gaba(0.5)")
        h("Ipop[5] netConn_projIE_gaba[458] = new NetCon(&v(0.5), syn_projIE_gaba[458], 20.0, 1.5, -0.0016545403)")  

        # Connection 459: cell 5, seg 0 (0.5) [0.5 on Ipop[5]] -> cell 59, seg 0 (0.5) [0.5 on Epop[59]], weight: -0.0016545403, delay 1.5
        h("Epop[59] syn_projIE_gaba[459] = new gaba(0.5)")
        h("Ipop[5] netConn_projIE_gaba[459] = new NetCon(&v(0.5), syn_projIE_gaba[459], 20.0, 1.5, -0.0016545403)")  

        # Connection 460: cell 5, seg 0 (0.5) [0.5 on Ipop[5]] -> cell 60, seg 0 (0.5) [0.5 on Epop[60]], weight: -0.0016545403, delay 1.5
        h("Epop[60] syn_projIE_gaba[460] = new gaba(0.5)")
        h("Ipop[5] netConn_projIE_gaba[460] = new NetCon(&v(0.5), syn_projIE_gaba[460], 20.0, 1.5, -0.0016545403)")  

        # Connection 461: cell 5, seg 0 (0.5) [0.5 on Ipop[5]] -> cell 61, seg 0 (0.5) [0.5 on Epop[61]], weight: -0.0016545403, delay 1.5
        h("Epop[61] syn_projIE_gaba[461] = new gaba(0.5)")
        h("Ipop[5] netConn_projIE_gaba[461] = new NetCon(&v(0.5), syn_projIE_gaba[461], 20.0, 1.5, -0.0016545403)")  

        # Connection 462: cell 5, seg 0 (0.5) [0.5 on Ipop[5]] -> cell 62, seg 0 (0.5) [0.5 on Epop[62]], weight: -0.0016545403, delay 1.5
        h("Epop[62] syn_projIE_gaba[462] = new gaba(0.5)")
        h("Ipop[5] netConn_projIE_gaba[462] = new NetCon(&v(0.5), syn_projIE_gaba[462], 20.0, 1.5, -0.0016545403)")  

        # Connection 463: cell 5, seg 0 (0.5) [0.5 on Ipop[5]] -> cell 63, seg 0 (0.5) [0.5 on Epop[63]], weight: -0.0016545403, delay 1.5
        h("Epop[63] syn_projIE_gaba[463] = new gaba(0.5)")
        h("Ipop[5] netConn_projIE_gaba[463] = new NetCon(&v(0.5), syn_projIE_gaba[463], 20.0, 1.5, -0.0016545403)")  

        # Connection 464: cell 5, seg 0 (0.5) [0.5 on Ipop[5]] -> cell 64, seg 0 (0.5) [0.5 on Epop[64]], weight: -0.0016545403, delay 1.5
        h("Epop[64] syn_projIE_gaba[464] = new gaba(0.5)")
        h("Ipop[5] netConn_projIE_gaba[464] = new NetCon(&v(0.5), syn_projIE_gaba[464], 20.0, 1.5, -0.0016545403)")  

        # Connection 465: cell 5, seg 0 (0.5) [0.5 on Ipop[5]] -> cell 65, seg 0 (0.5) [0.5 on Epop[65]], weight: -0.0016545403, delay 1.5
        h("Epop[65] syn_projIE_gaba[465] = new gaba(0.5)")
        h("Ipop[5] netConn_projIE_gaba[465] = new NetCon(&v(0.5), syn_projIE_gaba[465], 20.0, 1.5, -0.0016545403)")  

        # Connection 466: cell 5, seg 0 (0.5) [0.5 on Ipop[5]] -> cell 66, seg 0 (0.5) [0.5 on Epop[66]], weight: -0.0016545403, delay 1.5
        h("Epop[66] syn_projIE_gaba[466] = new gaba(0.5)")
        h("Ipop[5] netConn_projIE_gaba[466] = new NetCon(&v(0.5), syn_projIE_gaba[466], 20.0, 1.5, -0.0016545403)")  

        # Connection 467: cell 5, seg 0 (0.5) [0.5 on Ipop[5]] -> cell 67, seg 0 (0.5) [0.5 on Epop[67]], weight: -0.0016545403, delay 1.5
        h("Epop[67] syn_projIE_gaba[467] = new gaba(0.5)")
        h("Ipop[5] netConn_projIE_gaba[467] = new NetCon(&v(0.5), syn_projIE_gaba[467], 20.0, 1.5, -0.0016545403)")  

        # Connection 468: cell 5, seg 0 (0.5) [0.5 on Ipop[5]] -> cell 68, seg 0 (0.5) [0.5 on Epop[68]], weight: -0.0016545403, delay 1.5
        h("Epop[68] syn_projIE_gaba[468] = new gaba(0.5)")
        h("Ipop[5] netConn_projIE_gaba[468] = new NetCon(&v(0.5), syn_projIE_gaba[468], 20.0, 1.5, -0.0016545403)")  

        # Connection 469: cell 5, seg 0 (0.5) [0.5 on Ipop[5]] -> cell 69, seg 0 (0.5) [0.5 on Epop[69]], weight: -0.0016545403, delay 1.5
        h("Epop[69] syn_projIE_gaba[469] = new gaba(0.5)")
        h("Ipop[5] netConn_projIE_gaba[469] = new NetCon(&v(0.5), syn_projIE_gaba[469], 20.0, 1.5, -0.0016545403)")  

        # Connection 470: cell 5, seg 0 (0.5) [0.5 on Ipop[5]] -> cell 70, seg 0 (0.5) [0.5 on Epop[70]], weight: -0.0016545403, delay 1.5
        h("Epop[70] syn_projIE_gaba[470] = new gaba(0.5)")
        h("Ipop[5] netConn_projIE_gaba[470] = new NetCon(&v(0.5), syn_projIE_gaba[470], 20.0, 1.5, -0.0016545403)")  

        # Connection 471: cell 5, seg 0 (0.5) [0.5 on Ipop[5]] -> cell 71, seg 0 (0.5) [0.5 on Epop[71]], weight: -0.0016545403, delay 1.5
        h("Epop[71] syn_projIE_gaba[471] = new gaba(0.5)")
        h("Ipop[5] netConn_projIE_gaba[471] = new NetCon(&v(0.5), syn_projIE_gaba[471], 20.0, 1.5, -0.0016545403)")  

        # Connection 472: cell 5, seg 0 (0.5) [0.5 on Ipop[5]] -> cell 72, seg 0 (0.5) [0.5 on Epop[72]], weight: -0.0016545403, delay 1.5
        h("Epop[72] syn_projIE_gaba[472] = new gaba(0.5)")
        h("Ipop[5] netConn_projIE_gaba[472] = new NetCon(&v(0.5), syn_projIE_gaba[472], 20.0, 1.5, -0.0016545403)")  

        # Connection 473: cell 5, seg 0 (0.5) [0.5 on Ipop[5]] -> cell 73, seg 0 (0.5) [0.5 on Epop[73]], weight: -0.0016545403, delay 1.5
        h("Epop[73] syn_projIE_gaba[473] = new gaba(0.5)")
        h("Ipop[5] netConn_projIE_gaba[473] = new NetCon(&v(0.5), syn_projIE_gaba[473], 20.0, 1.5, -0.0016545403)")  

        # Connection 474: cell 5, seg 0 (0.5) [0.5 on Ipop[5]] -> cell 74, seg 0 (0.5) [0.5 on Epop[74]], weight: -0.0016545403, delay 1.5
        h("Epop[74] syn_projIE_gaba[474] = new gaba(0.5)")
        h("Ipop[5] netConn_projIE_gaba[474] = new NetCon(&v(0.5), syn_projIE_gaba[474], 20.0, 1.5, -0.0016545403)")  

        # Connection 475: cell 5, seg 0 (0.5) [0.5 on Ipop[5]] -> cell 75, seg 0 (0.5) [0.5 on Epop[75]], weight: -0.0016545403, delay 1.5
        h("Epop[75] syn_projIE_gaba[475] = new gaba(0.5)")
        h("Ipop[5] netConn_projIE_gaba[475] = new NetCon(&v(0.5), syn_projIE_gaba[475], 20.0, 1.5, -0.0016545403)")  

        # Connection 476: cell 5, seg 0 (0.5) [0.5 on Ipop[5]] -> cell 76, seg 0 (0.5) [0.5 on Epop[76]], weight: -0.0016545403, delay 1.5
        h("Epop[76] syn_projIE_gaba[476] = new gaba(0.5)")
        h("Ipop[5] netConn_projIE_gaba[476] = new NetCon(&v(0.5), syn_projIE_gaba[476], 20.0, 1.5, -0.0016545403)")  

        # Connection 477: cell 5, seg 0 (0.5) [0.5 on Ipop[5]] -> cell 77, seg 0 (0.5) [0.5 on Epop[77]], weight: -0.0016545403, delay 1.5
        h("Epop[77] syn_projIE_gaba[477] = new gaba(0.5)")
        h("Ipop[5] netConn_projIE_gaba[477] = new NetCon(&v(0.5), syn_projIE_gaba[477], 20.0, 1.5, -0.0016545403)")  

        # Connection 478: cell 5, seg 0 (0.5) [0.5 on Ipop[5]] -> cell 78, seg 0 (0.5) [0.5 on Epop[78]], weight: -0.0016545403, delay 1.5
        h("Epop[78] syn_projIE_gaba[478] = new gaba(0.5)")
        h("Ipop[5] netConn_projIE_gaba[478] = new NetCon(&v(0.5), syn_projIE_gaba[478], 20.0, 1.5, -0.0016545403)")  

        # Connection 479: cell 5, seg 0 (0.5) [0.5 on Ipop[5]] -> cell 79, seg 0 (0.5) [0.5 on Epop[79]], weight: -0.0016545403, delay 1.5
        h("Epop[79] syn_projIE_gaba[479] = new gaba(0.5)")
        h("Ipop[5] netConn_projIE_gaba[479] = new NetCon(&v(0.5), syn_projIE_gaba[479], 20.0, 1.5, -0.0016545403)")  

        # Connection 480: cell 6, seg 0 (0.5) [0.5 on Ipop[6]] -> cell 0, seg 0 (0.5) [0.5 on Epop[0]], weight: -0.0016545403, delay 1.5
        h("Epop[0] syn_projIE_gaba[480] = new gaba(0.5)")
        h("Ipop[6] netConn_projIE_gaba[480] = new NetCon(&v(0.5), syn_projIE_gaba[480], 20.0, 1.5, -0.0016545403)")  

        # Connection 481: cell 6, seg 0 (0.5) [0.5 on Ipop[6]] -> cell 1, seg 0 (0.5) [0.5 on Epop[1]], weight: -0.0016545403, delay 1.5
        h("Epop[1] syn_projIE_gaba[481] = new gaba(0.5)")
        h("Ipop[6] netConn_projIE_gaba[481] = new NetCon(&v(0.5), syn_projIE_gaba[481], 20.0, 1.5, -0.0016545403)")  

        # Connection 482: cell 6, seg 0 (0.5) [0.5 on Ipop[6]] -> cell 2, seg 0 (0.5) [0.5 on Epop[2]], weight: -0.0016545403, delay 1.5
        h("Epop[2] syn_projIE_gaba[482] = new gaba(0.5)")
        h("Ipop[6] netConn_projIE_gaba[482] = new NetCon(&v(0.5), syn_projIE_gaba[482], 20.0, 1.5, -0.0016545403)")  

        # Connection 483: cell 6, seg 0 (0.5) [0.5 on Ipop[6]] -> cell 3, seg 0 (0.5) [0.5 on Epop[3]], weight: -0.0016545403, delay 1.5
        h("Epop[3] syn_projIE_gaba[483] = new gaba(0.5)")
        h("Ipop[6] netConn_projIE_gaba[483] = new NetCon(&v(0.5), syn_projIE_gaba[483], 20.0, 1.5, -0.0016545403)")  

        # Connection 484: cell 6, seg 0 (0.5) [0.5 on Ipop[6]] -> cell 4, seg 0 (0.5) [0.5 on Epop[4]], weight: -0.0016545403, delay 1.5
        h("Epop[4] syn_projIE_gaba[484] = new gaba(0.5)")
        h("Ipop[6] netConn_projIE_gaba[484] = new NetCon(&v(0.5), syn_projIE_gaba[484], 20.0, 1.5, -0.0016545403)")  

        # Connection 485: cell 6, seg 0 (0.5) [0.5 on Ipop[6]] -> cell 5, seg 0 (0.5) [0.5 on Epop[5]], weight: -0.0016545403, delay 1.5
        h("Epop[5] syn_projIE_gaba[485] = new gaba(0.5)")
        h("Ipop[6] netConn_projIE_gaba[485] = new NetCon(&v(0.5), syn_projIE_gaba[485], 20.0, 1.5, -0.0016545403)")  

        # Connection 486: cell 6, seg 0 (0.5) [0.5 on Ipop[6]] -> cell 6, seg 0 (0.5) [0.5 on Epop[6]], weight: -0.0016545403, delay 1.5
        h("Epop[6] syn_projIE_gaba[486] = new gaba(0.5)")
        h("Ipop[6] netConn_projIE_gaba[486] = new NetCon(&v(0.5), syn_projIE_gaba[486], 20.0, 1.5, -0.0016545403)")  

        # Connection 487: cell 6, seg 0 (0.5) [0.5 on Ipop[6]] -> cell 7, seg 0 (0.5) [0.5 on Epop[7]], weight: -0.0016545403, delay 1.5
        h("Epop[7] syn_projIE_gaba[487] = new gaba(0.5)")
        h("Ipop[6] netConn_projIE_gaba[487] = new NetCon(&v(0.5), syn_projIE_gaba[487], 20.0, 1.5, -0.0016545403)")  

        # Connection 488: cell 6, seg 0 (0.5) [0.5 on Ipop[6]] -> cell 8, seg 0 (0.5) [0.5 on Epop[8]], weight: -0.0016545403, delay 1.5
        h("Epop[8] syn_projIE_gaba[488] = new gaba(0.5)")
        h("Ipop[6] netConn_projIE_gaba[488] = new NetCon(&v(0.5), syn_projIE_gaba[488], 20.0, 1.5, -0.0016545403)")  

        # Connection 489: cell 6, seg 0 (0.5) [0.5 on Ipop[6]] -> cell 9, seg 0 (0.5) [0.5 on Epop[9]], weight: -0.0016545403, delay 1.5
        h("Epop[9] syn_projIE_gaba[489] = new gaba(0.5)")
        h("Ipop[6] netConn_projIE_gaba[489] = new NetCon(&v(0.5), syn_projIE_gaba[489], 20.0, 1.5, -0.0016545403)")  

        # Connection 490: cell 6, seg 0 (0.5) [0.5 on Ipop[6]] -> cell 10, seg 0 (0.5) [0.5 on Epop[10]], weight: -0.0016545403, delay 1.5
        h("Epop[10] syn_projIE_gaba[490] = new gaba(0.5)")
        h("Ipop[6] netConn_projIE_gaba[490] = new NetCon(&v(0.5), syn_projIE_gaba[490], 20.0, 1.5, -0.0016545403)")  

        # Connection 491: cell 6, seg 0 (0.5) [0.5 on Ipop[6]] -> cell 11, seg 0 (0.5) [0.5 on Epop[11]], weight: -0.0016545403, delay 1.5
        h("Epop[11] syn_projIE_gaba[491] = new gaba(0.5)")
        h("Ipop[6] netConn_projIE_gaba[491] = new NetCon(&v(0.5), syn_projIE_gaba[491], 20.0, 1.5, -0.0016545403)")  

        # Connection 492: cell 6, seg 0 (0.5) [0.5 on Ipop[6]] -> cell 12, seg 0 (0.5) [0.5 on Epop[12]], weight: -0.0016545403, delay 1.5
        h("Epop[12] syn_projIE_gaba[492] = new gaba(0.5)")
        h("Ipop[6] netConn_projIE_gaba[492] = new NetCon(&v(0.5), syn_projIE_gaba[492], 20.0, 1.5, -0.0016545403)")  

        # Connection 493: cell 6, seg 0 (0.5) [0.5 on Ipop[6]] -> cell 13, seg 0 (0.5) [0.5 on Epop[13]], weight: -0.0016545403, delay 1.5
        h("Epop[13] syn_projIE_gaba[493] = new gaba(0.5)")
        h("Ipop[6] netConn_projIE_gaba[493] = new NetCon(&v(0.5), syn_projIE_gaba[493], 20.0, 1.5, -0.0016545403)")  

        # Connection 494: cell 6, seg 0 (0.5) [0.5 on Ipop[6]] -> cell 14, seg 0 (0.5) [0.5 on Epop[14]], weight: -0.0016545403, delay 1.5
        h("Epop[14] syn_projIE_gaba[494] = new gaba(0.5)")
        h("Ipop[6] netConn_projIE_gaba[494] = new NetCon(&v(0.5), syn_projIE_gaba[494], 20.0, 1.5, -0.0016545403)")  

        # Connection 495: cell 6, seg 0 (0.5) [0.5 on Ipop[6]] -> cell 15, seg 0 (0.5) [0.5 on Epop[15]], weight: -0.0016545403, delay 1.5
        h("Epop[15] syn_projIE_gaba[495] = new gaba(0.5)")
        h("Ipop[6] netConn_projIE_gaba[495] = new NetCon(&v(0.5), syn_projIE_gaba[495], 20.0, 1.5, -0.0016545403)")  

        # Connection 496: cell 6, seg 0 (0.5) [0.5 on Ipop[6]] -> cell 16, seg 0 (0.5) [0.5 on Epop[16]], weight: -0.0016545403, delay 1.5
        h("Epop[16] syn_projIE_gaba[496] = new gaba(0.5)")
        h("Ipop[6] netConn_projIE_gaba[496] = new NetCon(&v(0.5), syn_projIE_gaba[496], 20.0, 1.5, -0.0016545403)")  

        # Connection 497: cell 6, seg 0 (0.5) [0.5 on Ipop[6]] -> cell 17, seg 0 (0.5) [0.5 on Epop[17]], weight: -0.0016545403, delay 1.5
        h("Epop[17] syn_projIE_gaba[497] = new gaba(0.5)")
        h("Ipop[6] netConn_projIE_gaba[497] = new NetCon(&v(0.5), syn_projIE_gaba[497], 20.0, 1.5, -0.0016545403)")  

        # Connection 498: cell 6, seg 0 (0.5) [0.5 on Ipop[6]] -> cell 18, seg 0 (0.5) [0.5 on Epop[18]], weight: -0.0016545403, delay 1.5
        h("Epop[18] syn_projIE_gaba[498] = new gaba(0.5)")
        h("Ipop[6] netConn_projIE_gaba[498] = new NetCon(&v(0.5), syn_projIE_gaba[498], 20.0, 1.5, -0.0016545403)")  

        # Connection 499: cell 6, seg 0 (0.5) [0.5 on Ipop[6]] -> cell 19, seg 0 (0.5) [0.5 on Epop[19]], weight: -0.0016545403, delay 1.5
        h("Epop[19] syn_projIE_gaba[499] = new gaba(0.5)")
        h("Ipop[6] netConn_projIE_gaba[499] = new NetCon(&v(0.5), syn_projIE_gaba[499], 20.0, 1.5, -0.0016545403)")  

        # Connection 500: cell 6, seg 0 (0.5) [0.5 on Ipop[6]] -> cell 20, seg 0 (0.5) [0.5 on Epop[20]], weight: -0.0016545403, delay 1.5
        h("Epop[20] syn_projIE_gaba[500] = new gaba(0.5)")
        h("Ipop[6] netConn_projIE_gaba[500] = new NetCon(&v(0.5), syn_projIE_gaba[500], 20.0, 1.5, -0.0016545403)")  

        # Connection 501: cell 6, seg 0 (0.5) [0.5 on Ipop[6]] -> cell 21, seg 0 (0.5) [0.5 on Epop[21]], weight: -0.0016545403, delay 1.5
        h("Epop[21] syn_projIE_gaba[501] = new gaba(0.5)")
        h("Ipop[6] netConn_projIE_gaba[501] = new NetCon(&v(0.5), syn_projIE_gaba[501], 20.0, 1.5, -0.0016545403)")  

        # Connection 502: cell 6, seg 0 (0.5) [0.5 on Ipop[6]] -> cell 22, seg 0 (0.5) [0.5 on Epop[22]], weight: -0.0016545403, delay 1.5
        h("Epop[22] syn_projIE_gaba[502] = new gaba(0.5)")
        h("Ipop[6] netConn_projIE_gaba[502] = new NetCon(&v(0.5), syn_projIE_gaba[502], 20.0, 1.5, -0.0016545403)")  

        # Connection 503: cell 6, seg 0 (0.5) [0.5 on Ipop[6]] -> cell 23, seg 0 (0.5) [0.5 on Epop[23]], weight: -0.0016545403, delay 1.5
        h("Epop[23] syn_projIE_gaba[503] = new gaba(0.5)")
        h("Ipop[6] netConn_projIE_gaba[503] = new NetCon(&v(0.5), syn_projIE_gaba[503], 20.0, 1.5, -0.0016545403)")  

        # Connection 504: cell 6, seg 0 (0.5) [0.5 on Ipop[6]] -> cell 24, seg 0 (0.5) [0.5 on Epop[24]], weight: -0.0016545403, delay 1.5
        h("Epop[24] syn_projIE_gaba[504] = new gaba(0.5)")
        h("Ipop[6] netConn_projIE_gaba[504] = new NetCon(&v(0.5), syn_projIE_gaba[504], 20.0, 1.5, -0.0016545403)")  

        # Connection 505: cell 6, seg 0 (0.5) [0.5 on Ipop[6]] -> cell 25, seg 0 (0.5) [0.5 on Epop[25]], weight: -0.0016545403, delay 1.5
        h("Epop[25] syn_projIE_gaba[505] = new gaba(0.5)")
        h("Ipop[6] netConn_projIE_gaba[505] = new NetCon(&v(0.5), syn_projIE_gaba[505], 20.0, 1.5, -0.0016545403)")  

        # Connection 506: cell 6, seg 0 (0.5) [0.5 on Ipop[6]] -> cell 26, seg 0 (0.5) [0.5 on Epop[26]], weight: -0.0016545403, delay 1.5
        h("Epop[26] syn_projIE_gaba[506] = new gaba(0.5)")
        h("Ipop[6] netConn_projIE_gaba[506] = new NetCon(&v(0.5), syn_projIE_gaba[506], 20.0, 1.5, -0.0016545403)")  

        # Connection 507: cell 6, seg 0 (0.5) [0.5 on Ipop[6]] -> cell 27, seg 0 (0.5) [0.5 on Epop[27]], weight: -0.0016545403, delay 1.5
        h("Epop[27] syn_projIE_gaba[507] = new gaba(0.5)")
        h("Ipop[6] netConn_projIE_gaba[507] = new NetCon(&v(0.5), syn_projIE_gaba[507], 20.0, 1.5, -0.0016545403)")  

        # Connection 508: cell 6, seg 0 (0.5) [0.5 on Ipop[6]] -> cell 28, seg 0 (0.5) [0.5 on Epop[28]], weight: -0.0016545403, delay 1.5
        h("Epop[28] syn_projIE_gaba[508] = new gaba(0.5)")
        h("Ipop[6] netConn_projIE_gaba[508] = new NetCon(&v(0.5), syn_projIE_gaba[508], 20.0, 1.5, -0.0016545403)")  

        # Connection 509: cell 6, seg 0 (0.5) [0.5 on Ipop[6]] -> cell 29, seg 0 (0.5) [0.5 on Epop[29]], weight: -0.0016545403, delay 1.5
        h("Epop[29] syn_projIE_gaba[509] = new gaba(0.5)")
        h("Ipop[6] netConn_projIE_gaba[509] = new NetCon(&v(0.5), syn_projIE_gaba[509], 20.0, 1.5, -0.0016545403)")  

        # Connection 510: cell 6, seg 0 (0.5) [0.5 on Ipop[6]] -> cell 30, seg 0 (0.5) [0.5 on Epop[30]], weight: -0.0016545403, delay 1.5
        h("Epop[30] syn_projIE_gaba[510] = new gaba(0.5)")
        h("Ipop[6] netConn_projIE_gaba[510] = new NetCon(&v(0.5), syn_projIE_gaba[510], 20.0, 1.5, -0.0016545403)")  

        # Connection 511: cell 6, seg 0 (0.5) [0.5 on Ipop[6]] -> cell 31, seg 0 (0.5) [0.5 on Epop[31]], weight: -0.0016545403, delay 1.5
        h("Epop[31] syn_projIE_gaba[511] = new gaba(0.5)")
        h("Ipop[6] netConn_projIE_gaba[511] = new NetCon(&v(0.5), syn_projIE_gaba[511], 20.0, 1.5, -0.0016545403)")  

        # Connection 512: cell 6, seg 0 (0.5) [0.5 on Ipop[6]] -> cell 32, seg 0 (0.5) [0.5 on Epop[32]], weight: -0.0016545403, delay 1.5
        h("Epop[32] syn_projIE_gaba[512] = new gaba(0.5)")
        h("Ipop[6] netConn_projIE_gaba[512] = new NetCon(&v(0.5), syn_projIE_gaba[512], 20.0, 1.5, -0.0016545403)")  

        # Connection 513: cell 6, seg 0 (0.5) [0.5 on Ipop[6]] -> cell 33, seg 0 (0.5) [0.5 on Epop[33]], weight: -0.0016545403, delay 1.5
        h("Epop[33] syn_projIE_gaba[513] = new gaba(0.5)")
        h("Ipop[6] netConn_projIE_gaba[513] = new NetCon(&v(0.5), syn_projIE_gaba[513], 20.0, 1.5, -0.0016545403)")  

        # Connection 514: cell 6, seg 0 (0.5) [0.5 on Ipop[6]] -> cell 34, seg 0 (0.5) [0.5 on Epop[34]], weight: -0.0016545403, delay 1.5
        h("Epop[34] syn_projIE_gaba[514] = new gaba(0.5)")
        h("Ipop[6] netConn_projIE_gaba[514] = new NetCon(&v(0.5), syn_projIE_gaba[514], 20.0, 1.5, -0.0016545403)")  

        # Connection 515: cell 6, seg 0 (0.5) [0.5 on Ipop[6]] -> cell 35, seg 0 (0.5) [0.5 on Epop[35]], weight: -0.0016545403, delay 1.5
        h("Epop[35] syn_projIE_gaba[515] = new gaba(0.5)")
        h("Ipop[6] netConn_projIE_gaba[515] = new NetCon(&v(0.5), syn_projIE_gaba[515], 20.0, 1.5, -0.0016545403)")  

        # Connection 516: cell 6, seg 0 (0.5) [0.5 on Ipop[6]] -> cell 36, seg 0 (0.5) [0.5 on Epop[36]], weight: -0.0016545403, delay 1.5
        h("Epop[36] syn_projIE_gaba[516] = new gaba(0.5)")
        h("Ipop[6] netConn_projIE_gaba[516] = new NetCon(&v(0.5), syn_projIE_gaba[516], 20.0, 1.5, -0.0016545403)")  

        # Connection 517: cell 6, seg 0 (0.5) [0.5 on Ipop[6]] -> cell 37, seg 0 (0.5) [0.5 on Epop[37]], weight: -0.0016545403, delay 1.5
        h("Epop[37] syn_projIE_gaba[517] = new gaba(0.5)")
        h("Ipop[6] netConn_projIE_gaba[517] = new NetCon(&v(0.5), syn_projIE_gaba[517], 20.0, 1.5, -0.0016545403)")  

        # Connection 518: cell 6, seg 0 (0.5) [0.5 on Ipop[6]] -> cell 38, seg 0 (0.5) [0.5 on Epop[38]], weight: -0.0016545403, delay 1.5
        h("Epop[38] syn_projIE_gaba[518] = new gaba(0.5)")
        h("Ipop[6] netConn_projIE_gaba[518] = new NetCon(&v(0.5), syn_projIE_gaba[518], 20.0, 1.5, -0.0016545403)")  

        # Connection 519: cell 6, seg 0 (0.5) [0.5 on Ipop[6]] -> cell 39, seg 0 (0.5) [0.5 on Epop[39]], weight: -0.0016545403, delay 1.5
        h("Epop[39] syn_projIE_gaba[519] = new gaba(0.5)")
        h("Ipop[6] netConn_projIE_gaba[519] = new NetCon(&v(0.5), syn_projIE_gaba[519], 20.0, 1.5, -0.0016545403)")  

        # Connection 520: cell 6, seg 0 (0.5) [0.5 on Ipop[6]] -> cell 40, seg 0 (0.5) [0.5 on Epop[40]], weight: -0.0016545403, delay 1.5
        h("Epop[40] syn_projIE_gaba[520] = new gaba(0.5)")
        h("Ipop[6] netConn_projIE_gaba[520] = new NetCon(&v(0.5), syn_projIE_gaba[520], 20.0, 1.5, -0.0016545403)")  

        # Connection 521: cell 6, seg 0 (0.5) [0.5 on Ipop[6]] -> cell 41, seg 0 (0.5) [0.5 on Epop[41]], weight: -0.0016545403, delay 1.5
        h("Epop[41] syn_projIE_gaba[521] = new gaba(0.5)")
        h("Ipop[6] netConn_projIE_gaba[521] = new NetCon(&v(0.5), syn_projIE_gaba[521], 20.0, 1.5, -0.0016545403)")  

        # Connection 522: cell 6, seg 0 (0.5) [0.5 on Ipop[6]] -> cell 42, seg 0 (0.5) [0.5 on Epop[42]], weight: -0.0016545403, delay 1.5
        h("Epop[42] syn_projIE_gaba[522] = new gaba(0.5)")
        h("Ipop[6] netConn_projIE_gaba[522] = new NetCon(&v(0.5), syn_projIE_gaba[522], 20.0, 1.5, -0.0016545403)")  

        # Connection 523: cell 6, seg 0 (0.5) [0.5 on Ipop[6]] -> cell 43, seg 0 (0.5) [0.5 on Epop[43]], weight: -0.0016545403, delay 1.5
        h("Epop[43] syn_projIE_gaba[523] = new gaba(0.5)")
        h("Ipop[6] netConn_projIE_gaba[523] = new NetCon(&v(0.5), syn_projIE_gaba[523], 20.0, 1.5, -0.0016545403)")  

        # Connection 524: cell 6, seg 0 (0.5) [0.5 on Ipop[6]] -> cell 44, seg 0 (0.5) [0.5 on Epop[44]], weight: -0.0016545403, delay 1.5
        h("Epop[44] syn_projIE_gaba[524] = new gaba(0.5)")
        h("Ipop[6] netConn_projIE_gaba[524] = new NetCon(&v(0.5), syn_projIE_gaba[524], 20.0, 1.5, -0.0016545403)")  

        # Connection 525: cell 6, seg 0 (0.5) [0.5 on Ipop[6]] -> cell 45, seg 0 (0.5) [0.5 on Epop[45]], weight: -0.0016545403, delay 1.5
        h("Epop[45] syn_projIE_gaba[525] = new gaba(0.5)")
        h("Ipop[6] netConn_projIE_gaba[525] = new NetCon(&v(0.5), syn_projIE_gaba[525], 20.0, 1.5, -0.0016545403)")  

        # Connection 526: cell 6, seg 0 (0.5) [0.5 on Ipop[6]] -> cell 46, seg 0 (0.5) [0.5 on Epop[46]], weight: -0.0016545403, delay 1.5
        h("Epop[46] syn_projIE_gaba[526] = new gaba(0.5)")
        h("Ipop[6] netConn_projIE_gaba[526] = new NetCon(&v(0.5), syn_projIE_gaba[526], 20.0, 1.5, -0.0016545403)")  

        # Connection 527: cell 6, seg 0 (0.5) [0.5 on Ipop[6]] -> cell 47, seg 0 (0.5) [0.5 on Epop[47]], weight: -0.0016545403, delay 1.5
        h("Epop[47] syn_projIE_gaba[527] = new gaba(0.5)")
        h("Ipop[6] netConn_projIE_gaba[527] = new NetCon(&v(0.5), syn_projIE_gaba[527], 20.0, 1.5, -0.0016545403)")  

        # Connection 528: cell 6, seg 0 (0.5) [0.5 on Ipop[6]] -> cell 48, seg 0 (0.5) [0.5 on Epop[48]], weight: -0.0016545403, delay 1.5
        h("Epop[48] syn_projIE_gaba[528] = new gaba(0.5)")
        h("Ipop[6] netConn_projIE_gaba[528] = new NetCon(&v(0.5), syn_projIE_gaba[528], 20.0, 1.5, -0.0016545403)")  

        # Connection 529: cell 6, seg 0 (0.5) [0.5 on Ipop[6]] -> cell 49, seg 0 (0.5) [0.5 on Epop[49]], weight: -0.0016545403, delay 1.5
        h("Epop[49] syn_projIE_gaba[529] = new gaba(0.5)")
        h("Ipop[6] netConn_projIE_gaba[529] = new NetCon(&v(0.5), syn_projIE_gaba[529], 20.0, 1.5, -0.0016545403)")  

        # Connection 530: cell 6, seg 0 (0.5) [0.5 on Ipop[6]] -> cell 50, seg 0 (0.5) [0.5 on Epop[50]], weight: -0.0016545403, delay 1.5
        h("Epop[50] syn_projIE_gaba[530] = new gaba(0.5)")
        h("Ipop[6] netConn_projIE_gaba[530] = new NetCon(&v(0.5), syn_projIE_gaba[530], 20.0, 1.5, -0.0016545403)")  

        # Connection 531: cell 6, seg 0 (0.5) [0.5 on Ipop[6]] -> cell 51, seg 0 (0.5) [0.5 on Epop[51]], weight: -0.0016545403, delay 1.5
        h("Epop[51] syn_projIE_gaba[531] = new gaba(0.5)")
        h("Ipop[6] netConn_projIE_gaba[531] = new NetCon(&v(0.5), syn_projIE_gaba[531], 20.0, 1.5, -0.0016545403)")  

        # Connection 532: cell 6, seg 0 (0.5) [0.5 on Ipop[6]] -> cell 52, seg 0 (0.5) [0.5 on Epop[52]], weight: -0.0016545403, delay 1.5
        h("Epop[52] syn_projIE_gaba[532] = new gaba(0.5)")
        h("Ipop[6] netConn_projIE_gaba[532] = new NetCon(&v(0.5), syn_projIE_gaba[532], 20.0, 1.5, -0.0016545403)")  

        # Connection 533: cell 6, seg 0 (0.5) [0.5 on Ipop[6]] -> cell 53, seg 0 (0.5) [0.5 on Epop[53]], weight: -0.0016545403, delay 1.5
        h("Epop[53] syn_projIE_gaba[533] = new gaba(0.5)")
        h("Ipop[6] netConn_projIE_gaba[533] = new NetCon(&v(0.5), syn_projIE_gaba[533], 20.0, 1.5, -0.0016545403)")  

        # Connection 534: cell 6, seg 0 (0.5) [0.5 on Ipop[6]] -> cell 54, seg 0 (0.5) [0.5 on Epop[54]], weight: -0.0016545403, delay 1.5
        h("Epop[54] syn_projIE_gaba[534] = new gaba(0.5)")
        h("Ipop[6] netConn_projIE_gaba[534] = new NetCon(&v(0.5), syn_projIE_gaba[534], 20.0, 1.5, -0.0016545403)")  

        # Connection 535: cell 6, seg 0 (0.5) [0.5 on Ipop[6]] -> cell 55, seg 0 (0.5) [0.5 on Epop[55]], weight: -0.0016545403, delay 1.5
        h("Epop[55] syn_projIE_gaba[535] = new gaba(0.5)")
        h("Ipop[6] netConn_projIE_gaba[535] = new NetCon(&v(0.5), syn_projIE_gaba[535], 20.0, 1.5, -0.0016545403)")  

        # Connection 536: cell 6, seg 0 (0.5) [0.5 on Ipop[6]] -> cell 56, seg 0 (0.5) [0.5 on Epop[56]], weight: -0.0016545403, delay 1.5
        h("Epop[56] syn_projIE_gaba[536] = new gaba(0.5)")
        h("Ipop[6] netConn_projIE_gaba[536] = new NetCon(&v(0.5), syn_projIE_gaba[536], 20.0, 1.5, -0.0016545403)")  

        # Connection 537: cell 6, seg 0 (0.5) [0.5 on Ipop[6]] -> cell 57, seg 0 (0.5) [0.5 on Epop[57]], weight: -0.0016545403, delay 1.5
        h("Epop[57] syn_projIE_gaba[537] = new gaba(0.5)")
        h("Ipop[6] netConn_projIE_gaba[537] = new NetCon(&v(0.5), syn_projIE_gaba[537], 20.0, 1.5, -0.0016545403)")  

        # Connection 538: cell 6, seg 0 (0.5) [0.5 on Ipop[6]] -> cell 58, seg 0 (0.5) [0.5 on Epop[58]], weight: -0.0016545403, delay 1.5
        h("Epop[58] syn_projIE_gaba[538] = new gaba(0.5)")
        h("Ipop[6] netConn_projIE_gaba[538] = new NetCon(&v(0.5), syn_projIE_gaba[538], 20.0, 1.5, -0.0016545403)")  

        # Connection 539: cell 6, seg 0 (0.5) [0.5 on Ipop[6]] -> cell 59, seg 0 (0.5) [0.5 on Epop[59]], weight: -0.0016545403, delay 1.5
        h("Epop[59] syn_projIE_gaba[539] = new gaba(0.5)")
        h("Ipop[6] netConn_projIE_gaba[539] = new NetCon(&v(0.5), syn_projIE_gaba[539], 20.0, 1.5, -0.0016545403)")  

        # Connection 540: cell 6, seg 0 (0.5) [0.5 on Ipop[6]] -> cell 60, seg 0 (0.5) [0.5 on Epop[60]], weight: -0.0016545403, delay 1.5
        h("Epop[60] syn_projIE_gaba[540] = new gaba(0.5)")
        h("Ipop[6] netConn_projIE_gaba[540] = new NetCon(&v(0.5), syn_projIE_gaba[540], 20.0, 1.5, -0.0016545403)")  

        # Connection 541: cell 6, seg 0 (0.5) [0.5 on Ipop[6]] -> cell 61, seg 0 (0.5) [0.5 on Epop[61]], weight: -0.0016545403, delay 1.5
        h("Epop[61] syn_projIE_gaba[541] = new gaba(0.5)")
        h("Ipop[6] netConn_projIE_gaba[541] = new NetCon(&v(0.5), syn_projIE_gaba[541], 20.0, 1.5, -0.0016545403)")  

        # Connection 542: cell 6, seg 0 (0.5) [0.5 on Ipop[6]] -> cell 62, seg 0 (0.5) [0.5 on Epop[62]], weight: -0.0016545403, delay 1.5
        h("Epop[62] syn_projIE_gaba[542] = new gaba(0.5)")
        h("Ipop[6] netConn_projIE_gaba[542] = new NetCon(&v(0.5), syn_projIE_gaba[542], 20.0, 1.5, -0.0016545403)")  

        # Connection 543: cell 6, seg 0 (0.5) [0.5 on Ipop[6]] -> cell 63, seg 0 (0.5) [0.5 on Epop[63]], weight: -0.0016545403, delay 1.5
        h("Epop[63] syn_projIE_gaba[543] = new gaba(0.5)")
        h("Ipop[6] netConn_projIE_gaba[543] = new NetCon(&v(0.5), syn_projIE_gaba[543], 20.0, 1.5, -0.0016545403)")  

        # Connection 544: cell 6, seg 0 (0.5) [0.5 on Ipop[6]] -> cell 64, seg 0 (0.5) [0.5 on Epop[64]], weight: -0.0016545403, delay 1.5
        h("Epop[64] syn_projIE_gaba[544] = new gaba(0.5)")
        h("Ipop[6] netConn_projIE_gaba[544] = new NetCon(&v(0.5), syn_projIE_gaba[544], 20.0, 1.5, -0.0016545403)")  

        # Connection 545: cell 6, seg 0 (0.5) [0.5 on Ipop[6]] -> cell 65, seg 0 (0.5) [0.5 on Epop[65]], weight: -0.0016545403, delay 1.5
        h("Epop[65] syn_projIE_gaba[545] = new gaba(0.5)")
        h("Ipop[6] netConn_projIE_gaba[545] = new NetCon(&v(0.5), syn_projIE_gaba[545], 20.0, 1.5, -0.0016545403)")  

        # Connection 546: cell 6, seg 0 (0.5) [0.5 on Ipop[6]] -> cell 66, seg 0 (0.5) [0.5 on Epop[66]], weight: -0.0016545403, delay 1.5
        h("Epop[66] syn_projIE_gaba[546] = new gaba(0.5)")
        h("Ipop[6] netConn_projIE_gaba[546] = new NetCon(&v(0.5), syn_projIE_gaba[546], 20.0, 1.5, -0.0016545403)")  

        # Connection 547: cell 6, seg 0 (0.5) [0.5 on Ipop[6]] -> cell 67, seg 0 (0.5) [0.5 on Epop[67]], weight: -0.0016545403, delay 1.5
        h("Epop[67] syn_projIE_gaba[547] = new gaba(0.5)")
        h("Ipop[6] netConn_projIE_gaba[547] = new NetCon(&v(0.5), syn_projIE_gaba[547], 20.0, 1.5, -0.0016545403)")  

        # Connection 548: cell 6, seg 0 (0.5) [0.5 on Ipop[6]] -> cell 68, seg 0 (0.5) [0.5 on Epop[68]], weight: -0.0016545403, delay 1.5
        h("Epop[68] syn_projIE_gaba[548] = new gaba(0.5)")
        h("Ipop[6] netConn_projIE_gaba[548] = new NetCon(&v(0.5), syn_projIE_gaba[548], 20.0, 1.5, -0.0016545403)")  

        # Connection 549: cell 6, seg 0 (0.5) [0.5 on Ipop[6]] -> cell 69, seg 0 (0.5) [0.5 on Epop[69]], weight: -0.0016545403, delay 1.5
        h("Epop[69] syn_projIE_gaba[549] = new gaba(0.5)")
        h("Ipop[6] netConn_projIE_gaba[549] = new NetCon(&v(0.5), syn_projIE_gaba[549], 20.0, 1.5, -0.0016545403)")  

        # Connection 550: cell 6, seg 0 (0.5) [0.5 on Ipop[6]] -> cell 70, seg 0 (0.5) [0.5 on Epop[70]], weight: -0.0016545403, delay 1.5
        h("Epop[70] syn_projIE_gaba[550] = new gaba(0.5)")
        h("Ipop[6] netConn_projIE_gaba[550] = new NetCon(&v(0.5), syn_projIE_gaba[550], 20.0, 1.5, -0.0016545403)")  

        # Connection 551: cell 6, seg 0 (0.5) [0.5 on Ipop[6]] -> cell 71, seg 0 (0.5) [0.5 on Epop[71]], weight: -0.0016545403, delay 1.5
        h("Epop[71] syn_projIE_gaba[551] = new gaba(0.5)")
        h("Ipop[6] netConn_projIE_gaba[551] = new NetCon(&v(0.5), syn_projIE_gaba[551], 20.0, 1.5, -0.0016545403)")  

        # Connection 552: cell 6, seg 0 (0.5) [0.5 on Ipop[6]] -> cell 72, seg 0 (0.5) [0.5 on Epop[72]], weight: -0.0016545403, delay 1.5
        h("Epop[72] syn_projIE_gaba[552] = new gaba(0.5)")
        h("Ipop[6] netConn_projIE_gaba[552] = new NetCon(&v(0.5), syn_projIE_gaba[552], 20.0, 1.5, -0.0016545403)")  

        # Connection 553: cell 6, seg 0 (0.5) [0.5 on Ipop[6]] -> cell 73, seg 0 (0.5) [0.5 on Epop[73]], weight: -0.0016545403, delay 1.5
        h("Epop[73] syn_projIE_gaba[553] = new gaba(0.5)")
        h("Ipop[6] netConn_projIE_gaba[553] = new NetCon(&v(0.5), syn_projIE_gaba[553], 20.0, 1.5, -0.0016545403)")  

        # Connection 554: cell 6, seg 0 (0.5) [0.5 on Ipop[6]] -> cell 74, seg 0 (0.5) [0.5 on Epop[74]], weight: -0.0016545403, delay 1.5
        h("Epop[74] syn_projIE_gaba[554] = new gaba(0.5)")
        h("Ipop[6] netConn_projIE_gaba[554] = new NetCon(&v(0.5), syn_projIE_gaba[554], 20.0, 1.5, -0.0016545403)")  

        # Connection 555: cell 6, seg 0 (0.5) [0.5 on Ipop[6]] -> cell 75, seg 0 (0.5) [0.5 on Epop[75]], weight: -0.0016545403, delay 1.5
        h("Epop[75] syn_projIE_gaba[555] = new gaba(0.5)")
        h("Ipop[6] netConn_projIE_gaba[555] = new NetCon(&v(0.5), syn_projIE_gaba[555], 20.0, 1.5, -0.0016545403)")  

        # Connection 556: cell 6, seg 0 (0.5) [0.5 on Ipop[6]] -> cell 76, seg 0 (0.5) [0.5 on Epop[76]], weight: -0.0016545403, delay 1.5
        h("Epop[76] syn_projIE_gaba[556] = new gaba(0.5)")
        h("Ipop[6] netConn_projIE_gaba[556] = new NetCon(&v(0.5), syn_projIE_gaba[556], 20.0, 1.5, -0.0016545403)")  

        # Connection 557: cell 6, seg 0 (0.5) [0.5 on Ipop[6]] -> cell 77, seg 0 (0.5) [0.5 on Epop[77]], weight: -0.0016545403, delay 1.5
        h("Epop[77] syn_projIE_gaba[557] = new gaba(0.5)")
        h("Ipop[6] netConn_projIE_gaba[557] = new NetCon(&v(0.5), syn_projIE_gaba[557], 20.0, 1.5, -0.0016545403)")  

        # Connection 558: cell 6, seg 0 (0.5) [0.5 on Ipop[6]] -> cell 78, seg 0 (0.5) [0.5 on Epop[78]], weight: -0.0016545403, delay 1.5
        h("Epop[78] syn_projIE_gaba[558] = new gaba(0.5)")
        h("Ipop[6] netConn_projIE_gaba[558] = new NetCon(&v(0.5), syn_projIE_gaba[558], 20.0, 1.5, -0.0016545403)")  

        # Connection 559: cell 6, seg 0 (0.5) [0.5 on Ipop[6]] -> cell 79, seg 0 (0.5) [0.5 on Epop[79]], weight: -0.0016545403, delay 1.5
        h("Epop[79] syn_projIE_gaba[559] = new gaba(0.5)")
        h("Ipop[6] netConn_projIE_gaba[559] = new NetCon(&v(0.5), syn_projIE_gaba[559], 20.0, 1.5, -0.0016545403)")  

        # Connection 560: cell 7, seg 0 (0.5) [0.5 on Ipop[7]] -> cell 0, seg 0 (0.5) [0.5 on Epop[0]], weight: -0.0016545403, delay 1.5
        h("Epop[0] syn_projIE_gaba[560] = new gaba(0.5)")
        h("Ipop[7] netConn_projIE_gaba[560] = new NetCon(&v(0.5), syn_projIE_gaba[560], 20.0, 1.5, -0.0016545403)")  

        # Connection 561: cell 7, seg 0 (0.5) [0.5 on Ipop[7]] -> cell 1, seg 0 (0.5) [0.5 on Epop[1]], weight: -0.0016545403, delay 1.5
        h("Epop[1] syn_projIE_gaba[561] = new gaba(0.5)")
        h("Ipop[7] netConn_projIE_gaba[561] = new NetCon(&v(0.5), syn_projIE_gaba[561], 20.0, 1.5, -0.0016545403)")  

        # Connection 562: cell 7, seg 0 (0.5) [0.5 on Ipop[7]] -> cell 2, seg 0 (0.5) [0.5 on Epop[2]], weight: -0.0016545403, delay 1.5
        h("Epop[2] syn_projIE_gaba[562] = new gaba(0.5)")
        h("Ipop[7] netConn_projIE_gaba[562] = new NetCon(&v(0.5), syn_projIE_gaba[562], 20.0, 1.5, -0.0016545403)")  

        # Connection 563: cell 7, seg 0 (0.5) [0.5 on Ipop[7]] -> cell 3, seg 0 (0.5) [0.5 on Epop[3]], weight: -0.0016545403, delay 1.5
        h("Epop[3] syn_projIE_gaba[563] = new gaba(0.5)")
        h("Ipop[7] netConn_projIE_gaba[563] = new NetCon(&v(0.5), syn_projIE_gaba[563], 20.0, 1.5, -0.0016545403)")  

        # Connection 564: cell 7, seg 0 (0.5) [0.5 on Ipop[7]] -> cell 4, seg 0 (0.5) [0.5 on Epop[4]], weight: -0.0016545403, delay 1.5
        h("Epop[4] syn_projIE_gaba[564] = new gaba(0.5)")
        h("Ipop[7] netConn_projIE_gaba[564] = new NetCon(&v(0.5), syn_projIE_gaba[564], 20.0, 1.5, -0.0016545403)")  

        # Connection 565: cell 7, seg 0 (0.5) [0.5 on Ipop[7]] -> cell 5, seg 0 (0.5) [0.5 on Epop[5]], weight: -0.0016545403, delay 1.5
        h("Epop[5] syn_projIE_gaba[565] = new gaba(0.5)")
        h("Ipop[7] netConn_projIE_gaba[565] = new NetCon(&v(0.5), syn_projIE_gaba[565], 20.0, 1.5, -0.0016545403)")  

        # Connection 566: cell 7, seg 0 (0.5) [0.5 on Ipop[7]] -> cell 6, seg 0 (0.5) [0.5 on Epop[6]], weight: -0.0016545403, delay 1.5
        h("Epop[6] syn_projIE_gaba[566] = new gaba(0.5)")
        h("Ipop[7] netConn_projIE_gaba[566] = new NetCon(&v(0.5), syn_projIE_gaba[566], 20.0, 1.5, -0.0016545403)")  

        # Connection 567: cell 7, seg 0 (0.5) [0.5 on Ipop[7]] -> cell 7, seg 0 (0.5) [0.5 on Epop[7]], weight: -0.0016545403, delay 1.5
        h("Epop[7] syn_projIE_gaba[567] = new gaba(0.5)")
        h("Ipop[7] netConn_projIE_gaba[567] = new NetCon(&v(0.5), syn_projIE_gaba[567], 20.0, 1.5, -0.0016545403)")  

        # Connection 568: cell 7, seg 0 (0.5) [0.5 on Ipop[7]] -> cell 8, seg 0 (0.5) [0.5 on Epop[8]], weight: -0.0016545403, delay 1.5
        h("Epop[8] syn_projIE_gaba[568] = new gaba(0.5)")
        h("Ipop[7] netConn_projIE_gaba[568] = new NetCon(&v(0.5), syn_projIE_gaba[568], 20.0, 1.5, -0.0016545403)")  

        # Connection 569: cell 7, seg 0 (0.5) [0.5 on Ipop[7]] -> cell 9, seg 0 (0.5) [0.5 on Epop[9]], weight: -0.0016545403, delay 1.5
        h("Epop[9] syn_projIE_gaba[569] = new gaba(0.5)")
        h("Ipop[7] netConn_projIE_gaba[569] = new NetCon(&v(0.5), syn_projIE_gaba[569], 20.0, 1.5, -0.0016545403)")  

        # Connection 570: cell 7, seg 0 (0.5) [0.5 on Ipop[7]] -> cell 10, seg 0 (0.5) [0.5 on Epop[10]], weight: -0.0016545403, delay 1.5
        h("Epop[10] syn_projIE_gaba[570] = new gaba(0.5)")
        h("Ipop[7] netConn_projIE_gaba[570] = new NetCon(&v(0.5), syn_projIE_gaba[570], 20.0, 1.5, -0.0016545403)")  

        # Connection 571: cell 7, seg 0 (0.5) [0.5 on Ipop[7]] -> cell 11, seg 0 (0.5) [0.5 on Epop[11]], weight: -0.0016545403, delay 1.5
        h("Epop[11] syn_projIE_gaba[571] = new gaba(0.5)")
        h("Ipop[7] netConn_projIE_gaba[571] = new NetCon(&v(0.5), syn_projIE_gaba[571], 20.0, 1.5, -0.0016545403)")  

        # Connection 572: cell 7, seg 0 (0.5) [0.5 on Ipop[7]] -> cell 12, seg 0 (0.5) [0.5 on Epop[12]], weight: -0.0016545403, delay 1.5
        h("Epop[12] syn_projIE_gaba[572] = new gaba(0.5)")
        h("Ipop[7] netConn_projIE_gaba[572] = new NetCon(&v(0.5), syn_projIE_gaba[572], 20.0, 1.5, -0.0016545403)")  

        # Connection 573: cell 7, seg 0 (0.5) [0.5 on Ipop[7]] -> cell 13, seg 0 (0.5) [0.5 on Epop[13]], weight: -0.0016545403, delay 1.5
        h("Epop[13] syn_projIE_gaba[573] = new gaba(0.5)")
        h("Ipop[7] netConn_projIE_gaba[573] = new NetCon(&v(0.5), syn_projIE_gaba[573], 20.0, 1.5, -0.0016545403)")  

        # Connection 574: cell 7, seg 0 (0.5) [0.5 on Ipop[7]] -> cell 14, seg 0 (0.5) [0.5 on Epop[14]], weight: -0.0016545403, delay 1.5
        h("Epop[14] syn_projIE_gaba[574] = new gaba(0.5)")
        h("Ipop[7] netConn_projIE_gaba[574] = new NetCon(&v(0.5), syn_projIE_gaba[574], 20.0, 1.5, -0.0016545403)")  

        # Connection 575: cell 7, seg 0 (0.5) [0.5 on Ipop[7]] -> cell 15, seg 0 (0.5) [0.5 on Epop[15]], weight: -0.0016545403, delay 1.5
        h("Epop[15] syn_projIE_gaba[575] = new gaba(0.5)")
        h("Ipop[7] netConn_projIE_gaba[575] = new NetCon(&v(0.5), syn_projIE_gaba[575], 20.0, 1.5, -0.0016545403)")  

        # Connection 576: cell 7, seg 0 (0.5) [0.5 on Ipop[7]] -> cell 16, seg 0 (0.5) [0.5 on Epop[16]], weight: -0.0016545403, delay 1.5
        h("Epop[16] syn_projIE_gaba[576] = new gaba(0.5)")
        h("Ipop[7] netConn_projIE_gaba[576] = new NetCon(&v(0.5), syn_projIE_gaba[576], 20.0, 1.5, -0.0016545403)")  

        # Connection 577: cell 7, seg 0 (0.5) [0.5 on Ipop[7]] -> cell 17, seg 0 (0.5) [0.5 on Epop[17]], weight: -0.0016545403, delay 1.5
        h("Epop[17] syn_projIE_gaba[577] = new gaba(0.5)")
        h("Ipop[7] netConn_projIE_gaba[577] = new NetCon(&v(0.5), syn_projIE_gaba[577], 20.0, 1.5, -0.0016545403)")  

        # Connection 578: cell 7, seg 0 (0.5) [0.5 on Ipop[7]] -> cell 18, seg 0 (0.5) [0.5 on Epop[18]], weight: -0.0016545403, delay 1.5
        h("Epop[18] syn_projIE_gaba[578] = new gaba(0.5)")
        h("Ipop[7] netConn_projIE_gaba[578] = new NetCon(&v(0.5), syn_projIE_gaba[578], 20.0, 1.5, -0.0016545403)")  

        # Connection 579: cell 7, seg 0 (0.5) [0.5 on Ipop[7]] -> cell 19, seg 0 (0.5) [0.5 on Epop[19]], weight: -0.0016545403, delay 1.5
        h("Epop[19] syn_projIE_gaba[579] = new gaba(0.5)")
        h("Ipop[7] netConn_projIE_gaba[579] = new NetCon(&v(0.5), syn_projIE_gaba[579], 20.0, 1.5, -0.0016545403)")  

        # Connection 580: cell 7, seg 0 (0.5) [0.5 on Ipop[7]] -> cell 20, seg 0 (0.5) [0.5 on Epop[20]], weight: -0.0016545403, delay 1.5
        h("Epop[20] syn_projIE_gaba[580] = new gaba(0.5)")
        h("Ipop[7] netConn_projIE_gaba[580] = new NetCon(&v(0.5), syn_projIE_gaba[580], 20.0, 1.5, -0.0016545403)")  

        # Connection 581: cell 7, seg 0 (0.5) [0.5 on Ipop[7]] -> cell 21, seg 0 (0.5) [0.5 on Epop[21]], weight: -0.0016545403, delay 1.5
        h("Epop[21] syn_projIE_gaba[581] = new gaba(0.5)")
        h("Ipop[7] netConn_projIE_gaba[581] = new NetCon(&v(0.5), syn_projIE_gaba[581], 20.0, 1.5, -0.0016545403)")  

        # Connection 582: cell 7, seg 0 (0.5) [0.5 on Ipop[7]] -> cell 22, seg 0 (0.5) [0.5 on Epop[22]], weight: -0.0016545403, delay 1.5
        h("Epop[22] syn_projIE_gaba[582] = new gaba(0.5)")
        h("Ipop[7] netConn_projIE_gaba[582] = new NetCon(&v(0.5), syn_projIE_gaba[582], 20.0, 1.5, -0.0016545403)")  

        # Connection 583: cell 7, seg 0 (0.5) [0.5 on Ipop[7]] -> cell 23, seg 0 (0.5) [0.5 on Epop[23]], weight: -0.0016545403, delay 1.5
        h("Epop[23] syn_projIE_gaba[583] = new gaba(0.5)")
        h("Ipop[7] netConn_projIE_gaba[583] = new NetCon(&v(0.5), syn_projIE_gaba[583], 20.0, 1.5, -0.0016545403)")  

        # Connection 584: cell 7, seg 0 (0.5) [0.5 on Ipop[7]] -> cell 24, seg 0 (0.5) [0.5 on Epop[24]], weight: -0.0016545403, delay 1.5
        h("Epop[24] syn_projIE_gaba[584] = new gaba(0.5)")
        h("Ipop[7] netConn_projIE_gaba[584] = new NetCon(&v(0.5), syn_projIE_gaba[584], 20.0, 1.5, -0.0016545403)")  

        # Connection 585: cell 7, seg 0 (0.5) [0.5 on Ipop[7]] -> cell 25, seg 0 (0.5) [0.5 on Epop[25]], weight: -0.0016545403, delay 1.5
        h("Epop[25] syn_projIE_gaba[585] = new gaba(0.5)")
        h("Ipop[7] netConn_projIE_gaba[585] = new NetCon(&v(0.5), syn_projIE_gaba[585], 20.0, 1.5, -0.0016545403)")  

        # Connection 586: cell 7, seg 0 (0.5) [0.5 on Ipop[7]] -> cell 26, seg 0 (0.5) [0.5 on Epop[26]], weight: -0.0016545403, delay 1.5
        h("Epop[26] syn_projIE_gaba[586] = new gaba(0.5)")
        h("Ipop[7] netConn_projIE_gaba[586] = new NetCon(&v(0.5), syn_projIE_gaba[586], 20.0, 1.5, -0.0016545403)")  

        # Connection 587: cell 7, seg 0 (0.5) [0.5 on Ipop[7]] -> cell 27, seg 0 (0.5) [0.5 on Epop[27]], weight: -0.0016545403, delay 1.5
        h("Epop[27] syn_projIE_gaba[587] = new gaba(0.5)")
        h("Ipop[7] netConn_projIE_gaba[587] = new NetCon(&v(0.5), syn_projIE_gaba[587], 20.0, 1.5, -0.0016545403)")  

        # Connection 588: cell 7, seg 0 (0.5) [0.5 on Ipop[7]] -> cell 28, seg 0 (0.5) [0.5 on Epop[28]], weight: -0.0016545403, delay 1.5
        h("Epop[28] syn_projIE_gaba[588] = new gaba(0.5)")
        h("Ipop[7] netConn_projIE_gaba[588] = new NetCon(&v(0.5), syn_projIE_gaba[588], 20.0, 1.5, -0.0016545403)")  

        # Connection 589: cell 7, seg 0 (0.5) [0.5 on Ipop[7]] -> cell 29, seg 0 (0.5) [0.5 on Epop[29]], weight: -0.0016545403, delay 1.5
        h("Epop[29] syn_projIE_gaba[589] = new gaba(0.5)")
        h("Ipop[7] netConn_projIE_gaba[589] = new NetCon(&v(0.5), syn_projIE_gaba[589], 20.0, 1.5, -0.0016545403)")  

        # Connection 590: cell 7, seg 0 (0.5) [0.5 on Ipop[7]] -> cell 30, seg 0 (0.5) [0.5 on Epop[30]], weight: -0.0016545403, delay 1.5
        h("Epop[30] syn_projIE_gaba[590] = new gaba(0.5)")
        h("Ipop[7] netConn_projIE_gaba[590] = new NetCon(&v(0.5), syn_projIE_gaba[590], 20.0, 1.5, -0.0016545403)")  

        # Connection 591: cell 7, seg 0 (0.5) [0.5 on Ipop[7]] -> cell 31, seg 0 (0.5) [0.5 on Epop[31]], weight: -0.0016545403, delay 1.5
        h("Epop[31] syn_projIE_gaba[591] = new gaba(0.5)")
        h("Ipop[7] netConn_projIE_gaba[591] = new NetCon(&v(0.5), syn_projIE_gaba[591], 20.0, 1.5, -0.0016545403)")  

        # Connection 592: cell 7, seg 0 (0.5) [0.5 on Ipop[7]] -> cell 32, seg 0 (0.5) [0.5 on Epop[32]], weight: -0.0016545403, delay 1.5
        h("Epop[32] syn_projIE_gaba[592] = new gaba(0.5)")
        h("Ipop[7] netConn_projIE_gaba[592] = new NetCon(&v(0.5), syn_projIE_gaba[592], 20.0, 1.5, -0.0016545403)")  

        # Connection 593: cell 7, seg 0 (0.5) [0.5 on Ipop[7]] -> cell 33, seg 0 (0.5) [0.5 on Epop[33]], weight: -0.0016545403, delay 1.5
        h("Epop[33] syn_projIE_gaba[593] = new gaba(0.5)")
        h("Ipop[7] netConn_projIE_gaba[593] = new NetCon(&v(0.5), syn_projIE_gaba[593], 20.0, 1.5, -0.0016545403)")  

        # Connection 594: cell 7, seg 0 (0.5) [0.5 on Ipop[7]] -> cell 34, seg 0 (0.5) [0.5 on Epop[34]], weight: -0.0016545403, delay 1.5
        h("Epop[34] syn_projIE_gaba[594] = new gaba(0.5)")
        h("Ipop[7] netConn_projIE_gaba[594] = new NetCon(&v(0.5), syn_projIE_gaba[594], 20.0, 1.5, -0.0016545403)")  

        # Connection 595: cell 7, seg 0 (0.5) [0.5 on Ipop[7]] -> cell 35, seg 0 (0.5) [0.5 on Epop[35]], weight: -0.0016545403, delay 1.5
        h("Epop[35] syn_projIE_gaba[595] = new gaba(0.5)")
        h("Ipop[7] netConn_projIE_gaba[595] = new NetCon(&v(0.5), syn_projIE_gaba[595], 20.0, 1.5, -0.0016545403)")  

        # Connection 596: cell 7, seg 0 (0.5) [0.5 on Ipop[7]] -> cell 36, seg 0 (0.5) [0.5 on Epop[36]], weight: -0.0016545403, delay 1.5
        h("Epop[36] syn_projIE_gaba[596] = new gaba(0.5)")
        h("Ipop[7] netConn_projIE_gaba[596] = new NetCon(&v(0.5), syn_projIE_gaba[596], 20.0, 1.5, -0.0016545403)")  

        # Connection 597: cell 7, seg 0 (0.5) [0.5 on Ipop[7]] -> cell 37, seg 0 (0.5) [0.5 on Epop[37]], weight: -0.0016545403, delay 1.5
        h("Epop[37] syn_projIE_gaba[597] = new gaba(0.5)")
        h("Ipop[7] netConn_projIE_gaba[597] = new NetCon(&v(0.5), syn_projIE_gaba[597], 20.0, 1.5, -0.0016545403)")  

        # Connection 598: cell 7, seg 0 (0.5) [0.5 on Ipop[7]] -> cell 38, seg 0 (0.5) [0.5 on Epop[38]], weight: -0.0016545403, delay 1.5
        h("Epop[38] syn_projIE_gaba[598] = new gaba(0.5)")
        h("Ipop[7] netConn_projIE_gaba[598] = new NetCon(&v(0.5), syn_projIE_gaba[598], 20.0, 1.5, -0.0016545403)")  

        # Connection 599: cell 7, seg 0 (0.5) [0.5 on Ipop[7]] -> cell 39, seg 0 (0.5) [0.5 on Epop[39]], weight: -0.0016545403, delay 1.5
        h("Epop[39] syn_projIE_gaba[599] = new gaba(0.5)")
        h("Ipop[7] netConn_projIE_gaba[599] = new NetCon(&v(0.5), syn_projIE_gaba[599], 20.0, 1.5, -0.0016545403)")  

        # Connection 600: cell 7, seg 0 (0.5) [0.5 on Ipop[7]] -> cell 40, seg 0 (0.5) [0.5 on Epop[40]], weight: -0.0016545403, delay 1.5
        h("Epop[40] syn_projIE_gaba[600] = new gaba(0.5)")
        h("Ipop[7] netConn_projIE_gaba[600] = new NetCon(&v(0.5), syn_projIE_gaba[600], 20.0, 1.5, -0.0016545403)")  

        # Connection 601: cell 7, seg 0 (0.5) [0.5 on Ipop[7]] -> cell 41, seg 0 (0.5) [0.5 on Epop[41]], weight: -0.0016545403, delay 1.5
        h("Epop[41] syn_projIE_gaba[601] = new gaba(0.5)")
        h("Ipop[7] netConn_projIE_gaba[601] = new NetCon(&v(0.5), syn_projIE_gaba[601], 20.0, 1.5, -0.0016545403)")  

        # Connection 602: cell 7, seg 0 (0.5) [0.5 on Ipop[7]] -> cell 42, seg 0 (0.5) [0.5 on Epop[42]], weight: -0.0016545403, delay 1.5
        h("Epop[42] syn_projIE_gaba[602] = new gaba(0.5)")
        h("Ipop[7] netConn_projIE_gaba[602] = new NetCon(&v(0.5), syn_projIE_gaba[602], 20.0, 1.5, -0.0016545403)")  

        # Connection 603: cell 7, seg 0 (0.5) [0.5 on Ipop[7]] -> cell 43, seg 0 (0.5) [0.5 on Epop[43]], weight: -0.0016545403, delay 1.5
        h("Epop[43] syn_projIE_gaba[603] = new gaba(0.5)")
        h("Ipop[7] netConn_projIE_gaba[603] = new NetCon(&v(0.5), syn_projIE_gaba[603], 20.0, 1.5, -0.0016545403)")  

        # Connection 604: cell 7, seg 0 (0.5) [0.5 on Ipop[7]] -> cell 44, seg 0 (0.5) [0.5 on Epop[44]], weight: -0.0016545403, delay 1.5
        h("Epop[44] syn_projIE_gaba[604] = new gaba(0.5)")
        h("Ipop[7] netConn_projIE_gaba[604] = new NetCon(&v(0.5), syn_projIE_gaba[604], 20.0, 1.5, -0.0016545403)")  

        # Connection 605: cell 7, seg 0 (0.5) [0.5 on Ipop[7]] -> cell 45, seg 0 (0.5) [0.5 on Epop[45]], weight: -0.0016545403, delay 1.5
        h("Epop[45] syn_projIE_gaba[605] = new gaba(0.5)")
        h("Ipop[7] netConn_projIE_gaba[605] = new NetCon(&v(0.5), syn_projIE_gaba[605], 20.0, 1.5, -0.0016545403)")  

        # Connection 606: cell 7, seg 0 (0.5) [0.5 on Ipop[7]] -> cell 46, seg 0 (0.5) [0.5 on Epop[46]], weight: -0.0016545403, delay 1.5
        h("Epop[46] syn_projIE_gaba[606] = new gaba(0.5)")
        h("Ipop[7] netConn_projIE_gaba[606] = new NetCon(&v(0.5), syn_projIE_gaba[606], 20.0, 1.5, -0.0016545403)")  

        # Connection 607: cell 7, seg 0 (0.5) [0.5 on Ipop[7]] -> cell 47, seg 0 (0.5) [0.5 on Epop[47]], weight: -0.0016545403, delay 1.5
        h("Epop[47] syn_projIE_gaba[607] = new gaba(0.5)")
        h("Ipop[7] netConn_projIE_gaba[607] = new NetCon(&v(0.5), syn_projIE_gaba[607], 20.0, 1.5, -0.0016545403)")  

        # Connection 608: cell 7, seg 0 (0.5) [0.5 on Ipop[7]] -> cell 48, seg 0 (0.5) [0.5 on Epop[48]], weight: -0.0016545403, delay 1.5
        h("Epop[48] syn_projIE_gaba[608] = new gaba(0.5)")
        h("Ipop[7] netConn_projIE_gaba[608] = new NetCon(&v(0.5), syn_projIE_gaba[608], 20.0, 1.5, -0.0016545403)")  

        # Connection 609: cell 7, seg 0 (0.5) [0.5 on Ipop[7]] -> cell 49, seg 0 (0.5) [0.5 on Epop[49]], weight: -0.0016545403, delay 1.5
        h("Epop[49] syn_projIE_gaba[609] = new gaba(0.5)")
        h("Ipop[7] netConn_projIE_gaba[609] = new NetCon(&v(0.5), syn_projIE_gaba[609], 20.0, 1.5, -0.0016545403)")  

        # Connection 610: cell 7, seg 0 (0.5) [0.5 on Ipop[7]] -> cell 50, seg 0 (0.5) [0.5 on Epop[50]], weight: -0.0016545403, delay 1.5
        h("Epop[50] syn_projIE_gaba[610] = new gaba(0.5)")
        h("Ipop[7] netConn_projIE_gaba[610] = new NetCon(&v(0.5), syn_projIE_gaba[610], 20.0, 1.5, -0.0016545403)")  

        # Connection 611: cell 7, seg 0 (0.5) [0.5 on Ipop[7]] -> cell 51, seg 0 (0.5) [0.5 on Epop[51]], weight: -0.0016545403, delay 1.5
        h("Epop[51] syn_projIE_gaba[611] = new gaba(0.5)")
        h("Ipop[7] netConn_projIE_gaba[611] = new NetCon(&v(0.5), syn_projIE_gaba[611], 20.0, 1.5, -0.0016545403)")  

        # Connection 612: cell 7, seg 0 (0.5) [0.5 on Ipop[7]] -> cell 52, seg 0 (0.5) [0.5 on Epop[52]], weight: -0.0016545403, delay 1.5
        h("Epop[52] syn_projIE_gaba[612] = new gaba(0.5)")
        h("Ipop[7] netConn_projIE_gaba[612] = new NetCon(&v(0.5), syn_projIE_gaba[612], 20.0, 1.5, -0.0016545403)")  

        # Connection 613: cell 7, seg 0 (0.5) [0.5 on Ipop[7]] -> cell 53, seg 0 (0.5) [0.5 on Epop[53]], weight: -0.0016545403, delay 1.5
        h("Epop[53] syn_projIE_gaba[613] = new gaba(0.5)")
        h("Ipop[7] netConn_projIE_gaba[613] = new NetCon(&v(0.5), syn_projIE_gaba[613], 20.0, 1.5, -0.0016545403)")  

        # Connection 614: cell 7, seg 0 (0.5) [0.5 on Ipop[7]] -> cell 54, seg 0 (0.5) [0.5 on Epop[54]], weight: -0.0016545403, delay 1.5
        h("Epop[54] syn_projIE_gaba[614] = new gaba(0.5)")
        h("Ipop[7] netConn_projIE_gaba[614] = new NetCon(&v(0.5), syn_projIE_gaba[614], 20.0, 1.5, -0.0016545403)")  

        # Connection 615: cell 7, seg 0 (0.5) [0.5 on Ipop[7]] -> cell 55, seg 0 (0.5) [0.5 on Epop[55]], weight: -0.0016545403, delay 1.5
        h("Epop[55] syn_projIE_gaba[615] = new gaba(0.5)")
        h("Ipop[7] netConn_projIE_gaba[615] = new NetCon(&v(0.5), syn_projIE_gaba[615], 20.0, 1.5, -0.0016545403)")  

        # Connection 616: cell 7, seg 0 (0.5) [0.5 on Ipop[7]] -> cell 56, seg 0 (0.5) [0.5 on Epop[56]], weight: -0.0016545403, delay 1.5
        h("Epop[56] syn_projIE_gaba[616] = new gaba(0.5)")
        h("Ipop[7] netConn_projIE_gaba[616] = new NetCon(&v(0.5), syn_projIE_gaba[616], 20.0, 1.5, -0.0016545403)")  

        # Connection 617: cell 7, seg 0 (0.5) [0.5 on Ipop[7]] -> cell 57, seg 0 (0.5) [0.5 on Epop[57]], weight: -0.0016545403, delay 1.5
        h("Epop[57] syn_projIE_gaba[617] = new gaba(0.5)")
        h("Ipop[7] netConn_projIE_gaba[617] = new NetCon(&v(0.5), syn_projIE_gaba[617], 20.0, 1.5, -0.0016545403)")  

        # Connection 618: cell 7, seg 0 (0.5) [0.5 on Ipop[7]] -> cell 58, seg 0 (0.5) [0.5 on Epop[58]], weight: -0.0016545403, delay 1.5
        h("Epop[58] syn_projIE_gaba[618] = new gaba(0.5)")
        h("Ipop[7] netConn_projIE_gaba[618] = new NetCon(&v(0.5), syn_projIE_gaba[618], 20.0, 1.5, -0.0016545403)")  

        # Connection 619: cell 7, seg 0 (0.5) [0.5 on Ipop[7]] -> cell 59, seg 0 (0.5) [0.5 on Epop[59]], weight: -0.0016545403, delay 1.5
        h("Epop[59] syn_projIE_gaba[619] = new gaba(0.5)")
        h("Ipop[7] netConn_projIE_gaba[619] = new NetCon(&v(0.5), syn_projIE_gaba[619], 20.0, 1.5, -0.0016545403)")  

        # Connection 620: cell 7, seg 0 (0.5) [0.5 on Ipop[7]] -> cell 60, seg 0 (0.5) [0.5 on Epop[60]], weight: -0.0016545403, delay 1.5
        h("Epop[60] syn_projIE_gaba[620] = new gaba(0.5)")
        h("Ipop[7] netConn_projIE_gaba[620] = new NetCon(&v(0.5), syn_projIE_gaba[620], 20.0, 1.5, -0.0016545403)")  

        # Connection 621: cell 7, seg 0 (0.5) [0.5 on Ipop[7]] -> cell 61, seg 0 (0.5) [0.5 on Epop[61]], weight: -0.0016545403, delay 1.5
        h("Epop[61] syn_projIE_gaba[621] = new gaba(0.5)")
        h("Ipop[7] netConn_projIE_gaba[621] = new NetCon(&v(0.5), syn_projIE_gaba[621], 20.0, 1.5, -0.0016545403)")  

        # Connection 622: cell 7, seg 0 (0.5) [0.5 on Ipop[7]] -> cell 62, seg 0 (0.5) [0.5 on Epop[62]], weight: -0.0016545403, delay 1.5
        h("Epop[62] syn_projIE_gaba[622] = new gaba(0.5)")
        h("Ipop[7] netConn_projIE_gaba[622] = new NetCon(&v(0.5), syn_projIE_gaba[622], 20.0, 1.5, -0.0016545403)")  

        # Connection 623: cell 7, seg 0 (0.5) [0.5 on Ipop[7]] -> cell 63, seg 0 (0.5) [0.5 on Epop[63]], weight: -0.0016545403, delay 1.5
        h("Epop[63] syn_projIE_gaba[623] = new gaba(0.5)")
        h("Ipop[7] netConn_projIE_gaba[623] = new NetCon(&v(0.5), syn_projIE_gaba[623], 20.0, 1.5, -0.0016545403)")  

        # Connection 624: cell 7, seg 0 (0.5) [0.5 on Ipop[7]] -> cell 64, seg 0 (0.5) [0.5 on Epop[64]], weight: -0.0016545403, delay 1.5
        h("Epop[64] syn_projIE_gaba[624] = new gaba(0.5)")
        h("Ipop[7] netConn_projIE_gaba[624] = new NetCon(&v(0.5), syn_projIE_gaba[624], 20.0, 1.5, -0.0016545403)")  

        # Connection 625: cell 7, seg 0 (0.5) [0.5 on Ipop[7]] -> cell 65, seg 0 (0.5) [0.5 on Epop[65]], weight: -0.0016545403, delay 1.5
        h("Epop[65] syn_projIE_gaba[625] = new gaba(0.5)")
        h("Ipop[7] netConn_projIE_gaba[625] = new NetCon(&v(0.5), syn_projIE_gaba[625], 20.0, 1.5, -0.0016545403)")  

        # Connection 626: cell 7, seg 0 (0.5) [0.5 on Ipop[7]] -> cell 66, seg 0 (0.5) [0.5 on Epop[66]], weight: -0.0016545403, delay 1.5
        h("Epop[66] syn_projIE_gaba[626] = new gaba(0.5)")
        h("Ipop[7] netConn_projIE_gaba[626] = new NetCon(&v(0.5), syn_projIE_gaba[626], 20.0, 1.5, -0.0016545403)")  

        # Connection 627: cell 7, seg 0 (0.5) [0.5 on Ipop[7]] -> cell 67, seg 0 (0.5) [0.5 on Epop[67]], weight: -0.0016545403, delay 1.5
        h("Epop[67] syn_projIE_gaba[627] = new gaba(0.5)")
        h("Ipop[7] netConn_projIE_gaba[627] = new NetCon(&v(0.5), syn_projIE_gaba[627], 20.0, 1.5, -0.0016545403)")  

        # Connection 628: cell 7, seg 0 (0.5) [0.5 on Ipop[7]] -> cell 68, seg 0 (0.5) [0.5 on Epop[68]], weight: -0.0016545403, delay 1.5
        h("Epop[68] syn_projIE_gaba[628] = new gaba(0.5)")
        h("Ipop[7] netConn_projIE_gaba[628] = new NetCon(&v(0.5), syn_projIE_gaba[628], 20.0, 1.5, -0.0016545403)")  

        # Connection 629: cell 7, seg 0 (0.5) [0.5 on Ipop[7]] -> cell 69, seg 0 (0.5) [0.5 on Epop[69]], weight: -0.0016545403, delay 1.5
        h("Epop[69] syn_projIE_gaba[629] = new gaba(0.5)")
        h("Ipop[7] netConn_projIE_gaba[629] = new NetCon(&v(0.5), syn_projIE_gaba[629], 20.0, 1.5, -0.0016545403)")  

        # Connection 630: cell 7, seg 0 (0.5) [0.5 on Ipop[7]] -> cell 70, seg 0 (0.5) [0.5 on Epop[70]], weight: -0.0016545403, delay 1.5
        h("Epop[70] syn_projIE_gaba[630] = new gaba(0.5)")
        h("Ipop[7] netConn_projIE_gaba[630] = new NetCon(&v(0.5), syn_projIE_gaba[630], 20.0, 1.5, -0.0016545403)")  

        # Connection 631: cell 7, seg 0 (0.5) [0.5 on Ipop[7]] -> cell 71, seg 0 (0.5) [0.5 on Epop[71]], weight: -0.0016545403, delay 1.5
        h("Epop[71] syn_projIE_gaba[631] = new gaba(0.5)")
        h("Ipop[7] netConn_projIE_gaba[631] = new NetCon(&v(0.5), syn_projIE_gaba[631], 20.0, 1.5, -0.0016545403)")  

        # Connection 632: cell 7, seg 0 (0.5) [0.5 on Ipop[7]] -> cell 72, seg 0 (0.5) [0.5 on Epop[72]], weight: -0.0016545403, delay 1.5
        h("Epop[72] syn_projIE_gaba[632] = new gaba(0.5)")
        h("Ipop[7] netConn_projIE_gaba[632] = new NetCon(&v(0.5), syn_projIE_gaba[632], 20.0, 1.5, -0.0016545403)")  

        # Connection 633: cell 7, seg 0 (0.5) [0.5 on Ipop[7]] -> cell 73, seg 0 (0.5) [0.5 on Epop[73]], weight: -0.0016545403, delay 1.5
        h("Epop[73] syn_projIE_gaba[633] = new gaba(0.5)")
        h("Ipop[7] netConn_projIE_gaba[633] = new NetCon(&v(0.5), syn_projIE_gaba[633], 20.0, 1.5, -0.0016545403)")  

        # Connection 634: cell 7, seg 0 (0.5) [0.5 on Ipop[7]] -> cell 74, seg 0 (0.5) [0.5 on Epop[74]], weight: -0.0016545403, delay 1.5
        h("Epop[74] syn_projIE_gaba[634] = new gaba(0.5)")
        h("Ipop[7] netConn_projIE_gaba[634] = new NetCon(&v(0.5), syn_projIE_gaba[634], 20.0, 1.5, -0.0016545403)")  

        # Connection 635: cell 7, seg 0 (0.5) [0.5 on Ipop[7]] -> cell 75, seg 0 (0.5) [0.5 on Epop[75]], weight: -0.0016545403, delay 1.5
        h("Epop[75] syn_projIE_gaba[635] = new gaba(0.5)")
        h("Ipop[7] netConn_projIE_gaba[635] = new NetCon(&v(0.5), syn_projIE_gaba[635], 20.0, 1.5, -0.0016545403)")  

        # Connection 636: cell 7, seg 0 (0.5) [0.5 on Ipop[7]] -> cell 76, seg 0 (0.5) [0.5 on Epop[76]], weight: -0.0016545403, delay 1.5
        h("Epop[76] syn_projIE_gaba[636] = new gaba(0.5)")
        h("Ipop[7] netConn_projIE_gaba[636] = new NetCon(&v(0.5), syn_projIE_gaba[636], 20.0, 1.5, -0.0016545403)")  

        # Connection 637: cell 7, seg 0 (0.5) [0.5 on Ipop[7]] -> cell 77, seg 0 (0.5) [0.5 on Epop[77]], weight: -0.0016545403, delay 1.5
        h("Epop[77] syn_projIE_gaba[637] = new gaba(0.5)")
        h("Ipop[7] netConn_projIE_gaba[637] = new NetCon(&v(0.5), syn_projIE_gaba[637], 20.0, 1.5, -0.0016545403)")  

        # Connection 638: cell 7, seg 0 (0.5) [0.5 on Ipop[7]] -> cell 78, seg 0 (0.5) [0.5 on Epop[78]], weight: -0.0016545403, delay 1.5
        h("Epop[78] syn_projIE_gaba[638] = new gaba(0.5)")
        h("Ipop[7] netConn_projIE_gaba[638] = new NetCon(&v(0.5), syn_projIE_gaba[638], 20.0, 1.5, -0.0016545403)")  

        # Connection 639: cell 7, seg 0 (0.5) [0.5 on Ipop[7]] -> cell 79, seg 0 (0.5) [0.5 on Epop[79]], weight: -0.0016545403, delay 1.5
        h("Epop[79] syn_projIE_gaba[639] = new gaba(0.5)")
        h("Ipop[7] netConn_projIE_gaba[639] = new NetCon(&v(0.5), syn_projIE_gaba[639], 20.0, 1.5, -0.0016545403)")  

        # Connection 640: cell 8, seg 0 (0.5) [0.5 on Ipop[8]] -> cell 0, seg 0 (0.5) [0.5 on Epop[0]], weight: -0.0016545403, delay 1.5
        h("Epop[0] syn_projIE_gaba[640] = new gaba(0.5)")
        h("Ipop[8] netConn_projIE_gaba[640] = new NetCon(&v(0.5), syn_projIE_gaba[640], 20.0, 1.5, -0.0016545403)")  

        # Connection 641: cell 8, seg 0 (0.5) [0.5 on Ipop[8]] -> cell 1, seg 0 (0.5) [0.5 on Epop[1]], weight: -0.0016545403, delay 1.5
        h("Epop[1] syn_projIE_gaba[641] = new gaba(0.5)")
        h("Ipop[8] netConn_projIE_gaba[641] = new NetCon(&v(0.5), syn_projIE_gaba[641], 20.0, 1.5, -0.0016545403)")  

        # Connection 642: cell 8, seg 0 (0.5) [0.5 on Ipop[8]] -> cell 2, seg 0 (0.5) [0.5 on Epop[2]], weight: -0.0016545403, delay 1.5
        h("Epop[2] syn_projIE_gaba[642] = new gaba(0.5)")
        h("Ipop[8] netConn_projIE_gaba[642] = new NetCon(&v(0.5), syn_projIE_gaba[642], 20.0, 1.5, -0.0016545403)")  

        # Connection 643: cell 8, seg 0 (0.5) [0.5 on Ipop[8]] -> cell 3, seg 0 (0.5) [0.5 on Epop[3]], weight: -0.0016545403, delay 1.5
        h("Epop[3] syn_projIE_gaba[643] = new gaba(0.5)")
        h("Ipop[8] netConn_projIE_gaba[643] = new NetCon(&v(0.5), syn_projIE_gaba[643], 20.0, 1.5, -0.0016545403)")  

        # Connection 644: cell 8, seg 0 (0.5) [0.5 on Ipop[8]] -> cell 4, seg 0 (0.5) [0.5 on Epop[4]], weight: -0.0016545403, delay 1.5
        h("Epop[4] syn_projIE_gaba[644] = new gaba(0.5)")
        h("Ipop[8] netConn_projIE_gaba[644] = new NetCon(&v(0.5), syn_projIE_gaba[644], 20.0, 1.5, -0.0016545403)")  

        # Connection 645: cell 8, seg 0 (0.5) [0.5 on Ipop[8]] -> cell 5, seg 0 (0.5) [0.5 on Epop[5]], weight: -0.0016545403, delay 1.5
        h("Epop[5] syn_projIE_gaba[645] = new gaba(0.5)")
        h("Ipop[8] netConn_projIE_gaba[645] = new NetCon(&v(0.5), syn_projIE_gaba[645], 20.0, 1.5, -0.0016545403)")  

        # Connection 646: cell 8, seg 0 (0.5) [0.5 on Ipop[8]] -> cell 6, seg 0 (0.5) [0.5 on Epop[6]], weight: -0.0016545403, delay 1.5
        h("Epop[6] syn_projIE_gaba[646] = new gaba(0.5)")
        h("Ipop[8] netConn_projIE_gaba[646] = new NetCon(&v(0.5), syn_projIE_gaba[646], 20.0, 1.5, -0.0016545403)")  

        # Connection 647: cell 8, seg 0 (0.5) [0.5 on Ipop[8]] -> cell 7, seg 0 (0.5) [0.5 on Epop[7]], weight: -0.0016545403, delay 1.5
        h("Epop[7] syn_projIE_gaba[647] = new gaba(0.5)")
        h("Ipop[8] netConn_projIE_gaba[647] = new NetCon(&v(0.5), syn_projIE_gaba[647], 20.0, 1.5, -0.0016545403)")  

        # Connection 648: cell 8, seg 0 (0.5) [0.5 on Ipop[8]] -> cell 8, seg 0 (0.5) [0.5 on Epop[8]], weight: -0.0016545403, delay 1.5
        h("Epop[8] syn_projIE_gaba[648] = new gaba(0.5)")
        h("Ipop[8] netConn_projIE_gaba[648] = new NetCon(&v(0.5), syn_projIE_gaba[648], 20.0, 1.5, -0.0016545403)")  

        # Connection 649: cell 8, seg 0 (0.5) [0.5 on Ipop[8]] -> cell 9, seg 0 (0.5) [0.5 on Epop[9]], weight: -0.0016545403, delay 1.5
        h("Epop[9] syn_projIE_gaba[649] = new gaba(0.5)")
        h("Ipop[8] netConn_projIE_gaba[649] = new NetCon(&v(0.5), syn_projIE_gaba[649], 20.0, 1.5, -0.0016545403)")  

        # Connection 650: cell 8, seg 0 (0.5) [0.5 on Ipop[8]] -> cell 10, seg 0 (0.5) [0.5 on Epop[10]], weight: -0.0016545403, delay 1.5
        h("Epop[10] syn_projIE_gaba[650] = new gaba(0.5)")
        h("Ipop[8] netConn_projIE_gaba[650] = new NetCon(&v(0.5), syn_projIE_gaba[650], 20.0, 1.5, -0.0016545403)")  

        # Connection 651: cell 8, seg 0 (0.5) [0.5 on Ipop[8]] -> cell 11, seg 0 (0.5) [0.5 on Epop[11]], weight: -0.0016545403, delay 1.5
        h("Epop[11] syn_projIE_gaba[651] = new gaba(0.5)")
        h("Ipop[8] netConn_projIE_gaba[651] = new NetCon(&v(0.5), syn_projIE_gaba[651], 20.0, 1.5, -0.0016545403)")  

        # Connection 652: cell 8, seg 0 (0.5) [0.5 on Ipop[8]] -> cell 12, seg 0 (0.5) [0.5 on Epop[12]], weight: -0.0016545403, delay 1.5
        h("Epop[12] syn_projIE_gaba[652] = new gaba(0.5)")
        h("Ipop[8] netConn_projIE_gaba[652] = new NetCon(&v(0.5), syn_projIE_gaba[652], 20.0, 1.5, -0.0016545403)")  

        # Connection 653: cell 8, seg 0 (0.5) [0.5 on Ipop[8]] -> cell 13, seg 0 (0.5) [0.5 on Epop[13]], weight: -0.0016545403, delay 1.5
        h("Epop[13] syn_projIE_gaba[653] = new gaba(0.5)")
        h("Ipop[8] netConn_projIE_gaba[653] = new NetCon(&v(0.5), syn_projIE_gaba[653], 20.0, 1.5, -0.0016545403)")  

        # Connection 654: cell 8, seg 0 (0.5) [0.5 on Ipop[8]] -> cell 14, seg 0 (0.5) [0.5 on Epop[14]], weight: -0.0016545403, delay 1.5
        h("Epop[14] syn_projIE_gaba[654] = new gaba(0.5)")
        h("Ipop[8] netConn_projIE_gaba[654] = new NetCon(&v(0.5), syn_projIE_gaba[654], 20.0, 1.5, -0.0016545403)")  

        # Connection 655: cell 8, seg 0 (0.5) [0.5 on Ipop[8]] -> cell 15, seg 0 (0.5) [0.5 on Epop[15]], weight: -0.0016545403, delay 1.5
        h("Epop[15] syn_projIE_gaba[655] = new gaba(0.5)")
        h("Ipop[8] netConn_projIE_gaba[655] = new NetCon(&v(0.5), syn_projIE_gaba[655], 20.0, 1.5, -0.0016545403)")  

        # Connection 656: cell 8, seg 0 (0.5) [0.5 on Ipop[8]] -> cell 16, seg 0 (0.5) [0.5 on Epop[16]], weight: -0.0016545403, delay 1.5
        h("Epop[16] syn_projIE_gaba[656] = new gaba(0.5)")
        h("Ipop[8] netConn_projIE_gaba[656] = new NetCon(&v(0.5), syn_projIE_gaba[656], 20.0, 1.5, -0.0016545403)")  

        # Connection 657: cell 8, seg 0 (0.5) [0.5 on Ipop[8]] -> cell 17, seg 0 (0.5) [0.5 on Epop[17]], weight: -0.0016545403, delay 1.5
        h("Epop[17] syn_projIE_gaba[657] = new gaba(0.5)")
        h("Ipop[8] netConn_projIE_gaba[657] = new NetCon(&v(0.5), syn_projIE_gaba[657], 20.0, 1.5, -0.0016545403)")  

        # Connection 658: cell 8, seg 0 (0.5) [0.5 on Ipop[8]] -> cell 18, seg 0 (0.5) [0.5 on Epop[18]], weight: -0.0016545403, delay 1.5
        h("Epop[18] syn_projIE_gaba[658] = new gaba(0.5)")
        h("Ipop[8] netConn_projIE_gaba[658] = new NetCon(&v(0.5), syn_projIE_gaba[658], 20.0, 1.5, -0.0016545403)")  

        # Connection 659: cell 8, seg 0 (0.5) [0.5 on Ipop[8]] -> cell 19, seg 0 (0.5) [0.5 on Epop[19]], weight: -0.0016545403, delay 1.5
        h("Epop[19] syn_projIE_gaba[659] = new gaba(0.5)")
        h("Ipop[8] netConn_projIE_gaba[659] = new NetCon(&v(0.5), syn_projIE_gaba[659], 20.0, 1.5, -0.0016545403)")  

        # Connection 660: cell 8, seg 0 (0.5) [0.5 on Ipop[8]] -> cell 20, seg 0 (0.5) [0.5 on Epop[20]], weight: -0.0016545403, delay 1.5
        h("Epop[20] syn_projIE_gaba[660] = new gaba(0.5)")
        h("Ipop[8] netConn_projIE_gaba[660] = new NetCon(&v(0.5), syn_projIE_gaba[660], 20.0, 1.5, -0.0016545403)")  

        # Connection 661: cell 8, seg 0 (0.5) [0.5 on Ipop[8]] -> cell 21, seg 0 (0.5) [0.5 on Epop[21]], weight: -0.0016545403, delay 1.5
        h("Epop[21] syn_projIE_gaba[661] = new gaba(0.5)")
        h("Ipop[8] netConn_projIE_gaba[661] = new NetCon(&v(0.5), syn_projIE_gaba[661], 20.0, 1.5, -0.0016545403)")  

        # Connection 662: cell 8, seg 0 (0.5) [0.5 on Ipop[8]] -> cell 22, seg 0 (0.5) [0.5 on Epop[22]], weight: -0.0016545403, delay 1.5
        h("Epop[22] syn_projIE_gaba[662] = new gaba(0.5)")
        h("Ipop[8] netConn_projIE_gaba[662] = new NetCon(&v(0.5), syn_projIE_gaba[662], 20.0, 1.5, -0.0016545403)")  

        # Connection 663: cell 8, seg 0 (0.5) [0.5 on Ipop[8]] -> cell 23, seg 0 (0.5) [0.5 on Epop[23]], weight: -0.0016545403, delay 1.5
        h("Epop[23] syn_projIE_gaba[663] = new gaba(0.5)")
        h("Ipop[8] netConn_projIE_gaba[663] = new NetCon(&v(0.5), syn_projIE_gaba[663], 20.0, 1.5, -0.0016545403)")  

        # Connection 664: cell 8, seg 0 (0.5) [0.5 on Ipop[8]] -> cell 24, seg 0 (0.5) [0.5 on Epop[24]], weight: -0.0016545403, delay 1.5
        h("Epop[24] syn_projIE_gaba[664] = new gaba(0.5)")
        h("Ipop[8] netConn_projIE_gaba[664] = new NetCon(&v(0.5), syn_projIE_gaba[664], 20.0, 1.5, -0.0016545403)")  

        # Connection 665: cell 8, seg 0 (0.5) [0.5 on Ipop[8]] -> cell 25, seg 0 (0.5) [0.5 on Epop[25]], weight: -0.0016545403, delay 1.5
        h("Epop[25] syn_projIE_gaba[665] = new gaba(0.5)")
        h("Ipop[8] netConn_projIE_gaba[665] = new NetCon(&v(0.5), syn_projIE_gaba[665], 20.0, 1.5, -0.0016545403)")  

        # Connection 666: cell 8, seg 0 (0.5) [0.5 on Ipop[8]] -> cell 26, seg 0 (0.5) [0.5 on Epop[26]], weight: -0.0016545403, delay 1.5
        h("Epop[26] syn_projIE_gaba[666] = new gaba(0.5)")
        h("Ipop[8] netConn_projIE_gaba[666] = new NetCon(&v(0.5), syn_projIE_gaba[666], 20.0, 1.5, -0.0016545403)")  

        # Connection 667: cell 8, seg 0 (0.5) [0.5 on Ipop[8]] -> cell 27, seg 0 (0.5) [0.5 on Epop[27]], weight: -0.0016545403, delay 1.5
        h("Epop[27] syn_projIE_gaba[667] = new gaba(0.5)")
        h("Ipop[8] netConn_projIE_gaba[667] = new NetCon(&v(0.5), syn_projIE_gaba[667], 20.0, 1.5, -0.0016545403)")  

        # Connection 668: cell 8, seg 0 (0.5) [0.5 on Ipop[8]] -> cell 28, seg 0 (0.5) [0.5 on Epop[28]], weight: -0.0016545403, delay 1.5
        h("Epop[28] syn_projIE_gaba[668] = new gaba(0.5)")
        h("Ipop[8] netConn_projIE_gaba[668] = new NetCon(&v(0.5), syn_projIE_gaba[668], 20.0, 1.5, -0.0016545403)")  

        # Connection 669: cell 8, seg 0 (0.5) [0.5 on Ipop[8]] -> cell 29, seg 0 (0.5) [0.5 on Epop[29]], weight: -0.0016545403, delay 1.5
        h("Epop[29] syn_projIE_gaba[669] = new gaba(0.5)")
        h("Ipop[8] netConn_projIE_gaba[669] = new NetCon(&v(0.5), syn_projIE_gaba[669], 20.0, 1.5, -0.0016545403)")  

        # Connection 670: cell 8, seg 0 (0.5) [0.5 on Ipop[8]] -> cell 30, seg 0 (0.5) [0.5 on Epop[30]], weight: -0.0016545403, delay 1.5
        h("Epop[30] syn_projIE_gaba[670] = new gaba(0.5)")
        h("Ipop[8] netConn_projIE_gaba[670] = new NetCon(&v(0.5), syn_projIE_gaba[670], 20.0, 1.5, -0.0016545403)")  

        # Connection 671: cell 8, seg 0 (0.5) [0.5 on Ipop[8]] -> cell 31, seg 0 (0.5) [0.5 on Epop[31]], weight: -0.0016545403, delay 1.5
        h("Epop[31] syn_projIE_gaba[671] = new gaba(0.5)")
        h("Ipop[8] netConn_projIE_gaba[671] = new NetCon(&v(0.5), syn_projIE_gaba[671], 20.0, 1.5, -0.0016545403)")  

        # Connection 672: cell 8, seg 0 (0.5) [0.5 on Ipop[8]] -> cell 32, seg 0 (0.5) [0.5 on Epop[32]], weight: -0.0016545403, delay 1.5
        h("Epop[32] syn_projIE_gaba[672] = new gaba(0.5)")
        h("Ipop[8] netConn_projIE_gaba[672] = new NetCon(&v(0.5), syn_projIE_gaba[672], 20.0, 1.5, -0.0016545403)")  

        # Connection 673: cell 8, seg 0 (0.5) [0.5 on Ipop[8]] -> cell 33, seg 0 (0.5) [0.5 on Epop[33]], weight: -0.0016545403, delay 1.5
        h("Epop[33] syn_projIE_gaba[673] = new gaba(0.5)")
        h("Ipop[8] netConn_projIE_gaba[673] = new NetCon(&v(0.5), syn_projIE_gaba[673], 20.0, 1.5, -0.0016545403)")  

        # Connection 674: cell 8, seg 0 (0.5) [0.5 on Ipop[8]] -> cell 34, seg 0 (0.5) [0.5 on Epop[34]], weight: -0.0016545403, delay 1.5
        h("Epop[34] syn_projIE_gaba[674] = new gaba(0.5)")
        h("Ipop[8] netConn_projIE_gaba[674] = new NetCon(&v(0.5), syn_projIE_gaba[674], 20.0, 1.5, -0.0016545403)")  

        # Connection 675: cell 8, seg 0 (0.5) [0.5 on Ipop[8]] -> cell 35, seg 0 (0.5) [0.5 on Epop[35]], weight: -0.0016545403, delay 1.5
        h("Epop[35] syn_projIE_gaba[675] = new gaba(0.5)")
        h("Ipop[8] netConn_projIE_gaba[675] = new NetCon(&v(0.5), syn_projIE_gaba[675], 20.0, 1.5, -0.0016545403)")  

        # Connection 676: cell 8, seg 0 (0.5) [0.5 on Ipop[8]] -> cell 36, seg 0 (0.5) [0.5 on Epop[36]], weight: -0.0016545403, delay 1.5
        h("Epop[36] syn_projIE_gaba[676] = new gaba(0.5)")
        h("Ipop[8] netConn_projIE_gaba[676] = new NetCon(&v(0.5), syn_projIE_gaba[676], 20.0, 1.5, -0.0016545403)")  

        # Connection 677: cell 8, seg 0 (0.5) [0.5 on Ipop[8]] -> cell 37, seg 0 (0.5) [0.5 on Epop[37]], weight: -0.0016545403, delay 1.5
        h("Epop[37] syn_projIE_gaba[677] = new gaba(0.5)")
        h("Ipop[8] netConn_projIE_gaba[677] = new NetCon(&v(0.5), syn_projIE_gaba[677], 20.0, 1.5, -0.0016545403)")  

        # Connection 678: cell 8, seg 0 (0.5) [0.5 on Ipop[8]] -> cell 38, seg 0 (0.5) [0.5 on Epop[38]], weight: -0.0016545403, delay 1.5
        h("Epop[38] syn_projIE_gaba[678] = new gaba(0.5)")
        h("Ipop[8] netConn_projIE_gaba[678] = new NetCon(&v(0.5), syn_projIE_gaba[678], 20.0, 1.5, -0.0016545403)")  

        # Connection 679: cell 8, seg 0 (0.5) [0.5 on Ipop[8]] -> cell 39, seg 0 (0.5) [0.5 on Epop[39]], weight: -0.0016545403, delay 1.5
        h("Epop[39] syn_projIE_gaba[679] = new gaba(0.5)")
        h("Ipop[8] netConn_projIE_gaba[679] = new NetCon(&v(0.5), syn_projIE_gaba[679], 20.0, 1.5, -0.0016545403)")  

        # Connection 680: cell 8, seg 0 (0.5) [0.5 on Ipop[8]] -> cell 40, seg 0 (0.5) [0.5 on Epop[40]], weight: -0.0016545403, delay 1.5
        h("Epop[40] syn_projIE_gaba[680] = new gaba(0.5)")
        h("Ipop[8] netConn_projIE_gaba[680] = new NetCon(&v(0.5), syn_projIE_gaba[680], 20.0, 1.5, -0.0016545403)")  

        # Connection 681: cell 8, seg 0 (0.5) [0.5 on Ipop[8]] -> cell 41, seg 0 (0.5) [0.5 on Epop[41]], weight: -0.0016545403, delay 1.5
        h("Epop[41] syn_projIE_gaba[681] = new gaba(0.5)")
        h("Ipop[8] netConn_projIE_gaba[681] = new NetCon(&v(0.5), syn_projIE_gaba[681], 20.0, 1.5, -0.0016545403)")  

        # Connection 682: cell 8, seg 0 (0.5) [0.5 on Ipop[8]] -> cell 42, seg 0 (0.5) [0.5 on Epop[42]], weight: -0.0016545403, delay 1.5
        h("Epop[42] syn_projIE_gaba[682] = new gaba(0.5)")
        h("Ipop[8] netConn_projIE_gaba[682] = new NetCon(&v(0.5), syn_projIE_gaba[682], 20.0, 1.5, -0.0016545403)")  

        # Connection 683: cell 8, seg 0 (0.5) [0.5 on Ipop[8]] -> cell 43, seg 0 (0.5) [0.5 on Epop[43]], weight: -0.0016545403, delay 1.5
        h("Epop[43] syn_projIE_gaba[683] = new gaba(0.5)")
        h("Ipop[8] netConn_projIE_gaba[683] = new NetCon(&v(0.5), syn_projIE_gaba[683], 20.0, 1.5, -0.0016545403)")  

        # Connection 684: cell 8, seg 0 (0.5) [0.5 on Ipop[8]] -> cell 44, seg 0 (0.5) [0.5 on Epop[44]], weight: -0.0016545403, delay 1.5
        h("Epop[44] syn_projIE_gaba[684] = new gaba(0.5)")
        h("Ipop[8] netConn_projIE_gaba[684] = new NetCon(&v(0.5), syn_projIE_gaba[684], 20.0, 1.5, -0.0016545403)")  

        # Connection 685: cell 8, seg 0 (0.5) [0.5 on Ipop[8]] -> cell 45, seg 0 (0.5) [0.5 on Epop[45]], weight: -0.0016545403, delay 1.5
        h("Epop[45] syn_projIE_gaba[685] = new gaba(0.5)")
        h("Ipop[8] netConn_projIE_gaba[685] = new NetCon(&v(0.5), syn_projIE_gaba[685], 20.0, 1.5, -0.0016545403)")  

        # Connection 686: cell 8, seg 0 (0.5) [0.5 on Ipop[8]] -> cell 46, seg 0 (0.5) [0.5 on Epop[46]], weight: -0.0016545403, delay 1.5
        h("Epop[46] syn_projIE_gaba[686] = new gaba(0.5)")
        h("Ipop[8] netConn_projIE_gaba[686] = new NetCon(&v(0.5), syn_projIE_gaba[686], 20.0, 1.5, -0.0016545403)")  

        # Connection 687: cell 8, seg 0 (0.5) [0.5 on Ipop[8]] -> cell 47, seg 0 (0.5) [0.5 on Epop[47]], weight: -0.0016545403, delay 1.5
        h("Epop[47] syn_projIE_gaba[687] = new gaba(0.5)")
        h("Ipop[8] netConn_projIE_gaba[687] = new NetCon(&v(0.5), syn_projIE_gaba[687], 20.0, 1.5, -0.0016545403)")  

        # Connection 688: cell 8, seg 0 (0.5) [0.5 on Ipop[8]] -> cell 48, seg 0 (0.5) [0.5 on Epop[48]], weight: -0.0016545403, delay 1.5
        h("Epop[48] syn_projIE_gaba[688] = new gaba(0.5)")
        h("Ipop[8] netConn_projIE_gaba[688] = new NetCon(&v(0.5), syn_projIE_gaba[688], 20.0, 1.5, -0.0016545403)")  

        # Connection 689: cell 8, seg 0 (0.5) [0.5 on Ipop[8]] -> cell 49, seg 0 (0.5) [0.5 on Epop[49]], weight: -0.0016545403, delay 1.5
        h("Epop[49] syn_projIE_gaba[689] = new gaba(0.5)")
        h("Ipop[8] netConn_projIE_gaba[689] = new NetCon(&v(0.5), syn_projIE_gaba[689], 20.0, 1.5, -0.0016545403)")  

        # Connection 690: cell 8, seg 0 (0.5) [0.5 on Ipop[8]] -> cell 50, seg 0 (0.5) [0.5 on Epop[50]], weight: -0.0016545403, delay 1.5
        h("Epop[50] syn_projIE_gaba[690] = new gaba(0.5)")
        h("Ipop[8] netConn_projIE_gaba[690] = new NetCon(&v(0.5), syn_projIE_gaba[690], 20.0, 1.5, -0.0016545403)")  

        # Connection 691: cell 8, seg 0 (0.5) [0.5 on Ipop[8]] -> cell 51, seg 0 (0.5) [0.5 on Epop[51]], weight: -0.0016545403, delay 1.5
        h("Epop[51] syn_projIE_gaba[691] = new gaba(0.5)")
        h("Ipop[8] netConn_projIE_gaba[691] = new NetCon(&v(0.5), syn_projIE_gaba[691], 20.0, 1.5, -0.0016545403)")  

        # Connection 692: cell 8, seg 0 (0.5) [0.5 on Ipop[8]] -> cell 52, seg 0 (0.5) [0.5 on Epop[52]], weight: -0.0016545403, delay 1.5
        h("Epop[52] syn_projIE_gaba[692] = new gaba(0.5)")
        h("Ipop[8] netConn_projIE_gaba[692] = new NetCon(&v(0.5), syn_projIE_gaba[692], 20.0, 1.5, -0.0016545403)")  

        # Connection 693: cell 8, seg 0 (0.5) [0.5 on Ipop[8]] -> cell 53, seg 0 (0.5) [0.5 on Epop[53]], weight: -0.0016545403, delay 1.5
        h("Epop[53] syn_projIE_gaba[693] = new gaba(0.5)")
        h("Ipop[8] netConn_projIE_gaba[693] = new NetCon(&v(0.5), syn_projIE_gaba[693], 20.0, 1.5, -0.0016545403)")  

        # Connection 694: cell 8, seg 0 (0.5) [0.5 on Ipop[8]] -> cell 54, seg 0 (0.5) [0.5 on Epop[54]], weight: -0.0016545403, delay 1.5
        h("Epop[54] syn_projIE_gaba[694] = new gaba(0.5)")
        h("Ipop[8] netConn_projIE_gaba[694] = new NetCon(&v(0.5), syn_projIE_gaba[694], 20.0, 1.5, -0.0016545403)")  

        # Connection 695: cell 8, seg 0 (0.5) [0.5 on Ipop[8]] -> cell 55, seg 0 (0.5) [0.5 on Epop[55]], weight: -0.0016545403, delay 1.5
        h("Epop[55] syn_projIE_gaba[695] = new gaba(0.5)")
        h("Ipop[8] netConn_projIE_gaba[695] = new NetCon(&v(0.5), syn_projIE_gaba[695], 20.0, 1.5, -0.0016545403)")  

        # Connection 696: cell 8, seg 0 (0.5) [0.5 on Ipop[8]] -> cell 56, seg 0 (0.5) [0.5 on Epop[56]], weight: -0.0016545403, delay 1.5
        h("Epop[56] syn_projIE_gaba[696] = new gaba(0.5)")
        h("Ipop[8] netConn_projIE_gaba[696] = new NetCon(&v(0.5), syn_projIE_gaba[696], 20.0, 1.5, -0.0016545403)")  

        # Connection 697: cell 8, seg 0 (0.5) [0.5 on Ipop[8]] -> cell 57, seg 0 (0.5) [0.5 on Epop[57]], weight: -0.0016545403, delay 1.5
        h("Epop[57] syn_projIE_gaba[697] = new gaba(0.5)")
        h("Ipop[8] netConn_projIE_gaba[697] = new NetCon(&v(0.5), syn_projIE_gaba[697], 20.0, 1.5, -0.0016545403)")  

        # Connection 698: cell 8, seg 0 (0.5) [0.5 on Ipop[8]] -> cell 58, seg 0 (0.5) [0.5 on Epop[58]], weight: -0.0016545403, delay 1.5
        h("Epop[58] syn_projIE_gaba[698] = new gaba(0.5)")
        h("Ipop[8] netConn_projIE_gaba[698] = new NetCon(&v(0.5), syn_projIE_gaba[698], 20.0, 1.5, -0.0016545403)")  

        # Connection 699: cell 8, seg 0 (0.5) [0.5 on Ipop[8]] -> cell 59, seg 0 (0.5) [0.5 on Epop[59]], weight: -0.0016545403, delay 1.5
        h("Epop[59] syn_projIE_gaba[699] = new gaba(0.5)")
        h("Ipop[8] netConn_projIE_gaba[699] = new NetCon(&v(0.5), syn_projIE_gaba[699], 20.0, 1.5, -0.0016545403)")  

        # Connection 700: cell 8, seg 0 (0.5) [0.5 on Ipop[8]] -> cell 60, seg 0 (0.5) [0.5 on Epop[60]], weight: -0.0016545403, delay 1.5
        h("Epop[60] syn_projIE_gaba[700] = new gaba(0.5)")
        h("Ipop[8] netConn_projIE_gaba[700] = new NetCon(&v(0.5), syn_projIE_gaba[700], 20.0, 1.5, -0.0016545403)")  

        # Connection 701: cell 8, seg 0 (0.5) [0.5 on Ipop[8]] -> cell 61, seg 0 (0.5) [0.5 on Epop[61]], weight: -0.0016545403, delay 1.5
        h("Epop[61] syn_projIE_gaba[701] = new gaba(0.5)")
        h("Ipop[8] netConn_projIE_gaba[701] = new NetCon(&v(0.5), syn_projIE_gaba[701], 20.0, 1.5, -0.0016545403)")  

        # Connection 702: cell 8, seg 0 (0.5) [0.5 on Ipop[8]] -> cell 62, seg 0 (0.5) [0.5 on Epop[62]], weight: -0.0016545403, delay 1.5
        h("Epop[62] syn_projIE_gaba[702] = new gaba(0.5)")
        h("Ipop[8] netConn_projIE_gaba[702] = new NetCon(&v(0.5), syn_projIE_gaba[702], 20.0, 1.5, -0.0016545403)")  

        # Connection 703: cell 8, seg 0 (0.5) [0.5 on Ipop[8]] -> cell 63, seg 0 (0.5) [0.5 on Epop[63]], weight: -0.0016545403, delay 1.5
        h("Epop[63] syn_projIE_gaba[703] = new gaba(0.5)")
        h("Ipop[8] netConn_projIE_gaba[703] = new NetCon(&v(0.5), syn_projIE_gaba[703], 20.0, 1.5, -0.0016545403)")  

        # Connection 704: cell 8, seg 0 (0.5) [0.5 on Ipop[8]] -> cell 64, seg 0 (0.5) [0.5 on Epop[64]], weight: -0.0016545403, delay 1.5
        h("Epop[64] syn_projIE_gaba[704] = new gaba(0.5)")
        h("Ipop[8] netConn_projIE_gaba[704] = new NetCon(&v(0.5), syn_projIE_gaba[704], 20.0, 1.5, -0.0016545403)")  

        # Connection 705: cell 8, seg 0 (0.5) [0.5 on Ipop[8]] -> cell 65, seg 0 (0.5) [0.5 on Epop[65]], weight: -0.0016545403, delay 1.5
        h("Epop[65] syn_projIE_gaba[705] = new gaba(0.5)")
        h("Ipop[8] netConn_projIE_gaba[705] = new NetCon(&v(0.5), syn_projIE_gaba[705], 20.0, 1.5, -0.0016545403)")  

        # Connection 706: cell 8, seg 0 (0.5) [0.5 on Ipop[8]] -> cell 66, seg 0 (0.5) [0.5 on Epop[66]], weight: -0.0016545403, delay 1.5
        h("Epop[66] syn_projIE_gaba[706] = new gaba(0.5)")
        h("Ipop[8] netConn_projIE_gaba[706] = new NetCon(&v(0.5), syn_projIE_gaba[706], 20.0, 1.5, -0.0016545403)")  

        # Connection 707: cell 8, seg 0 (0.5) [0.5 on Ipop[8]] -> cell 67, seg 0 (0.5) [0.5 on Epop[67]], weight: -0.0016545403, delay 1.5
        h("Epop[67] syn_projIE_gaba[707] = new gaba(0.5)")
        h("Ipop[8] netConn_projIE_gaba[707] = new NetCon(&v(0.5), syn_projIE_gaba[707], 20.0, 1.5, -0.0016545403)")  

        # Connection 708: cell 8, seg 0 (0.5) [0.5 on Ipop[8]] -> cell 68, seg 0 (0.5) [0.5 on Epop[68]], weight: -0.0016545403, delay 1.5
        h("Epop[68] syn_projIE_gaba[708] = new gaba(0.5)")
        h("Ipop[8] netConn_projIE_gaba[708] = new NetCon(&v(0.5), syn_projIE_gaba[708], 20.0, 1.5, -0.0016545403)")  

        # Connection 709: cell 8, seg 0 (0.5) [0.5 on Ipop[8]] -> cell 69, seg 0 (0.5) [0.5 on Epop[69]], weight: -0.0016545403, delay 1.5
        h("Epop[69] syn_projIE_gaba[709] = new gaba(0.5)")
        h("Ipop[8] netConn_projIE_gaba[709] = new NetCon(&v(0.5), syn_projIE_gaba[709], 20.0, 1.5, -0.0016545403)")  

        # Connection 710: cell 8, seg 0 (0.5) [0.5 on Ipop[8]] -> cell 70, seg 0 (0.5) [0.5 on Epop[70]], weight: -0.0016545403, delay 1.5
        h("Epop[70] syn_projIE_gaba[710] = new gaba(0.5)")
        h("Ipop[8] netConn_projIE_gaba[710] = new NetCon(&v(0.5), syn_projIE_gaba[710], 20.0, 1.5, -0.0016545403)")  

        # Connection 711: cell 8, seg 0 (0.5) [0.5 on Ipop[8]] -> cell 71, seg 0 (0.5) [0.5 on Epop[71]], weight: -0.0016545403, delay 1.5
        h("Epop[71] syn_projIE_gaba[711] = new gaba(0.5)")
        h("Ipop[8] netConn_projIE_gaba[711] = new NetCon(&v(0.5), syn_projIE_gaba[711], 20.0, 1.5, -0.0016545403)")  

        # Connection 712: cell 8, seg 0 (0.5) [0.5 on Ipop[8]] -> cell 72, seg 0 (0.5) [0.5 on Epop[72]], weight: -0.0016545403, delay 1.5
        h("Epop[72] syn_projIE_gaba[712] = new gaba(0.5)")
        h("Ipop[8] netConn_projIE_gaba[712] = new NetCon(&v(0.5), syn_projIE_gaba[712], 20.0, 1.5, -0.0016545403)")  

        # Connection 713: cell 8, seg 0 (0.5) [0.5 on Ipop[8]] -> cell 73, seg 0 (0.5) [0.5 on Epop[73]], weight: -0.0016545403, delay 1.5
        h("Epop[73] syn_projIE_gaba[713] = new gaba(0.5)")
        h("Ipop[8] netConn_projIE_gaba[713] = new NetCon(&v(0.5), syn_projIE_gaba[713], 20.0, 1.5, -0.0016545403)")  

        # Connection 714: cell 8, seg 0 (0.5) [0.5 on Ipop[8]] -> cell 74, seg 0 (0.5) [0.5 on Epop[74]], weight: -0.0016545403, delay 1.5
        h("Epop[74] syn_projIE_gaba[714] = new gaba(0.5)")
        h("Ipop[8] netConn_projIE_gaba[714] = new NetCon(&v(0.5), syn_projIE_gaba[714], 20.0, 1.5, -0.0016545403)")  

        # Connection 715: cell 8, seg 0 (0.5) [0.5 on Ipop[8]] -> cell 75, seg 0 (0.5) [0.5 on Epop[75]], weight: -0.0016545403, delay 1.5
        h("Epop[75] syn_projIE_gaba[715] = new gaba(0.5)")
        h("Ipop[8] netConn_projIE_gaba[715] = new NetCon(&v(0.5), syn_projIE_gaba[715], 20.0, 1.5, -0.0016545403)")  

        # Connection 716: cell 8, seg 0 (0.5) [0.5 on Ipop[8]] -> cell 76, seg 0 (0.5) [0.5 on Epop[76]], weight: -0.0016545403, delay 1.5
        h("Epop[76] syn_projIE_gaba[716] = new gaba(0.5)")
        h("Ipop[8] netConn_projIE_gaba[716] = new NetCon(&v(0.5), syn_projIE_gaba[716], 20.0, 1.5, -0.0016545403)")  

        # Connection 717: cell 8, seg 0 (0.5) [0.5 on Ipop[8]] -> cell 77, seg 0 (0.5) [0.5 on Epop[77]], weight: -0.0016545403, delay 1.5
        h("Epop[77] syn_projIE_gaba[717] = new gaba(0.5)")
        h("Ipop[8] netConn_projIE_gaba[717] = new NetCon(&v(0.5), syn_projIE_gaba[717], 20.0, 1.5, -0.0016545403)")  

        # Connection 718: cell 8, seg 0 (0.5) [0.5 on Ipop[8]] -> cell 78, seg 0 (0.5) [0.5 on Epop[78]], weight: -0.0016545403, delay 1.5
        h("Epop[78] syn_projIE_gaba[718] = new gaba(0.5)")
        h("Ipop[8] netConn_projIE_gaba[718] = new NetCon(&v(0.5), syn_projIE_gaba[718], 20.0, 1.5, -0.0016545403)")  

        # Connection 719: cell 8, seg 0 (0.5) [0.5 on Ipop[8]] -> cell 79, seg 0 (0.5) [0.5 on Epop[79]], weight: -0.0016545403, delay 1.5
        h("Epop[79] syn_projIE_gaba[719] = new gaba(0.5)")
        h("Ipop[8] netConn_projIE_gaba[719] = new NetCon(&v(0.5), syn_projIE_gaba[719], 20.0, 1.5, -0.0016545403)")  

        # Connection 720: cell 9, seg 0 (0.5) [0.5 on Ipop[9]] -> cell 0, seg 0 (0.5) [0.5 on Epop[0]], weight: -0.0016545403, delay 1.5
        h("Epop[0] syn_projIE_gaba[720] = new gaba(0.5)")
        h("Ipop[9] netConn_projIE_gaba[720] = new NetCon(&v(0.5), syn_projIE_gaba[720], 20.0, 1.5, -0.0016545403)")  

        # Connection 721: cell 9, seg 0 (0.5) [0.5 on Ipop[9]] -> cell 1, seg 0 (0.5) [0.5 on Epop[1]], weight: -0.0016545403, delay 1.5
        h("Epop[1] syn_projIE_gaba[721] = new gaba(0.5)")
        h("Ipop[9] netConn_projIE_gaba[721] = new NetCon(&v(0.5), syn_projIE_gaba[721], 20.0, 1.5, -0.0016545403)")  

        # Connection 722: cell 9, seg 0 (0.5) [0.5 on Ipop[9]] -> cell 2, seg 0 (0.5) [0.5 on Epop[2]], weight: -0.0016545403, delay 1.5
        h("Epop[2] syn_projIE_gaba[722] = new gaba(0.5)")
        h("Ipop[9] netConn_projIE_gaba[722] = new NetCon(&v(0.5), syn_projIE_gaba[722], 20.0, 1.5, -0.0016545403)")  

        # Connection 723: cell 9, seg 0 (0.5) [0.5 on Ipop[9]] -> cell 3, seg 0 (0.5) [0.5 on Epop[3]], weight: -0.0016545403, delay 1.5
        h("Epop[3] syn_projIE_gaba[723] = new gaba(0.5)")
        h("Ipop[9] netConn_projIE_gaba[723] = new NetCon(&v(0.5), syn_projIE_gaba[723], 20.0, 1.5, -0.0016545403)")  

        # Connection 724: cell 9, seg 0 (0.5) [0.5 on Ipop[9]] -> cell 4, seg 0 (0.5) [0.5 on Epop[4]], weight: -0.0016545403, delay 1.5
        h("Epop[4] syn_projIE_gaba[724] = new gaba(0.5)")
        h("Ipop[9] netConn_projIE_gaba[724] = new NetCon(&v(0.5), syn_projIE_gaba[724], 20.0, 1.5, -0.0016545403)")  

        # Connection 725: cell 9, seg 0 (0.5) [0.5 on Ipop[9]] -> cell 5, seg 0 (0.5) [0.5 on Epop[5]], weight: -0.0016545403, delay 1.5
        h("Epop[5] syn_projIE_gaba[725] = new gaba(0.5)")
        h("Ipop[9] netConn_projIE_gaba[725] = new NetCon(&v(0.5), syn_projIE_gaba[725], 20.0, 1.5, -0.0016545403)")  

        # Connection 726: cell 9, seg 0 (0.5) [0.5 on Ipop[9]] -> cell 6, seg 0 (0.5) [0.5 on Epop[6]], weight: -0.0016545403, delay 1.5
        h("Epop[6] syn_projIE_gaba[726] = new gaba(0.5)")
        h("Ipop[9] netConn_projIE_gaba[726] = new NetCon(&v(0.5), syn_projIE_gaba[726], 20.0, 1.5, -0.0016545403)")  

        # Connection 727: cell 9, seg 0 (0.5) [0.5 on Ipop[9]] -> cell 7, seg 0 (0.5) [0.5 on Epop[7]], weight: -0.0016545403, delay 1.5
        h("Epop[7] syn_projIE_gaba[727] = new gaba(0.5)")
        h("Ipop[9] netConn_projIE_gaba[727] = new NetCon(&v(0.5), syn_projIE_gaba[727], 20.0, 1.5, -0.0016545403)")  

        # Connection 728: cell 9, seg 0 (0.5) [0.5 on Ipop[9]] -> cell 8, seg 0 (0.5) [0.5 on Epop[8]], weight: -0.0016545403, delay 1.5
        h("Epop[8] syn_projIE_gaba[728] = new gaba(0.5)")
        h("Ipop[9] netConn_projIE_gaba[728] = new NetCon(&v(0.5), syn_projIE_gaba[728], 20.0, 1.5, -0.0016545403)")  

        # Connection 729: cell 9, seg 0 (0.5) [0.5 on Ipop[9]] -> cell 9, seg 0 (0.5) [0.5 on Epop[9]], weight: -0.0016545403, delay 1.5
        h("Epop[9] syn_projIE_gaba[729] = new gaba(0.5)")
        h("Ipop[9] netConn_projIE_gaba[729] = new NetCon(&v(0.5), syn_projIE_gaba[729], 20.0, 1.5, -0.0016545403)")  

        # Connection 730: cell 9, seg 0 (0.5) [0.5 on Ipop[9]] -> cell 10, seg 0 (0.5) [0.5 on Epop[10]], weight: -0.0016545403, delay 1.5
        h("Epop[10] syn_projIE_gaba[730] = new gaba(0.5)")
        h("Ipop[9] netConn_projIE_gaba[730] = new NetCon(&v(0.5), syn_projIE_gaba[730], 20.0, 1.5, -0.0016545403)")  

        # Connection 731: cell 9, seg 0 (0.5) [0.5 on Ipop[9]] -> cell 11, seg 0 (0.5) [0.5 on Epop[11]], weight: -0.0016545403, delay 1.5
        h("Epop[11] syn_projIE_gaba[731] = new gaba(0.5)")
        h("Ipop[9] netConn_projIE_gaba[731] = new NetCon(&v(0.5), syn_projIE_gaba[731], 20.0, 1.5, -0.0016545403)")  

        # Connection 732: cell 9, seg 0 (0.5) [0.5 on Ipop[9]] -> cell 12, seg 0 (0.5) [0.5 on Epop[12]], weight: -0.0016545403, delay 1.5
        h("Epop[12] syn_projIE_gaba[732] = new gaba(0.5)")
        h("Ipop[9] netConn_projIE_gaba[732] = new NetCon(&v(0.5), syn_projIE_gaba[732], 20.0, 1.5, -0.0016545403)")  

        # Connection 733: cell 9, seg 0 (0.5) [0.5 on Ipop[9]] -> cell 13, seg 0 (0.5) [0.5 on Epop[13]], weight: -0.0016545403, delay 1.5
        h("Epop[13] syn_projIE_gaba[733] = new gaba(0.5)")
        h("Ipop[9] netConn_projIE_gaba[733] = new NetCon(&v(0.5), syn_projIE_gaba[733], 20.0, 1.5, -0.0016545403)")  

        # Connection 734: cell 9, seg 0 (0.5) [0.5 on Ipop[9]] -> cell 14, seg 0 (0.5) [0.5 on Epop[14]], weight: -0.0016545403, delay 1.5
        h("Epop[14] syn_projIE_gaba[734] = new gaba(0.5)")
        h("Ipop[9] netConn_projIE_gaba[734] = new NetCon(&v(0.5), syn_projIE_gaba[734], 20.0, 1.5, -0.0016545403)")  

        # Connection 735: cell 9, seg 0 (0.5) [0.5 on Ipop[9]] -> cell 15, seg 0 (0.5) [0.5 on Epop[15]], weight: -0.0016545403, delay 1.5
        h("Epop[15] syn_projIE_gaba[735] = new gaba(0.5)")
        h("Ipop[9] netConn_projIE_gaba[735] = new NetCon(&v(0.5), syn_projIE_gaba[735], 20.0, 1.5, -0.0016545403)")  

        # Connection 736: cell 9, seg 0 (0.5) [0.5 on Ipop[9]] -> cell 16, seg 0 (0.5) [0.5 on Epop[16]], weight: -0.0016545403, delay 1.5
        h("Epop[16] syn_projIE_gaba[736] = new gaba(0.5)")
        h("Ipop[9] netConn_projIE_gaba[736] = new NetCon(&v(0.5), syn_projIE_gaba[736], 20.0, 1.5, -0.0016545403)")  

        # Connection 737: cell 9, seg 0 (0.5) [0.5 on Ipop[9]] -> cell 17, seg 0 (0.5) [0.5 on Epop[17]], weight: -0.0016545403, delay 1.5
        h("Epop[17] syn_projIE_gaba[737] = new gaba(0.5)")
        h("Ipop[9] netConn_projIE_gaba[737] = new NetCon(&v(0.5), syn_projIE_gaba[737], 20.0, 1.5, -0.0016545403)")  

        # Connection 738: cell 9, seg 0 (0.5) [0.5 on Ipop[9]] -> cell 18, seg 0 (0.5) [0.5 on Epop[18]], weight: -0.0016545403, delay 1.5
        h("Epop[18] syn_projIE_gaba[738] = new gaba(0.5)")
        h("Ipop[9] netConn_projIE_gaba[738] = new NetCon(&v(0.5), syn_projIE_gaba[738], 20.0, 1.5, -0.0016545403)")  

        # Connection 739: cell 9, seg 0 (0.5) [0.5 on Ipop[9]] -> cell 19, seg 0 (0.5) [0.5 on Epop[19]], weight: -0.0016545403, delay 1.5
        h("Epop[19] syn_projIE_gaba[739] = new gaba(0.5)")
        h("Ipop[9] netConn_projIE_gaba[739] = new NetCon(&v(0.5), syn_projIE_gaba[739], 20.0, 1.5, -0.0016545403)")  

        # Connection 740: cell 9, seg 0 (0.5) [0.5 on Ipop[9]] -> cell 20, seg 0 (0.5) [0.5 on Epop[20]], weight: -0.0016545403, delay 1.5
        h("Epop[20] syn_projIE_gaba[740] = new gaba(0.5)")
        h("Ipop[9] netConn_projIE_gaba[740] = new NetCon(&v(0.5), syn_projIE_gaba[740], 20.0, 1.5, -0.0016545403)")  

        # Connection 741: cell 9, seg 0 (0.5) [0.5 on Ipop[9]] -> cell 21, seg 0 (0.5) [0.5 on Epop[21]], weight: -0.0016545403, delay 1.5
        h("Epop[21] syn_projIE_gaba[741] = new gaba(0.5)")
        h("Ipop[9] netConn_projIE_gaba[741] = new NetCon(&v(0.5), syn_projIE_gaba[741], 20.0, 1.5, -0.0016545403)")  

        # Connection 742: cell 9, seg 0 (0.5) [0.5 on Ipop[9]] -> cell 22, seg 0 (0.5) [0.5 on Epop[22]], weight: -0.0016545403, delay 1.5
        h("Epop[22] syn_projIE_gaba[742] = new gaba(0.5)")
        h("Ipop[9] netConn_projIE_gaba[742] = new NetCon(&v(0.5), syn_projIE_gaba[742], 20.0, 1.5, -0.0016545403)")  

        # Connection 743: cell 9, seg 0 (0.5) [0.5 on Ipop[9]] -> cell 23, seg 0 (0.5) [0.5 on Epop[23]], weight: -0.0016545403, delay 1.5
        h("Epop[23] syn_projIE_gaba[743] = new gaba(0.5)")
        h("Ipop[9] netConn_projIE_gaba[743] = new NetCon(&v(0.5), syn_projIE_gaba[743], 20.0, 1.5, -0.0016545403)")  

        # Connection 744: cell 9, seg 0 (0.5) [0.5 on Ipop[9]] -> cell 24, seg 0 (0.5) [0.5 on Epop[24]], weight: -0.0016545403, delay 1.5
        h("Epop[24] syn_projIE_gaba[744] = new gaba(0.5)")
        h("Ipop[9] netConn_projIE_gaba[744] = new NetCon(&v(0.5), syn_projIE_gaba[744], 20.0, 1.5, -0.0016545403)")  

        # Connection 745: cell 9, seg 0 (0.5) [0.5 on Ipop[9]] -> cell 25, seg 0 (0.5) [0.5 on Epop[25]], weight: -0.0016545403, delay 1.5
        h("Epop[25] syn_projIE_gaba[745] = new gaba(0.5)")
        h("Ipop[9] netConn_projIE_gaba[745] = new NetCon(&v(0.5), syn_projIE_gaba[745], 20.0, 1.5, -0.0016545403)")  

        # Connection 746: cell 9, seg 0 (0.5) [0.5 on Ipop[9]] -> cell 26, seg 0 (0.5) [0.5 on Epop[26]], weight: -0.0016545403, delay 1.5
        h("Epop[26] syn_projIE_gaba[746] = new gaba(0.5)")
        h("Ipop[9] netConn_projIE_gaba[746] = new NetCon(&v(0.5), syn_projIE_gaba[746], 20.0, 1.5, -0.0016545403)")  

        # Connection 747: cell 9, seg 0 (0.5) [0.5 on Ipop[9]] -> cell 27, seg 0 (0.5) [0.5 on Epop[27]], weight: -0.0016545403, delay 1.5
        h("Epop[27] syn_projIE_gaba[747] = new gaba(0.5)")
        h("Ipop[9] netConn_projIE_gaba[747] = new NetCon(&v(0.5), syn_projIE_gaba[747], 20.0, 1.5, -0.0016545403)")  

        # Connection 748: cell 9, seg 0 (0.5) [0.5 on Ipop[9]] -> cell 28, seg 0 (0.5) [0.5 on Epop[28]], weight: -0.0016545403, delay 1.5
        h("Epop[28] syn_projIE_gaba[748] = new gaba(0.5)")
        h("Ipop[9] netConn_projIE_gaba[748] = new NetCon(&v(0.5), syn_projIE_gaba[748], 20.0, 1.5, -0.0016545403)")  

        # Connection 749: cell 9, seg 0 (0.5) [0.5 on Ipop[9]] -> cell 29, seg 0 (0.5) [0.5 on Epop[29]], weight: -0.0016545403, delay 1.5
        h("Epop[29] syn_projIE_gaba[749] = new gaba(0.5)")
        h("Ipop[9] netConn_projIE_gaba[749] = new NetCon(&v(0.5), syn_projIE_gaba[749], 20.0, 1.5, -0.0016545403)")  

        # Connection 750: cell 9, seg 0 (0.5) [0.5 on Ipop[9]] -> cell 30, seg 0 (0.5) [0.5 on Epop[30]], weight: -0.0016545403, delay 1.5
        h("Epop[30] syn_projIE_gaba[750] = new gaba(0.5)")
        h("Ipop[9] netConn_projIE_gaba[750] = new NetCon(&v(0.5), syn_projIE_gaba[750], 20.0, 1.5, -0.0016545403)")  

        # Connection 751: cell 9, seg 0 (0.5) [0.5 on Ipop[9]] -> cell 31, seg 0 (0.5) [0.5 on Epop[31]], weight: -0.0016545403, delay 1.5
        h("Epop[31] syn_projIE_gaba[751] = new gaba(0.5)")
        h("Ipop[9] netConn_projIE_gaba[751] = new NetCon(&v(0.5), syn_projIE_gaba[751], 20.0, 1.5, -0.0016545403)")  

        # Connection 752: cell 9, seg 0 (0.5) [0.5 on Ipop[9]] -> cell 32, seg 0 (0.5) [0.5 on Epop[32]], weight: -0.0016545403, delay 1.5
        h("Epop[32] syn_projIE_gaba[752] = new gaba(0.5)")
        h("Ipop[9] netConn_projIE_gaba[752] = new NetCon(&v(0.5), syn_projIE_gaba[752], 20.0, 1.5, -0.0016545403)")  

        # Connection 753: cell 9, seg 0 (0.5) [0.5 on Ipop[9]] -> cell 33, seg 0 (0.5) [0.5 on Epop[33]], weight: -0.0016545403, delay 1.5
        h("Epop[33] syn_projIE_gaba[753] = new gaba(0.5)")
        h("Ipop[9] netConn_projIE_gaba[753] = new NetCon(&v(0.5), syn_projIE_gaba[753], 20.0, 1.5, -0.0016545403)")  

        # Connection 754: cell 9, seg 0 (0.5) [0.5 on Ipop[9]] -> cell 34, seg 0 (0.5) [0.5 on Epop[34]], weight: -0.0016545403, delay 1.5
        h("Epop[34] syn_projIE_gaba[754] = new gaba(0.5)")
        h("Ipop[9] netConn_projIE_gaba[754] = new NetCon(&v(0.5), syn_projIE_gaba[754], 20.0, 1.5, -0.0016545403)")  

        # Connection 755: cell 9, seg 0 (0.5) [0.5 on Ipop[9]] -> cell 35, seg 0 (0.5) [0.5 on Epop[35]], weight: -0.0016545403, delay 1.5
        h("Epop[35] syn_projIE_gaba[755] = new gaba(0.5)")
        h("Ipop[9] netConn_projIE_gaba[755] = new NetCon(&v(0.5), syn_projIE_gaba[755], 20.0, 1.5, -0.0016545403)")  

        # Connection 756: cell 9, seg 0 (0.5) [0.5 on Ipop[9]] -> cell 36, seg 0 (0.5) [0.5 on Epop[36]], weight: -0.0016545403, delay 1.5
        h("Epop[36] syn_projIE_gaba[756] = new gaba(0.5)")
        h("Ipop[9] netConn_projIE_gaba[756] = new NetCon(&v(0.5), syn_projIE_gaba[756], 20.0, 1.5, -0.0016545403)")  

        # Connection 757: cell 9, seg 0 (0.5) [0.5 on Ipop[9]] -> cell 37, seg 0 (0.5) [0.5 on Epop[37]], weight: -0.0016545403, delay 1.5
        h("Epop[37] syn_projIE_gaba[757] = new gaba(0.5)")
        h("Ipop[9] netConn_projIE_gaba[757] = new NetCon(&v(0.5), syn_projIE_gaba[757], 20.0, 1.5, -0.0016545403)")  

        # Connection 758: cell 9, seg 0 (0.5) [0.5 on Ipop[9]] -> cell 38, seg 0 (0.5) [0.5 on Epop[38]], weight: -0.0016545403, delay 1.5
        h("Epop[38] syn_projIE_gaba[758] = new gaba(0.5)")
        h("Ipop[9] netConn_projIE_gaba[758] = new NetCon(&v(0.5), syn_projIE_gaba[758], 20.0, 1.5, -0.0016545403)")  

        # Connection 759: cell 9, seg 0 (0.5) [0.5 on Ipop[9]] -> cell 39, seg 0 (0.5) [0.5 on Epop[39]], weight: -0.0016545403, delay 1.5
        h("Epop[39] syn_projIE_gaba[759] = new gaba(0.5)")
        h("Ipop[9] netConn_projIE_gaba[759] = new NetCon(&v(0.5), syn_projIE_gaba[759], 20.0, 1.5, -0.0016545403)")  

        # Connection 760: cell 9, seg 0 (0.5) [0.5 on Ipop[9]] -> cell 40, seg 0 (0.5) [0.5 on Epop[40]], weight: -0.0016545403, delay 1.5
        h("Epop[40] syn_projIE_gaba[760] = new gaba(0.5)")
        h("Ipop[9] netConn_projIE_gaba[760] = new NetCon(&v(0.5), syn_projIE_gaba[760], 20.0, 1.5, -0.0016545403)")  

        # Connection 761: cell 9, seg 0 (0.5) [0.5 on Ipop[9]] -> cell 41, seg 0 (0.5) [0.5 on Epop[41]], weight: -0.0016545403, delay 1.5
        h("Epop[41] syn_projIE_gaba[761] = new gaba(0.5)")
        h("Ipop[9] netConn_projIE_gaba[761] = new NetCon(&v(0.5), syn_projIE_gaba[761], 20.0, 1.5, -0.0016545403)")  

        # Connection 762: cell 9, seg 0 (0.5) [0.5 on Ipop[9]] -> cell 42, seg 0 (0.5) [0.5 on Epop[42]], weight: -0.0016545403, delay 1.5
        h("Epop[42] syn_projIE_gaba[762] = new gaba(0.5)")
        h("Ipop[9] netConn_projIE_gaba[762] = new NetCon(&v(0.5), syn_projIE_gaba[762], 20.0, 1.5, -0.0016545403)")  

        # Connection 763: cell 9, seg 0 (0.5) [0.5 on Ipop[9]] -> cell 43, seg 0 (0.5) [0.5 on Epop[43]], weight: -0.0016545403, delay 1.5
        h("Epop[43] syn_projIE_gaba[763] = new gaba(0.5)")
        h("Ipop[9] netConn_projIE_gaba[763] = new NetCon(&v(0.5), syn_projIE_gaba[763], 20.0, 1.5, -0.0016545403)")  

        # Connection 764: cell 9, seg 0 (0.5) [0.5 on Ipop[9]] -> cell 44, seg 0 (0.5) [0.5 on Epop[44]], weight: -0.0016545403, delay 1.5
        h("Epop[44] syn_projIE_gaba[764] = new gaba(0.5)")
        h("Ipop[9] netConn_projIE_gaba[764] = new NetCon(&v(0.5), syn_projIE_gaba[764], 20.0, 1.5, -0.0016545403)")  

        # Connection 765: cell 9, seg 0 (0.5) [0.5 on Ipop[9]] -> cell 45, seg 0 (0.5) [0.5 on Epop[45]], weight: -0.0016545403, delay 1.5
        h("Epop[45] syn_projIE_gaba[765] = new gaba(0.5)")
        h("Ipop[9] netConn_projIE_gaba[765] = new NetCon(&v(0.5), syn_projIE_gaba[765], 20.0, 1.5, -0.0016545403)")  

        # Connection 766: cell 9, seg 0 (0.5) [0.5 on Ipop[9]] -> cell 46, seg 0 (0.5) [0.5 on Epop[46]], weight: -0.0016545403, delay 1.5
        h("Epop[46] syn_projIE_gaba[766] = new gaba(0.5)")
        h("Ipop[9] netConn_projIE_gaba[766] = new NetCon(&v(0.5), syn_projIE_gaba[766], 20.0, 1.5, -0.0016545403)")  

        # Connection 767: cell 9, seg 0 (0.5) [0.5 on Ipop[9]] -> cell 47, seg 0 (0.5) [0.5 on Epop[47]], weight: -0.0016545403, delay 1.5
        h("Epop[47] syn_projIE_gaba[767] = new gaba(0.5)")
        h("Ipop[9] netConn_projIE_gaba[767] = new NetCon(&v(0.5), syn_projIE_gaba[767], 20.0, 1.5, -0.0016545403)")  

        # Connection 768: cell 9, seg 0 (0.5) [0.5 on Ipop[9]] -> cell 48, seg 0 (0.5) [0.5 on Epop[48]], weight: -0.0016545403, delay 1.5
        h("Epop[48] syn_projIE_gaba[768] = new gaba(0.5)")
        h("Ipop[9] netConn_projIE_gaba[768] = new NetCon(&v(0.5), syn_projIE_gaba[768], 20.0, 1.5, -0.0016545403)")  

        # Connection 769: cell 9, seg 0 (0.5) [0.5 on Ipop[9]] -> cell 49, seg 0 (0.5) [0.5 on Epop[49]], weight: -0.0016545403, delay 1.5
        h("Epop[49] syn_projIE_gaba[769] = new gaba(0.5)")
        h("Ipop[9] netConn_projIE_gaba[769] = new NetCon(&v(0.5), syn_projIE_gaba[769], 20.0, 1.5, -0.0016545403)")  

        # Connection 770: cell 9, seg 0 (0.5) [0.5 on Ipop[9]] -> cell 50, seg 0 (0.5) [0.5 on Epop[50]], weight: -0.0016545403, delay 1.5
        h("Epop[50] syn_projIE_gaba[770] = new gaba(0.5)")
        h("Ipop[9] netConn_projIE_gaba[770] = new NetCon(&v(0.5), syn_projIE_gaba[770], 20.0, 1.5, -0.0016545403)")  

        # Connection 771: cell 9, seg 0 (0.5) [0.5 on Ipop[9]] -> cell 51, seg 0 (0.5) [0.5 on Epop[51]], weight: -0.0016545403, delay 1.5
        h("Epop[51] syn_projIE_gaba[771] = new gaba(0.5)")
        h("Ipop[9] netConn_projIE_gaba[771] = new NetCon(&v(0.5), syn_projIE_gaba[771], 20.0, 1.5, -0.0016545403)")  

        # Connection 772: cell 9, seg 0 (0.5) [0.5 on Ipop[9]] -> cell 52, seg 0 (0.5) [0.5 on Epop[52]], weight: -0.0016545403, delay 1.5
        h("Epop[52] syn_projIE_gaba[772] = new gaba(0.5)")
        h("Ipop[9] netConn_projIE_gaba[772] = new NetCon(&v(0.5), syn_projIE_gaba[772], 20.0, 1.5, -0.0016545403)")  

        # Connection 773: cell 9, seg 0 (0.5) [0.5 on Ipop[9]] -> cell 53, seg 0 (0.5) [0.5 on Epop[53]], weight: -0.0016545403, delay 1.5
        h("Epop[53] syn_projIE_gaba[773] = new gaba(0.5)")
        h("Ipop[9] netConn_projIE_gaba[773] = new NetCon(&v(0.5), syn_projIE_gaba[773], 20.0, 1.5, -0.0016545403)")  

        # Connection 774: cell 9, seg 0 (0.5) [0.5 on Ipop[9]] -> cell 54, seg 0 (0.5) [0.5 on Epop[54]], weight: -0.0016545403, delay 1.5
        h("Epop[54] syn_projIE_gaba[774] = new gaba(0.5)")
        h("Ipop[9] netConn_projIE_gaba[774] = new NetCon(&v(0.5), syn_projIE_gaba[774], 20.0, 1.5, -0.0016545403)")  

        # Connection 775: cell 9, seg 0 (0.5) [0.5 on Ipop[9]] -> cell 55, seg 0 (0.5) [0.5 on Epop[55]], weight: -0.0016545403, delay 1.5
        h("Epop[55] syn_projIE_gaba[775] = new gaba(0.5)")
        h("Ipop[9] netConn_projIE_gaba[775] = new NetCon(&v(0.5), syn_projIE_gaba[775], 20.0, 1.5, -0.0016545403)")  

        # Connection 776: cell 9, seg 0 (0.5) [0.5 on Ipop[9]] -> cell 56, seg 0 (0.5) [0.5 on Epop[56]], weight: -0.0016545403, delay 1.5
        h("Epop[56] syn_projIE_gaba[776] = new gaba(0.5)")
        h("Ipop[9] netConn_projIE_gaba[776] = new NetCon(&v(0.5), syn_projIE_gaba[776], 20.0, 1.5, -0.0016545403)")  

        # Connection 777: cell 9, seg 0 (0.5) [0.5 on Ipop[9]] -> cell 57, seg 0 (0.5) [0.5 on Epop[57]], weight: -0.0016545403, delay 1.5
        h("Epop[57] syn_projIE_gaba[777] = new gaba(0.5)")
        h("Ipop[9] netConn_projIE_gaba[777] = new NetCon(&v(0.5), syn_projIE_gaba[777], 20.0, 1.5, -0.0016545403)")  

        # Connection 778: cell 9, seg 0 (0.5) [0.5 on Ipop[9]] -> cell 58, seg 0 (0.5) [0.5 on Epop[58]], weight: -0.0016545403, delay 1.5
        h("Epop[58] syn_projIE_gaba[778] = new gaba(0.5)")
        h("Ipop[9] netConn_projIE_gaba[778] = new NetCon(&v(0.5), syn_projIE_gaba[778], 20.0, 1.5, -0.0016545403)")  

        # Connection 779: cell 9, seg 0 (0.5) [0.5 on Ipop[9]] -> cell 59, seg 0 (0.5) [0.5 on Epop[59]], weight: -0.0016545403, delay 1.5
        h("Epop[59] syn_projIE_gaba[779] = new gaba(0.5)")
        h("Ipop[9] netConn_projIE_gaba[779] = new NetCon(&v(0.5), syn_projIE_gaba[779], 20.0, 1.5, -0.0016545403)")  

        # Connection 780: cell 9, seg 0 (0.5) [0.5 on Ipop[9]] -> cell 60, seg 0 (0.5) [0.5 on Epop[60]], weight: -0.0016545403, delay 1.5
        h("Epop[60] syn_projIE_gaba[780] = new gaba(0.5)")
        h("Ipop[9] netConn_projIE_gaba[780] = new NetCon(&v(0.5), syn_projIE_gaba[780], 20.0, 1.5, -0.0016545403)")  

        # Connection 781: cell 9, seg 0 (0.5) [0.5 on Ipop[9]] -> cell 61, seg 0 (0.5) [0.5 on Epop[61]], weight: -0.0016545403, delay 1.5
        h("Epop[61] syn_projIE_gaba[781] = new gaba(0.5)")
        h("Ipop[9] netConn_projIE_gaba[781] = new NetCon(&v(0.5), syn_projIE_gaba[781], 20.0, 1.5, -0.0016545403)")  

        # Connection 782: cell 9, seg 0 (0.5) [0.5 on Ipop[9]] -> cell 62, seg 0 (0.5) [0.5 on Epop[62]], weight: -0.0016545403, delay 1.5
        h("Epop[62] syn_projIE_gaba[782] = new gaba(0.5)")
        h("Ipop[9] netConn_projIE_gaba[782] = new NetCon(&v(0.5), syn_projIE_gaba[782], 20.0, 1.5, -0.0016545403)")  

        # Connection 783: cell 9, seg 0 (0.5) [0.5 on Ipop[9]] -> cell 63, seg 0 (0.5) [0.5 on Epop[63]], weight: -0.0016545403, delay 1.5
        h("Epop[63] syn_projIE_gaba[783] = new gaba(0.5)")
        h("Ipop[9] netConn_projIE_gaba[783] = new NetCon(&v(0.5), syn_projIE_gaba[783], 20.0, 1.5, -0.0016545403)")  

        # Connection 784: cell 9, seg 0 (0.5) [0.5 on Ipop[9]] -> cell 64, seg 0 (0.5) [0.5 on Epop[64]], weight: -0.0016545403, delay 1.5
        h("Epop[64] syn_projIE_gaba[784] = new gaba(0.5)")
        h("Ipop[9] netConn_projIE_gaba[784] = new NetCon(&v(0.5), syn_projIE_gaba[784], 20.0, 1.5, -0.0016545403)")  

        # Connection 785: cell 9, seg 0 (0.5) [0.5 on Ipop[9]] -> cell 65, seg 0 (0.5) [0.5 on Epop[65]], weight: -0.0016545403, delay 1.5
        h("Epop[65] syn_projIE_gaba[785] = new gaba(0.5)")
        h("Ipop[9] netConn_projIE_gaba[785] = new NetCon(&v(0.5), syn_projIE_gaba[785], 20.0, 1.5, -0.0016545403)")  

        # Connection 786: cell 9, seg 0 (0.5) [0.5 on Ipop[9]] -> cell 66, seg 0 (0.5) [0.5 on Epop[66]], weight: -0.0016545403, delay 1.5
        h("Epop[66] syn_projIE_gaba[786] = new gaba(0.5)")
        h("Ipop[9] netConn_projIE_gaba[786] = new NetCon(&v(0.5), syn_projIE_gaba[786], 20.0, 1.5, -0.0016545403)")  

        # Connection 787: cell 9, seg 0 (0.5) [0.5 on Ipop[9]] -> cell 67, seg 0 (0.5) [0.5 on Epop[67]], weight: -0.0016545403, delay 1.5
        h("Epop[67] syn_projIE_gaba[787] = new gaba(0.5)")
        h("Ipop[9] netConn_projIE_gaba[787] = new NetCon(&v(0.5), syn_projIE_gaba[787], 20.0, 1.5, -0.0016545403)")  

        # Connection 788: cell 9, seg 0 (0.5) [0.5 on Ipop[9]] -> cell 68, seg 0 (0.5) [0.5 on Epop[68]], weight: -0.0016545403, delay 1.5
        h("Epop[68] syn_projIE_gaba[788] = new gaba(0.5)")
        h("Ipop[9] netConn_projIE_gaba[788] = new NetCon(&v(0.5), syn_projIE_gaba[788], 20.0, 1.5, -0.0016545403)")  

        # Connection 789: cell 9, seg 0 (0.5) [0.5 on Ipop[9]] -> cell 69, seg 0 (0.5) [0.5 on Epop[69]], weight: -0.0016545403, delay 1.5
        h("Epop[69] syn_projIE_gaba[789] = new gaba(0.5)")
        h("Ipop[9] netConn_projIE_gaba[789] = new NetCon(&v(0.5), syn_projIE_gaba[789], 20.0, 1.5, -0.0016545403)")  

        # Connection 790: cell 9, seg 0 (0.5) [0.5 on Ipop[9]] -> cell 70, seg 0 (0.5) [0.5 on Epop[70]], weight: -0.0016545403, delay 1.5
        h("Epop[70] syn_projIE_gaba[790] = new gaba(0.5)")
        h("Ipop[9] netConn_projIE_gaba[790] = new NetCon(&v(0.5), syn_projIE_gaba[790], 20.0, 1.5, -0.0016545403)")  

        # Connection 791: cell 9, seg 0 (0.5) [0.5 on Ipop[9]] -> cell 71, seg 0 (0.5) [0.5 on Epop[71]], weight: -0.0016545403, delay 1.5
        h("Epop[71] syn_projIE_gaba[791] = new gaba(0.5)")
        h("Ipop[9] netConn_projIE_gaba[791] = new NetCon(&v(0.5), syn_projIE_gaba[791], 20.0, 1.5, -0.0016545403)")  

        # Connection 792: cell 9, seg 0 (0.5) [0.5 on Ipop[9]] -> cell 72, seg 0 (0.5) [0.5 on Epop[72]], weight: -0.0016545403, delay 1.5
        h("Epop[72] syn_projIE_gaba[792] = new gaba(0.5)")
        h("Ipop[9] netConn_projIE_gaba[792] = new NetCon(&v(0.5), syn_projIE_gaba[792], 20.0, 1.5, -0.0016545403)")  

        # Connection 793: cell 9, seg 0 (0.5) [0.5 on Ipop[9]] -> cell 73, seg 0 (0.5) [0.5 on Epop[73]], weight: -0.0016545403, delay 1.5
        h("Epop[73] syn_projIE_gaba[793] = new gaba(0.5)")
        h("Ipop[9] netConn_projIE_gaba[793] = new NetCon(&v(0.5), syn_projIE_gaba[793], 20.0, 1.5, -0.0016545403)")  

        # Connection 794: cell 9, seg 0 (0.5) [0.5 on Ipop[9]] -> cell 74, seg 0 (0.5) [0.5 on Epop[74]], weight: -0.0016545403, delay 1.5
        h("Epop[74] syn_projIE_gaba[794] = new gaba(0.5)")
        h("Ipop[9] netConn_projIE_gaba[794] = new NetCon(&v(0.5), syn_projIE_gaba[794], 20.0, 1.5, -0.0016545403)")  

        # Connection 795: cell 9, seg 0 (0.5) [0.5 on Ipop[9]] -> cell 75, seg 0 (0.5) [0.5 on Epop[75]], weight: -0.0016545403, delay 1.5
        h("Epop[75] syn_projIE_gaba[795] = new gaba(0.5)")
        h("Ipop[9] netConn_projIE_gaba[795] = new NetCon(&v(0.5), syn_projIE_gaba[795], 20.0, 1.5, -0.0016545403)")  

        # Connection 796: cell 9, seg 0 (0.5) [0.5 on Ipop[9]] -> cell 76, seg 0 (0.5) [0.5 on Epop[76]], weight: -0.0016545403, delay 1.5
        h("Epop[76] syn_projIE_gaba[796] = new gaba(0.5)")
        h("Ipop[9] netConn_projIE_gaba[796] = new NetCon(&v(0.5), syn_projIE_gaba[796], 20.0, 1.5, -0.0016545403)")  

        # Connection 797: cell 9, seg 0 (0.5) [0.5 on Ipop[9]] -> cell 77, seg 0 (0.5) [0.5 on Epop[77]], weight: -0.0016545403, delay 1.5
        h("Epop[77] syn_projIE_gaba[797] = new gaba(0.5)")
        h("Ipop[9] netConn_projIE_gaba[797] = new NetCon(&v(0.5), syn_projIE_gaba[797], 20.0, 1.5, -0.0016545403)")  

        # Connection 798: cell 9, seg 0 (0.5) [0.5 on Ipop[9]] -> cell 78, seg 0 (0.5) [0.5 on Epop[78]], weight: -0.0016545403, delay 1.5
        h("Epop[78] syn_projIE_gaba[798] = new gaba(0.5)")
        h("Ipop[9] netConn_projIE_gaba[798] = new NetCon(&v(0.5), syn_projIE_gaba[798], 20.0, 1.5, -0.0016545403)")  

        # Connection 799: cell 9, seg 0 (0.5) [0.5 on Ipop[9]] -> cell 79, seg 0 (0.5) [0.5 on Epop[79]], weight: -0.0016545403, delay 1.5
        h("Epop[79] syn_projIE_gaba[799] = new gaba(0.5)")
        h("Ipop[9] netConn_projIE_gaba[799] = new NetCon(&v(0.5), syn_projIE_gaba[799], 20.0, 1.5, -0.0016545403)")  

        # Connection 800: cell 10, seg 0 (0.5) [0.5 on Ipop[10]] -> cell 0, seg 0 (0.5) [0.5 on Epop[0]], weight: -0.0016545403, delay 1.5
        h("Epop[0] syn_projIE_gaba[800] = new gaba(0.5)")
        h("Ipop[10] netConn_projIE_gaba[800] = new NetCon(&v(0.5), syn_projIE_gaba[800], 20.0, 1.5, -0.0016545403)")  

        # Connection 801: cell 10, seg 0 (0.5) [0.5 on Ipop[10]] -> cell 1, seg 0 (0.5) [0.5 on Epop[1]], weight: -0.0016545403, delay 1.5
        h("Epop[1] syn_projIE_gaba[801] = new gaba(0.5)")
        h("Ipop[10] netConn_projIE_gaba[801] = new NetCon(&v(0.5), syn_projIE_gaba[801], 20.0, 1.5, -0.0016545403)")  

        # Connection 802: cell 10, seg 0 (0.5) [0.5 on Ipop[10]] -> cell 2, seg 0 (0.5) [0.5 on Epop[2]], weight: -0.0016545403, delay 1.5
        h("Epop[2] syn_projIE_gaba[802] = new gaba(0.5)")
        h("Ipop[10] netConn_projIE_gaba[802] = new NetCon(&v(0.5), syn_projIE_gaba[802], 20.0, 1.5, -0.0016545403)")  

        # Connection 803: cell 10, seg 0 (0.5) [0.5 on Ipop[10]] -> cell 3, seg 0 (0.5) [0.5 on Epop[3]], weight: -0.0016545403, delay 1.5
        h("Epop[3] syn_projIE_gaba[803] = new gaba(0.5)")
        h("Ipop[10] netConn_projIE_gaba[803] = new NetCon(&v(0.5), syn_projIE_gaba[803], 20.0, 1.5, -0.0016545403)")  

        # Connection 804: cell 10, seg 0 (0.5) [0.5 on Ipop[10]] -> cell 4, seg 0 (0.5) [0.5 on Epop[4]], weight: -0.0016545403, delay 1.5
        h("Epop[4] syn_projIE_gaba[804] = new gaba(0.5)")
        h("Ipop[10] netConn_projIE_gaba[804] = new NetCon(&v(0.5), syn_projIE_gaba[804], 20.0, 1.5, -0.0016545403)")  

        # Connection 805: cell 10, seg 0 (0.5) [0.5 on Ipop[10]] -> cell 5, seg 0 (0.5) [0.5 on Epop[5]], weight: -0.0016545403, delay 1.5
        h("Epop[5] syn_projIE_gaba[805] = new gaba(0.5)")
        h("Ipop[10] netConn_projIE_gaba[805] = new NetCon(&v(0.5), syn_projIE_gaba[805], 20.0, 1.5, -0.0016545403)")  

        # Connection 806: cell 10, seg 0 (0.5) [0.5 on Ipop[10]] -> cell 6, seg 0 (0.5) [0.5 on Epop[6]], weight: -0.0016545403, delay 1.5
        h("Epop[6] syn_projIE_gaba[806] = new gaba(0.5)")
        h("Ipop[10] netConn_projIE_gaba[806] = new NetCon(&v(0.5), syn_projIE_gaba[806], 20.0, 1.5, -0.0016545403)")  

        # Connection 807: cell 10, seg 0 (0.5) [0.5 on Ipop[10]] -> cell 7, seg 0 (0.5) [0.5 on Epop[7]], weight: -0.0016545403, delay 1.5
        h("Epop[7] syn_projIE_gaba[807] = new gaba(0.5)")
        h("Ipop[10] netConn_projIE_gaba[807] = new NetCon(&v(0.5), syn_projIE_gaba[807], 20.0, 1.5, -0.0016545403)")  

        # Connection 808: cell 10, seg 0 (0.5) [0.5 on Ipop[10]] -> cell 8, seg 0 (0.5) [0.5 on Epop[8]], weight: -0.0016545403, delay 1.5
        h("Epop[8] syn_projIE_gaba[808] = new gaba(0.5)")
        h("Ipop[10] netConn_projIE_gaba[808] = new NetCon(&v(0.5), syn_projIE_gaba[808], 20.0, 1.5, -0.0016545403)")  

        # Connection 809: cell 10, seg 0 (0.5) [0.5 on Ipop[10]] -> cell 9, seg 0 (0.5) [0.5 on Epop[9]], weight: -0.0016545403, delay 1.5
        h("Epop[9] syn_projIE_gaba[809] = new gaba(0.5)")
        h("Ipop[10] netConn_projIE_gaba[809] = new NetCon(&v(0.5), syn_projIE_gaba[809], 20.0, 1.5, -0.0016545403)")  

        # Connection 810: cell 10, seg 0 (0.5) [0.5 on Ipop[10]] -> cell 10, seg 0 (0.5) [0.5 on Epop[10]], weight: -0.0016545403, delay 1.5
        h("Epop[10] syn_projIE_gaba[810] = new gaba(0.5)")
        h("Ipop[10] netConn_projIE_gaba[810] = new NetCon(&v(0.5), syn_projIE_gaba[810], 20.0, 1.5, -0.0016545403)")  

        # Connection 811: cell 10, seg 0 (0.5) [0.5 on Ipop[10]] -> cell 11, seg 0 (0.5) [0.5 on Epop[11]], weight: -0.0016545403, delay 1.5
        h("Epop[11] syn_projIE_gaba[811] = new gaba(0.5)")
        h("Ipop[10] netConn_projIE_gaba[811] = new NetCon(&v(0.5), syn_projIE_gaba[811], 20.0, 1.5, -0.0016545403)")  

        # Connection 812: cell 10, seg 0 (0.5) [0.5 on Ipop[10]] -> cell 12, seg 0 (0.5) [0.5 on Epop[12]], weight: -0.0016545403, delay 1.5
        h("Epop[12] syn_projIE_gaba[812] = new gaba(0.5)")
        h("Ipop[10] netConn_projIE_gaba[812] = new NetCon(&v(0.5), syn_projIE_gaba[812], 20.0, 1.5, -0.0016545403)")  

        # Connection 813: cell 10, seg 0 (0.5) [0.5 on Ipop[10]] -> cell 13, seg 0 (0.5) [0.5 on Epop[13]], weight: -0.0016545403, delay 1.5
        h("Epop[13] syn_projIE_gaba[813] = new gaba(0.5)")
        h("Ipop[10] netConn_projIE_gaba[813] = new NetCon(&v(0.5), syn_projIE_gaba[813], 20.0, 1.5, -0.0016545403)")  

        # Connection 814: cell 10, seg 0 (0.5) [0.5 on Ipop[10]] -> cell 14, seg 0 (0.5) [0.5 on Epop[14]], weight: -0.0016545403, delay 1.5
        h("Epop[14] syn_projIE_gaba[814] = new gaba(0.5)")
        h("Ipop[10] netConn_projIE_gaba[814] = new NetCon(&v(0.5), syn_projIE_gaba[814], 20.0, 1.5, -0.0016545403)")  

        # Connection 815: cell 10, seg 0 (0.5) [0.5 on Ipop[10]] -> cell 15, seg 0 (0.5) [0.5 on Epop[15]], weight: -0.0016545403, delay 1.5
        h("Epop[15] syn_projIE_gaba[815] = new gaba(0.5)")
        h("Ipop[10] netConn_projIE_gaba[815] = new NetCon(&v(0.5), syn_projIE_gaba[815], 20.0, 1.5, -0.0016545403)")  

        # Connection 816: cell 10, seg 0 (0.5) [0.5 on Ipop[10]] -> cell 16, seg 0 (0.5) [0.5 on Epop[16]], weight: -0.0016545403, delay 1.5
        h("Epop[16] syn_projIE_gaba[816] = new gaba(0.5)")
        h("Ipop[10] netConn_projIE_gaba[816] = new NetCon(&v(0.5), syn_projIE_gaba[816], 20.0, 1.5, -0.0016545403)")  

        # Connection 817: cell 10, seg 0 (0.5) [0.5 on Ipop[10]] -> cell 17, seg 0 (0.5) [0.5 on Epop[17]], weight: -0.0016545403, delay 1.5
        h("Epop[17] syn_projIE_gaba[817] = new gaba(0.5)")
        h("Ipop[10] netConn_projIE_gaba[817] = new NetCon(&v(0.5), syn_projIE_gaba[817], 20.0, 1.5, -0.0016545403)")  

        # Connection 818: cell 10, seg 0 (0.5) [0.5 on Ipop[10]] -> cell 18, seg 0 (0.5) [0.5 on Epop[18]], weight: -0.0016545403, delay 1.5
        h("Epop[18] syn_projIE_gaba[818] = new gaba(0.5)")
        h("Ipop[10] netConn_projIE_gaba[818] = new NetCon(&v(0.5), syn_projIE_gaba[818], 20.0, 1.5, -0.0016545403)")  

        # Connection 819: cell 10, seg 0 (0.5) [0.5 on Ipop[10]] -> cell 19, seg 0 (0.5) [0.5 on Epop[19]], weight: -0.0016545403, delay 1.5
        h("Epop[19] syn_projIE_gaba[819] = new gaba(0.5)")
        h("Ipop[10] netConn_projIE_gaba[819] = new NetCon(&v(0.5), syn_projIE_gaba[819], 20.0, 1.5, -0.0016545403)")  

        # Connection 820: cell 10, seg 0 (0.5) [0.5 on Ipop[10]] -> cell 20, seg 0 (0.5) [0.5 on Epop[20]], weight: -0.0016545403, delay 1.5
        h("Epop[20] syn_projIE_gaba[820] = new gaba(0.5)")
        h("Ipop[10] netConn_projIE_gaba[820] = new NetCon(&v(0.5), syn_projIE_gaba[820], 20.0, 1.5, -0.0016545403)")  

        # Connection 821: cell 10, seg 0 (0.5) [0.5 on Ipop[10]] -> cell 21, seg 0 (0.5) [0.5 on Epop[21]], weight: -0.0016545403, delay 1.5
        h("Epop[21] syn_projIE_gaba[821] = new gaba(0.5)")
        h("Ipop[10] netConn_projIE_gaba[821] = new NetCon(&v(0.5), syn_projIE_gaba[821], 20.0, 1.5, -0.0016545403)")  

        # Connection 822: cell 10, seg 0 (0.5) [0.5 on Ipop[10]] -> cell 22, seg 0 (0.5) [0.5 on Epop[22]], weight: -0.0016545403, delay 1.5
        h("Epop[22] syn_projIE_gaba[822] = new gaba(0.5)")
        h("Ipop[10] netConn_projIE_gaba[822] = new NetCon(&v(0.5), syn_projIE_gaba[822], 20.0, 1.5, -0.0016545403)")  

        # Connection 823: cell 10, seg 0 (0.5) [0.5 on Ipop[10]] -> cell 23, seg 0 (0.5) [0.5 on Epop[23]], weight: -0.0016545403, delay 1.5
        h("Epop[23] syn_projIE_gaba[823] = new gaba(0.5)")
        h("Ipop[10] netConn_projIE_gaba[823] = new NetCon(&v(0.5), syn_projIE_gaba[823], 20.0, 1.5, -0.0016545403)")  

        # Connection 824: cell 10, seg 0 (0.5) [0.5 on Ipop[10]] -> cell 24, seg 0 (0.5) [0.5 on Epop[24]], weight: -0.0016545403, delay 1.5
        h("Epop[24] syn_projIE_gaba[824] = new gaba(0.5)")
        h("Ipop[10] netConn_projIE_gaba[824] = new NetCon(&v(0.5), syn_projIE_gaba[824], 20.0, 1.5, -0.0016545403)")  

        # Connection 825: cell 10, seg 0 (0.5) [0.5 on Ipop[10]] -> cell 25, seg 0 (0.5) [0.5 on Epop[25]], weight: -0.0016545403, delay 1.5
        h("Epop[25] syn_projIE_gaba[825] = new gaba(0.5)")
        h("Ipop[10] netConn_projIE_gaba[825] = new NetCon(&v(0.5), syn_projIE_gaba[825], 20.0, 1.5, -0.0016545403)")  

        # Connection 826: cell 10, seg 0 (0.5) [0.5 on Ipop[10]] -> cell 26, seg 0 (0.5) [0.5 on Epop[26]], weight: -0.0016545403, delay 1.5
        h("Epop[26] syn_projIE_gaba[826] = new gaba(0.5)")
        h("Ipop[10] netConn_projIE_gaba[826] = new NetCon(&v(0.5), syn_projIE_gaba[826], 20.0, 1.5, -0.0016545403)")  

        # Connection 827: cell 10, seg 0 (0.5) [0.5 on Ipop[10]] -> cell 27, seg 0 (0.5) [0.5 on Epop[27]], weight: -0.0016545403, delay 1.5
        h("Epop[27] syn_projIE_gaba[827] = new gaba(0.5)")
        h("Ipop[10] netConn_projIE_gaba[827] = new NetCon(&v(0.5), syn_projIE_gaba[827], 20.0, 1.5, -0.0016545403)")  

        # Connection 828: cell 10, seg 0 (0.5) [0.5 on Ipop[10]] -> cell 28, seg 0 (0.5) [0.5 on Epop[28]], weight: -0.0016545403, delay 1.5
        h("Epop[28] syn_projIE_gaba[828] = new gaba(0.5)")
        h("Ipop[10] netConn_projIE_gaba[828] = new NetCon(&v(0.5), syn_projIE_gaba[828], 20.0, 1.5, -0.0016545403)")  

        # Connection 829: cell 10, seg 0 (0.5) [0.5 on Ipop[10]] -> cell 29, seg 0 (0.5) [0.5 on Epop[29]], weight: -0.0016545403, delay 1.5
        h("Epop[29] syn_projIE_gaba[829] = new gaba(0.5)")
        h("Ipop[10] netConn_projIE_gaba[829] = new NetCon(&v(0.5), syn_projIE_gaba[829], 20.0, 1.5, -0.0016545403)")  

        # Connection 830: cell 10, seg 0 (0.5) [0.5 on Ipop[10]] -> cell 30, seg 0 (0.5) [0.5 on Epop[30]], weight: -0.0016545403, delay 1.5
        h("Epop[30] syn_projIE_gaba[830] = new gaba(0.5)")
        h("Ipop[10] netConn_projIE_gaba[830] = new NetCon(&v(0.5), syn_projIE_gaba[830], 20.0, 1.5, -0.0016545403)")  

        # Connection 831: cell 10, seg 0 (0.5) [0.5 on Ipop[10]] -> cell 31, seg 0 (0.5) [0.5 on Epop[31]], weight: -0.0016545403, delay 1.5
        h("Epop[31] syn_projIE_gaba[831] = new gaba(0.5)")
        h("Ipop[10] netConn_projIE_gaba[831] = new NetCon(&v(0.5), syn_projIE_gaba[831], 20.0, 1.5, -0.0016545403)")  

        # Connection 832: cell 10, seg 0 (0.5) [0.5 on Ipop[10]] -> cell 32, seg 0 (0.5) [0.5 on Epop[32]], weight: -0.0016545403, delay 1.5
        h("Epop[32] syn_projIE_gaba[832] = new gaba(0.5)")
        h("Ipop[10] netConn_projIE_gaba[832] = new NetCon(&v(0.5), syn_projIE_gaba[832], 20.0, 1.5, -0.0016545403)")  

        # Connection 833: cell 10, seg 0 (0.5) [0.5 on Ipop[10]] -> cell 33, seg 0 (0.5) [0.5 on Epop[33]], weight: -0.0016545403, delay 1.5
        h("Epop[33] syn_projIE_gaba[833] = new gaba(0.5)")
        h("Ipop[10] netConn_projIE_gaba[833] = new NetCon(&v(0.5), syn_projIE_gaba[833], 20.0, 1.5, -0.0016545403)")  

        # Connection 834: cell 10, seg 0 (0.5) [0.5 on Ipop[10]] -> cell 34, seg 0 (0.5) [0.5 on Epop[34]], weight: -0.0016545403, delay 1.5
        h("Epop[34] syn_projIE_gaba[834] = new gaba(0.5)")
        h("Ipop[10] netConn_projIE_gaba[834] = new NetCon(&v(0.5), syn_projIE_gaba[834], 20.0, 1.5, -0.0016545403)")  

        # Connection 835: cell 10, seg 0 (0.5) [0.5 on Ipop[10]] -> cell 35, seg 0 (0.5) [0.5 on Epop[35]], weight: -0.0016545403, delay 1.5
        h("Epop[35] syn_projIE_gaba[835] = new gaba(0.5)")
        h("Ipop[10] netConn_projIE_gaba[835] = new NetCon(&v(0.5), syn_projIE_gaba[835], 20.0, 1.5, -0.0016545403)")  

        # Connection 836: cell 10, seg 0 (0.5) [0.5 on Ipop[10]] -> cell 36, seg 0 (0.5) [0.5 on Epop[36]], weight: -0.0016545403, delay 1.5
        h("Epop[36] syn_projIE_gaba[836] = new gaba(0.5)")
        h("Ipop[10] netConn_projIE_gaba[836] = new NetCon(&v(0.5), syn_projIE_gaba[836], 20.0, 1.5, -0.0016545403)")  

        # Connection 837: cell 10, seg 0 (0.5) [0.5 on Ipop[10]] -> cell 37, seg 0 (0.5) [0.5 on Epop[37]], weight: -0.0016545403, delay 1.5
        h("Epop[37] syn_projIE_gaba[837] = new gaba(0.5)")
        h("Ipop[10] netConn_projIE_gaba[837] = new NetCon(&v(0.5), syn_projIE_gaba[837], 20.0, 1.5, -0.0016545403)")  

        # Connection 838: cell 10, seg 0 (0.5) [0.5 on Ipop[10]] -> cell 38, seg 0 (0.5) [0.5 on Epop[38]], weight: -0.0016545403, delay 1.5
        h("Epop[38] syn_projIE_gaba[838] = new gaba(0.5)")
        h("Ipop[10] netConn_projIE_gaba[838] = new NetCon(&v(0.5), syn_projIE_gaba[838], 20.0, 1.5, -0.0016545403)")  

        # Connection 839: cell 10, seg 0 (0.5) [0.5 on Ipop[10]] -> cell 39, seg 0 (0.5) [0.5 on Epop[39]], weight: -0.0016545403, delay 1.5
        h("Epop[39] syn_projIE_gaba[839] = new gaba(0.5)")
        h("Ipop[10] netConn_projIE_gaba[839] = new NetCon(&v(0.5), syn_projIE_gaba[839], 20.0, 1.5, -0.0016545403)")  

        # Connection 840: cell 10, seg 0 (0.5) [0.5 on Ipop[10]] -> cell 40, seg 0 (0.5) [0.5 on Epop[40]], weight: -0.0016545403, delay 1.5
        h("Epop[40] syn_projIE_gaba[840] = new gaba(0.5)")
        h("Ipop[10] netConn_projIE_gaba[840] = new NetCon(&v(0.5), syn_projIE_gaba[840], 20.0, 1.5, -0.0016545403)")  

        # Connection 841: cell 10, seg 0 (0.5) [0.5 on Ipop[10]] -> cell 41, seg 0 (0.5) [0.5 on Epop[41]], weight: -0.0016545403, delay 1.5
        h("Epop[41] syn_projIE_gaba[841] = new gaba(0.5)")
        h("Ipop[10] netConn_projIE_gaba[841] = new NetCon(&v(0.5), syn_projIE_gaba[841], 20.0, 1.5, -0.0016545403)")  

        # Connection 842: cell 10, seg 0 (0.5) [0.5 on Ipop[10]] -> cell 42, seg 0 (0.5) [0.5 on Epop[42]], weight: -0.0016545403, delay 1.5
        h("Epop[42] syn_projIE_gaba[842] = new gaba(0.5)")
        h("Ipop[10] netConn_projIE_gaba[842] = new NetCon(&v(0.5), syn_projIE_gaba[842], 20.0, 1.5, -0.0016545403)")  

        # Connection 843: cell 10, seg 0 (0.5) [0.5 on Ipop[10]] -> cell 43, seg 0 (0.5) [0.5 on Epop[43]], weight: -0.0016545403, delay 1.5
        h("Epop[43] syn_projIE_gaba[843] = new gaba(0.5)")
        h("Ipop[10] netConn_projIE_gaba[843] = new NetCon(&v(0.5), syn_projIE_gaba[843], 20.0, 1.5, -0.0016545403)")  

        # Connection 844: cell 10, seg 0 (0.5) [0.5 on Ipop[10]] -> cell 44, seg 0 (0.5) [0.5 on Epop[44]], weight: -0.0016545403, delay 1.5
        h("Epop[44] syn_projIE_gaba[844] = new gaba(0.5)")
        h("Ipop[10] netConn_projIE_gaba[844] = new NetCon(&v(0.5), syn_projIE_gaba[844], 20.0, 1.5, -0.0016545403)")  

        # Connection 845: cell 10, seg 0 (0.5) [0.5 on Ipop[10]] -> cell 45, seg 0 (0.5) [0.5 on Epop[45]], weight: -0.0016545403, delay 1.5
        h("Epop[45] syn_projIE_gaba[845] = new gaba(0.5)")
        h("Ipop[10] netConn_projIE_gaba[845] = new NetCon(&v(0.5), syn_projIE_gaba[845], 20.0, 1.5, -0.0016545403)")  

        # Connection 846: cell 10, seg 0 (0.5) [0.5 on Ipop[10]] -> cell 46, seg 0 (0.5) [0.5 on Epop[46]], weight: -0.0016545403, delay 1.5
        h("Epop[46] syn_projIE_gaba[846] = new gaba(0.5)")
        h("Ipop[10] netConn_projIE_gaba[846] = new NetCon(&v(0.5), syn_projIE_gaba[846], 20.0, 1.5, -0.0016545403)")  

        # Connection 847: cell 10, seg 0 (0.5) [0.5 on Ipop[10]] -> cell 47, seg 0 (0.5) [0.5 on Epop[47]], weight: -0.0016545403, delay 1.5
        h("Epop[47] syn_projIE_gaba[847] = new gaba(0.5)")
        h("Ipop[10] netConn_projIE_gaba[847] = new NetCon(&v(0.5), syn_projIE_gaba[847], 20.0, 1.5, -0.0016545403)")  

        # Connection 848: cell 10, seg 0 (0.5) [0.5 on Ipop[10]] -> cell 48, seg 0 (0.5) [0.5 on Epop[48]], weight: -0.0016545403, delay 1.5
        h("Epop[48] syn_projIE_gaba[848] = new gaba(0.5)")
        h("Ipop[10] netConn_projIE_gaba[848] = new NetCon(&v(0.5), syn_projIE_gaba[848], 20.0, 1.5, -0.0016545403)")  

        # Connection 849: cell 10, seg 0 (0.5) [0.5 on Ipop[10]] -> cell 49, seg 0 (0.5) [0.5 on Epop[49]], weight: -0.0016545403, delay 1.5
        h("Epop[49] syn_projIE_gaba[849] = new gaba(0.5)")
        h("Ipop[10] netConn_projIE_gaba[849] = new NetCon(&v(0.5), syn_projIE_gaba[849], 20.0, 1.5, -0.0016545403)")  

        # Connection 850: cell 10, seg 0 (0.5) [0.5 on Ipop[10]] -> cell 50, seg 0 (0.5) [0.5 on Epop[50]], weight: -0.0016545403, delay 1.5
        h("Epop[50] syn_projIE_gaba[850] = new gaba(0.5)")
        h("Ipop[10] netConn_projIE_gaba[850] = new NetCon(&v(0.5), syn_projIE_gaba[850], 20.0, 1.5, -0.0016545403)")  

        # Connection 851: cell 10, seg 0 (0.5) [0.5 on Ipop[10]] -> cell 51, seg 0 (0.5) [0.5 on Epop[51]], weight: -0.0016545403, delay 1.5
        h("Epop[51] syn_projIE_gaba[851] = new gaba(0.5)")
        h("Ipop[10] netConn_projIE_gaba[851] = new NetCon(&v(0.5), syn_projIE_gaba[851], 20.0, 1.5, -0.0016545403)")  

        # Connection 852: cell 10, seg 0 (0.5) [0.5 on Ipop[10]] -> cell 52, seg 0 (0.5) [0.5 on Epop[52]], weight: -0.0016545403, delay 1.5
        h("Epop[52] syn_projIE_gaba[852] = new gaba(0.5)")
        h("Ipop[10] netConn_projIE_gaba[852] = new NetCon(&v(0.5), syn_projIE_gaba[852], 20.0, 1.5, -0.0016545403)")  

        # Connection 853: cell 10, seg 0 (0.5) [0.5 on Ipop[10]] -> cell 53, seg 0 (0.5) [0.5 on Epop[53]], weight: -0.0016545403, delay 1.5
        h("Epop[53] syn_projIE_gaba[853] = new gaba(0.5)")
        h("Ipop[10] netConn_projIE_gaba[853] = new NetCon(&v(0.5), syn_projIE_gaba[853], 20.0, 1.5, -0.0016545403)")  

        # Connection 854: cell 10, seg 0 (0.5) [0.5 on Ipop[10]] -> cell 54, seg 0 (0.5) [0.5 on Epop[54]], weight: -0.0016545403, delay 1.5
        h("Epop[54] syn_projIE_gaba[854] = new gaba(0.5)")
        h("Ipop[10] netConn_projIE_gaba[854] = new NetCon(&v(0.5), syn_projIE_gaba[854], 20.0, 1.5, -0.0016545403)")  

        # Connection 855: cell 10, seg 0 (0.5) [0.5 on Ipop[10]] -> cell 55, seg 0 (0.5) [0.5 on Epop[55]], weight: -0.0016545403, delay 1.5
        h("Epop[55] syn_projIE_gaba[855] = new gaba(0.5)")
        h("Ipop[10] netConn_projIE_gaba[855] = new NetCon(&v(0.5), syn_projIE_gaba[855], 20.0, 1.5, -0.0016545403)")  

        # Connection 856: cell 10, seg 0 (0.5) [0.5 on Ipop[10]] -> cell 56, seg 0 (0.5) [0.5 on Epop[56]], weight: -0.0016545403, delay 1.5
        h("Epop[56] syn_projIE_gaba[856] = new gaba(0.5)")
        h("Ipop[10] netConn_projIE_gaba[856] = new NetCon(&v(0.5), syn_projIE_gaba[856], 20.0, 1.5, -0.0016545403)")  

        # Connection 857: cell 10, seg 0 (0.5) [0.5 on Ipop[10]] -> cell 57, seg 0 (0.5) [0.5 on Epop[57]], weight: -0.0016545403, delay 1.5
        h("Epop[57] syn_projIE_gaba[857] = new gaba(0.5)")
        h("Ipop[10] netConn_projIE_gaba[857] = new NetCon(&v(0.5), syn_projIE_gaba[857], 20.0, 1.5, -0.0016545403)")  

        # Connection 858: cell 10, seg 0 (0.5) [0.5 on Ipop[10]] -> cell 58, seg 0 (0.5) [0.5 on Epop[58]], weight: -0.0016545403, delay 1.5
        h("Epop[58] syn_projIE_gaba[858] = new gaba(0.5)")
        h("Ipop[10] netConn_projIE_gaba[858] = new NetCon(&v(0.5), syn_projIE_gaba[858], 20.0, 1.5, -0.0016545403)")  

        # Connection 859: cell 10, seg 0 (0.5) [0.5 on Ipop[10]] -> cell 59, seg 0 (0.5) [0.5 on Epop[59]], weight: -0.0016545403, delay 1.5
        h("Epop[59] syn_projIE_gaba[859] = new gaba(0.5)")
        h("Ipop[10] netConn_projIE_gaba[859] = new NetCon(&v(0.5), syn_projIE_gaba[859], 20.0, 1.5, -0.0016545403)")  

        # Connection 860: cell 10, seg 0 (0.5) [0.5 on Ipop[10]] -> cell 60, seg 0 (0.5) [0.5 on Epop[60]], weight: -0.0016545403, delay 1.5
        h("Epop[60] syn_projIE_gaba[860] = new gaba(0.5)")
        h("Ipop[10] netConn_projIE_gaba[860] = new NetCon(&v(0.5), syn_projIE_gaba[860], 20.0, 1.5, -0.0016545403)")  

        # Connection 861: cell 10, seg 0 (0.5) [0.5 on Ipop[10]] -> cell 61, seg 0 (0.5) [0.5 on Epop[61]], weight: -0.0016545403, delay 1.5
        h("Epop[61] syn_projIE_gaba[861] = new gaba(0.5)")
        h("Ipop[10] netConn_projIE_gaba[861] = new NetCon(&v(0.5), syn_projIE_gaba[861], 20.0, 1.5, -0.0016545403)")  

        # Connection 862: cell 10, seg 0 (0.5) [0.5 on Ipop[10]] -> cell 62, seg 0 (0.5) [0.5 on Epop[62]], weight: -0.0016545403, delay 1.5
        h("Epop[62] syn_projIE_gaba[862] = new gaba(0.5)")
        h("Ipop[10] netConn_projIE_gaba[862] = new NetCon(&v(0.5), syn_projIE_gaba[862], 20.0, 1.5, -0.0016545403)")  

        # Connection 863: cell 10, seg 0 (0.5) [0.5 on Ipop[10]] -> cell 63, seg 0 (0.5) [0.5 on Epop[63]], weight: -0.0016545403, delay 1.5
        h("Epop[63] syn_projIE_gaba[863] = new gaba(0.5)")
        h("Ipop[10] netConn_projIE_gaba[863] = new NetCon(&v(0.5), syn_projIE_gaba[863], 20.0, 1.5, -0.0016545403)")  

        # Connection 864: cell 10, seg 0 (0.5) [0.5 on Ipop[10]] -> cell 64, seg 0 (0.5) [0.5 on Epop[64]], weight: -0.0016545403, delay 1.5
        h("Epop[64] syn_projIE_gaba[864] = new gaba(0.5)")
        h("Ipop[10] netConn_projIE_gaba[864] = new NetCon(&v(0.5), syn_projIE_gaba[864], 20.0, 1.5, -0.0016545403)")  

        # Connection 865: cell 10, seg 0 (0.5) [0.5 on Ipop[10]] -> cell 65, seg 0 (0.5) [0.5 on Epop[65]], weight: -0.0016545403, delay 1.5
        h("Epop[65] syn_projIE_gaba[865] = new gaba(0.5)")
        h("Ipop[10] netConn_projIE_gaba[865] = new NetCon(&v(0.5), syn_projIE_gaba[865], 20.0, 1.5, -0.0016545403)")  

        # Connection 866: cell 10, seg 0 (0.5) [0.5 on Ipop[10]] -> cell 66, seg 0 (0.5) [0.5 on Epop[66]], weight: -0.0016545403, delay 1.5
        h("Epop[66] syn_projIE_gaba[866] = new gaba(0.5)")
        h("Ipop[10] netConn_projIE_gaba[866] = new NetCon(&v(0.5), syn_projIE_gaba[866], 20.0, 1.5, -0.0016545403)")  

        # Connection 867: cell 10, seg 0 (0.5) [0.5 on Ipop[10]] -> cell 67, seg 0 (0.5) [0.5 on Epop[67]], weight: -0.0016545403, delay 1.5
        h("Epop[67] syn_projIE_gaba[867] = new gaba(0.5)")
        h("Ipop[10] netConn_projIE_gaba[867] = new NetCon(&v(0.5), syn_projIE_gaba[867], 20.0, 1.5, -0.0016545403)")  

        # Connection 868: cell 10, seg 0 (0.5) [0.5 on Ipop[10]] -> cell 68, seg 0 (0.5) [0.5 on Epop[68]], weight: -0.0016545403, delay 1.5
        h("Epop[68] syn_projIE_gaba[868] = new gaba(0.5)")
        h("Ipop[10] netConn_projIE_gaba[868] = new NetCon(&v(0.5), syn_projIE_gaba[868], 20.0, 1.5, -0.0016545403)")  

        # Connection 869: cell 10, seg 0 (0.5) [0.5 on Ipop[10]] -> cell 69, seg 0 (0.5) [0.5 on Epop[69]], weight: -0.0016545403, delay 1.5
        h("Epop[69] syn_projIE_gaba[869] = new gaba(0.5)")
        h("Ipop[10] netConn_projIE_gaba[869] = new NetCon(&v(0.5), syn_projIE_gaba[869], 20.0, 1.5, -0.0016545403)")  

        # Connection 870: cell 10, seg 0 (0.5) [0.5 on Ipop[10]] -> cell 70, seg 0 (0.5) [0.5 on Epop[70]], weight: -0.0016545403, delay 1.5
        h("Epop[70] syn_projIE_gaba[870] = new gaba(0.5)")
        h("Ipop[10] netConn_projIE_gaba[870] = new NetCon(&v(0.5), syn_projIE_gaba[870], 20.0, 1.5, -0.0016545403)")  

        # Connection 871: cell 10, seg 0 (0.5) [0.5 on Ipop[10]] -> cell 71, seg 0 (0.5) [0.5 on Epop[71]], weight: -0.0016545403, delay 1.5
        h("Epop[71] syn_projIE_gaba[871] = new gaba(0.5)")
        h("Ipop[10] netConn_projIE_gaba[871] = new NetCon(&v(0.5), syn_projIE_gaba[871], 20.0, 1.5, -0.0016545403)")  

        # Connection 872: cell 10, seg 0 (0.5) [0.5 on Ipop[10]] -> cell 72, seg 0 (0.5) [0.5 on Epop[72]], weight: -0.0016545403, delay 1.5
        h("Epop[72] syn_projIE_gaba[872] = new gaba(0.5)")
        h("Ipop[10] netConn_projIE_gaba[872] = new NetCon(&v(0.5), syn_projIE_gaba[872], 20.0, 1.5, -0.0016545403)")  

        # Connection 873: cell 10, seg 0 (0.5) [0.5 on Ipop[10]] -> cell 73, seg 0 (0.5) [0.5 on Epop[73]], weight: -0.0016545403, delay 1.5
        h("Epop[73] syn_projIE_gaba[873] = new gaba(0.5)")
        h("Ipop[10] netConn_projIE_gaba[873] = new NetCon(&v(0.5), syn_projIE_gaba[873], 20.0, 1.5, -0.0016545403)")  

        # Connection 874: cell 10, seg 0 (0.5) [0.5 on Ipop[10]] -> cell 74, seg 0 (0.5) [0.5 on Epop[74]], weight: -0.0016545403, delay 1.5
        h("Epop[74] syn_projIE_gaba[874] = new gaba(0.5)")
        h("Ipop[10] netConn_projIE_gaba[874] = new NetCon(&v(0.5), syn_projIE_gaba[874], 20.0, 1.5, -0.0016545403)")  

        # Connection 875: cell 10, seg 0 (0.5) [0.5 on Ipop[10]] -> cell 75, seg 0 (0.5) [0.5 on Epop[75]], weight: -0.0016545403, delay 1.5
        h("Epop[75] syn_projIE_gaba[875] = new gaba(0.5)")
        h("Ipop[10] netConn_projIE_gaba[875] = new NetCon(&v(0.5), syn_projIE_gaba[875], 20.0, 1.5, -0.0016545403)")  

        # Connection 876: cell 10, seg 0 (0.5) [0.5 on Ipop[10]] -> cell 76, seg 0 (0.5) [0.5 on Epop[76]], weight: -0.0016545403, delay 1.5
        h("Epop[76] syn_projIE_gaba[876] = new gaba(0.5)")
        h("Ipop[10] netConn_projIE_gaba[876] = new NetCon(&v(0.5), syn_projIE_gaba[876], 20.0, 1.5, -0.0016545403)")  

        # Connection 877: cell 10, seg 0 (0.5) [0.5 on Ipop[10]] -> cell 77, seg 0 (0.5) [0.5 on Epop[77]], weight: -0.0016545403, delay 1.5
        h("Epop[77] syn_projIE_gaba[877] = new gaba(0.5)")
        h("Ipop[10] netConn_projIE_gaba[877] = new NetCon(&v(0.5), syn_projIE_gaba[877], 20.0, 1.5, -0.0016545403)")  

        # Connection 878: cell 10, seg 0 (0.5) [0.5 on Ipop[10]] -> cell 78, seg 0 (0.5) [0.5 on Epop[78]], weight: -0.0016545403, delay 1.5
        h("Epop[78] syn_projIE_gaba[878] = new gaba(0.5)")
        h("Ipop[10] netConn_projIE_gaba[878] = new NetCon(&v(0.5), syn_projIE_gaba[878], 20.0, 1.5, -0.0016545403)")  

        # Connection 879: cell 10, seg 0 (0.5) [0.5 on Ipop[10]] -> cell 79, seg 0 (0.5) [0.5 on Epop[79]], weight: -0.0016545403, delay 1.5
        h("Epop[79] syn_projIE_gaba[879] = new gaba(0.5)")
        h("Ipop[10] netConn_projIE_gaba[879] = new NetCon(&v(0.5), syn_projIE_gaba[879], 20.0, 1.5, -0.0016545403)")  

        # Connection 880: cell 11, seg 0 (0.5) [0.5 on Ipop[11]] -> cell 0, seg 0 (0.5) [0.5 on Epop[0]], weight: -0.0016545403, delay 1.5
        h("Epop[0] syn_projIE_gaba[880] = new gaba(0.5)")
        h("Ipop[11] netConn_projIE_gaba[880] = new NetCon(&v(0.5), syn_projIE_gaba[880], 20.0, 1.5, -0.0016545403)")  

        # Connection 881: cell 11, seg 0 (0.5) [0.5 on Ipop[11]] -> cell 1, seg 0 (0.5) [0.5 on Epop[1]], weight: -0.0016545403, delay 1.5
        h("Epop[1] syn_projIE_gaba[881] = new gaba(0.5)")
        h("Ipop[11] netConn_projIE_gaba[881] = new NetCon(&v(0.5), syn_projIE_gaba[881], 20.0, 1.5, -0.0016545403)")  

        # Connection 882: cell 11, seg 0 (0.5) [0.5 on Ipop[11]] -> cell 2, seg 0 (0.5) [0.5 on Epop[2]], weight: -0.0016545403, delay 1.5
        h("Epop[2] syn_projIE_gaba[882] = new gaba(0.5)")
        h("Ipop[11] netConn_projIE_gaba[882] = new NetCon(&v(0.5), syn_projIE_gaba[882], 20.0, 1.5, -0.0016545403)")  

        # Connection 883: cell 11, seg 0 (0.5) [0.5 on Ipop[11]] -> cell 3, seg 0 (0.5) [0.5 on Epop[3]], weight: -0.0016545403, delay 1.5
        h("Epop[3] syn_projIE_gaba[883] = new gaba(0.5)")
        h("Ipop[11] netConn_projIE_gaba[883] = new NetCon(&v(0.5), syn_projIE_gaba[883], 20.0, 1.5, -0.0016545403)")  

        # Connection 884: cell 11, seg 0 (0.5) [0.5 on Ipop[11]] -> cell 4, seg 0 (0.5) [0.5 on Epop[4]], weight: -0.0016545403, delay 1.5
        h("Epop[4] syn_projIE_gaba[884] = new gaba(0.5)")
        h("Ipop[11] netConn_projIE_gaba[884] = new NetCon(&v(0.5), syn_projIE_gaba[884], 20.0, 1.5, -0.0016545403)")  

        # Connection 885: cell 11, seg 0 (0.5) [0.5 on Ipop[11]] -> cell 5, seg 0 (0.5) [0.5 on Epop[5]], weight: -0.0016545403, delay 1.5
        h("Epop[5] syn_projIE_gaba[885] = new gaba(0.5)")
        h("Ipop[11] netConn_projIE_gaba[885] = new NetCon(&v(0.5), syn_projIE_gaba[885], 20.0, 1.5, -0.0016545403)")  

        # Connection 886: cell 11, seg 0 (0.5) [0.5 on Ipop[11]] -> cell 6, seg 0 (0.5) [0.5 on Epop[6]], weight: -0.0016545403, delay 1.5
        h("Epop[6] syn_projIE_gaba[886] = new gaba(0.5)")
        h("Ipop[11] netConn_projIE_gaba[886] = new NetCon(&v(0.5), syn_projIE_gaba[886], 20.0, 1.5, -0.0016545403)")  

        # Connection 887: cell 11, seg 0 (0.5) [0.5 on Ipop[11]] -> cell 7, seg 0 (0.5) [0.5 on Epop[7]], weight: -0.0016545403, delay 1.5
        h("Epop[7] syn_projIE_gaba[887] = new gaba(0.5)")
        h("Ipop[11] netConn_projIE_gaba[887] = new NetCon(&v(0.5), syn_projIE_gaba[887], 20.0, 1.5, -0.0016545403)")  

        # Connection 888: cell 11, seg 0 (0.5) [0.5 on Ipop[11]] -> cell 8, seg 0 (0.5) [0.5 on Epop[8]], weight: -0.0016545403, delay 1.5
        h("Epop[8] syn_projIE_gaba[888] = new gaba(0.5)")
        h("Ipop[11] netConn_projIE_gaba[888] = new NetCon(&v(0.5), syn_projIE_gaba[888], 20.0, 1.5, -0.0016545403)")  

        # Connection 889: cell 11, seg 0 (0.5) [0.5 on Ipop[11]] -> cell 9, seg 0 (0.5) [0.5 on Epop[9]], weight: -0.0016545403, delay 1.5
        h("Epop[9] syn_projIE_gaba[889] = new gaba(0.5)")
        h("Ipop[11] netConn_projIE_gaba[889] = new NetCon(&v(0.5), syn_projIE_gaba[889], 20.0, 1.5, -0.0016545403)")  

        # Connection 890: cell 11, seg 0 (0.5) [0.5 on Ipop[11]] -> cell 10, seg 0 (0.5) [0.5 on Epop[10]], weight: -0.0016545403, delay 1.5
        h("Epop[10] syn_projIE_gaba[890] = new gaba(0.5)")
        h("Ipop[11] netConn_projIE_gaba[890] = new NetCon(&v(0.5), syn_projIE_gaba[890], 20.0, 1.5, -0.0016545403)")  

        # Connection 891: cell 11, seg 0 (0.5) [0.5 on Ipop[11]] -> cell 11, seg 0 (0.5) [0.5 on Epop[11]], weight: -0.0016545403, delay 1.5
        h("Epop[11] syn_projIE_gaba[891] = new gaba(0.5)")
        h("Ipop[11] netConn_projIE_gaba[891] = new NetCon(&v(0.5), syn_projIE_gaba[891], 20.0, 1.5, -0.0016545403)")  

        # Connection 892: cell 11, seg 0 (0.5) [0.5 on Ipop[11]] -> cell 12, seg 0 (0.5) [0.5 on Epop[12]], weight: -0.0016545403, delay 1.5
        h("Epop[12] syn_projIE_gaba[892] = new gaba(0.5)")
        h("Ipop[11] netConn_projIE_gaba[892] = new NetCon(&v(0.5), syn_projIE_gaba[892], 20.0, 1.5, -0.0016545403)")  

        # Connection 893: cell 11, seg 0 (0.5) [0.5 on Ipop[11]] -> cell 13, seg 0 (0.5) [0.5 on Epop[13]], weight: -0.0016545403, delay 1.5
        h("Epop[13] syn_projIE_gaba[893] = new gaba(0.5)")
        h("Ipop[11] netConn_projIE_gaba[893] = new NetCon(&v(0.5), syn_projIE_gaba[893], 20.0, 1.5, -0.0016545403)")  

        # Connection 894: cell 11, seg 0 (0.5) [0.5 on Ipop[11]] -> cell 14, seg 0 (0.5) [0.5 on Epop[14]], weight: -0.0016545403, delay 1.5
        h("Epop[14] syn_projIE_gaba[894] = new gaba(0.5)")
        h("Ipop[11] netConn_projIE_gaba[894] = new NetCon(&v(0.5), syn_projIE_gaba[894], 20.0, 1.5, -0.0016545403)")  

        # Connection 895: cell 11, seg 0 (0.5) [0.5 on Ipop[11]] -> cell 15, seg 0 (0.5) [0.5 on Epop[15]], weight: -0.0016545403, delay 1.5
        h("Epop[15] syn_projIE_gaba[895] = new gaba(0.5)")
        h("Ipop[11] netConn_projIE_gaba[895] = new NetCon(&v(0.5), syn_projIE_gaba[895], 20.0, 1.5, -0.0016545403)")  

        # Connection 896: cell 11, seg 0 (0.5) [0.5 on Ipop[11]] -> cell 16, seg 0 (0.5) [0.5 on Epop[16]], weight: -0.0016545403, delay 1.5
        h("Epop[16] syn_projIE_gaba[896] = new gaba(0.5)")
        h("Ipop[11] netConn_projIE_gaba[896] = new NetCon(&v(0.5), syn_projIE_gaba[896], 20.0, 1.5, -0.0016545403)")  

        # Connection 897: cell 11, seg 0 (0.5) [0.5 on Ipop[11]] -> cell 17, seg 0 (0.5) [0.5 on Epop[17]], weight: -0.0016545403, delay 1.5
        h("Epop[17] syn_projIE_gaba[897] = new gaba(0.5)")
        h("Ipop[11] netConn_projIE_gaba[897] = new NetCon(&v(0.5), syn_projIE_gaba[897], 20.0, 1.5, -0.0016545403)")  

        # Connection 898: cell 11, seg 0 (0.5) [0.5 on Ipop[11]] -> cell 18, seg 0 (0.5) [0.5 on Epop[18]], weight: -0.0016545403, delay 1.5
        h("Epop[18] syn_projIE_gaba[898] = new gaba(0.5)")
        h("Ipop[11] netConn_projIE_gaba[898] = new NetCon(&v(0.5), syn_projIE_gaba[898], 20.0, 1.5, -0.0016545403)")  

        # Connection 899: cell 11, seg 0 (0.5) [0.5 on Ipop[11]] -> cell 19, seg 0 (0.5) [0.5 on Epop[19]], weight: -0.0016545403, delay 1.5
        h("Epop[19] syn_projIE_gaba[899] = new gaba(0.5)")
        h("Ipop[11] netConn_projIE_gaba[899] = new NetCon(&v(0.5), syn_projIE_gaba[899], 20.0, 1.5, -0.0016545403)")  

        # Connection 900: cell 11, seg 0 (0.5) [0.5 on Ipop[11]] -> cell 20, seg 0 (0.5) [0.5 on Epop[20]], weight: -0.0016545403, delay 1.5
        h("Epop[20] syn_projIE_gaba[900] = new gaba(0.5)")
        h("Ipop[11] netConn_projIE_gaba[900] = new NetCon(&v(0.5), syn_projIE_gaba[900], 20.0, 1.5, -0.0016545403)")  

        # Connection 901: cell 11, seg 0 (0.5) [0.5 on Ipop[11]] -> cell 21, seg 0 (0.5) [0.5 on Epop[21]], weight: -0.0016545403, delay 1.5
        h("Epop[21] syn_projIE_gaba[901] = new gaba(0.5)")
        h("Ipop[11] netConn_projIE_gaba[901] = new NetCon(&v(0.5), syn_projIE_gaba[901], 20.0, 1.5, -0.0016545403)")  

        # Connection 902: cell 11, seg 0 (0.5) [0.5 on Ipop[11]] -> cell 22, seg 0 (0.5) [0.5 on Epop[22]], weight: -0.0016545403, delay 1.5
        h("Epop[22] syn_projIE_gaba[902] = new gaba(0.5)")
        h("Ipop[11] netConn_projIE_gaba[902] = new NetCon(&v(0.5), syn_projIE_gaba[902], 20.0, 1.5, -0.0016545403)")  

        # Connection 903: cell 11, seg 0 (0.5) [0.5 on Ipop[11]] -> cell 23, seg 0 (0.5) [0.5 on Epop[23]], weight: -0.0016545403, delay 1.5
        h("Epop[23] syn_projIE_gaba[903] = new gaba(0.5)")
        h("Ipop[11] netConn_projIE_gaba[903] = new NetCon(&v(0.5), syn_projIE_gaba[903], 20.0, 1.5, -0.0016545403)")  

        # Connection 904: cell 11, seg 0 (0.5) [0.5 on Ipop[11]] -> cell 24, seg 0 (0.5) [0.5 on Epop[24]], weight: -0.0016545403, delay 1.5
        h("Epop[24] syn_projIE_gaba[904] = new gaba(0.5)")
        h("Ipop[11] netConn_projIE_gaba[904] = new NetCon(&v(0.5), syn_projIE_gaba[904], 20.0, 1.5, -0.0016545403)")  

        # Connection 905: cell 11, seg 0 (0.5) [0.5 on Ipop[11]] -> cell 25, seg 0 (0.5) [0.5 on Epop[25]], weight: -0.0016545403, delay 1.5
        h("Epop[25] syn_projIE_gaba[905] = new gaba(0.5)")
        h("Ipop[11] netConn_projIE_gaba[905] = new NetCon(&v(0.5), syn_projIE_gaba[905], 20.0, 1.5, -0.0016545403)")  

        # Connection 906: cell 11, seg 0 (0.5) [0.5 on Ipop[11]] -> cell 26, seg 0 (0.5) [0.5 on Epop[26]], weight: -0.0016545403, delay 1.5
        h("Epop[26] syn_projIE_gaba[906] = new gaba(0.5)")
        h("Ipop[11] netConn_projIE_gaba[906] = new NetCon(&v(0.5), syn_projIE_gaba[906], 20.0, 1.5, -0.0016545403)")  

        # Connection 907: cell 11, seg 0 (0.5) [0.5 on Ipop[11]] -> cell 27, seg 0 (0.5) [0.5 on Epop[27]], weight: -0.0016545403, delay 1.5
        h("Epop[27] syn_projIE_gaba[907] = new gaba(0.5)")
        h("Ipop[11] netConn_projIE_gaba[907] = new NetCon(&v(0.5), syn_projIE_gaba[907], 20.0, 1.5, -0.0016545403)")  

        # Connection 908: cell 11, seg 0 (0.5) [0.5 on Ipop[11]] -> cell 28, seg 0 (0.5) [0.5 on Epop[28]], weight: -0.0016545403, delay 1.5
        h("Epop[28] syn_projIE_gaba[908] = new gaba(0.5)")
        h("Ipop[11] netConn_projIE_gaba[908] = new NetCon(&v(0.5), syn_projIE_gaba[908], 20.0, 1.5, -0.0016545403)")  

        # Connection 909: cell 11, seg 0 (0.5) [0.5 on Ipop[11]] -> cell 29, seg 0 (0.5) [0.5 on Epop[29]], weight: -0.0016545403, delay 1.5
        h("Epop[29] syn_projIE_gaba[909] = new gaba(0.5)")
        h("Ipop[11] netConn_projIE_gaba[909] = new NetCon(&v(0.5), syn_projIE_gaba[909], 20.0, 1.5, -0.0016545403)")  

        # Connection 910: cell 11, seg 0 (0.5) [0.5 on Ipop[11]] -> cell 30, seg 0 (0.5) [0.5 on Epop[30]], weight: -0.0016545403, delay 1.5
        h("Epop[30] syn_projIE_gaba[910] = new gaba(0.5)")
        h("Ipop[11] netConn_projIE_gaba[910] = new NetCon(&v(0.5), syn_projIE_gaba[910], 20.0, 1.5, -0.0016545403)")  

        # Connection 911: cell 11, seg 0 (0.5) [0.5 on Ipop[11]] -> cell 31, seg 0 (0.5) [0.5 on Epop[31]], weight: -0.0016545403, delay 1.5
        h("Epop[31] syn_projIE_gaba[911] = new gaba(0.5)")
        h("Ipop[11] netConn_projIE_gaba[911] = new NetCon(&v(0.5), syn_projIE_gaba[911], 20.0, 1.5, -0.0016545403)")  

        # Connection 912: cell 11, seg 0 (0.5) [0.5 on Ipop[11]] -> cell 32, seg 0 (0.5) [0.5 on Epop[32]], weight: -0.0016545403, delay 1.5
        h("Epop[32] syn_projIE_gaba[912] = new gaba(0.5)")
        h("Ipop[11] netConn_projIE_gaba[912] = new NetCon(&v(0.5), syn_projIE_gaba[912], 20.0, 1.5, -0.0016545403)")  

        # Connection 913: cell 11, seg 0 (0.5) [0.5 on Ipop[11]] -> cell 33, seg 0 (0.5) [0.5 on Epop[33]], weight: -0.0016545403, delay 1.5
        h("Epop[33] syn_projIE_gaba[913] = new gaba(0.5)")
        h("Ipop[11] netConn_projIE_gaba[913] = new NetCon(&v(0.5), syn_projIE_gaba[913], 20.0, 1.5, -0.0016545403)")  

        # Connection 914: cell 11, seg 0 (0.5) [0.5 on Ipop[11]] -> cell 34, seg 0 (0.5) [0.5 on Epop[34]], weight: -0.0016545403, delay 1.5
        h("Epop[34] syn_projIE_gaba[914] = new gaba(0.5)")
        h("Ipop[11] netConn_projIE_gaba[914] = new NetCon(&v(0.5), syn_projIE_gaba[914], 20.0, 1.5, -0.0016545403)")  

        # Connection 915: cell 11, seg 0 (0.5) [0.5 on Ipop[11]] -> cell 35, seg 0 (0.5) [0.5 on Epop[35]], weight: -0.0016545403, delay 1.5
        h("Epop[35] syn_projIE_gaba[915] = new gaba(0.5)")
        h("Ipop[11] netConn_projIE_gaba[915] = new NetCon(&v(0.5), syn_projIE_gaba[915], 20.0, 1.5, -0.0016545403)")  

        # Connection 916: cell 11, seg 0 (0.5) [0.5 on Ipop[11]] -> cell 36, seg 0 (0.5) [0.5 on Epop[36]], weight: -0.0016545403, delay 1.5
        h("Epop[36] syn_projIE_gaba[916] = new gaba(0.5)")
        h("Ipop[11] netConn_projIE_gaba[916] = new NetCon(&v(0.5), syn_projIE_gaba[916], 20.0, 1.5, -0.0016545403)")  

        # Connection 917: cell 11, seg 0 (0.5) [0.5 on Ipop[11]] -> cell 37, seg 0 (0.5) [0.5 on Epop[37]], weight: -0.0016545403, delay 1.5
        h("Epop[37] syn_projIE_gaba[917] = new gaba(0.5)")
        h("Ipop[11] netConn_projIE_gaba[917] = new NetCon(&v(0.5), syn_projIE_gaba[917], 20.0, 1.5, -0.0016545403)")  

        # Connection 918: cell 11, seg 0 (0.5) [0.5 on Ipop[11]] -> cell 38, seg 0 (0.5) [0.5 on Epop[38]], weight: -0.0016545403, delay 1.5
        h("Epop[38] syn_projIE_gaba[918] = new gaba(0.5)")
        h("Ipop[11] netConn_projIE_gaba[918] = new NetCon(&v(0.5), syn_projIE_gaba[918], 20.0, 1.5, -0.0016545403)")  

        # Connection 919: cell 11, seg 0 (0.5) [0.5 on Ipop[11]] -> cell 39, seg 0 (0.5) [0.5 on Epop[39]], weight: -0.0016545403, delay 1.5
        h("Epop[39] syn_projIE_gaba[919] = new gaba(0.5)")
        h("Ipop[11] netConn_projIE_gaba[919] = new NetCon(&v(0.5), syn_projIE_gaba[919], 20.0, 1.5, -0.0016545403)")  

        # Connection 920: cell 11, seg 0 (0.5) [0.5 on Ipop[11]] -> cell 40, seg 0 (0.5) [0.5 on Epop[40]], weight: -0.0016545403, delay 1.5
        h("Epop[40] syn_projIE_gaba[920] = new gaba(0.5)")
        h("Ipop[11] netConn_projIE_gaba[920] = new NetCon(&v(0.5), syn_projIE_gaba[920], 20.0, 1.5, -0.0016545403)")  

        # Connection 921: cell 11, seg 0 (0.5) [0.5 on Ipop[11]] -> cell 41, seg 0 (0.5) [0.5 on Epop[41]], weight: -0.0016545403, delay 1.5
        h("Epop[41] syn_projIE_gaba[921] = new gaba(0.5)")
        h("Ipop[11] netConn_projIE_gaba[921] = new NetCon(&v(0.5), syn_projIE_gaba[921], 20.0, 1.5, -0.0016545403)")  

        # Connection 922: cell 11, seg 0 (0.5) [0.5 on Ipop[11]] -> cell 42, seg 0 (0.5) [0.5 on Epop[42]], weight: -0.0016545403, delay 1.5
        h("Epop[42] syn_projIE_gaba[922] = new gaba(0.5)")
        h("Ipop[11] netConn_projIE_gaba[922] = new NetCon(&v(0.5), syn_projIE_gaba[922], 20.0, 1.5, -0.0016545403)")  

        # Connection 923: cell 11, seg 0 (0.5) [0.5 on Ipop[11]] -> cell 43, seg 0 (0.5) [0.5 on Epop[43]], weight: -0.0016545403, delay 1.5
        h("Epop[43] syn_projIE_gaba[923] = new gaba(0.5)")
        h("Ipop[11] netConn_projIE_gaba[923] = new NetCon(&v(0.5), syn_projIE_gaba[923], 20.0, 1.5, -0.0016545403)")  

        # Connection 924: cell 11, seg 0 (0.5) [0.5 on Ipop[11]] -> cell 44, seg 0 (0.5) [0.5 on Epop[44]], weight: -0.0016545403, delay 1.5
        h("Epop[44] syn_projIE_gaba[924] = new gaba(0.5)")
        h("Ipop[11] netConn_projIE_gaba[924] = new NetCon(&v(0.5), syn_projIE_gaba[924], 20.0, 1.5, -0.0016545403)")  

        # Connection 925: cell 11, seg 0 (0.5) [0.5 on Ipop[11]] -> cell 45, seg 0 (0.5) [0.5 on Epop[45]], weight: -0.0016545403, delay 1.5
        h("Epop[45] syn_projIE_gaba[925] = new gaba(0.5)")
        h("Ipop[11] netConn_projIE_gaba[925] = new NetCon(&v(0.5), syn_projIE_gaba[925], 20.0, 1.5, -0.0016545403)")  

        # Connection 926: cell 11, seg 0 (0.5) [0.5 on Ipop[11]] -> cell 46, seg 0 (0.5) [0.5 on Epop[46]], weight: -0.0016545403, delay 1.5
        h("Epop[46] syn_projIE_gaba[926] = new gaba(0.5)")
        h("Ipop[11] netConn_projIE_gaba[926] = new NetCon(&v(0.5), syn_projIE_gaba[926], 20.0, 1.5, -0.0016545403)")  

        # Connection 927: cell 11, seg 0 (0.5) [0.5 on Ipop[11]] -> cell 47, seg 0 (0.5) [0.5 on Epop[47]], weight: -0.0016545403, delay 1.5
        h("Epop[47] syn_projIE_gaba[927] = new gaba(0.5)")
        h("Ipop[11] netConn_projIE_gaba[927] = new NetCon(&v(0.5), syn_projIE_gaba[927], 20.0, 1.5, -0.0016545403)")  

        # Connection 928: cell 11, seg 0 (0.5) [0.5 on Ipop[11]] -> cell 48, seg 0 (0.5) [0.5 on Epop[48]], weight: -0.0016545403, delay 1.5
        h("Epop[48] syn_projIE_gaba[928] = new gaba(0.5)")
        h("Ipop[11] netConn_projIE_gaba[928] = new NetCon(&v(0.5), syn_projIE_gaba[928], 20.0, 1.5, -0.0016545403)")  

        # Connection 929: cell 11, seg 0 (0.5) [0.5 on Ipop[11]] -> cell 49, seg 0 (0.5) [0.5 on Epop[49]], weight: -0.0016545403, delay 1.5
        h("Epop[49] syn_projIE_gaba[929] = new gaba(0.5)")
        h("Ipop[11] netConn_projIE_gaba[929] = new NetCon(&v(0.5), syn_projIE_gaba[929], 20.0, 1.5, -0.0016545403)")  

        # Connection 930: cell 11, seg 0 (0.5) [0.5 on Ipop[11]] -> cell 50, seg 0 (0.5) [0.5 on Epop[50]], weight: -0.0016545403, delay 1.5
        h("Epop[50] syn_projIE_gaba[930] = new gaba(0.5)")
        h("Ipop[11] netConn_projIE_gaba[930] = new NetCon(&v(0.5), syn_projIE_gaba[930], 20.0, 1.5, -0.0016545403)")  

        # Connection 931: cell 11, seg 0 (0.5) [0.5 on Ipop[11]] -> cell 51, seg 0 (0.5) [0.5 on Epop[51]], weight: -0.0016545403, delay 1.5
        h("Epop[51] syn_projIE_gaba[931] = new gaba(0.5)")
        h("Ipop[11] netConn_projIE_gaba[931] = new NetCon(&v(0.5), syn_projIE_gaba[931], 20.0, 1.5, -0.0016545403)")  

        # Connection 932: cell 11, seg 0 (0.5) [0.5 on Ipop[11]] -> cell 52, seg 0 (0.5) [0.5 on Epop[52]], weight: -0.0016545403, delay 1.5
        h("Epop[52] syn_projIE_gaba[932] = new gaba(0.5)")
        h("Ipop[11] netConn_projIE_gaba[932] = new NetCon(&v(0.5), syn_projIE_gaba[932], 20.0, 1.5, -0.0016545403)")  

        # Connection 933: cell 11, seg 0 (0.5) [0.5 on Ipop[11]] -> cell 53, seg 0 (0.5) [0.5 on Epop[53]], weight: -0.0016545403, delay 1.5
        h("Epop[53] syn_projIE_gaba[933] = new gaba(0.5)")
        h("Ipop[11] netConn_projIE_gaba[933] = new NetCon(&v(0.5), syn_projIE_gaba[933], 20.0, 1.5, -0.0016545403)")  

        # Connection 934: cell 11, seg 0 (0.5) [0.5 on Ipop[11]] -> cell 54, seg 0 (0.5) [0.5 on Epop[54]], weight: -0.0016545403, delay 1.5
        h("Epop[54] syn_projIE_gaba[934] = new gaba(0.5)")
        h("Ipop[11] netConn_projIE_gaba[934] = new NetCon(&v(0.5), syn_projIE_gaba[934], 20.0, 1.5, -0.0016545403)")  

        # Connection 935: cell 11, seg 0 (0.5) [0.5 on Ipop[11]] -> cell 55, seg 0 (0.5) [0.5 on Epop[55]], weight: -0.0016545403, delay 1.5
        h("Epop[55] syn_projIE_gaba[935] = new gaba(0.5)")
        h("Ipop[11] netConn_projIE_gaba[935] = new NetCon(&v(0.5), syn_projIE_gaba[935], 20.0, 1.5, -0.0016545403)")  

        # Connection 936: cell 11, seg 0 (0.5) [0.5 on Ipop[11]] -> cell 56, seg 0 (0.5) [0.5 on Epop[56]], weight: -0.0016545403, delay 1.5
        h("Epop[56] syn_projIE_gaba[936] = new gaba(0.5)")
        h("Ipop[11] netConn_projIE_gaba[936] = new NetCon(&v(0.5), syn_projIE_gaba[936], 20.0, 1.5, -0.0016545403)")  

        # Connection 937: cell 11, seg 0 (0.5) [0.5 on Ipop[11]] -> cell 57, seg 0 (0.5) [0.5 on Epop[57]], weight: -0.0016545403, delay 1.5
        h("Epop[57] syn_projIE_gaba[937] = new gaba(0.5)")
        h("Ipop[11] netConn_projIE_gaba[937] = new NetCon(&v(0.5), syn_projIE_gaba[937], 20.0, 1.5, -0.0016545403)")  

        # Connection 938: cell 11, seg 0 (0.5) [0.5 on Ipop[11]] -> cell 58, seg 0 (0.5) [0.5 on Epop[58]], weight: -0.0016545403, delay 1.5
        h("Epop[58] syn_projIE_gaba[938] = new gaba(0.5)")
        h("Ipop[11] netConn_projIE_gaba[938] = new NetCon(&v(0.5), syn_projIE_gaba[938], 20.0, 1.5, -0.0016545403)")  

        # Connection 939: cell 11, seg 0 (0.5) [0.5 on Ipop[11]] -> cell 59, seg 0 (0.5) [0.5 on Epop[59]], weight: -0.0016545403, delay 1.5
        h("Epop[59] syn_projIE_gaba[939] = new gaba(0.5)")
        h("Ipop[11] netConn_projIE_gaba[939] = new NetCon(&v(0.5), syn_projIE_gaba[939], 20.0, 1.5, -0.0016545403)")  

        # Connection 940: cell 11, seg 0 (0.5) [0.5 on Ipop[11]] -> cell 60, seg 0 (0.5) [0.5 on Epop[60]], weight: -0.0016545403, delay 1.5
        h("Epop[60] syn_projIE_gaba[940] = new gaba(0.5)")
        h("Ipop[11] netConn_projIE_gaba[940] = new NetCon(&v(0.5), syn_projIE_gaba[940], 20.0, 1.5, -0.0016545403)")  

        # Connection 941: cell 11, seg 0 (0.5) [0.5 on Ipop[11]] -> cell 61, seg 0 (0.5) [0.5 on Epop[61]], weight: -0.0016545403, delay 1.5
        h("Epop[61] syn_projIE_gaba[941] = new gaba(0.5)")
        h("Ipop[11] netConn_projIE_gaba[941] = new NetCon(&v(0.5), syn_projIE_gaba[941], 20.0, 1.5, -0.0016545403)")  

        # Connection 942: cell 11, seg 0 (0.5) [0.5 on Ipop[11]] -> cell 62, seg 0 (0.5) [0.5 on Epop[62]], weight: -0.0016545403, delay 1.5
        h("Epop[62] syn_projIE_gaba[942] = new gaba(0.5)")
        h("Ipop[11] netConn_projIE_gaba[942] = new NetCon(&v(0.5), syn_projIE_gaba[942], 20.0, 1.5, -0.0016545403)")  

        # Connection 943: cell 11, seg 0 (0.5) [0.5 on Ipop[11]] -> cell 63, seg 0 (0.5) [0.5 on Epop[63]], weight: -0.0016545403, delay 1.5
        h("Epop[63] syn_projIE_gaba[943] = new gaba(0.5)")
        h("Ipop[11] netConn_projIE_gaba[943] = new NetCon(&v(0.5), syn_projIE_gaba[943], 20.0, 1.5, -0.0016545403)")  

        # Connection 944: cell 11, seg 0 (0.5) [0.5 on Ipop[11]] -> cell 64, seg 0 (0.5) [0.5 on Epop[64]], weight: -0.0016545403, delay 1.5
        h("Epop[64] syn_projIE_gaba[944] = new gaba(0.5)")
        h("Ipop[11] netConn_projIE_gaba[944] = new NetCon(&v(0.5), syn_projIE_gaba[944], 20.0, 1.5, -0.0016545403)")  

        # Connection 945: cell 11, seg 0 (0.5) [0.5 on Ipop[11]] -> cell 65, seg 0 (0.5) [0.5 on Epop[65]], weight: -0.0016545403, delay 1.5
        h("Epop[65] syn_projIE_gaba[945] = new gaba(0.5)")
        h("Ipop[11] netConn_projIE_gaba[945] = new NetCon(&v(0.5), syn_projIE_gaba[945], 20.0, 1.5, -0.0016545403)")  

        # Connection 946: cell 11, seg 0 (0.5) [0.5 on Ipop[11]] -> cell 66, seg 0 (0.5) [0.5 on Epop[66]], weight: -0.0016545403, delay 1.5
        h("Epop[66] syn_projIE_gaba[946] = new gaba(0.5)")
        h("Ipop[11] netConn_projIE_gaba[946] = new NetCon(&v(0.5), syn_projIE_gaba[946], 20.0, 1.5, -0.0016545403)")  

        # Connection 947: cell 11, seg 0 (0.5) [0.5 on Ipop[11]] -> cell 67, seg 0 (0.5) [0.5 on Epop[67]], weight: -0.0016545403, delay 1.5
        h("Epop[67] syn_projIE_gaba[947] = new gaba(0.5)")
        h("Ipop[11] netConn_projIE_gaba[947] = new NetCon(&v(0.5), syn_projIE_gaba[947], 20.0, 1.5, -0.0016545403)")  

        # Connection 948: cell 11, seg 0 (0.5) [0.5 on Ipop[11]] -> cell 68, seg 0 (0.5) [0.5 on Epop[68]], weight: -0.0016545403, delay 1.5
        h("Epop[68] syn_projIE_gaba[948] = new gaba(0.5)")
        h("Ipop[11] netConn_projIE_gaba[948] = new NetCon(&v(0.5), syn_projIE_gaba[948], 20.0, 1.5, -0.0016545403)")  

        # Connection 949: cell 11, seg 0 (0.5) [0.5 on Ipop[11]] -> cell 69, seg 0 (0.5) [0.5 on Epop[69]], weight: -0.0016545403, delay 1.5
        h("Epop[69] syn_projIE_gaba[949] = new gaba(0.5)")
        h("Ipop[11] netConn_projIE_gaba[949] = new NetCon(&v(0.5), syn_projIE_gaba[949], 20.0, 1.5, -0.0016545403)")  

        # Connection 950: cell 11, seg 0 (0.5) [0.5 on Ipop[11]] -> cell 70, seg 0 (0.5) [0.5 on Epop[70]], weight: -0.0016545403, delay 1.5
        h("Epop[70] syn_projIE_gaba[950] = new gaba(0.5)")
        h("Ipop[11] netConn_projIE_gaba[950] = new NetCon(&v(0.5), syn_projIE_gaba[950], 20.0, 1.5, -0.0016545403)")  

        # Connection 951: cell 11, seg 0 (0.5) [0.5 on Ipop[11]] -> cell 71, seg 0 (0.5) [0.5 on Epop[71]], weight: -0.0016545403, delay 1.5
        h("Epop[71] syn_projIE_gaba[951] = new gaba(0.5)")
        h("Ipop[11] netConn_projIE_gaba[951] = new NetCon(&v(0.5), syn_projIE_gaba[951], 20.0, 1.5, -0.0016545403)")  

        # Connection 952: cell 11, seg 0 (0.5) [0.5 on Ipop[11]] -> cell 72, seg 0 (0.5) [0.5 on Epop[72]], weight: -0.0016545403, delay 1.5
        h("Epop[72] syn_projIE_gaba[952] = new gaba(0.5)")
        h("Ipop[11] netConn_projIE_gaba[952] = new NetCon(&v(0.5), syn_projIE_gaba[952], 20.0, 1.5, -0.0016545403)")  

        # Connection 953: cell 11, seg 0 (0.5) [0.5 on Ipop[11]] -> cell 73, seg 0 (0.5) [0.5 on Epop[73]], weight: -0.0016545403, delay 1.5
        h("Epop[73] syn_projIE_gaba[953] = new gaba(0.5)")
        h("Ipop[11] netConn_projIE_gaba[953] = new NetCon(&v(0.5), syn_projIE_gaba[953], 20.0, 1.5, -0.0016545403)")  

        # Connection 954: cell 11, seg 0 (0.5) [0.5 on Ipop[11]] -> cell 74, seg 0 (0.5) [0.5 on Epop[74]], weight: -0.0016545403, delay 1.5
        h("Epop[74] syn_projIE_gaba[954] = new gaba(0.5)")
        h("Ipop[11] netConn_projIE_gaba[954] = new NetCon(&v(0.5), syn_projIE_gaba[954], 20.0, 1.5, -0.0016545403)")  

        # Connection 955: cell 11, seg 0 (0.5) [0.5 on Ipop[11]] -> cell 75, seg 0 (0.5) [0.5 on Epop[75]], weight: -0.0016545403, delay 1.5
        h("Epop[75] syn_projIE_gaba[955] = new gaba(0.5)")
        h("Ipop[11] netConn_projIE_gaba[955] = new NetCon(&v(0.5), syn_projIE_gaba[955], 20.0, 1.5, -0.0016545403)")  

        # Connection 956: cell 11, seg 0 (0.5) [0.5 on Ipop[11]] -> cell 76, seg 0 (0.5) [0.5 on Epop[76]], weight: -0.0016545403, delay 1.5
        h("Epop[76] syn_projIE_gaba[956] = new gaba(0.5)")
        h("Ipop[11] netConn_projIE_gaba[956] = new NetCon(&v(0.5), syn_projIE_gaba[956], 20.0, 1.5, -0.0016545403)")  

        # Connection 957: cell 11, seg 0 (0.5) [0.5 on Ipop[11]] -> cell 77, seg 0 (0.5) [0.5 on Epop[77]], weight: -0.0016545403, delay 1.5
        h("Epop[77] syn_projIE_gaba[957] = new gaba(0.5)")
        h("Ipop[11] netConn_projIE_gaba[957] = new NetCon(&v(0.5), syn_projIE_gaba[957], 20.0, 1.5, -0.0016545403)")  

        # Connection 958: cell 11, seg 0 (0.5) [0.5 on Ipop[11]] -> cell 78, seg 0 (0.5) [0.5 on Epop[78]], weight: -0.0016545403, delay 1.5
        h("Epop[78] syn_projIE_gaba[958] = new gaba(0.5)")
        h("Ipop[11] netConn_projIE_gaba[958] = new NetCon(&v(0.5), syn_projIE_gaba[958], 20.0, 1.5, -0.0016545403)")  

        # Connection 959: cell 11, seg 0 (0.5) [0.5 on Ipop[11]] -> cell 79, seg 0 (0.5) [0.5 on Epop[79]], weight: -0.0016545403, delay 1.5
        h("Epop[79] syn_projIE_gaba[959] = new gaba(0.5)")
        h("Ipop[11] netConn_projIE_gaba[959] = new NetCon(&v(0.5), syn_projIE_gaba[959], 20.0, 1.5, -0.0016545403)")  

        # Connection 960: cell 12, seg 0 (0.5) [0.5 on Ipop[12]] -> cell 0, seg 0 (0.5) [0.5 on Epop[0]], weight: -0.0016545403, delay 1.5
        h("Epop[0] syn_projIE_gaba[960] = new gaba(0.5)")
        h("Ipop[12] netConn_projIE_gaba[960] = new NetCon(&v(0.5), syn_projIE_gaba[960], 20.0, 1.5, -0.0016545403)")  

        # Connection 961: cell 12, seg 0 (0.5) [0.5 on Ipop[12]] -> cell 1, seg 0 (0.5) [0.5 on Epop[1]], weight: -0.0016545403, delay 1.5
        h("Epop[1] syn_projIE_gaba[961] = new gaba(0.5)")
        h("Ipop[12] netConn_projIE_gaba[961] = new NetCon(&v(0.5), syn_projIE_gaba[961], 20.0, 1.5, -0.0016545403)")  

        # Connection 962: cell 12, seg 0 (0.5) [0.5 on Ipop[12]] -> cell 2, seg 0 (0.5) [0.5 on Epop[2]], weight: -0.0016545403, delay 1.5
        h("Epop[2] syn_projIE_gaba[962] = new gaba(0.5)")
        h("Ipop[12] netConn_projIE_gaba[962] = new NetCon(&v(0.5), syn_projIE_gaba[962], 20.0, 1.5, -0.0016545403)")  

        # Connection 963: cell 12, seg 0 (0.5) [0.5 on Ipop[12]] -> cell 3, seg 0 (0.5) [0.5 on Epop[3]], weight: -0.0016545403, delay 1.5
        h("Epop[3] syn_projIE_gaba[963] = new gaba(0.5)")
        h("Ipop[12] netConn_projIE_gaba[963] = new NetCon(&v(0.5), syn_projIE_gaba[963], 20.0, 1.5, -0.0016545403)")  

        # Connection 964: cell 12, seg 0 (0.5) [0.5 on Ipop[12]] -> cell 4, seg 0 (0.5) [0.5 on Epop[4]], weight: -0.0016545403, delay 1.5
        h("Epop[4] syn_projIE_gaba[964] = new gaba(0.5)")
        h("Ipop[12] netConn_projIE_gaba[964] = new NetCon(&v(0.5), syn_projIE_gaba[964], 20.0, 1.5, -0.0016545403)")  

        # Connection 965: cell 12, seg 0 (0.5) [0.5 on Ipop[12]] -> cell 5, seg 0 (0.5) [0.5 on Epop[5]], weight: -0.0016545403, delay 1.5
        h("Epop[5] syn_projIE_gaba[965] = new gaba(0.5)")
        h("Ipop[12] netConn_projIE_gaba[965] = new NetCon(&v(0.5), syn_projIE_gaba[965], 20.0, 1.5, -0.0016545403)")  

        # Connection 966: cell 12, seg 0 (0.5) [0.5 on Ipop[12]] -> cell 6, seg 0 (0.5) [0.5 on Epop[6]], weight: -0.0016545403, delay 1.5
        h("Epop[6] syn_projIE_gaba[966] = new gaba(0.5)")
        h("Ipop[12] netConn_projIE_gaba[966] = new NetCon(&v(0.5), syn_projIE_gaba[966], 20.0, 1.5, -0.0016545403)")  

        # Connection 967: cell 12, seg 0 (0.5) [0.5 on Ipop[12]] -> cell 7, seg 0 (0.5) [0.5 on Epop[7]], weight: -0.0016545403, delay 1.5
        h("Epop[7] syn_projIE_gaba[967] = new gaba(0.5)")
        h("Ipop[12] netConn_projIE_gaba[967] = new NetCon(&v(0.5), syn_projIE_gaba[967], 20.0, 1.5, -0.0016545403)")  

        # Connection 968: cell 12, seg 0 (0.5) [0.5 on Ipop[12]] -> cell 8, seg 0 (0.5) [0.5 on Epop[8]], weight: -0.0016545403, delay 1.5
        h("Epop[8] syn_projIE_gaba[968] = new gaba(0.5)")
        h("Ipop[12] netConn_projIE_gaba[968] = new NetCon(&v(0.5), syn_projIE_gaba[968], 20.0, 1.5, -0.0016545403)")  

        # Connection 969: cell 12, seg 0 (0.5) [0.5 on Ipop[12]] -> cell 9, seg 0 (0.5) [0.5 on Epop[9]], weight: -0.0016545403, delay 1.5
        h("Epop[9] syn_projIE_gaba[969] = new gaba(0.5)")
        h("Ipop[12] netConn_projIE_gaba[969] = new NetCon(&v(0.5), syn_projIE_gaba[969], 20.0, 1.5, -0.0016545403)")  

        # Connection 970: cell 12, seg 0 (0.5) [0.5 on Ipop[12]] -> cell 10, seg 0 (0.5) [0.5 on Epop[10]], weight: -0.0016545403, delay 1.5
        h("Epop[10] syn_projIE_gaba[970] = new gaba(0.5)")
        h("Ipop[12] netConn_projIE_gaba[970] = new NetCon(&v(0.5), syn_projIE_gaba[970], 20.0, 1.5, -0.0016545403)")  

        # Connection 971: cell 12, seg 0 (0.5) [0.5 on Ipop[12]] -> cell 11, seg 0 (0.5) [0.5 on Epop[11]], weight: -0.0016545403, delay 1.5
        h("Epop[11] syn_projIE_gaba[971] = new gaba(0.5)")
        h("Ipop[12] netConn_projIE_gaba[971] = new NetCon(&v(0.5), syn_projIE_gaba[971], 20.0, 1.5, -0.0016545403)")  

        # Connection 972: cell 12, seg 0 (0.5) [0.5 on Ipop[12]] -> cell 12, seg 0 (0.5) [0.5 on Epop[12]], weight: -0.0016545403, delay 1.5
        h("Epop[12] syn_projIE_gaba[972] = new gaba(0.5)")
        h("Ipop[12] netConn_projIE_gaba[972] = new NetCon(&v(0.5), syn_projIE_gaba[972], 20.0, 1.5, -0.0016545403)")  

        # Connection 973: cell 12, seg 0 (0.5) [0.5 on Ipop[12]] -> cell 13, seg 0 (0.5) [0.5 on Epop[13]], weight: -0.0016545403, delay 1.5
        h("Epop[13] syn_projIE_gaba[973] = new gaba(0.5)")
        h("Ipop[12] netConn_projIE_gaba[973] = new NetCon(&v(0.5), syn_projIE_gaba[973], 20.0, 1.5, -0.0016545403)")  

        # Connection 974: cell 12, seg 0 (0.5) [0.5 on Ipop[12]] -> cell 14, seg 0 (0.5) [0.5 on Epop[14]], weight: -0.0016545403, delay 1.5
        h("Epop[14] syn_projIE_gaba[974] = new gaba(0.5)")
        h("Ipop[12] netConn_projIE_gaba[974] = new NetCon(&v(0.5), syn_projIE_gaba[974], 20.0, 1.5, -0.0016545403)")  

        # Connection 975: cell 12, seg 0 (0.5) [0.5 on Ipop[12]] -> cell 15, seg 0 (0.5) [0.5 on Epop[15]], weight: -0.0016545403, delay 1.5
        h("Epop[15] syn_projIE_gaba[975] = new gaba(0.5)")
        h("Ipop[12] netConn_projIE_gaba[975] = new NetCon(&v(0.5), syn_projIE_gaba[975], 20.0, 1.5, -0.0016545403)")  

        # Connection 976: cell 12, seg 0 (0.5) [0.5 on Ipop[12]] -> cell 16, seg 0 (0.5) [0.5 on Epop[16]], weight: -0.0016545403, delay 1.5
        h("Epop[16] syn_projIE_gaba[976] = new gaba(0.5)")
        h("Ipop[12] netConn_projIE_gaba[976] = new NetCon(&v(0.5), syn_projIE_gaba[976], 20.0, 1.5, -0.0016545403)")  

        # Connection 977: cell 12, seg 0 (0.5) [0.5 on Ipop[12]] -> cell 17, seg 0 (0.5) [0.5 on Epop[17]], weight: -0.0016545403, delay 1.5
        h("Epop[17] syn_projIE_gaba[977] = new gaba(0.5)")
        h("Ipop[12] netConn_projIE_gaba[977] = new NetCon(&v(0.5), syn_projIE_gaba[977], 20.0, 1.5, -0.0016545403)")  

        # Connection 978: cell 12, seg 0 (0.5) [0.5 on Ipop[12]] -> cell 18, seg 0 (0.5) [0.5 on Epop[18]], weight: -0.0016545403, delay 1.5
        h("Epop[18] syn_projIE_gaba[978] = new gaba(0.5)")
        h("Ipop[12] netConn_projIE_gaba[978] = new NetCon(&v(0.5), syn_projIE_gaba[978], 20.0, 1.5, -0.0016545403)")  

        # Connection 979: cell 12, seg 0 (0.5) [0.5 on Ipop[12]] -> cell 19, seg 0 (0.5) [0.5 on Epop[19]], weight: -0.0016545403, delay 1.5
        h("Epop[19] syn_projIE_gaba[979] = new gaba(0.5)")
        h("Ipop[12] netConn_projIE_gaba[979] = new NetCon(&v(0.5), syn_projIE_gaba[979], 20.0, 1.5, -0.0016545403)")  

        # Connection 980: cell 12, seg 0 (0.5) [0.5 on Ipop[12]] -> cell 20, seg 0 (0.5) [0.5 on Epop[20]], weight: -0.0016545403, delay 1.5
        h("Epop[20] syn_projIE_gaba[980] = new gaba(0.5)")
        h("Ipop[12] netConn_projIE_gaba[980] = new NetCon(&v(0.5), syn_projIE_gaba[980], 20.0, 1.5, -0.0016545403)")  

        # Connection 981: cell 12, seg 0 (0.5) [0.5 on Ipop[12]] -> cell 21, seg 0 (0.5) [0.5 on Epop[21]], weight: -0.0016545403, delay 1.5
        h("Epop[21] syn_projIE_gaba[981] = new gaba(0.5)")
        h("Ipop[12] netConn_projIE_gaba[981] = new NetCon(&v(0.5), syn_projIE_gaba[981], 20.0, 1.5, -0.0016545403)")  

        # Connection 982: cell 12, seg 0 (0.5) [0.5 on Ipop[12]] -> cell 22, seg 0 (0.5) [0.5 on Epop[22]], weight: -0.0016545403, delay 1.5
        h("Epop[22] syn_projIE_gaba[982] = new gaba(0.5)")
        h("Ipop[12] netConn_projIE_gaba[982] = new NetCon(&v(0.5), syn_projIE_gaba[982], 20.0, 1.5, -0.0016545403)")  

        # Connection 983: cell 12, seg 0 (0.5) [0.5 on Ipop[12]] -> cell 23, seg 0 (0.5) [0.5 on Epop[23]], weight: -0.0016545403, delay 1.5
        h("Epop[23] syn_projIE_gaba[983] = new gaba(0.5)")
        h("Ipop[12] netConn_projIE_gaba[983] = new NetCon(&v(0.5), syn_projIE_gaba[983], 20.0, 1.5, -0.0016545403)")  

        # Connection 984: cell 12, seg 0 (0.5) [0.5 on Ipop[12]] -> cell 24, seg 0 (0.5) [0.5 on Epop[24]], weight: -0.0016545403, delay 1.5
        h("Epop[24] syn_projIE_gaba[984] = new gaba(0.5)")
        h("Ipop[12] netConn_projIE_gaba[984] = new NetCon(&v(0.5), syn_projIE_gaba[984], 20.0, 1.5, -0.0016545403)")  

        # Connection 985: cell 12, seg 0 (0.5) [0.5 on Ipop[12]] -> cell 25, seg 0 (0.5) [0.5 on Epop[25]], weight: -0.0016545403, delay 1.5
        h("Epop[25] syn_projIE_gaba[985] = new gaba(0.5)")
        h("Ipop[12] netConn_projIE_gaba[985] = new NetCon(&v(0.5), syn_projIE_gaba[985], 20.0, 1.5, -0.0016545403)")  

        # Connection 986: cell 12, seg 0 (0.5) [0.5 on Ipop[12]] -> cell 26, seg 0 (0.5) [0.5 on Epop[26]], weight: -0.0016545403, delay 1.5
        h("Epop[26] syn_projIE_gaba[986] = new gaba(0.5)")
        h("Ipop[12] netConn_projIE_gaba[986] = new NetCon(&v(0.5), syn_projIE_gaba[986], 20.0, 1.5, -0.0016545403)")  

        # Connection 987: cell 12, seg 0 (0.5) [0.5 on Ipop[12]] -> cell 27, seg 0 (0.5) [0.5 on Epop[27]], weight: -0.0016545403, delay 1.5
        h("Epop[27] syn_projIE_gaba[987] = new gaba(0.5)")
        h("Ipop[12] netConn_projIE_gaba[987] = new NetCon(&v(0.5), syn_projIE_gaba[987], 20.0, 1.5, -0.0016545403)")  

        # Connection 988: cell 12, seg 0 (0.5) [0.5 on Ipop[12]] -> cell 28, seg 0 (0.5) [0.5 on Epop[28]], weight: -0.0016545403, delay 1.5
        h("Epop[28] syn_projIE_gaba[988] = new gaba(0.5)")
        h("Ipop[12] netConn_projIE_gaba[988] = new NetCon(&v(0.5), syn_projIE_gaba[988], 20.0, 1.5, -0.0016545403)")  

        # Connection 989: cell 12, seg 0 (0.5) [0.5 on Ipop[12]] -> cell 29, seg 0 (0.5) [0.5 on Epop[29]], weight: -0.0016545403, delay 1.5
        h("Epop[29] syn_projIE_gaba[989] = new gaba(0.5)")
        h("Ipop[12] netConn_projIE_gaba[989] = new NetCon(&v(0.5), syn_projIE_gaba[989], 20.0, 1.5, -0.0016545403)")  

        # Connection 990: cell 12, seg 0 (0.5) [0.5 on Ipop[12]] -> cell 30, seg 0 (0.5) [0.5 on Epop[30]], weight: -0.0016545403, delay 1.5
        h("Epop[30] syn_projIE_gaba[990] = new gaba(0.5)")
        h("Ipop[12] netConn_projIE_gaba[990] = new NetCon(&v(0.5), syn_projIE_gaba[990], 20.0, 1.5, -0.0016545403)")  

        # Connection 991: cell 12, seg 0 (0.5) [0.5 on Ipop[12]] -> cell 31, seg 0 (0.5) [0.5 on Epop[31]], weight: -0.0016545403, delay 1.5
        h("Epop[31] syn_projIE_gaba[991] = new gaba(0.5)")
        h("Ipop[12] netConn_projIE_gaba[991] = new NetCon(&v(0.5), syn_projIE_gaba[991], 20.0, 1.5, -0.0016545403)")  

        # Connection 992: cell 12, seg 0 (0.5) [0.5 on Ipop[12]] -> cell 32, seg 0 (0.5) [0.5 on Epop[32]], weight: -0.0016545403, delay 1.5
        h("Epop[32] syn_projIE_gaba[992] = new gaba(0.5)")
        h("Ipop[12] netConn_projIE_gaba[992] = new NetCon(&v(0.5), syn_projIE_gaba[992], 20.0, 1.5, -0.0016545403)")  

        # Connection 993: cell 12, seg 0 (0.5) [0.5 on Ipop[12]] -> cell 33, seg 0 (0.5) [0.5 on Epop[33]], weight: -0.0016545403, delay 1.5
        h("Epop[33] syn_projIE_gaba[993] = new gaba(0.5)")
        h("Ipop[12] netConn_projIE_gaba[993] = new NetCon(&v(0.5), syn_projIE_gaba[993], 20.0, 1.5, -0.0016545403)")  

        # Connection 994: cell 12, seg 0 (0.5) [0.5 on Ipop[12]] -> cell 34, seg 0 (0.5) [0.5 on Epop[34]], weight: -0.0016545403, delay 1.5
        h("Epop[34] syn_projIE_gaba[994] = new gaba(0.5)")
        h("Ipop[12] netConn_projIE_gaba[994] = new NetCon(&v(0.5), syn_projIE_gaba[994], 20.0, 1.5, -0.0016545403)")  

        # Connection 995: cell 12, seg 0 (0.5) [0.5 on Ipop[12]] -> cell 35, seg 0 (0.5) [0.5 on Epop[35]], weight: -0.0016545403, delay 1.5
        h("Epop[35] syn_projIE_gaba[995] = new gaba(0.5)")
        h("Ipop[12] netConn_projIE_gaba[995] = new NetCon(&v(0.5), syn_projIE_gaba[995], 20.0, 1.5, -0.0016545403)")  

        # Connection 996: cell 12, seg 0 (0.5) [0.5 on Ipop[12]] -> cell 36, seg 0 (0.5) [0.5 on Epop[36]], weight: -0.0016545403, delay 1.5
        h("Epop[36] syn_projIE_gaba[996] = new gaba(0.5)")
        h("Ipop[12] netConn_projIE_gaba[996] = new NetCon(&v(0.5), syn_projIE_gaba[996], 20.0, 1.5, -0.0016545403)")  

        # Connection 997: cell 12, seg 0 (0.5) [0.5 on Ipop[12]] -> cell 37, seg 0 (0.5) [0.5 on Epop[37]], weight: -0.0016545403, delay 1.5
        h("Epop[37] syn_projIE_gaba[997] = new gaba(0.5)")
        h("Ipop[12] netConn_projIE_gaba[997] = new NetCon(&v(0.5), syn_projIE_gaba[997], 20.0, 1.5, -0.0016545403)")  

        # Connection 998: cell 12, seg 0 (0.5) [0.5 on Ipop[12]] -> cell 38, seg 0 (0.5) [0.5 on Epop[38]], weight: -0.0016545403, delay 1.5
        h("Epop[38] syn_projIE_gaba[998] = new gaba(0.5)")
        h("Ipop[12] netConn_projIE_gaba[998] = new NetCon(&v(0.5), syn_projIE_gaba[998], 20.0, 1.5, -0.0016545403)")  

        # Connection 999: cell 12, seg 0 (0.5) [0.5 on Ipop[12]] -> cell 39, seg 0 (0.5) [0.5 on Epop[39]], weight: -0.0016545403, delay 1.5
        h("Epop[39] syn_projIE_gaba[999] = new gaba(0.5)")
        h("Ipop[12] netConn_projIE_gaba[999] = new NetCon(&v(0.5), syn_projIE_gaba[999], 20.0, 1.5, -0.0016545403)")  

        # Connection 1000: cell 12, seg 0 (0.5) [0.5 on Ipop[12]] -> cell 40, seg 0 (0.5) [0.5 on Epop[40]], weight: -0.0016545403, delay 1.5
        h("Epop[40] syn_projIE_gaba[1000] = new gaba(0.5)")
        h("Ipop[12] netConn_projIE_gaba[1000] = new NetCon(&v(0.5), syn_projIE_gaba[1000], 20.0, 1.5, -0.0016545403)")  

        # Connection 1001: cell 12, seg 0 (0.5) [0.5 on Ipop[12]] -> cell 41, seg 0 (0.5) [0.5 on Epop[41]], weight: -0.0016545403, delay 1.5
        h("Epop[41] syn_projIE_gaba[1001] = new gaba(0.5)")
        h("Ipop[12] netConn_projIE_gaba[1001] = new NetCon(&v(0.5), syn_projIE_gaba[1001], 20.0, 1.5, -0.0016545403)")  

        # Connection 1002: cell 12, seg 0 (0.5) [0.5 on Ipop[12]] -> cell 42, seg 0 (0.5) [0.5 on Epop[42]], weight: -0.0016545403, delay 1.5
        h("Epop[42] syn_projIE_gaba[1002] = new gaba(0.5)")
        h("Ipop[12] netConn_projIE_gaba[1002] = new NetCon(&v(0.5), syn_projIE_gaba[1002], 20.0, 1.5, -0.0016545403)")  

        # Connection 1003: cell 12, seg 0 (0.5) [0.5 on Ipop[12]] -> cell 43, seg 0 (0.5) [0.5 on Epop[43]], weight: -0.0016545403, delay 1.5
        h("Epop[43] syn_projIE_gaba[1003] = new gaba(0.5)")
        h("Ipop[12] netConn_projIE_gaba[1003] = new NetCon(&v(0.5), syn_projIE_gaba[1003], 20.0, 1.5, -0.0016545403)")  

        # Connection 1004: cell 12, seg 0 (0.5) [0.5 on Ipop[12]] -> cell 44, seg 0 (0.5) [0.5 on Epop[44]], weight: -0.0016545403, delay 1.5
        h("Epop[44] syn_projIE_gaba[1004] = new gaba(0.5)")
        h("Ipop[12] netConn_projIE_gaba[1004] = new NetCon(&v(0.5), syn_projIE_gaba[1004], 20.0, 1.5, -0.0016545403)")  

        # Connection 1005: cell 12, seg 0 (0.5) [0.5 on Ipop[12]] -> cell 45, seg 0 (0.5) [0.5 on Epop[45]], weight: -0.0016545403, delay 1.5
        h("Epop[45] syn_projIE_gaba[1005] = new gaba(0.5)")
        h("Ipop[12] netConn_projIE_gaba[1005] = new NetCon(&v(0.5), syn_projIE_gaba[1005], 20.0, 1.5, -0.0016545403)")  

        # Connection 1006: cell 12, seg 0 (0.5) [0.5 on Ipop[12]] -> cell 46, seg 0 (0.5) [0.5 on Epop[46]], weight: -0.0016545403, delay 1.5
        h("Epop[46] syn_projIE_gaba[1006] = new gaba(0.5)")
        h("Ipop[12] netConn_projIE_gaba[1006] = new NetCon(&v(0.5), syn_projIE_gaba[1006], 20.0, 1.5, -0.0016545403)")  

        # Connection 1007: cell 12, seg 0 (0.5) [0.5 on Ipop[12]] -> cell 47, seg 0 (0.5) [0.5 on Epop[47]], weight: -0.0016545403, delay 1.5
        h("Epop[47] syn_projIE_gaba[1007] = new gaba(0.5)")
        h("Ipop[12] netConn_projIE_gaba[1007] = new NetCon(&v(0.5), syn_projIE_gaba[1007], 20.0, 1.5, -0.0016545403)")  

        # Connection 1008: cell 12, seg 0 (0.5) [0.5 on Ipop[12]] -> cell 48, seg 0 (0.5) [0.5 on Epop[48]], weight: -0.0016545403, delay 1.5
        h("Epop[48] syn_projIE_gaba[1008] = new gaba(0.5)")
        h("Ipop[12] netConn_projIE_gaba[1008] = new NetCon(&v(0.5), syn_projIE_gaba[1008], 20.0, 1.5, -0.0016545403)")  

        # Connection 1009: cell 12, seg 0 (0.5) [0.5 on Ipop[12]] -> cell 49, seg 0 (0.5) [0.5 on Epop[49]], weight: -0.0016545403, delay 1.5
        h("Epop[49] syn_projIE_gaba[1009] = new gaba(0.5)")
        h("Ipop[12] netConn_projIE_gaba[1009] = new NetCon(&v(0.5), syn_projIE_gaba[1009], 20.0, 1.5, -0.0016545403)")  

        # Connection 1010: cell 12, seg 0 (0.5) [0.5 on Ipop[12]] -> cell 50, seg 0 (0.5) [0.5 on Epop[50]], weight: -0.0016545403, delay 1.5
        h("Epop[50] syn_projIE_gaba[1010] = new gaba(0.5)")
        h("Ipop[12] netConn_projIE_gaba[1010] = new NetCon(&v(0.5), syn_projIE_gaba[1010], 20.0, 1.5, -0.0016545403)")  

        # Connection 1011: cell 12, seg 0 (0.5) [0.5 on Ipop[12]] -> cell 51, seg 0 (0.5) [0.5 on Epop[51]], weight: -0.0016545403, delay 1.5
        h("Epop[51] syn_projIE_gaba[1011] = new gaba(0.5)")
        h("Ipop[12] netConn_projIE_gaba[1011] = new NetCon(&v(0.5), syn_projIE_gaba[1011], 20.0, 1.5, -0.0016545403)")  

        # Connection 1012: cell 12, seg 0 (0.5) [0.5 on Ipop[12]] -> cell 52, seg 0 (0.5) [0.5 on Epop[52]], weight: -0.0016545403, delay 1.5
        h("Epop[52] syn_projIE_gaba[1012] = new gaba(0.5)")
        h("Ipop[12] netConn_projIE_gaba[1012] = new NetCon(&v(0.5), syn_projIE_gaba[1012], 20.0, 1.5, -0.0016545403)")  

        # Connection 1013: cell 12, seg 0 (0.5) [0.5 on Ipop[12]] -> cell 53, seg 0 (0.5) [0.5 on Epop[53]], weight: -0.0016545403, delay 1.5
        h("Epop[53] syn_projIE_gaba[1013] = new gaba(0.5)")
        h("Ipop[12] netConn_projIE_gaba[1013] = new NetCon(&v(0.5), syn_projIE_gaba[1013], 20.0, 1.5, -0.0016545403)")  

        # Connection 1014: cell 12, seg 0 (0.5) [0.5 on Ipop[12]] -> cell 54, seg 0 (0.5) [0.5 on Epop[54]], weight: -0.0016545403, delay 1.5
        h("Epop[54] syn_projIE_gaba[1014] = new gaba(0.5)")
        h("Ipop[12] netConn_projIE_gaba[1014] = new NetCon(&v(0.5), syn_projIE_gaba[1014], 20.0, 1.5, -0.0016545403)")  

        # Connection 1015: cell 12, seg 0 (0.5) [0.5 on Ipop[12]] -> cell 55, seg 0 (0.5) [0.5 on Epop[55]], weight: -0.0016545403, delay 1.5
        h("Epop[55] syn_projIE_gaba[1015] = new gaba(0.5)")
        h("Ipop[12] netConn_projIE_gaba[1015] = new NetCon(&v(0.5), syn_projIE_gaba[1015], 20.0, 1.5, -0.0016545403)")  

        # Connection 1016: cell 12, seg 0 (0.5) [0.5 on Ipop[12]] -> cell 56, seg 0 (0.5) [0.5 on Epop[56]], weight: -0.0016545403, delay 1.5
        h("Epop[56] syn_projIE_gaba[1016] = new gaba(0.5)")
        h("Ipop[12] netConn_projIE_gaba[1016] = new NetCon(&v(0.5), syn_projIE_gaba[1016], 20.0, 1.5, -0.0016545403)")  

        # Connection 1017: cell 12, seg 0 (0.5) [0.5 on Ipop[12]] -> cell 57, seg 0 (0.5) [0.5 on Epop[57]], weight: -0.0016545403, delay 1.5
        h("Epop[57] syn_projIE_gaba[1017] = new gaba(0.5)")
        h("Ipop[12] netConn_projIE_gaba[1017] = new NetCon(&v(0.5), syn_projIE_gaba[1017], 20.0, 1.5, -0.0016545403)")  

        # Connection 1018: cell 12, seg 0 (0.5) [0.5 on Ipop[12]] -> cell 58, seg 0 (0.5) [0.5 on Epop[58]], weight: -0.0016545403, delay 1.5
        h("Epop[58] syn_projIE_gaba[1018] = new gaba(0.5)")
        h("Ipop[12] netConn_projIE_gaba[1018] = new NetCon(&v(0.5), syn_projIE_gaba[1018], 20.0, 1.5, -0.0016545403)")  

        # Connection 1019: cell 12, seg 0 (0.5) [0.5 on Ipop[12]] -> cell 59, seg 0 (0.5) [0.5 on Epop[59]], weight: -0.0016545403, delay 1.5
        h("Epop[59] syn_projIE_gaba[1019] = new gaba(0.5)")
        h("Ipop[12] netConn_projIE_gaba[1019] = new NetCon(&v(0.5), syn_projIE_gaba[1019], 20.0, 1.5, -0.0016545403)")  

        # Connection 1020: cell 12, seg 0 (0.5) [0.5 on Ipop[12]] -> cell 60, seg 0 (0.5) [0.5 on Epop[60]], weight: -0.0016545403, delay 1.5
        h("Epop[60] syn_projIE_gaba[1020] = new gaba(0.5)")
        h("Ipop[12] netConn_projIE_gaba[1020] = new NetCon(&v(0.5), syn_projIE_gaba[1020], 20.0, 1.5, -0.0016545403)")  

        # Connection 1021: cell 12, seg 0 (0.5) [0.5 on Ipop[12]] -> cell 61, seg 0 (0.5) [0.5 on Epop[61]], weight: -0.0016545403, delay 1.5
        h("Epop[61] syn_projIE_gaba[1021] = new gaba(0.5)")
        h("Ipop[12] netConn_projIE_gaba[1021] = new NetCon(&v(0.5), syn_projIE_gaba[1021], 20.0, 1.5, -0.0016545403)")  

        # Connection 1022: cell 12, seg 0 (0.5) [0.5 on Ipop[12]] -> cell 62, seg 0 (0.5) [0.5 on Epop[62]], weight: -0.0016545403, delay 1.5
        h("Epop[62] syn_projIE_gaba[1022] = new gaba(0.5)")
        h("Ipop[12] netConn_projIE_gaba[1022] = new NetCon(&v(0.5), syn_projIE_gaba[1022], 20.0, 1.5, -0.0016545403)")  

        # Connection 1023: cell 12, seg 0 (0.5) [0.5 on Ipop[12]] -> cell 63, seg 0 (0.5) [0.5 on Epop[63]], weight: -0.0016545403, delay 1.5
        h("Epop[63] syn_projIE_gaba[1023] = new gaba(0.5)")
        h("Ipop[12] netConn_projIE_gaba[1023] = new NetCon(&v(0.5), syn_projIE_gaba[1023], 20.0, 1.5, -0.0016545403)")  

        # Connection 1024: cell 12, seg 0 (0.5) [0.5 on Ipop[12]] -> cell 64, seg 0 (0.5) [0.5 on Epop[64]], weight: -0.0016545403, delay 1.5
        h("Epop[64] syn_projIE_gaba[1024] = new gaba(0.5)")
        h("Ipop[12] netConn_projIE_gaba[1024] = new NetCon(&v(0.5), syn_projIE_gaba[1024], 20.0, 1.5, -0.0016545403)")  

        # Connection 1025: cell 12, seg 0 (0.5) [0.5 on Ipop[12]] -> cell 65, seg 0 (0.5) [0.5 on Epop[65]], weight: -0.0016545403, delay 1.5
        h("Epop[65] syn_projIE_gaba[1025] = new gaba(0.5)")
        h("Ipop[12] netConn_projIE_gaba[1025] = new NetCon(&v(0.5), syn_projIE_gaba[1025], 20.0, 1.5, -0.0016545403)")  

        # Connection 1026: cell 12, seg 0 (0.5) [0.5 on Ipop[12]] -> cell 66, seg 0 (0.5) [0.5 on Epop[66]], weight: -0.0016545403, delay 1.5
        h("Epop[66] syn_projIE_gaba[1026] = new gaba(0.5)")
        h("Ipop[12] netConn_projIE_gaba[1026] = new NetCon(&v(0.5), syn_projIE_gaba[1026], 20.0, 1.5, -0.0016545403)")  

        # Connection 1027: cell 12, seg 0 (0.5) [0.5 on Ipop[12]] -> cell 67, seg 0 (0.5) [0.5 on Epop[67]], weight: -0.0016545403, delay 1.5
        h("Epop[67] syn_projIE_gaba[1027] = new gaba(0.5)")
        h("Ipop[12] netConn_projIE_gaba[1027] = new NetCon(&v(0.5), syn_projIE_gaba[1027], 20.0, 1.5, -0.0016545403)")  

        # Connection 1028: cell 12, seg 0 (0.5) [0.5 on Ipop[12]] -> cell 68, seg 0 (0.5) [0.5 on Epop[68]], weight: -0.0016545403, delay 1.5
        h("Epop[68] syn_projIE_gaba[1028] = new gaba(0.5)")
        h("Ipop[12] netConn_projIE_gaba[1028] = new NetCon(&v(0.5), syn_projIE_gaba[1028], 20.0, 1.5, -0.0016545403)")  

        # Connection 1029: cell 12, seg 0 (0.5) [0.5 on Ipop[12]] -> cell 69, seg 0 (0.5) [0.5 on Epop[69]], weight: -0.0016545403, delay 1.5
        h("Epop[69] syn_projIE_gaba[1029] = new gaba(0.5)")
        h("Ipop[12] netConn_projIE_gaba[1029] = new NetCon(&v(0.5), syn_projIE_gaba[1029], 20.0, 1.5, -0.0016545403)")  

        # Connection 1030: cell 12, seg 0 (0.5) [0.5 on Ipop[12]] -> cell 70, seg 0 (0.5) [0.5 on Epop[70]], weight: -0.0016545403, delay 1.5
        h("Epop[70] syn_projIE_gaba[1030] = new gaba(0.5)")
        h("Ipop[12] netConn_projIE_gaba[1030] = new NetCon(&v(0.5), syn_projIE_gaba[1030], 20.0, 1.5, -0.0016545403)")  

        # Connection 1031: cell 12, seg 0 (0.5) [0.5 on Ipop[12]] -> cell 71, seg 0 (0.5) [0.5 on Epop[71]], weight: -0.0016545403, delay 1.5
        h("Epop[71] syn_projIE_gaba[1031] = new gaba(0.5)")
        h("Ipop[12] netConn_projIE_gaba[1031] = new NetCon(&v(0.5), syn_projIE_gaba[1031], 20.0, 1.5, -0.0016545403)")  

        # Connection 1032: cell 12, seg 0 (0.5) [0.5 on Ipop[12]] -> cell 72, seg 0 (0.5) [0.5 on Epop[72]], weight: -0.0016545403, delay 1.5
        h("Epop[72] syn_projIE_gaba[1032] = new gaba(0.5)")
        h("Ipop[12] netConn_projIE_gaba[1032] = new NetCon(&v(0.5), syn_projIE_gaba[1032], 20.0, 1.5, -0.0016545403)")  

        # Connection 1033: cell 12, seg 0 (0.5) [0.5 on Ipop[12]] -> cell 73, seg 0 (0.5) [0.5 on Epop[73]], weight: -0.0016545403, delay 1.5
        h("Epop[73] syn_projIE_gaba[1033] = new gaba(0.5)")
        h("Ipop[12] netConn_projIE_gaba[1033] = new NetCon(&v(0.5), syn_projIE_gaba[1033], 20.0, 1.5, -0.0016545403)")  

        # Connection 1034: cell 12, seg 0 (0.5) [0.5 on Ipop[12]] -> cell 74, seg 0 (0.5) [0.5 on Epop[74]], weight: -0.0016545403, delay 1.5
        h("Epop[74] syn_projIE_gaba[1034] = new gaba(0.5)")
        h("Ipop[12] netConn_projIE_gaba[1034] = new NetCon(&v(0.5), syn_projIE_gaba[1034], 20.0, 1.5, -0.0016545403)")  

        # Connection 1035: cell 12, seg 0 (0.5) [0.5 on Ipop[12]] -> cell 75, seg 0 (0.5) [0.5 on Epop[75]], weight: -0.0016545403, delay 1.5
        h("Epop[75] syn_projIE_gaba[1035] = new gaba(0.5)")
        h("Ipop[12] netConn_projIE_gaba[1035] = new NetCon(&v(0.5), syn_projIE_gaba[1035], 20.0, 1.5, -0.0016545403)")  

        # Connection 1036: cell 12, seg 0 (0.5) [0.5 on Ipop[12]] -> cell 76, seg 0 (0.5) [0.5 on Epop[76]], weight: -0.0016545403, delay 1.5
        h("Epop[76] syn_projIE_gaba[1036] = new gaba(0.5)")
        h("Ipop[12] netConn_projIE_gaba[1036] = new NetCon(&v(0.5), syn_projIE_gaba[1036], 20.0, 1.5, -0.0016545403)")  

        # Connection 1037: cell 12, seg 0 (0.5) [0.5 on Ipop[12]] -> cell 77, seg 0 (0.5) [0.5 on Epop[77]], weight: -0.0016545403, delay 1.5
        h("Epop[77] syn_projIE_gaba[1037] = new gaba(0.5)")
        h("Ipop[12] netConn_projIE_gaba[1037] = new NetCon(&v(0.5), syn_projIE_gaba[1037], 20.0, 1.5, -0.0016545403)")  

        # Connection 1038: cell 12, seg 0 (0.5) [0.5 on Ipop[12]] -> cell 78, seg 0 (0.5) [0.5 on Epop[78]], weight: -0.0016545403, delay 1.5
        h("Epop[78] syn_projIE_gaba[1038] = new gaba(0.5)")
        h("Ipop[12] netConn_projIE_gaba[1038] = new NetCon(&v(0.5), syn_projIE_gaba[1038], 20.0, 1.5, -0.0016545403)")  

        # Connection 1039: cell 12, seg 0 (0.5) [0.5 on Ipop[12]] -> cell 79, seg 0 (0.5) [0.5 on Epop[79]], weight: -0.0016545403, delay 1.5
        h("Epop[79] syn_projIE_gaba[1039] = new gaba(0.5)")
        h("Ipop[12] netConn_projIE_gaba[1039] = new NetCon(&v(0.5), syn_projIE_gaba[1039], 20.0, 1.5, -0.0016545403)")  

        # Connection 1040: cell 13, seg 0 (0.5) [0.5 on Ipop[13]] -> cell 0, seg 0 (0.5) [0.5 on Epop[0]], weight: -0.0016545403, delay 1.5
        h("Epop[0] syn_projIE_gaba[1040] = new gaba(0.5)")
        h("Ipop[13] netConn_projIE_gaba[1040] = new NetCon(&v(0.5), syn_projIE_gaba[1040], 20.0, 1.5, -0.0016545403)")  

        # Connection 1041: cell 13, seg 0 (0.5) [0.5 on Ipop[13]] -> cell 1, seg 0 (0.5) [0.5 on Epop[1]], weight: -0.0016545403, delay 1.5
        h("Epop[1] syn_projIE_gaba[1041] = new gaba(0.5)")
        h("Ipop[13] netConn_projIE_gaba[1041] = new NetCon(&v(0.5), syn_projIE_gaba[1041], 20.0, 1.5, -0.0016545403)")  

        # Connection 1042: cell 13, seg 0 (0.5) [0.5 on Ipop[13]] -> cell 2, seg 0 (0.5) [0.5 on Epop[2]], weight: -0.0016545403, delay 1.5
        h("Epop[2] syn_projIE_gaba[1042] = new gaba(0.5)")
        h("Ipop[13] netConn_projIE_gaba[1042] = new NetCon(&v(0.5), syn_projIE_gaba[1042], 20.0, 1.5, -0.0016545403)")  

        # Connection 1043: cell 13, seg 0 (0.5) [0.5 on Ipop[13]] -> cell 3, seg 0 (0.5) [0.5 on Epop[3]], weight: -0.0016545403, delay 1.5
        h("Epop[3] syn_projIE_gaba[1043] = new gaba(0.5)")
        h("Ipop[13] netConn_projIE_gaba[1043] = new NetCon(&v(0.5), syn_projIE_gaba[1043], 20.0, 1.5, -0.0016545403)")  

        # Connection 1044: cell 13, seg 0 (0.5) [0.5 on Ipop[13]] -> cell 4, seg 0 (0.5) [0.5 on Epop[4]], weight: -0.0016545403, delay 1.5
        h("Epop[4] syn_projIE_gaba[1044] = new gaba(0.5)")
        h("Ipop[13] netConn_projIE_gaba[1044] = new NetCon(&v(0.5), syn_projIE_gaba[1044], 20.0, 1.5, -0.0016545403)")  

        # Connection 1045: cell 13, seg 0 (0.5) [0.5 on Ipop[13]] -> cell 5, seg 0 (0.5) [0.5 on Epop[5]], weight: -0.0016545403, delay 1.5
        h("Epop[5] syn_projIE_gaba[1045] = new gaba(0.5)")
        h("Ipop[13] netConn_projIE_gaba[1045] = new NetCon(&v(0.5), syn_projIE_gaba[1045], 20.0, 1.5, -0.0016545403)")  

        # Connection 1046: cell 13, seg 0 (0.5) [0.5 on Ipop[13]] -> cell 6, seg 0 (0.5) [0.5 on Epop[6]], weight: -0.0016545403, delay 1.5
        h("Epop[6] syn_projIE_gaba[1046] = new gaba(0.5)")
        h("Ipop[13] netConn_projIE_gaba[1046] = new NetCon(&v(0.5), syn_projIE_gaba[1046], 20.0, 1.5, -0.0016545403)")  

        # Connection 1047: cell 13, seg 0 (0.5) [0.5 on Ipop[13]] -> cell 7, seg 0 (0.5) [0.5 on Epop[7]], weight: -0.0016545403, delay 1.5
        h("Epop[7] syn_projIE_gaba[1047] = new gaba(0.5)")
        h("Ipop[13] netConn_projIE_gaba[1047] = new NetCon(&v(0.5), syn_projIE_gaba[1047], 20.0, 1.5, -0.0016545403)")  

        # Connection 1048: cell 13, seg 0 (0.5) [0.5 on Ipop[13]] -> cell 8, seg 0 (0.5) [0.5 on Epop[8]], weight: -0.0016545403, delay 1.5
        h("Epop[8] syn_projIE_gaba[1048] = new gaba(0.5)")
        h("Ipop[13] netConn_projIE_gaba[1048] = new NetCon(&v(0.5), syn_projIE_gaba[1048], 20.0, 1.5, -0.0016545403)")  

        # Connection 1049: cell 13, seg 0 (0.5) [0.5 on Ipop[13]] -> cell 9, seg 0 (0.5) [0.5 on Epop[9]], weight: -0.0016545403, delay 1.5
        h("Epop[9] syn_projIE_gaba[1049] = new gaba(0.5)")
        h("Ipop[13] netConn_projIE_gaba[1049] = new NetCon(&v(0.5), syn_projIE_gaba[1049], 20.0, 1.5, -0.0016545403)")  

        # Connection 1050: cell 13, seg 0 (0.5) [0.5 on Ipop[13]] -> cell 10, seg 0 (0.5) [0.5 on Epop[10]], weight: -0.0016545403, delay 1.5
        h("Epop[10] syn_projIE_gaba[1050] = new gaba(0.5)")
        h("Ipop[13] netConn_projIE_gaba[1050] = new NetCon(&v(0.5), syn_projIE_gaba[1050], 20.0, 1.5, -0.0016545403)")  

        # Connection 1051: cell 13, seg 0 (0.5) [0.5 on Ipop[13]] -> cell 11, seg 0 (0.5) [0.5 on Epop[11]], weight: -0.0016545403, delay 1.5
        h("Epop[11] syn_projIE_gaba[1051] = new gaba(0.5)")
        h("Ipop[13] netConn_projIE_gaba[1051] = new NetCon(&v(0.5), syn_projIE_gaba[1051], 20.0, 1.5, -0.0016545403)")  

        # Connection 1052: cell 13, seg 0 (0.5) [0.5 on Ipop[13]] -> cell 12, seg 0 (0.5) [0.5 on Epop[12]], weight: -0.0016545403, delay 1.5
        h("Epop[12] syn_projIE_gaba[1052] = new gaba(0.5)")
        h("Ipop[13] netConn_projIE_gaba[1052] = new NetCon(&v(0.5), syn_projIE_gaba[1052], 20.0, 1.5, -0.0016545403)")  

        # Connection 1053: cell 13, seg 0 (0.5) [0.5 on Ipop[13]] -> cell 13, seg 0 (0.5) [0.5 on Epop[13]], weight: -0.0016545403, delay 1.5
        h("Epop[13] syn_projIE_gaba[1053] = new gaba(0.5)")
        h("Ipop[13] netConn_projIE_gaba[1053] = new NetCon(&v(0.5), syn_projIE_gaba[1053], 20.0, 1.5, -0.0016545403)")  

        # Connection 1054: cell 13, seg 0 (0.5) [0.5 on Ipop[13]] -> cell 14, seg 0 (0.5) [0.5 on Epop[14]], weight: -0.0016545403, delay 1.5
        h("Epop[14] syn_projIE_gaba[1054] = new gaba(0.5)")
        h("Ipop[13] netConn_projIE_gaba[1054] = new NetCon(&v(0.5), syn_projIE_gaba[1054], 20.0, 1.5, -0.0016545403)")  

        # Connection 1055: cell 13, seg 0 (0.5) [0.5 on Ipop[13]] -> cell 15, seg 0 (0.5) [0.5 on Epop[15]], weight: -0.0016545403, delay 1.5
        h("Epop[15] syn_projIE_gaba[1055] = new gaba(0.5)")
        h("Ipop[13] netConn_projIE_gaba[1055] = new NetCon(&v(0.5), syn_projIE_gaba[1055], 20.0, 1.5, -0.0016545403)")  

        # Connection 1056: cell 13, seg 0 (0.5) [0.5 on Ipop[13]] -> cell 16, seg 0 (0.5) [0.5 on Epop[16]], weight: -0.0016545403, delay 1.5
        h("Epop[16] syn_projIE_gaba[1056] = new gaba(0.5)")
        h("Ipop[13] netConn_projIE_gaba[1056] = new NetCon(&v(0.5), syn_projIE_gaba[1056], 20.0, 1.5, -0.0016545403)")  

        # Connection 1057: cell 13, seg 0 (0.5) [0.5 on Ipop[13]] -> cell 17, seg 0 (0.5) [0.5 on Epop[17]], weight: -0.0016545403, delay 1.5
        h("Epop[17] syn_projIE_gaba[1057] = new gaba(0.5)")
        h("Ipop[13] netConn_projIE_gaba[1057] = new NetCon(&v(0.5), syn_projIE_gaba[1057], 20.0, 1.5, -0.0016545403)")  

        # Connection 1058: cell 13, seg 0 (0.5) [0.5 on Ipop[13]] -> cell 18, seg 0 (0.5) [0.5 on Epop[18]], weight: -0.0016545403, delay 1.5
        h("Epop[18] syn_projIE_gaba[1058] = new gaba(0.5)")
        h("Ipop[13] netConn_projIE_gaba[1058] = new NetCon(&v(0.5), syn_projIE_gaba[1058], 20.0, 1.5, -0.0016545403)")  

        # Connection 1059: cell 13, seg 0 (0.5) [0.5 on Ipop[13]] -> cell 19, seg 0 (0.5) [0.5 on Epop[19]], weight: -0.0016545403, delay 1.5
        h("Epop[19] syn_projIE_gaba[1059] = new gaba(0.5)")
        h("Ipop[13] netConn_projIE_gaba[1059] = new NetCon(&v(0.5), syn_projIE_gaba[1059], 20.0, 1.5, -0.0016545403)")  

        # Connection 1060: cell 13, seg 0 (0.5) [0.5 on Ipop[13]] -> cell 20, seg 0 (0.5) [0.5 on Epop[20]], weight: -0.0016545403, delay 1.5
        h("Epop[20] syn_projIE_gaba[1060] = new gaba(0.5)")
        h("Ipop[13] netConn_projIE_gaba[1060] = new NetCon(&v(0.5), syn_projIE_gaba[1060], 20.0, 1.5, -0.0016545403)")  

        # Connection 1061: cell 13, seg 0 (0.5) [0.5 on Ipop[13]] -> cell 21, seg 0 (0.5) [0.5 on Epop[21]], weight: -0.0016545403, delay 1.5
        h("Epop[21] syn_projIE_gaba[1061] = new gaba(0.5)")
        h("Ipop[13] netConn_projIE_gaba[1061] = new NetCon(&v(0.5), syn_projIE_gaba[1061], 20.0, 1.5, -0.0016545403)")  

        # Connection 1062: cell 13, seg 0 (0.5) [0.5 on Ipop[13]] -> cell 22, seg 0 (0.5) [0.5 on Epop[22]], weight: -0.0016545403, delay 1.5
        h("Epop[22] syn_projIE_gaba[1062] = new gaba(0.5)")
        h("Ipop[13] netConn_projIE_gaba[1062] = new NetCon(&v(0.5), syn_projIE_gaba[1062], 20.0, 1.5, -0.0016545403)")  

        # Connection 1063: cell 13, seg 0 (0.5) [0.5 on Ipop[13]] -> cell 23, seg 0 (0.5) [0.5 on Epop[23]], weight: -0.0016545403, delay 1.5
        h("Epop[23] syn_projIE_gaba[1063] = new gaba(0.5)")
        h("Ipop[13] netConn_projIE_gaba[1063] = new NetCon(&v(0.5), syn_projIE_gaba[1063], 20.0, 1.5, -0.0016545403)")  

        # Connection 1064: cell 13, seg 0 (0.5) [0.5 on Ipop[13]] -> cell 24, seg 0 (0.5) [0.5 on Epop[24]], weight: -0.0016545403, delay 1.5
        h("Epop[24] syn_projIE_gaba[1064] = new gaba(0.5)")
        h("Ipop[13] netConn_projIE_gaba[1064] = new NetCon(&v(0.5), syn_projIE_gaba[1064], 20.0, 1.5, -0.0016545403)")  

        # Connection 1065: cell 13, seg 0 (0.5) [0.5 on Ipop[13]] -> cell 25, seg 0 (0.5) [0.5 on Epop[25]], weight: -0.0016545403, delay 1.5
        h("Epop[25] syn_projIE_gaba[1065] = new gaba(0.5)")
        h("Ipop[13] netConn_projIE_gaba[1065] = new NetCon(&v(0.5), syn_projIE_gaba[1065], 20.0, 1.5, -0.0016545403)")  

        # Connection 1066: cell 13, seg 0 (0.5) [0.5 on Ipop[13]] -> cell 26, seg 0 (0.5) [0.5 on Epop[26]], weight: -0.0016545403, delay 1.5
        h("Epop[26] syn_projIE_gaba[1066] = new gaba(0.5)")
        h("Ipop[13] netConn_projIE_gaba[1066] = new NetCon(&v(0.5), syn_projIE_gaba[1066], 20.0, 1.5, -0.0016545403)")  

        # Connection 1067: cell 13, seg 0 (0.5) [0.5 on Ipop[13]] -> cell 27, seg 0 (0.5) [0.5 on Epop[27]], weight: -0.0016545403, delay 1.5
        h("Epop[27] syn_projIE_gaba[1067] = new gaba(0.5)")
        h("Ipop[13] netConn_projIE_gaba[1067] = new NetCon(&v(0.5), syn_projIE_gaba[1067], 20.0, 1.5, -0.0016545403)")  

        # Connection 1068: cell 13, seg 0 (0.5) [0.5 on Ipop[13]] -> cell 28, seg 0 (0.5) [0.5 on Epop[28]], weight: -0.0016545403, delay 1.5
        h("Epop[28] syn_projIE_gaba[1068] = new gaba(0.5)")
        h("Ipop[13] netConn_projIE_gaba[1068] = new NetCon(&v(0.5), syn_projIE_gaba[1068], 20.0, 1.5, -0.0016545403)")  

        # Connection 1069: cell 13, seg 0 (0.5) [0.5 on Ipop[13]] -> cell 29, seg 0 (0.5) [0.5 on Epop[29]], weight: -0.0016545403, delay 1.5
        h("Epop[29] syn_projIE_gaba[1069] = new gaba(0.5)")
        h("Ipop[13] netConn_projIE_gaba[1069] = new NetCon(&v(0.5), syn_projIE_gaba[1069], 20.0, 1.5, -0.0016545403)")  

        # Connection 1070: cell 13, seg 0 (0.5) [0.5 on Ipop[13]] -> cell 30, seg 0 (0.5) [0.5 on Epop[30]], weight: -0.0016545403, delay 1.5
        h("Epop[30] syn_projIE_gaba[1070] = new gaba(0.5)")
        h("Ipop[13] netConn_projIE_gaba[1070] = new NetCon(&v(0.5), syn_projIE_gaba[1070], 20.0, 1.5, -0.0016545403)")  

        # Connection 1071: cell 13, seg 0 (0.5) [0.5 on Ipop[13]] -> cell 31, seg 0 (0.5) [0.5 on Epop[31]], weight: -0.0016545403, delay 1.5
        h("Epop[31] syn_projIE_gaba[1071] = new gaba(0.5)")
        h("Ipop[13] netConn_projIE_gaba[1071] = new NetCon(&v(0.5), syn_projIE_gaba[1071], 20.0, 1.5, -0.0016545403)")  

        # Connection 1072: cell 13, seg 0 (0.5) [0.5 on Ipop[13]] -> cell 32, seg 0 (0.5) [0.5 on Epop[32]], weight: -0.0016545403, delay 1.5
        h("Epop[32] syn_projIE_gaba[1072] = new gaba(0.5)")
        h("Ipop[13] netConn_projIE_gaba[1072] = new NetCon(&v(0.5), syn_projIE_gaba[1072], 20.0, 1.5, -0.0016545403)")  

        # Connection 1073: cell 13, seg 0 (0.5) [0.5 on Ipop[13]] -> cell 33, seg 0 (0.5) [0.5 on Epop[33]], weight: -0.0016545403, delay 1.5
        h("Epop[33] syn_projIE_gaba[1073] = new gaba(0.5)")
        h("Ipop[13] netConn_projIE_gaba[1073] = new NetCon(&v(0.5), syn_projIE_gaba[1073], 20.0, 1.5, -0.0016545403)")  

        # Connection 1074: cell 13, seg 0 (0.5) [0.5 on Ipop[13]] -> cell 34, seg 0 (0.5) [0.5 on Epop[34]], weight: -0.0016545403, delay 1.5
        h("Epop[34] syn_projIE_gaba[1074] = new gaba(0.5)")
        h("Ipop[13] netConn_projIE_gaba[1074] = new NetCon(&v(0.5), syn_projIE_gaba[1074], 20.0, 1.5, -0.0016545403)")  

        # Connection 1075: cell 13, seg 0 (0.5) [0.5 on Ipop[13]] -> cell 35, seg 0 (0.5) [0.5 on Epop[35]], weight: -0.0016545403, delay 1.5
        h("Epop[35] syn_projIE_gaba[1075] = new gaba(0.5)")
        h("Ipop[13] netConn_projIE_gaba[1075] = new NetCon(&v(0.5), syn_projIE_gaba[1075], 20.0, 1.5, -0.0016545403)")  

        # Connection 1076: cell 13, seg 0 (0.5) [0.5 on Ipop[13]] -> cell 36, seg 0 (0.5) [0.5 on Epop[36]], weight: -0.0016545403, delay 1.5
        h("Epop[36] syn_projIE_gaba[1076] = new gaba(0.5)")
        h("Ipop[13] netConn_projIE_gaba[1076] = new NetCon(&v(0.5), syn_projIE_gaba[1076], 20.0, 1.5, -0.0016545403)")  

        # Connection 1077: cell 13, seg 0 (0.5) [0.5 on Ipop[13]] -> cell 37, seg 0 (0.5) [0.5 on Epop[37]], weight: -0.0016545403, delay 1.5
        h("Epop[37] syn_projIE_gaba[1077] = new gaba(0.5)")
        h("Ipop[13] netConn_projIE_gaba[1077] = new NetCon(&v(0.5), syn_projIE_gaba[1077], 20.0, 1.5, -0.0016545403)")  

        # Connection 1078: cell 13, seg 0 (0.5) [0.5 on Ipop[13]] -> cell 38, seg 0 (0.5) [0.5 on Epop[38]], weight: -0.0016545403, delay 1.5
        h("Epop[38] syn_projIE_gaba[1078] = new gaba(0.5)")
        h("Ipop[13] netConn_projIE_gaba[1078] = new NetCon(&v(0.5), syn_projIE_gaba[1078], 20.0, 1.5, -0.0016545403)")  

        # Connection 1079: cell 13, seg 0 (0.5) [0.5 on Ipop[13]] -> cell 39, seg 0 (0.5) [0.5 on Epop[39]], weight: -0.0016545403, delay 1.5
        h("Epop[39] syn_projIE_gaba[1079] = new gaba(0.5)")
        h("Ipop[13] netConn_projIE_gaba[1079] = new NetCon(&v(0.5), syn_projIE_gaba[1079], 20.0, 1.5, -0.0016545403)")  

        # Connection 1080: cell 13, seg 0 (0.5) [0.5 on Ipop[13]] -> cell 40, seg 0 (0.5) [0.5 on Epop[40]], weight: -0.0016545403, delay 1.5
        h("Epop[40] syn_projIE_gaba[1080] = new gaba(0.5)")
        h("Ipop[13] netConn_projIE_gaba[1080] = new NetCon(&v(0.5), syn_projIE_gaba[1080], 20.0, 1.5, -0.0016545403)")  

        # Connection 1081: cell 13, seg 0 (0.5) [0.5 on Ipop[13]] -> cell 41, seg 0 (0.5) [0.5 on Epop[41]], weight: -0.0016545403, delay 1.5
        h("Epop[41] syn_projIE_gaba[1081] = new gaba(0.5)")
        h("Ipop[13] netConn_projIE_gaba[1081] = new NetCon(&v(0.5), syn_projIE_gaba[1081], 20.0, 1.5, -0.0016545403)")  

        # Connection 1082: cell 13, seg 0 (0.5) [0.5 on Ipop[13]] -> cell 42, seg 0 (0.5) [0.5 on Epop[42]], weight: -0.0016545403, delay 1.5
        h("Epop[42] syn_projIE_gaba[1082] = new gaba(0.5)")
        h("Ipop[13] netConn_projIE_gaba[1082] = new NetCon(&v(0.5), syn_projIE_gaba[1082], 20.0, 1.5, -0.0016545403)")  

        # Connection 1083: cell 13, seg 0 (0.5) [0.5 on Ipop[13]] -> cell 43, seg 0 (0.5) [0.5 on Epop[43]], weight: -0.0016545403, delay 1.5
        h("Epop[43] syn_projIE_gaba[1083] = new gaba(0.5)")
        h("Ipop[13] netConn_projIE_gaba[1083] = new NetCon(&v(0.5), syn_projIE_gaba[1083], 20.0, 1.5, -0.0016545403)")  

        # Connection 1084: cell 13, seg 0 (0.5) [0.5 on Ipop[13]] -> cell 44, seg 0 (0.5) [0.5 on Epop[44]], weight: -0.0016545403, delay 1.5
        h("Epop[44] syn_projIE_gaba[1084] = new gaba(0.5)")
        h("Ipop[13] netConn_projIE_gaba[1084] = new NetCon(&v(0.5), syn_projIE_gaba[1084], 20.0, 1.5, -0.0016545403)")  

        # Connection 1085: cell 13, seg 0 (0.5) [0.5 on Ipop[13]] -> cell 45, seg 0 (0.5) [0.5 on Epop[45]], weight: -0.0016545403, delay 1.5
        h("Epop[45] syn_projIE_gaba[1085] = new gaba(0.5)")
        h("Ipop[13] netConn_projIE_gaba[1085] = new NetCon(&v(0.5), syn_projIE_gaba[1085], 20.0, 1.5, -0.0016545403)")  

        # Connection 1086: cell 13, seg 0 (0.5) [0.5 on Ipop[13]] -> cell 46, seg 0 (0.5) [0.5 on Epop[46]], weight: -0.0016545403, delay 1.5
        h("Epop[46] syn_projIE_gaba[1086] = new gaba(0.5)")
        h("Ipop[13] netConn_projIE_gaba[1086] = new NetCon(&v(0.5), syn_projIE_gaba[1086], 20.0, 1.5, -0.0016545403)")  

        # Connection 1087: cell 13, seg 0 (0.5) [0.5 on Ipop[13]] -> cell 47, seg 0 (0.5) [0.5 on Epop[47]], weight: -0.0016545403, delay 1.5
        h("Epop[47] syn_projIE_gaba[1087] = new gaba(0.5)")
        h("Ipop[13] netConn_projIE_gaba[1087] = new NetCon(&v(0.5), syn_projIE_gaba[1087], 20.0, 1.5, -0.0016545403)")  

        # Connection 1088: cell 13, seg 0 (0.5) [0.5 on Ipop[13]] -> cell 48, seg 0 (0.5) [0.5 on Epop[48]], weight: -0.0016545403, delay 1.5
        h("Epop[48] syn_projIE_gaba[1088] = new gaba(0.5)")
        h("Ipop[13] netConn_projIE_gaba[1088] = new NetCon(&v(0.5), syn_projIE_gaba[1088], 20.0, 1.5, -0.0016545403)")  

        # Connection 1089: cell 13, seg 0 (0.5) [0.5 on Ipop[13]] -> cell 49, seg 0 (0.5) [0.5 on Epop[49]], weight: -0.0016545403, delay 1.5
        h("Epop[49] syn_projIE_gaba[1089] = new gaba(0.5)")
        h("Ipop[13] netConn_projIE_gaba[1089] = new NetCon(&v(0.5), syn_projIE_gaba[1089], 20.0, 1.5, -0.0016545403)")  

        # Connection 1090: cell 13, seg 0 (0.5) [0.5 on Ipop[13]] -> cell 50, seg 0 (0.5) [0.5 on Epop[50]], weight: -0.0016545403, delay 1.5
        h("Epop[50] syn_projIE_gaba[1090] = new gaba(0.5)")
        h("Ipop[13] netConn_projIE_gaba[1090] = new NetCon(&v(0.5), syn_projIE_gaba[1090], 20.0, 1.5, -0.0016545403)")  

        # Connection 1091: cell 13, seg 0 (0.5) [0.5 on Ipop[13]] -> cell 51, seg 0 (0.5) [0.5 on Epop[51]], weight: -0.0016545403, delay 1.5
        h("Epop[51] syn_projIE_gaba[1091] = new gaba(0.5)")
        h("Ipop[13] netConn_projIE_gaba[1091] = new NetCon(&v(0.5), syn_projIE_gaba[1091], 20.0, 1.5, -0.0016545403)")  

        # Connection 1092: cell 13, seg 0 (0.5) [0.5 on Ipop[13]] -> cell 52, seg 0 (0.5) [0.5 on Epop[52]], weight: -0.0016545403, delay 1.5
        h("Epop[52] syn_projIE_gaba[1092] = new gaba(0.5)")
        h("Ipop[13] netConn_projIE_gaba[1092] = new NetCon(&v(0.5), syn_projIE_gaba[1092], 20.0, 1.5, -0.0016545403)")  

        # Connection 1093: cell 13, seg 0 (0.5) [0.5 on Ipop[13]] -> cell 53, seg 0 (0.5) [0.5 on Epop[53]], weight: -0.0016545403, delay 1.5
        h("Epop[53] syn_projIE_gaba[1093] = new gaba(0.5)")
        h("Ipop[13] netConn_projIE_gaba[1093] = new NetCon(&v(0.5), syn_projIE_gaba[1093], 20.0, 1.5, -0.0016545403)")  

        # Connection 1094: cell 13, seg 0 (0.5) [0.5 on Ipop[13]] -> cell 54, seg 0 (0.5) [0.5 on Epop[54]], weight: -0.0016545403, delay 1.5
        h("Epop[54] syn_projIE_gaba[1094] = new gaba(0.5)")
        h("Ipop[13] netConn_projIE_gaba[1094] = new NetCon(&v(0.5), syn_projIE_gaba[1094], 20.0, 1.5, -0.0016545403)")  

        # Connection 1095: cell 13, seg 0 (0.5) [0.5 on Ipop[13]] -> cell 55, seg 0 (0.5) [0.5 on Epop[55]], weight: -0.0016545403, delay 1.5
        h("Epop[55] syn_projIE_gaba[1095] = new gaba(0.5)")
        h("Ipop[13] netConn_projIE_gaba[1095] = new NetCon(&v(0.5), syn_projIE_gaba[1095], 20.0, 1.5, -0.0016545403)")  

        # Connection 1096: cell 13, seg 0 (0.5) [0.5 on Ipop[13]] -> cell 56, seg 0 (0.5) [0.5 on Epop[56]], weight: -0.0016545403, delay 1.5
        h("Epop[56] syn_projIE_gaba[1096] = new gaba(0.5)")
        h("Ipop[13] netConn_projIE_gaba[1096] = new NetCon(&v(0.5), syn_projIE_gaba[1096], 20.0, 1.5, -0.0016545403)")  

        # Connection 1097: cell 13, seg 0 (0.5) [0.5 on Ipop[13]] -> cell 57, seg 0 (0.5) [0.5 on Epop[57]], weight: -0.0016545403, delay 1.5
        h("Epop[57] syn_projIE_gaba[1097] = new gaba(0.5)")
        h("Ipop[13] netConn_projIE_gaba[1097] = new NetCon(&v(0.5), syn_projIE_gaba[1097], 20.0, 1.5, -0.0016545403)")  

        # Connection 1098: cell 13, seg 0 (0.5) [0.5 on Ipop[13]] -> cell 58, seg 0 (0.5) [0.5 on Epop[58]], weight: -0.0016545403, delay 1.5
        h("Epop[58] syn_projIE_gaba[1098] = new gaba(0.5)")
        h("Ipop[13] netConn_projIE_gaba[1098] = new NetCon(&v(0.5), syn_projIE_gaba[1098], 20.0, 1.5, -0.0016545403)")  

        # Connection 1099: cell 13, seg 0 (0.5) [0.5 on Ipop[13]] -> cell 59, seg 0 (0.5) [0.5 on Epop[59]], weight: -0.0016545403, delay 1.5
        h("Epop[59] syn_projIE_gaba[1099] = new gaba(0.5)")
        h("Ipop[13] netConn_projIE_gaba[1099] = new NetCon(&v(0.5), syn_projIE_gaba[1099], 20.0, 1.5, -0.0016545403)")  

        # Connection 1100: cell 13, seg 0 (0.5) [0.5 on Ipop[13]] -> cell 60, seg 0 (0.5) [0.5 on Epop[60]], weight: -0.0016545403, delay 1.5
        h("Epop[60] syn_projIE_gaba[1100] = new gaba(0.5)")
        h("Ipop[13] netConn_projIE_gaba[1100] = new NetCon(&v(0.5), syn_projIE_gaba[1100], 20.0, 1.5, -0.0016545403)")  

        # Connection 1101: cell 13, seg 0 (0.5) [0.5 on Ipop[13]] -> cell 61, seg 0 (0.5) [0.5 on Epop[61]], weight: -0.0016545403, delay 1.5
        h("Epop[61] syn_projIE_gaba[1101] = new gaba(0.5)")
        h("Ipop[13] netConn_projIE_gaba[1101] = new NetCon(&v(0.5), syn_projIE_gaba[1101], 20.0, 1.5, -0.0016545403)")  

        # Connection 1102: cell 13, seg 0 (0.5) [0.5 on Ipop[13]] -> cell 62, seg 0 (0.5) [0.5 on Epop[62]], weight: -0.0016545403, delay 1.5
        h("Epop[62] syn_projIE_gaba[1102] = new gaba(0.5)")
        h("Ipop[13] netConn_projIE_gaba[1102] = new NetCon(&v(0.5), syn_projIE_gaba[1102], 20.0, 1.5, -0.0016545403)")  

        # Connection 1103: cell 13, seg 0 (0.5) [0.5 on Ipop[13]] -> cell 63, seg 0 (0.5) [0.5 on Epop[63]], weight: -0.0016545403, delay 1.5
        h("Epop[63] syn_projIE_gaba[1103] = new gaba(0.5)")
        h("Ipop[13] netConn_projIE_gaba[1103] = new NetCon(&v(0.5), syn_projIE_gaba[1103], 20.0, 1.5, -0.0016545403)")  

        # Connection 1104: cell 13, seg 0 (0.5) [0.5 on Ipop[13]] -> cell 64, seg 0 (0.5) [0.5 on Epop[64]], weight: -0.0016545403, delay 1.5
        h("Epop[64] syn_projIE_gaba[1104] = new gaba(0.5)")
        h("Ipop[13] netConn_projIE_gaba[1104] = new NetCon(&v(0.5), syn_projIE_gaba[1104], 20.0, 1.5, -0.0016545403)")  

        # Connection 1105: cell 13, seg 0 (0.5) [0.5 on Ipop[13]] -> cell 65, seg 0 (0.5) [0.5 on Epop[65]], weight: -0.0016545403, delay 1.5
        h("Epop[65] syn_projIE_gaba[1105] = new gaba(0.5)")
        h("Ipop[13] netConn_projIE_gaba[1105] = new NetCon(&v(0.5), syn_projIE_gaba[1105], 20.0, 1.5, -0.0016545403)")  

        # Connection 1106: cell 13, seg 0 (0.5) [0.5 on Ipop[13]] -> cell 66, seg 0 (0.5) [0.5 on Epop[66]], weight: -0.0016545403, delay 1.5
        h("Epop[66] syn_projIE_gaba[1106] = new gaba(0.5)")
        h("Ipop[13] netConn_projIE_gaba[1106] = new NetCon(&v(0.5), syn_projIE_gaba[1106], 20.0, 1.5, -0.0016545403)")  

        # Connection 1107: cell 13, seg 0 (0.5) [0.5 on Ipop[13]] -> cell 67, seg 0 (0.5) [0.5 on Epop[67]], weight: -0.0016545403, delay 1.5
        h("Epop[67] syn_projIE_gaba[1107] = new gaba(0.5)")
        h("Ipop[13] netConn_projIE_gaba[1107] = new NetCon(&v(0.5), syn_projIE_gaba[1107], 20.0, 1.5, -0.0016545403)")  

        # Connection 1108: cell 13, seg 0 (0.5) [0.5 on Ipop[13]] -> cell 68, seg 0 (0.5) [0.5 on Epop[68]], weight: -0.0016545403, delay 1.5
        h("Epop[68] syn_projIE_gaba[1108] = new gaba(0.5)")
        h("Ipop[13] netConn_projIE_gaba[1108] = new NetCon(&v(0.5), syn_projIE_gaba[1108], 20.0, 1.5, -0.0016545403)")  

        # Connection 1109: cell 13, seg 0 (0.5) [0.5 on Ipop[13]] -> cell 69, seg 0 (0.5) [0.5 on Epop[69]], weight: -0.0016545403, delay 1.5
        h("Epop[69] syn_projIE_gaba[1109] = new gaba(0.5)")
        h("Ipop[13] netConn_projIE_gaba[1109] = new NetCon(&v(0.5), syn_projIE_gaba[1109], 20.0, 1.5, -0.0016545403)")  

        # Connection 1110: cell 13, seg 0 (0.5) [0.5 on Ipop[13]] -> cell 70, seg 0 (0.5) [0.5 on Epop[70]], weight: -0.0016545403, delay 1.5
        h("Epop[70] syn_projIE_gaba[1110] = new gaba(0.5)")
        h("Ipop[13] netConn_projIE_gaba[1110] = new NetCon(&v(0.5), syn_projIE_gaba[1110], 20.0, 1.5, -0.0016545403)")  

        # Connection 1111: cell 13, seg 0 (0.5) [0.5 on Ipop[13]] -> cell 71, seg 0 (0.5) [0.5 on Epop[71]], weight: -0.0016545403, delay 1.5
        h("Epop[71] syn_projIE_gaba[1111] = new gaba(0.5)")
        h("Ipop[13] netConn_projIE_gaba[1111] = new NetCon(&v(0.5), syn_projIE_gaba[1111], 20.0, 1.5, -0.0016545403)")  

        # Connection 1112: cell 13, seg 0 (0.5) [0.5 on Ipop[13]] -> cell 72, seg 0 (0.5) [0.5 on Epop[72]], weight: -0.0016545403, delay 1.5
        h("Epop[72] syn_projIE_gaba[1112] = new gaba(0.5)")
        h("Ipop[13] netConn_projIE_gaba[1112] = new NetCon(&v(0.5), syn_projIE_gaba[1112], 20.0, 1.5, -0.0016545403)")  

        # Connection 1113: cell 13, seg 0 (0.5) [0.5 on Ipop[13]] -> cell 73, seg 0 (0.5) [0.5 on Epop[73]], weight: -0.0016545403, delay 1.5
        h("Epop[73] syn_projIE_gaba[1113] = new gaba(0.5)")
        h("Ipop[13] netConn_projIE_gaba[1113] = new NetCon(&v(0.5), syn_projIE_gaba[1113], 20.0, 1.5, -0.0016545403)")  

        # Connection 1114: cell 13, seg 0 (0.5) [0.5 on Ipop[13]] -> cell 74, seg 0 (0.5) [0.5 on Epop[74]], weight: -0.0016545403, delay 1.5
        h("Epop[74] syn_projIE_gaba[1114] = new gaba(0.5)")
        h("Ipop[13] netConn_projIE_gaba[1114] = new NetCon(&v(0.5), syn_projIE_gaba[1114], 20.0, 1.5, -0.0016545403)")  

        # Connection 1115: cell 13, seg 0 (0.5) [0.5 on Ipop[13]] -> cell 75, seg 0 (0.5) [0.5 on Epop[75]], weight: -0.0016545403, delay 1.5
        h("Epop[75] syn_projIE_gaba[1115] = new gaba(0.5)")
        h("Ipop[13] netConn_projIE_gaba[1115] = new NetCon(&v(0.5), syn_projIE_gaba[1115], 20.0, 1.5, -0.0016545403)")  

        # Connection 1116: cell 13, seg 0 (0.5) [0.5 on Ipop[13]] -> cell 76, seg 0 (0.5) [0.5 on Epop[76]], weight: -0.0016545403, delay 1.5
        h("Epop[76] syn_projIE_gaba[1116] = new gaba(0.5)")
        h("Ipop[13] netConn_projIE_gaba[1116] = new NetCon(&v(0.5), syn_projIE_gaba[1116], 20.0, 1.5, -0.0016545403)")  

        # Connection 1117: cell 13, seg 0 (0.5) [0.5 on Ipop[13]] -> cell 77, seg 0 (0.5) [0.5 on Epop[77]], weight: -0.0016545403, delay 1.5
        h("Epop[77] syn_projIE_gaba[1117] = new gaba(0.5)")
        h("Ipop[13] netConn_projIE_gaba[1117] = new NetCon(&v(0.5), syn_projIE_gaba[1117], 20.0, 1.5, -0.0016545403)")  

        # Connection 1118: cell 13, seg 0 (0.5) [0.5 on Ipop[13]] -> cell 78, seg 0 (0.5) [0.5 on Epop[78]], weight: -0.0016545403, delay 1.5
        h("Epop[78] syn_projIE_gaba[1118] = new gaba(0.5)")
        h("Ipop[13] netConn_projIE_gaba[1118] = new NetCon(&v(0.5), syn_projIE_gaba[1118], 20.0, 1.5, -0.0016545403)")  

        # Connection 1119: cell 13, seg 0 (0.5) [0.5 on Ipop[13]] -> cell 79, seg 0 (0.5) [0.5 on Epop[79]], weight: -0.0016545403, delay 1.5
        h("Epop[79] syn_projIE_gaba[1119] = new gaba(0.5)")
        h("Ipop[13] netConn_projIE_gaba[1119] = new NetCon(&v(0.5), syn_projIE_gaba[1119], 20.0, 1.5, -0.0016545403)")  

        # Connection 1120: cell 14, seg 0 (0.5) [0.5 on Ipop[14]] -> cell 0, seg 0 (0.5) [0.5 on Epop[0]], weight: -0.0016545403, delay 1.5
        h("Epop[0] syn_projIE_gaba[1120] = new gaba(0.5)")
        h("Ipop[14] netConn_projIE_gaba[1120] = new NetCon(&v(0.5), syn_projIE_gaba[1120], 20.0, 1.5, -0.0016545403)")  

        # Connection 1121: cell 14, seg 0 (0.5) [0.5 on Ipop[14]] -> cell 1, seg 0 (0.5) [0.5 on Epop[1]], weight: -0.0016545403, delay 1.5
        h("Epop[1] syn_projIE_gaba[1121] = new gaba(0.5)")
        h("Ipop[14] netConn_projIE_gaba[1121] = new NetCon(&v(0.5), syn_projIE_gaba[1121], 20.0, 1.5, -0.0016545403)")  

        # Connection 1122: cell 14, seg 0 (0.5) [0.5 on Ipop[14]] -> cell 2, seg 0 (0.5) [0.5 on Epop[2]], weight: -0.0016545403, delay 1.5
        h("Epop[2] syn_projIE_gaba[1122] = new gaba(0.5)")
        h("Ipop[14] netConn_projIE_gaba[1122] = new NetCon(&v(0.5), syn_projIE_gaba[1122], 20.0, 1.5, -0.0016545403)")  

        # Connection 1123: cell 14, seg 0 (0.5) [0.5 on Ipop[14]] -> cell 3, seg 0 (0.5) [0.5 on Epop[3]], weight: -0.0016545403, delay 1.5
        h("Epop[3] syn_projIE_gaba[1123] = new gaba(0.5)")
        h("Ipop[14] netConn_projIE_gaba[1123] = new NetCon(&v(0.5), syn_projIE_gaba[1123], 20.0, 1.5, -0.0016545403)")  

        # Connection 1124: cell 14, seg 0 (0.5) [0.5 on Ipop[14]] -> cell 4, seg 0 (0.5) [0.5 on Epop[4]], weight: -0.0016545403, delay 1.5
        h("Epop[4] syn_projIE_gaba[1124] = new gaba(0.5)")
        h("Ipop[14] netConn_projIE_gaba[1124] = new NetCon(&v(0.5), syn_projIE_gaba[1124], 20.0, 1.5, -0.0016545403)")  

        # Connection 1125: cell 14, seg 0 (0.5) [0.5 on Ipop[14]] -> cell 5, seg 0 (0.5) [0.5 on Epop[5]], weight: -0.0016545403, delay 1.5
        h("Epop[5] syn_projIE_gaba[1125] = new gaba(0.5)")
        h("Ipop[14] netConn_projIE_gaba[1125] = new NetCon(&v(0.5), syn_projIE_gaba[1125], 20.0, 1.5, -0.0016545403)")  

        # Connection 1126: cell 14, seg 0 (0.5) [0.5 on Ipop[14]] -> cell 6, seg 0 (0.5) [0.5 on Epop[6]], weight: -0.0016545403, delay 1.5
        h("Epop[6] syn_projIE_gaba[1126] = new gaba(0.5)")
        h("Ipop[14] netConn_projIE_gaba[1126] = new NetCon(&v(0.5), syn_projIE_gaba[1126], 20.0, 1.5, -0.0016545403)")  

        # Connection 1127: cell 14, seg 0 (0.5) [0.5 on Ipop[14]] -> cell 7, seg 0 (0.5) [0.5 on Epop[7]], weight: -0.0016545403, delay 1.5
        h("Epop[7] syn_projIE_gaba[1127] = new gaba(0.5)")
        h("Ipop[14] netConn_projIE_gaba[1127] = new NetCon(&v(0.5), syn_projIE_gaba[1127], 20.0, 1.5, -0.0016545403)")  

        # Connection 1128: cell 14, seg 0 (0.5) [0.5 on Ipop[14]] -> cell 8, seg 0 (0.5) [0.5 on Epop[8]], weight: -0.0016545403, delay 1.5
        h("Epop[8] syn_projIE_gaba[1128] = new gaba(0.5)")
        h("Ipop[14] netConn_projIE_gaba[1128] = new NetCon(&v(0.5), syn_projIE_gaba[1128], 20.0, 1.5, -0.0016545403)")  

        # Connection 1129: cell 14, seg 0 (0.5) [0.5 on Ipop[14]] -> cell 9, seg 0 (0.5) [0.5 on Epop[9]], weight: -0.0016545403, delay 1.5
        h("Epop[9] syn_projIE_gaba[1129] = new gaba(0.5)")
        h("Ipop[14] netConn_projIE_gaba[1129] = new NetCon(&v(0.5), syn_projIE_gaba[1129], 20.0, 1.5, -0.0016545403)")  

        # Connection 1130: cell 14, seg 0 (0.5) [0.5 on Ipop[14]] -> cell 10, seg 0 (0.5) [0.5 on Epop[10]], weight: -0.0016545403, delay 1.5
        h("Epop[10] syn_projIE_gaba[1130] = new gaba(0.5)")
        h("Ipop[14] netConn_projIE_gaba[1130] = new NetCon(&v(0.5), syn_projIE_gaba[1130], 20.0, 1.5, -0.0016545403)")  

        # Connection 1131: cell 14, seg 0 (0.5) [0.5 on Ipop[14]] -> cell 11, seg 0 (0.5) [0.5 on Epop[11]], weight: -0.0016545403, delay 1.5
        h("Epop[11] syn_projIE_gaba[1131] = new gaba(0.5)")
        h("Ipop[14] netConn_projIE_gaba[1131] = new NetCon(&v(0.5), syn_projIE_gaba[1131], 20.0, 1.5, -0.0016545403)")  

        # Connection 1132: cell 14, seg 0 (0.5) [0.5 on Ipop[14]] -> cell 12, seg 0 (0.5) [0.5 on Epop[12]], weight: -0.0016545403, delay 1.5
        h("Epop[12] syn_projIE_gaba[1132] = new gaba(0.5)")
        h("Ipop[14] netConn_projIE_gaba[1132] = new NetCon(&v(0.5), syn_projIE_gaba[1132], 20.0, 1.5, -0.0016545403)")  

        # Connection 1133: cell 14, seg 0 (0.5) [0.5 on Ipop[14]] -> cell 13, seg 0 (0.5) [0.5 on Epop[13]], weight: -0.0016545403, delay 1.5
        h("Epop[13] syn_projIE_gaba[1133] = new gaba(0.5)")
        h("Ipop[14] netConn_projIE_gaba[1133] = new NetCon(&v(0.5), syn_projIE_gaba[1133], 20.0, 1.5, -0.0016545403)")  

        # Connection 1134: cell 14, seg 0 (0.5) [0.5 on Ipop[14]] -> cell 14, seg 0 (0.5) [0.5 on Epop[14]], weight: -0.0016545403, delay 1.5
        h("Epop[14] syn_projIE_gaba[1134] = new gaba(0.5)")
        h("Ipop[14] netConn_projIE_gaba[1134] = new NetCon(&v(0.5), syn_projIE_gaba[1134], 20.0, 1.5, -0.0016545403)")  

        # Connection 1135: cell 14, seg 0 (0.5) [0.5 on Ipop[14]] -> cell 15, seg 0 (0.5) [0.5 on Epop[15]], weight: -0.0016545403, delay 1.5
        h("Epop[15] syn_projIE_gaba[1135] = new gaba(0.5)")
        h("Ipop[14] netConn_projIE_gaba[1135] = new NetCon(&v(0.5), syn_projIE_gaba[1135], 20.0, 1.5, -0.0016545403)")  

        # Connection 1136: cell 14, seg 0 (0.5) [0.5 on Ipop[14]] -> cell 16, seg 0 (0.5) [0.5 on Epop[16]], weight: -0.0016545403, delay 1.5
        h("Epop[16] syn_projIE_gaba[1136] = new gaba(0.5)")
        h("Ipop[14] netConn_projIE_gaba[1136] = new NetCon(&v(0.5), syn_projIE_gaba[1136], 20.0, 1.5, -0.0016545403)")  

        # Connection 1137: cell 14, seg 0 (0.5) [0.5 on Ipop[14]] -> cell 17, seg 0 (0.5) [0.5 on Epop[17]], weight: -0.0016545403, delay 1.5
        h("Epop[17] syn_projIE_gaba[1137] = new gaba(0.5)")
        h("Ipop[14] netConn_projIE_gaba[1137] = new NetCon(&v(0.5), syn_projIE_gaba[1137], 20.0, 1.5, -0.0016545403)")  

        # Connection 1138: cell 14, seg 0 (0.5) [0.5 on Ipop[14]] -> cell 18, seg 0 (0.5) [0.5 on Epop[18]], weight: -0.0016545403, delay 1.5
        h("Epop[18] syn_projIE_gaba[1138] = new gaba(0.5)")
        h("Ipop[14] netConn_projIE_gaba[1138] = new NetCon(&v(0.5), syn_projIE_gaba[1138], 20.0, 1.5, -0.0016545403)")  

        # Connection 1139: cell 14, seg 0 (0.5) [0.5 on Ipop[14]] -> cell 19, seg 0 (0.5) [0.5 on Epop[19]], weight: -0.0016545403, delay 1.5
        h("Epop[19] syn_projIE_gaba[1139] = new gaba(0.5)")
        h("Ipop[14] netConn_projIE_gaba[1139] = new NetCon(&v(0.5), syn_projIE_gaba[1139], 20.0, 1.5, -0.0016545403)")  

        # Connection 1140: cell 14, seg 0 (0.5) [0.5 on Ipop[14]] -> cell 20, seg 0 (0.5) [0.5 on Epop[20]], weight: -0.0016545403, delay 1.5
        h("Epop[20] syn_projIE_gaba[1140] = new gaba(0.5)")
        h("Ipop[14] netConn_projIE_gaba[1140] = new NetCon(&v(0.5), syn_projIE_gaba[1140], 20.0, 1.5, -0.0016545403)")  

        # Connection 1141: cell 14, seg 0 (0.5) [0.5 on Ipop[14]] -> cell 21, seg 0 (0.5) [0.5 on Epop[21]], weight: -0.0016545403, delay 1.5
        h("Epop[21] syn_projIE_gaba[1141] = new gaba(0.5)")
        h("Ipop[14] netConn_projIE_gaba[1141] = new NetCon(&v(0.5), syn_projIE_gaba[1141], 20.0, 1.5, -0.0016545403)")  

        # Connection 1142: cell 14, seg 0 (0.5) [0.5 on Ipop[14]] -> cell 22, seg 0 (0.5) [0.5 on Epop[22]], weight: -0.0016545403, delay 1.5
        h("Epop[22] syn_projIE_gaba[1142] = new gaba(0.5)")
        h("Ipop[14] netConn_projIE_gaba[1142] = new NetCon(&v(0.5), syn_projIE_gaba[1142], 20.0, 1.5, -0.0016545403)")  

        # Connection 1143: cell 14, seg 0 (0.5) [0.5 on Ipop[14]] -> cell 23, seg 0 (0.5) [0.5 on Epop[23]], weight: -0.0016545403, delay 1.5
        h("Epop[23] syn_projIE_gaba[1143] = new gaba(0.5)")
        h("Ipop[14] netConn_projIE_gaba[1143] = new NetCon(&v(0.5), syn_projIE_gaba[1143], 20.0, 1.5, -0.0016545403)")  

        # Connection 1144: cell 14, seg 0 (0.5) [0.5 on Ipop[14]] -> cell 24, seg 0 (0.5) [0.5 on Epop[24]], weight: -0.0016545403, delay 1.5
        h("Epop[24] syn_projIE_gaba[1144] = new gaba(0.5)")
        h("Ipop[14] netConn_projIE_gaba[1144] = new NetCon(&v(0.5), syn_projIE_gaba[1144], 20.0, 1.5, -0.0016545403)")  

        # Connection 1145: cell 14, seg 0 (0.5) [0.5 on Ipop[14]] -> cell 25, seg 0 (0.5) [0.5 on Epop[25]], weight: -0.0016545403, delay 1.5
        h("Epop[25] syn_projIE_gaba[1145] = new gaba(0.5)")
        h("Ipop[14] netConn_projIE_gaba[1145] = new NetCon(&v(0.5), syn_projIE_gaba[1145], 20.0, 1.5, -0.0016545403)")  

        # Connection 1146: cell 14, seg 0 (0.5) [0.5 on Ipop[14]] -> cell 26, seg 0 (0.5) [0.5 on Epop[26]], weight: -0.0016545403, delay 1.5
        h("Epop[26] syn_projIE_gaba[1146] = new gaba(0.5)")
        h("Ipop[14] netConn_projIE_gaba[1146] = new NetCon(&v(0.5), syn_projIE_gaba[1146], 20.0, 1.5, -0.0016545403)")  

        # Connection 1147: cell 14, seg 0 (0.5) [0.5 on Ipop[14]] -> cell 27, seg 0 (0.5) [0.5 on Epop[27]], weight: -0.0016545403, delay 1.5
        h("Epop[27] syn_projIE_gaba[1147] = new gaba(0.5)")
        h("Ipop[14] netConn_projIE_gaba[1147] = new NetCon(&v(0.5), syn_projIE_gaba[1147], 20.0, 1.5, -0.0016545403)")  

        # Connection 1148: cell 14, seg 0 (0.5) [0.5 on Ipop[14]] -> cell 28, seg 0 (0.5) [0.5 on Epop[28]], weight: -0.0016545403, delay 1.5
        h("Epop[28] syn_projIE_gaba[1148] = new gaba(0.5)")
        h("Ipop[14] netConn_projIE_gaba[1148] = new NetCon(&v(0.5), syn_projIE_gaba[1148], 20.0, 1.5, -0.0016545403)")  

        # Connection 1149: cell 14, seg 0 (0.5) [0.5 on Ipop[14]] -> cell 29, seg 0 (0.5) [0.5 on Epop[29]], weight: -0.0016545403, delay 1.5
        h("Epop[29] syn_projIE_gaba[1149] = new gaba(0.5)")
        h("Ipop[14] netConn_projIE_gaba[1149] = new NetCon(&v(0.5), syn_projIE_gaba[1149], 20.0, 1.5, -0.0016545403)")  

        # Connection 1150: cell 14, seg 0 (0.5) [0.5 on Ipop[14]] -> cell 30, seg 0 (0.5) [0.5 on Epop[30]], weight: -0.0016545403, delay 1.5
        h("Epop[30] syn_projIE_gaba[1150] = new gaba(0.5)")
        h("Ipop[14] netConn_projIE_gaba[1150] = new NetCon(&v(0.5), syn_projIE_gaba[1150], 20.0, 1.5, -0.0016545403)")  

        # Connection 1151: cell 14, seg 0 (0.5) [0.5 on Ipop[14]] -> cell 31, seg 0 (0.5) [0.5 on Epop[31]], weight: -0.0016545403, delay 1.5
        h("Epop[31] syn_projIE_gaba[1151] = new gaba(0.5)")
        h("Ipop[14] netConn_projIE_gaba[1151] = new NetCon(&v(0.5), syn_projIE_gaba[1151], 20.0, 1.5, -0.0016545403)")  

        # Connection 1152: cell 14, seg 0 (0.5) [0.5 on Ipop[14]] -> cell 32, seg 0 (0.5) [0.5 on Epop[32]], weight: -0.0016545403, delay 1.5
        h("Epop[32] syn_projIE_gaba[1152] = new gaba(0.5)")
        h("Ipop[14] netConn_projIE_gaba[1152] = new NetCon(&v(0.5), syn_projIE_gaba[1152], 20.0, 1.5, -0.0016545403)")  

        # Connection 1153: cell 14, seg 0 (0.5) [0.5 on Ipop[14]] -> cell 33, seg 0 (0.5) [0.5 on Epop[33]], weight: -0.0016545403, delay 1.5
        h("Epop[33] syn_projIE_gaba[1153] = new gaba(0.5)")
        h("Ipop[14] netConn_projIE_gaba[1153] = new NetCon(&v(0.5), syn_projIE_gaba[1153], 20.0, 1.5, -0.0016545403)")  

        # Connection 1154: cell 14, seg 0 (0.5) [0.5 on Ipop[14]] -> cell 34, seg 0 (0.5) [0.5 on Epop[34]], weight: -0.0016545403, delay 1.5
        h("Epop[34] syn_projIE_gaba[1154] = new gaba(0.5)")
        h("Ipop[14] netConn_projIE_gaba[1154] = new NetCon(&v(0.5), syn_projIE_gaba[1154], 20.0, 1.5, -0.0016545403)")  

        # Connection 1155: cell 14, seg 0 (0.5) [0.5 on Ipop[14]] -> cell 35, seg 0 (0.5) [0.5 on Epop[35]], weight: -0.0016545403, delay 1.5
        h("Epop[35] syn_projIE_gaba[1155] = new gaba(0.5)")
        h("Ipop[14] netConn_projIE_gaba[1155] = new NetCon(&v(0.5), syn_projIE_gaba[1155], 20.0, 1.5, -0.0016545403)")  

        # Connection 1156: cell 14, seg 0 (0.5) [0.5 on Ipop[14]] -> cell 36, seg 0 (0.5) [0.5 on Epop[36]], weight: -0.0016545403, delay 1.5
        h("Epop[36] syn_projIE_gaba[1156] = new gaba(0.5)")
        h("Ipop[14] netConn_projIE_gaba[1156] = new NetCon(&v(0.5), syn_projIE_gaba[1156], 20.0, 1.5, -0.0016545403)")  

        # Connection 1157: cell 14, seg 0 (0.5) [0.5 on Ipop[14]] -> cell 37, seg 0 (0.5) [0.5 on Epop[37]], weight: -0.0016545403, delay 1.5
        h("Epop[37] syn_projIE_gaba[1157] = new gaba(0.5)")
        h("Ipop[14] netConn_projIE_gaba[1157] = new NetCon(&v(0.5), syn_projIE_gaba[1157], 20.0, 1.5, -0.0016545403)")  

        # Connection 1158: cell 14, seg 0 (0.5) [0.5 on Ipop[14]] -> cell 38, seg 0 (0.5) [0.5 on Epop[38]], weight: -0.0016545403, delay 1.5
        h("Epop[38] syn_projIE_gaba[1158] = new gaba(0.5)")
        h("Ipop[14] netConn_projIE_gaba[1158] = new NetCon(&v(0.5), syn_projIE_gaba[1158], 20.0, 1.5, -0.0016545403)")  

        # Connection 1159: cell 14, seg 0 (0.5) [0.5 on Ipop[14]] -> cell 39, seg 0 (0.5) [0.5 on Epop[39]], weight: -0.0016545403, delay 1.5
        h("Epop[39] syn_projIE_gaba[1159] = new gaba(0.5)")
        h("Ipop[14] netConn_projIE_gaba[1159] = new NetCon(&v(0.5), syn_projIE_gaba[1159], 20.0, 1.5, -0.0016545403)")  

        # Connection 1160: cell 14, seg 0 (0.5) [0.5 on Ipop[14]] -> cell 40, seg 0 (0.5) [0.5 on Epop[40]], weight: -0.0016545403, delay 1.5
        h("Epop[40] syn_projIE_gaba[1160] = new gaba(0.5)")
        h("Ipop[14] netConn_projIE_gaba[1160] = new NetCon(&v(0.5), syn_projIE_gaba[1160], 20.0, 1.5, -0.0016545403)")  

        # Connection 1161: cell 14, seg 0 (0.5) [0.5 on Ipop[14]] -> cell 41, seg 0 (0.5) [0.5 on Epop[41]], weight: -0.0016545403, delay 1.5
        h("Epop[41] syn_projIE_gaba[1161] = new gaba(0.5)")
        h("Ipop[14] netConn_projIE_gaba[1161] = new NetCon(&v(0.5), syn_projIE_gaba[1161], 20.0, 1.5, -0.0016545403)")  

        # Connection 1162: cell 14, seg 0 (0.5) [0.5 on Ipop[14]] -> cell 42, seg 0 (0.5) [0.5 on Epop[42]], weight: -0.0016545403, delay 1.5
        h("Epop[42] syn_projIE_gaba[1162] = new gaba(0.5)")
        h("Ipop[14] netConn_projIE_gaba[1162] = new NetCon(&v(0.5), syn_projIE_gaba[1162], 20.0, 1.5, -0.0016545403)")  

        # Connection 1163: cell 14, seg 0 (0.5) [0.5 on Ipop[14]] -> cell 43, seg 0 (0.5) [0.5 on Epop[43]], weight: -0.0016545403, delay 1.5
        h("Epop[43] syn_projIE_gaba[1163] = new gaba(0.5)")
        h("Ipop[14] netConn_projIE_gaba[1163] = new NetCon(&v(0.5), syn_projIE_gaba[1163], 20.0, 1.5, -0.0016545403)")  

        # Connection 1164: cell 14, seg 0 (0.5) [0.5 on Ipop[14]] -> cell 44, seg 0 (0.5) [0.5 on Epop[44]], weight: -0.0016545403, delay 1.5
        h("Epop[44] syn_projIE_gaba[1164] = new gaba(0.5)")
        h("Ipop[14] netConn_projIE_gaba[1164] = new NetCon(&v(0.5), syn_projIE_gaba[1164], 20.0, 1.5, -0.0016545403)")  

        # Connection 1165: cell 14, seg 0 (0.5) [0.5 on Ipop[14]] -> cell 45, seg 0 (0.5) [0.5 on Epop[45]], weight: -0.0016545403, delay 1.5
        h("Epop[45] syn_projIE_gaba[1165] = new gaba(0.5)")
        h("Ipop[14] netConn_projIE_gaba[1165] = new NetCon(&v(0.5), syn_projIE_gaba[1165], 20.0, 1.5, -0.0016545403)")  

        # Connection 1166: cell 14, seg 0 (0.5) [0.5 on Ipop[14]] -> cell 46, seg 0 (0.5) [0.5 on Epop[46]], weight: -0.0016545403, delay 1.5
        h("Epop[46] syn_projIE_gaba[1166] = new gaba(0.5)")
        h("Ipop[14] netConn_projIE_gaba[1166] = new NetCon(&v(0.5), syn_projIE_gaba[1166], 20.0, 1.5, -0.0016545403)")  

        # Connection 1167: cell 14, seg 0 (0.5) [0.5 on Ipop[14]] -> cell 47, seg 0 (0.5) [0.5 on Epop[47]], weight: -0.0016545403, delay 1.5
        h("Epop[47] syn_projIE_gaba[1167] = new gaba(0.5)")
        h("Ipop[14] netConn_projIE_gaba[1167] = new NetCon(&v(0.5), syn_projIE_gaba[1167], 20.0, 1.5, -0.0016545403)")  

        # Connection 1168: cell 14, seg 0 (0.5) [0.5 on Ipop[14]] -> cell 48, seg 0 (0.5) [0.5 on Epop[48]], weight: -0.0016545403, delay 1.5
        h("Epop[48] syn_projIE_gaba[1168] = new gaba(0.5)")
        h("Ipop[14] netConn_projIE_gaba[1168] = new NetCon(&v(0.5), syn_projIE_gaba[1168], 20.0, 1.5, -0.0016545403)")  

        # Connection 1169: cell 14, seg 0 (0.5) [0.5 on Ipop[14]] -> cell 49, seg 0 (0.5) [0.5 on Epop[49]], weight: -0.0016545403, delay 1.5
        h("Epop[49] syn_projIE_gaba[1169] = new gaba(0.5)")
        h("Ipop[14] netConn_projIE_gaba[1169] = new NetCon(&v(0.5), syn_projIE_gaba[1169], 20.0, 1.5, -0.0016545403)")  

        # Connection 1170: cell 14, seg 0 (0.5) [0.5 on Ipop[14]] -> cell 50, seg 0 (0.5) [0.5 on Epop[50]], weight: -0.0016545403, delay 1.5
        h("Epop[50] syn_projIE_gaba[1170] = new gaba(0.5)")
        h("Ipop[14] netConn_projIE_gaba[1170] = new NetCon(&v(0.5), syn_projIE_gaba[1170], 20.0, 1.5, -0.0016545403)")  

        # Connection 1171: cell 14, seg 0 (0.5) [0.5 on Ipop[14]] -> cell 51, seg 0 (0.5) [0.5 on Epop[51]], weight: -0.0016545403, delay 1.5
        h("Epop[51] syn_projIE_gaba[1171] = new gaba(0.5)")
        h("Ipop[14] netConn_projIE_gaba[1171] = new NetCon(&v(0.5), syn_projIE_gaba[1171], 20.0, 1.5, -0.0016545403)")  

        # Connection 1172: cell 14, seg 0 (0.5) [0.5 on Ipop[14]] -> cell 52, seg 0 (0.5) [0.5 on Epop[52]], weight: -0.0016545403, delay 1.5
        h("Epop[52] syn_projIE_gaba[1172] = new gaba(0.5)")
        h("Ipop[14] netConn_projIE_gaba[1172] = new NetCon(&v(0.5), syn_projIE_gaba[1172], 20.0, 1.5, -0.0016545403)")  

        # Connection 1173: cell 14, seg 0 (0.5) [0.5 on Ipop[14]] -> cell 53, seg 0 (0.5) [0.5 on Epop[53]], weight: -0.0016545403, delay 1.5
        h("Epop[53] syn_projIE_gaba[1173] = new gaba(0.5)")
        h("Ipop[14] netConn_projIE_gaba[1173] = new NetCon(&v(0.5), syn_projIE_gaba[1173], 20.0, 1.5, -0.0016545403)")  

        # Connection 1174: cell 14, seg 0 (0.5) [0.5 on Ipop[14]] -> cell 54, seg 0 (0.5) [0.5 on Epop[54]], weight: -0.0016545403, delay 1.5
        h("Epop[54] syn_projIE_gaba[1174] = new gaba(0.5)")
        h("Ipop[14] netConn_projIE_gaba[1174] = new NetCon(&v(0.5), syn_projIE_gaba[1174], 20.0, 1.5, -0.0016545403)")  

        # Connection 1175: cell 14, seg 0 (0.5) [0.5 on Ipop[14]] -> cell 55, seg 0 (0.5) [0.5 on Epop[55]], weight: -0.0016545403, delay 1.5
        h("Epop[55] syn_projIE_gaba[1175] = new gaba(0.5)")
        h("Ipop[14] netConn_projIE_gaba[1175] = new NetCon(&v(0.5), syn_projIE_gaba[1175], 20.0, 1.5, -0.0016545403)")  

        # Connection 1176: cell 14, seg 0 (0.5) [0.5 on Ipop[14]] -> cell 56, seg 0 (0.5) [0.5 on Epop[56]], weight: -0.0016545403, delay 1.5
        h("Epop[56] syn_projIE_gaba[1176] = new gaba(0.5)")
        h("Ipop[14] netConn_projIE_gaba[1176] = new NetCon(&v(0.5), syn_projIE_gaba[1176], 20.0, 1.5, -0.0016545403)")  

        # Connection 1177: cell 14, seg 0 (0.5) [0.5 on Ipop[14]] -> cell 57, seg 0 (0.5) [0.5 on Epop[57]], weight: -0.0016545403, delay 1.5
        h("Epop[57] syn_projIE_gaba[1177] = new gaba(0.5)")
        h("Ipop[14] netConn_projIE_gaba[1177] = new NetCon(&v(0.5), syn_projIE_gaba[1177], 20.0, 1.5, -0.0016545403)")  

        # Connection 1178: cell 14, seg 0 (0.5) [0.5 on Ipop[14]] -> cell 58, seg 0 (0.5) [0.5 on Epop[58]], weight: -0.0016545403, delay 1.5
        h("Epop[58] syn_projIE_gaba[1178] = new gaba(0.5)")
        h("Ipop[14] netConn_projIE_gaba[1178] = new NetCon(&v(0.5), syn_projIE_gaba[1178], 20.0, 1.5, -0.0016545403)")  

        # Connection 1179: cell 14, seg 0 (0.5) [0.5 on Ipop[14]] -> cell 59, seg 0 (0.5) [0.5 on Epop[59]], weight: -0.0016545403, delay 1.5
        h("Epop[59] syn_projIE_gaba[1179] = new gaba(0.5)")
        h("Ipop[14] netConn_projIE_gaba[1179] = new NetCon(&v(0.5), syn_projIE_gaba[1179], 20.0, 1.5, -0.0016545403)")  

        # Connection 1180: cell 14, seg 0 (0.5) [0.5 on Ipop[14]] -> cell 60, seg 0 (0.5) [0.5 on Epop[60]], weight: -0.0016545403, delay 1.5
        h("Epop[60] syn_projIE_gaba[1180] = new gaba(0.5)")
        h("Ipop[14] netConn_projIE_gaba[1180] = new NetCon(&v(0.5), syn_projIE_gaba[1180], 20.0, 1.5, -0.0016545403)")  

        # Connection 1181: cell 14, seg 0 (0.5) [0.5 on Ipop[14]] -> cell 61, seg 0 (0.5) [0.5 on Epop[61]], weight: -0.0016545403, delay 1.5
        h("Epop[61] syn_projIE_gaba[1181] = new gaba(0.5)")
        h("Ipop[14] netConn_projIE_gaba[1181] = new NetCon(&v(0.5), syn_projIE_gaba[1181], 20.0, 1.5, -0.0016545403)")  

        # Connection 1182: cell 14, seg 0 (0.5) [0.5 on Ipop[14]] -> cell 62, seg 0 (0.5) [0.5 on Epop[62]], weight: -0.0016545403, delay 1.5
        h("Epop[62] syn_projIE_gaba[1182] = new gaba(0.5)")
        h("Ipop[14] netConn_projIE_gaba[1182] = new NetCon(&v(0.5), syn_projIE_gaba[1182], 20.0, 1.5, -0.0016545403)")  

        # Connection 1183: cell 14, seg 0 (0.5) [0.5 on Ipop[14]] -> cell 63, seg 0 (0.5) [0.5 on Epop[63]], weight: -0.0016545403, delay 1.5
        h("Epop[63] syn_projIE_gaba[1183] = new gaba(0.5)")
        h("Ipop[14] netConn_projIE_gaba[1183] = new NetCon(&v(0.5), syn_projIE_gaba[1183], 20.0, 1.5, -0.0016545403)")  

        # Connection 1184: cell 14, seg 0 (0.5) [0.5 on Ipop[14]] -> cell 64, seg 0 (0.5) [0.5 on Epop[64]], weight: -0.0016545403, delay 1.5
        h("Epop[64] syn_projIE_gaba[1184] = new gaba(0.5)")
        h("Ipop[14] netConn_projIE_gaba[1184] = new NetCon(&v(0.5), syn_projIE_gaba[1184], 20.0, 1.5, -0.0016545403)")  

        # Connection 1185: cell 14, seg 0 (0.5) [0.5 on Ipop[14]] -> cell 65, seg 0 (0.5) [0.5 on Epop[65]], weight: -0.0016545403, delay 1.5
        h("Epop[65] syn_projIE_gaba[1185] = new gaba(0.5)")
        h("Ipop[14] netConn_projIE_gaba[1185] = new NetCon(&v(0.5), syn_projIE_gaba[1185], 20.0, 1.5, -0.0016545403)")  

        # Connection 1186: cell 14, seg 0 (0.5) [0.5 on Ipop[14]] -> cell 66, seg 0 (0.5) [0.5 on Epop[66]], weight: -0.0016545403, delay 1.5
        h("Epop[66] syn_projIE_gaba[1186] = new gaba(0.5)")
        h("Ipop[14] netConn_projIE_gaba[1186] = new NetCon(&v(0.5), syn_projIE_gaba[1186], 20.0, 1.5, -0.0016545403)")  

        # Connection 1187: cell 14, seg 0 (0.5) [0.5 on Ipop[14]] -> cell 67, seg 0 (0.5) [0.5 on Epop[67]], weight: -0.0016545403, delay 1.5
        h("Epop[67] syn_projIE_gaba[1187] = new gaba(0.5)")
        h("Ipop[14] netConn_projIE_gaba[1187] = new NetCon(&v(0.5), syn_projIE_gaba[1187], 20.0, 1.5, -0.0016545403)")  

        # Connection 1188: cell 14, seg 0 (0.5) [0.5 on Ipop[14]] -> cell 68, seg 0 (0.5) [0.5 on Epop[68]], weight: -0.0016545403, delay 1.5
        h("Epop[68] syn_projIE_gaba[1188] = new gaba(0.5)")
        h("Ipop[14] netConn_projIE_gaba[1188] = new NetCon(&v(0.5), syn_projIE_gaba[1188], 20.0, 1.5, -0.0016545403)")  

        # Connection 1189: cell 14, seg 0 (0.5) [0.5 on Ipop[14]] -> cell 69, seg 0 (0.5) [0.5 on Epop[69]], weight: -0.0016545403, delay 1.5
        h("Epop[69] syn_projIE_gaba[1189] = new gaba(0.5)")
        h("Ipop[14] netConn_projIE_gaba[1189] = new NetCon(&v(0.5), syn_projIE_gaba[1189], 20.0, 1.5, -0.0016545403)")  

        # Connection 1190: cell 14, seg 0 (0.5) [0.5 on Ipop[14]] -> cell 70, seg 0 (0.5) [0.5 on Epop[70]], weight: -0.0016545403, delay 1.5
        h("Epop[70] syn_projIE_gaba[1190] = new gaba(0.5)")
        h("Ipop[14] netConn_projIE_gaba[1190] = new NetCon(&v(0.5), syn_projIE_gaba[1190], 20.0, 1.5, -0.0016545403)")  

        # Connection 1191: cell 14, seg 0 (0.5) [0.5 on Ipop[14]] -> cell 71, seg 0 (0.5) [0.5 on Epop[71]], weight: -0.0016545403, delay 1.5
        h("Epop[71] syn_projIE_gaba[1191] = new gaba(0.5)")
        h("Ipop[14] netConn_projIE_gaba[1191] = new NetCon(&v(0.5), syn_projIE_gaba[1191], 20.0, 1.5, -0.0016545403)")  

        # Connection 1192: cell 14, seg 0 (0.5) [0.5 on Ipop[14]] -> cell 72, seg 0 (0.5) [0.5 on Epop[72]], weight: -0.0016545403, delay 1.5
        h("Epop[72] syn_projIE_gaba[1192] = new gaba(0.5)")
        h("Ipop[14] netConn_projIE_gaba[1192] = new NetCon(&v(0.5), syn_projIE_gaba[1192], 20.0, 1.5, -0.0016545403)")  

        # Connection 1193: cell 14, seg 0 (0.5) [0.5 on Ipop[14]] -> cell 73, seg 0 (0.5) [0.5 on Epop[73]], weight: -0.0016545403, delay 1.5
        h("Epop[73] syn_projIE_gaba[1193] = new gaba(0.5)")
        h("Ipop[14] netConn_projIE_gaba[1193] = new NetCon(&v(0.5), syn_projIE_gaba[1193], 20.0, 1.5, -0.0016545403)")  

        # Connection 1194: cell 14, seg 0 (0.5) [0.5 on Ipop[14]] -> cell 74, seg 0 (0.5) [0.5 on Epop[74]], weight: -0.0016545403, delay 1.5
        h("Epop[74] syn_projIE_gaba[1194] = new gaba(0.5)")
        h("Ipop[14] netConn_projIE_gaba[1194] = new NetCon(&v(0.5), syn_projIE_gaba[1194], 20.0, 1.5, -0.0016545403)")  

        # Connection 1195: cell 14, seg 0 (0.5) [0.5 on Ipop[14]] -> cell 75, seg 0 (0.5) [0.5 on Epop[75]], weight: -0.0016545403, delay 1.5
        h("Epop[75] syn_projIE_gaba[1195] = new gaba(0.5)")
        h("Ipop[14] netConn_projIE_gaba[1195] = new NetCon(&v(0.5), syn_projIE_gaba[1195], 20.0, 1.5, -0.0016545403)")  

        # Connection 1196: cell 14, seg 0 (0.5) [0.5 on Ipop[14]] -> cell 76, seg 0 (0.5) [0.5 on Epop[76]], weight: -0.0016545403, delay 1.5
        h("Epop[76] syn_projIE_gaba[1196] = new gaba(0.5)")
        h("Ipop[14] netConn_projIE_gaba[1196] = new NetCon(&v(0.5), syn_projIE_gaba[1196], 20.0, 1.5, -0.0016545403)")  

        # Connection 1197: cell 14, seg 0 (0.5) [0.5 on Ipop[14]] -> cell 77, seg 0 (0.5) [0.5 on Epop[77]], weight: -0.0016545403, delay 1.5
        h("Epop[77] syn_projIE_gaba[1197] = new gaba(0.5)")
        h("Ipop[14] netConn_projIE_gaba[1197] = new NetCon(&v(0.5), syn_projIE_gaba[1197], 20.0, 1.5, -0.0016545403)")  

        # Connection 1198: cell 14, seg 0 (0.5) [0.5 on Ipop[14]] -> cell 78, seg 0 (0.5) [0.5 on Epop[78]], weight: -0.0016545403, delay 1.5
        h("Epop[78] syn_projIE_gaba[1198] = new gaba(0.5)")
        h("Ipop[14] netConn_projIE_gaba[1198] = new NetCon(&v(0.5), syn_projIE_gaba[1198], 20.0, 1.5, -0.0016545403)")  

        # Connection 1199: cell 14, seg 0 (0.5) [0.5 on Ipop[14]] -> cell 79, seg 0 (0.5) [0.5 on Epop[79]], weight: -0.0016545403, delay 1.5
        h("Epop[79] syn_projIE_gaba[1199] = new gaba(0.5)")
        h("Ipop[14] netConn_projIE_gaba[1199] = new NetCon(&v(0.5), syn_projIE_gaba[1199], 20.0, 1.5, -0.0016545403)")  

        # Connection 1200: cell 15, seg 0 (0.5) [0.5 on Ipop[15]] -> cell 0, seg 0 (0.5) [0.5 on Epop[0]], weight: -0.0016545403, delay 1.5
        h("Epop[0] syn_projIE_gaba[1200] = new gaba(0.5)")
        h("Ipop[15] netConn_projIE_gaba[1200] = new NetCon(&v(0.5), syn_projIE_gaba[1200], 20.0, 1.5, -0.0016545403)")  

        # Connection 1201: cell 15, seg 0 (0.5) [0.5 on Ipop[15]] -> cell 1, seg 0 (0.5) [0.5 on Epop[1]], weight: -0.0016545403, delay 1.5
        h("Epop[1] syn_projIE_gaba[1201] = new gaba(0.5)")
        h("Ipop[15] netConn_projIE_gaba[1201] = new NetCon(&v(0.5), syn_projIE_gaba[1201], 20.0, 1.5, -0.0016545403)")  

        # Connection 1202: cell 15, seg 0 (0.5) [0.5 on Ipop[15]] -> cell 2, seg 0 (0.5) [0.5 on Epop[2]], weight: -0.0016545403, delay 1.5
        h("Epop[2] syn_projIE_gaba[1202] = new gaba(0.5)")
        h("Ipop[15] netConn_projIE_gaba[1202] = new NetCon(&v(0.5), syn_projIE_gaba[1202], 20.0, 1.5, -0.0016545403)")  

        # Connection 1203: cell 15, seg 0 (0.5) [0.5 on Ipop[15]] -> cell 3, seg 0 (0.5) [0.5 on Epop[3]], weight: -0.0016545403, delay 1.5
        h("Epop[3] syn_projIE_gaba[1203] = new gaba(0.5)")
        h("Ipop[15] netConn_projIE_gaba[1203] = new NetCon(&v(0.5), syn_projIE_gaba[1203], 20.0, 1.5, -0.0016545403)")  

        # Connection 1204: cell 15, seg 0 (0.5) [0.5 on Ipop[15]] -> cell 4, seg 0 (0.5) [0.5 on Epop[4]], weight: -0.0016545403, delay 1.5
        h("Epop[4] syn_projIE_gaba[1204] = new gaba(0.5)")
        h("Ipop[15] netConn_projIE_gaba[1204] = new NetCon(&v(0.5), syn_projIE_gaba[1204], 20.0, 1.5, -0.0016545403)")  

        # Connection 1205: cell 15, seg 0 (0.5) [0.5 on Ipop[15]] -> cell 5, seg 0 (0.5) [0.5 on Epop[5]], weight: -0.0016545403, delay 1.5
        h("Epop[5] syn_projIE_gaba[1205] = new gaba(0.5)")
        h("Ipop[15] netConn_projIE_gaba[1205] = new NetCon(&v(0.5), syn_projIE_gaba[1205], 20.0, 1.5, -0.0016545403)")  

        # Connection 1206: cell 15, seg 0 (0.5) [0.5 on Ipop[15]] -> cell 6, seg 0 (0.5) [0.5 on Epop[6]], weight: -0.0016545403, delay 1.5
        h("Epop[6] syn_projIE_gaba[1206] = new gaba(0.5)")
        h("Ipop[15] netConn_projIE_gaba[1206] = new NetCon(&v(0.5), syn_projIE_gaba[1206], 20.0, 1.5, -0.0016545403)")  

        # Connection 1207: cell 15, seg 0 (0.5) [0.5 on Ipop[15]] -> cell 7, seg 0 (0.5) [0.5 on Epop[7]], weight: -0.0016545403, delay 1.5
        h("Epop[7] syn_projIE_gaba[1207] = new gaba(0.5)")
        h("Ipop[15] netConn_projIE_gaba[1207] = new NetCon(&v(0.5), syn_projIE_gaba[1207], 20.0, 1.5, -0.0016545403)")  

        # Connection 1208: cell 15, seg 0 (0.5) [0.5 on Ipop[15]] -> cell 8, seg 0 (0.5) [0.5 on Epop[8]], weight: -0.0016545403, delay 1.5
        h("Epop[8] syn_projIE_gaba[1208] = new gaba(0.5)")
        h("Ipop[15] netConn_projIE_gaba[1208] = new NetCon(&v(0.5), syn_projIE_gaba[1208], 20.0, 1.5, -0.0016545403)")  

        # Connection 1209: cell 15, seg 0 (0.5) [0.5 on Ipop[15]] -> cell 9, seg 0 (0.5) [0.5 on Epop[9]], weight: -0.0016545403, delay 1.5
        h("Epop[9] syn_projIE_gaba[1209] = new gaba(0.5)")
        h("Ipop[15] netConn_projIE_gaba[1209] = new NetCon(&v(0.5), syn_projIE_gaba[1209], 20.0, 1.5, -0.0016545403)")  

        # Connection 1210: cell 15, seg 0 (0.5) [0.5 on Ipop[15]] -> cell 10, seg 0 (0.5) [0.5 on Epop[10]], weight: -0.0016545403, delay 1.5
        h("Epop[10] syn_projIE_gaba[1210] = new gaba(0.5)")
        h("Ipop[15] netConn_projIE_gaba[1210] = new NetCon(&v(0.5), syn_projIE_gaba[1210], 20.0, 1.5, -0.0016545403)")  

        # Connection 1211: cell 15, seg 0 (0.5) [0.5 on Ipop[15]] -> cell 11, seg 0 (0.5) [0.5 on Epop[11]], weight: -0.0016545403, delay 1.5
        h("Epop[11] syn_projIE_gaba[1211] = new gaba(0.5)")
        h("Ipop[15] netConn_projIE_gaba[1211] = new NetCon(&v(0.5), syn_projIE_gaba[1211], 20.0, 1.5, -0.0016545403)")  

        # Connection 1212: cell 15, seg 0 (0.5) [0.5 on Ipop[15]] -> cell 12, seg 0 (0.5) [0.5 on Epop[12]], weight: -0.0016545403, delay 1.5
        h("Epop[12] syn_projIE_gaba[1212] = new gaba(0.5)")
        h("Ipop[15] netConn_projIE_gaba[1212] = new NetCon(&v(0.5), syn_projIE_gaba[1212], 20.0, 1.5, -0.0016545403)")  

        # Connection 1213: cell 15, seg 0 (0.5) [0.5 on Ipop[15]] -> cell 13, seg 0 (0.5) [0.5 on Epop[13]], weight: -0.0016545403, delay 1.5
        h("Epop[13] syn_projIE_gaba[1213] = new gaba(0.5)")
        h("Ipop[15] netConn_projIE_gaba[1213] = new NetCon(&v(0.5), syn_projIE_gaba[1213], 20.0, 1.5, -0.0016545403)")  

        # Connection 1214: cell 15, seg 0 (0.5) [0.5 on Ipop[15]] -> cell 14, seg 0 (0.5) [0.5 on Epop[14]], weight: -0.0016545403, delay 1.5
        h("Epop[14] syn_projIE_gaba[1214] = new gaba(0.5)")
        h("Ipop[15] netConn_projIE_gaba[1214] = new NetCon(&v(0.5), syn_projIE_gaba[1214], 20.0, 1.5, -0.0016545403)")  

        # Connection 1215: cell 15, seg 0 (0.5) [0.5 on Ipop[15]] -> cell 15, seg 0 (0.5) [0.5 on Epop[15]], weight: -0.0016545403, delay 1.5
        h("Epop[15] syn_projIE_gaba[1215] = new gaba(0.5)")
        h("Ipop[15] netConn_projIE_gaba[1215] = new NetCon(&v(0.5), syn_projIE_gaba[1215], 20.0, 1.5, -0.0016545403)")  

        # Connection 1216: cell 15, seg 0 (0.5) [0.5 on Ipop[15]] -> cell 16, seg 0 (0.5) [0.5 on Epop[16]], weight: -0.0016545403, delay 1.5
        h("Epop[16] syn_projIE_gaba[1216] = new gaba(0.5)")
        h("Ipop[15] netConn_projIE_gaba[1216] = new NetCon(&v(0.5), syn_projIE_gaba[1216], 20.0, 1.5, -0.0016545403)")  

        # Connection 1217: cell 15, seg 0 (0.5) [0.5 on Ipop[15]] -> cell 17, seg 0 (0.5) [0.5 on Epop[17]], weight: -0.0016545403, delay 1.5
        h("Epop[17] syn_projIE_gaba[1217] = new gaba(0.5)")
        h("Ipop[15] netConn_projIE_gaba[1217] = new NetCon(&v(0.5), syn_projIE_gaba[1217], 20.0, 1.5, -0.0016545403)")  

        # Connection 1218: cell 15, seg 0 (0.5) [0.5 on Ipop[15]] -> cell 18, seg 0 (0.5) [0.5 on Epop[18]], weight: -0.0016545403, delay 1.5
        h("Epop[18] syn_projIE_gaba[1218] = new gaba(0.5)")
        h("Ipop[15] netConn_projIE_gaba[1218] = new NetCon(&v(0.5), syn_projIE_gaba[1218], 20.0, 1.5, -0.0016545403)")  

        # Connection 1219: cell 15, seg 0 (0.5) [0.5 on Ipop[15]] -> cell 19, seg 0 (0.5) [0.5 on Epop[19]], weight: -0.0016545403, delay 1.5
        h("Epop[19] syn_projIE_gaba[1219] = new gaba(0.5)")
        h("Ipop[15] netConn_projIE_gaba[1219] = new NetCon(&v(0.5), syn_projIE_gaba[1219], 20.0, 1.5, -0.0016545403)")  

        # Connection 1220: cell 15, seg 0 (0.5) [0.5 on Ipop[15]] -> cell 20, seg 0 (0.5) [0.5 on Epop[20]], weight: -0.0016545403, delay 1.5
        h("Epop[20] syn_projIE_gaba[1220] = new gaba(0.5)")
        h("Ipop[15] netConn_projIE_gaba[1220] = new NetCon(&v(0.5), syn_projIE_gaba[1220], 20.0, 1.5, -0.0016545403)")  

        # Connection 1221: cell 15, seg 0 (0.5) [0.5 on Ipop[15]] -> cell 21, seg 0 (0.5) [0.5 on Epop[21]], weight: -0.0016545403, delay 1.5
        h("Epop[21] syn_projIE_gaba[1221] = new gaba(0.5)")
        h("Ipop[15] netConn_projIE_gaba[1221] = new NetCon(&v(0.5), syn_projIE_gaba[1221], 20.0, 1.5, -0.0016545403)")  

        # Connection 1222: cell 15, seg 0 (0.5) [0.5 on Ipop[15]] -> cell 22, seg 0 (0.5) [0.5 on Epop[22]], weight: -0.0016545403, delay 1.5
        h("Epop[22] syn_projIE_gaba[1222] = new gaba(0.5)")
        h("Ipop[15] netConn_projIE_gaba[1222] = new NetCon(&v(0.5), syn_projIE_gaba[1222], 20.0, 1.5, -0.0016545403)")  

        # Connection 1223: cell 15, seg 0 (0.5) [0.5 on Ipop[15]] -> cell 23, seg 0 (0.5) [0.5 on Epop[23]], weight: -0.0016545403, delay 1.5
        h("Epop[23] syn_projIE_gaba[1223] = new gaba(0.5)")
        h("Ipop[15] netConn_projIE_gaba[1223] = new NetCon(&v(0.5), syn_projIE_gaba[1223], 20.0, 1.5, -0.0016545403)")  

        # Connection 1224: cell 15, seg 0 (0.5) [0.5 on Ipop[15]] -> cell 24, seg 0 (0.5) [0.5 on Epop[24]], weight: -0.0016545403, delay 1.5
        h("Epop[24] syn_projIE_gaba[1224] = new gaba(0.5)")
        h("Ipop[15] netConn_projIE_gaba[1224] = new NetCon(&v(0.5), syn_projIE_gaba[1224], 20.0, 1.5, -0.0016545403)")  

        # Connection 1225: cell 15, seg 0 (0.5) [0.5 on Ipop[15]] -> cell 25, seg 0 (0.5) [0.5 on Epop[25]], weight: -0.0016545403, delay 1.5
        h("Epop[25] syn_projIE_gaba[1225] = new gaba(0.5)")
        h("Ipop[15] netConn_projIE_gaba[1225] = new NetCon(&v(0.5), syn_projIE_gaba[1225], 20.0, 1.5, -0.0016545403)")  

        # Connection 1226: cell 15, seg 0 (0.5) [0.5 on Ipop[15]] -> cell 26, seg 0 (0.5) [0.5 on Epop[26]], weight: -0.0016545403, delay 1.5
        h("Epop[26] syn_projIE_gaba[1226] = new gaba(0.5)")
        h("Ipop[15] netConn_projIE_gaba[1226] = new NetCon(&v(0.5), syn_projIE_gaba[1226], 20.0, 1.5, -0.0016545403)")  

        # Connection 1227: cell 15, seg 0 (0.5) [0.5 on Ipop[15]] -> cell 27, seg 0 (0.5) [0.5 on Epop[27]], weight: -0.0016545403, delay 1.5
        h("Epop[27] syn_projIE_gaba[1227] = new gaba(0.5)")
        h("Ipop[15] netConn_projIE_gaba[1227] = new NetCon(&v(0.5), syn_projIE_gaba[1227], 20.0, 1.5, -0.0016545403)")  

        # Connection 1228: cell 15, seg 0 (0.5) [0.5 on Ipop[15]] -> cell 28, seg 0 (0.5) [0.5 on Epop[28]], weight: -0.0016545403, delay 1.5
        h("Epop[28] syn_projIE_gaba[1228] = new gaba(0.5)")
        h("Ipop[15] netConn_projIE_gaba[1228] = new NetCon(&v(0.5), syn_projIE_gaba[1228], 20.0, 1.5, -0.0016545403)")  

        # Connection 1229: cell 15, seg 0 (0.5) [0.5 on Ipop[15]] -> cell 29, seg 0 (0.5) [0.5 on Epop[29]], weight: -0.0016545403, delay 1.5
        h("Epop[29] syn_projIE_gaba[1229] = new gaba(0.5)")
        h("Ipop[15] netConn_projIE_gaba[1229] = new NetCon(&v(0.5), syn_projIE_gaba[1229], 20.0, 1.5, -0.0016545403)")  

        # Connection 1230: cell 15, seg 0 (0.5) [0.5 on Ipop[15]] -> cell 30, seg 0 (0.5) [0.5 on Epop[30]], weight: -0.0016545403, delay 1.5
        h("Epop[30] syn_projIE_gaba[1230] = new gaba(0.5)")
        h("Ipop[15] netConn_projIE_gaba[1230] = new NetCon(&v(0.5), syn_projIE_gaba[1230], 20.0, 1.5, -0.0016545403)")  

        # Connection 1231: cell 15, seg 0 (0.5) [0.5 on Ipop[15]] -> cell 31, seg 0 (0.5) [0.5 on Epop[31]], weight: -0.0016545403, delay 1.5
        h("Epop[31] syn_projIE_gaba[1231] = new gaba(0.5)")
        h("Ipop[15] netConn_projIE_gaba[1231] = new NetCon(&v(0.5), syn_projIE_gaba[1231], 20.0, 1.5, -0.0016545403)")  

        # Connection 1232: cell 15, seg 0 (0.5) [0.5 on Ipop[15]] -> cell 32, seg 0 (0.5) [0.5 on Epop[32]], weight: -0.0016545403, delay 1.5
        h("Epop[32] syn_projIE_gaba[1232] = new gaba(0.5)")
        h("Ipop[15] netConn_projIE_gaba[1232] = new NetCon(&v(0.5), syn_projIE_gaba[1232], 20.0, 1.5, -0.0016545403)")  

        # Connection 1233: cell 15, seg 0 (0.5) [0.5 on Ipop[15]] -> cell 33, seg 0 (0.5) [0.5 on Epop[33]], weight: -0.0016545403, delay 1.5
        h("Epop[33] syn_projIE_gaba[1233] = new gaba(0.5)")
        h("Ipop[15] netConn_projIE_gaba[1233] = new NetCon(&v(0.5), syn_projIE_gaba[1233], 20.0, 1.5, -0.0016545403)")  

        # Connection 1234: cell 15, seg 0 (0.5) [0.5 on Ipop[15]] -> cell 34, seg 0 (0.5) [0.5 on Epop[34]], weight: -0.0016545403, delay 1.5
        h("Epop[34] syn_projIE_gaba[1234] = new gaba(0.5)")
        h("Ipop[15] netConn_projIE_gaba[1234] = new NetCon(&v(0.5), syn_projIE_gaba[1234], 20.0, 1.5, -0.0016545403)")  

        # Connection 1235: cell 15, seg 0 (0.5) [0.5 on Ipop[15]] -> cell 35, seg 0 (0.5) [0.5 on Epop[35]], weight: -0.0016545403, delay 1.5
        h("Epop[35] syn_projIE_gaba[1235] = new gaba(0.5)")
        h("Ipop[15] netConn_projIE_gaba[1235] = new NetCon(&v(0.5), syn_projIE_gaba[1235], 20.0, 1.5, -0.0016545403)")  

        # Connection 1236: cell 15, seg 0 (0.5) [0.5 on Ipop[15]] -> cell 36, seg 0 (0.5) [0.5 on Epop[36]], weight: -0.0016545403, delay 1.5
        h("Epop[36] syn_projIE_gaba[1236] = new gaba(0.5)")
        h("Ipop[15] netConn_projIE_gaba[1236] = new NetCon(&v(0.5), syn_projIE_gaba[1236], 20.0, 1.5, -0.0016545403)")  

        # Connection 1237: cell 15, seg 0 (0.5) [0.5 on Ipop[15]] -> cell 37, seg 0 (0.5) [0.5 on Epop[37]], weight: -0.0016545403, delay 1.5
        h("Epop[37] syn_projIE_gaba[1237] = new gaba(0.5)")
        h("Ipop[15] netConn_projIE_gaba[1237] = new NetCon(&v(0.5), syn_projIE_gaba[1237], 20.0, 1.5, -0.0016545403)")  

        # Connection 1238: cell 15, seg 0 (0.5) [0.5 on Ipop[15]] -> cell 38, seg 0 (0.5) [0.5 on Epop[38]], weight: -0.0016545403, delay 1.5
        h("Epop[38] syn_projIE_gaba[1238] = new gaba(0.5)")
        h("Ipop[15] netConn_projIE_gaba[1238] = new NetCon(&v(0.5), syn_projIE_gaba[1238], 20.0, 1.5, -0.0016545403)")  

        # Connection 1239: cell 15, seg 0 (0.5) [0.5 on Ipop[15]] -> cell 39, seg 0 (0.5) [0.5 on Epop[39]], weight: -0.0016545403, delay 1.5
        h("Epop[39] syn_projIE_gaba[1239] = new gaba(0.5)")
        h("Ipop[15] netConn_projIE_gaba[1239] = new NetCon(&v(0.5), syn_projIE_gaba[1239], 20.0, 1.5, -0.0016545403)")  

        # Connection 1240: cell 15, seg 0 (0.5) [0.5 on Ipop[15]] -> cell 40, seg 0 (0.5) [0.5 on Epop[40]], weight: -0.0016545403, delay 1.5
        h("Epop[40] syn_projIE_gaba[1240] = new gaba(0.5)")
        h("Ipop[15] netConn_projIE_gaba[1240] = new NetCon(&v(0.5), syn_projIE_gaba[1240], 20.0, 1.5, -0.0016545403)")  

        # Connection 1241: cell 15, seg 0 (0.5) [0.5 on Ipop[15]] -> cell 41, seg 0 (0.5) [0.5 on Epop[41]], weight: -0.0016545403, delay 1.5
        h("Epop[41] syn_projIE_gaba[1241] = new gaba(0.5)")
        h("Ipop[15] netConn_projIE_gaba[1241] = new NetCon(&v(0.5), syn_projIE_gaba[1241], 20.0, 1.5, -0.0016545403)")  

        # Connection 1242: cell 15, seg 0 (0.5) [0.5 on Ipop[15]] -> cell 42, seg 0 (0.5) [0.5 on Epop[42]], weight: -0.0016545403, delay 1.5
        h("Epop[42] syn_projIE_gaba[1242] = new gaba(0.5)")
        h("Ipop[15] netConn_projIE_gaba[1242] = new NetCon(&v(0.5), syn_projIE_gaba[1242], 20.0, 1.5, -0.0016545403)")  

        # Connection 1243: cell 15, seg 0 (0.5) [0.5 on Ipop[15]] -> cell 43, seg 0 (0.5) [0.5 on Epop[43]], weight: -0.0016545403, delay 1.5
        h("Epop[43] syn_projIE_gaba[1243] = new gaba(0.5)")
        h("Ipop[15] netConn_projIE_gaba[1243] = new NetCon(&v(0.5), syn_projIE_gaba[1243], 20.0, 1.5, -0.0016545403)")  

        # Connection 1244: cell 15, seg 0 (0.5) [0.5 on Ipop[15]] -> cell 44, seg 0 (0.5) [0.5 on Epop[44]], weight: -0.0016545403, delay 1.5
        h("Epop[44] syn_projIE_gaba[1244] = new gaba(0.5)")
        h("Ipop[15] netConn_projIE_gaba[1244] = new NetCon(&v(0.5), syn_projIE_gaba[1244], 20.0, 1.5, -0.0016545403)")  

        # Connection 1245: cell 15, seg 0 (0.5) [0.5 on Ipop[15]] -> cell 45, seg 0 (0.5) [0.5 on Epop[45]], weight: -0.0016545403, delay 1.5
        h("Epop[45] syn_projIE_gaba[1245] = new gaba(0.5)")
        h("Ipop[15] netConn_projIE_gaba[1245] = new NetCon(&v(0.5), syn_projIE_gaba[1245], 20.0, 1.5, -0.0016545403)")  

        # Connection 1246: cell 15, seg 0 (0.5) [0.5 on Ipop[15]] -> cell 46, seg 0 (0.5) [0.5 on Epop[46]], weight: -0.0016545403, delay 1.5
        h("Epop[46] syn_projIE_gaba[1246] = new gaba(0.5)")
        h("Ipop[15] netConn_projIE_gaba[1246] = new NetCon(&v(0.5), syn_projIE_gaba[1246], 20.0, 1.5, -0.0016545403)")  

        # Connection 1247: cell 15, seg 0 (0.5) [0.5 on Ipop[15]] -> cell 47, seg 0 (0.5) [0.5 on Epop[47]], weight: -0.0016545403, delay 1.5
        h("Epop[47] syn_projIE_gaba[1247] = new gaba(0.5)")
        h("Ipop[15] netConn_projIE_gaba[1247] = new NetCon(&v(0.5), syn_projIE_gaba[1247], 20.0, 1.5, -0.0016545403)")  

        # Connection 1248: cell 15, seg 0 (0.5) [0.5 on Ipop[15]] -> cell 48, seg 0 (0.5) [0.5 on Epop[48]], weight: -0.0016545403, delay 1.5
        h("Epop[48] syn_projIE_gaba[1248] = new gaba(0.5)")
        h("Ipop[15] netConn_projIE_gaba[1248] = new NetCon(&v(0.5), syn_projIE_gaba[1248], 20.0, 1.5, -0.0016545403)")  

        # Connection 1249: cell 15, seg 0 (0.5) [0.5 on Ipop[15]] -> cell 49, seg 0 (0.5) [0.5 on Epop[49]], weight: -0.0016545403, delay 1.5
        h("Epop[49] syn_projIE_gaba[1249] = new gaba(0.5)")
        h("Ipop[15] netConn_projIE_gaba[1249] = new NetCon(&v(0.5), syn_projIE_gaba[1249], 20.0, 1.5, -0.0016545403)")  

        # Connection 1250: cell 15, seg 0 (0.5) [0.5 on Ipop[15]] -> cell 50, seg 0 (0.5) [0.5 on Epop[50]], weight: -0.0016545403, delay 1.5
        h("Epop[50] syn_projIE_gaba[1250] = new gaba(0.5)")
        h("Ipop[15] netConn_projIE_gaba[1250] = new NetCon(&v(0.5), syn_projIE_gaba[1250], 20.0, 1.5, -0.0016545403)")  

        # Connection 1251: cell 15, seg 0 (0.5) [0.5 on Ipop[15]] -> cell 51, seg 0 (0.5) [0.5 on Epop[51]], weight: -0.0016545403, delay 1.5
        h("Epop[51] syn_projIE_gaba[1251] = new gaba(0.5)")
        h("Ipop[15] netConn_projIE_gaba[1251] = new NetCon(&v(0.5), syn_projIE_gaba[1251], 20.0, 1.5, -0.0016545403)")  

        # Connection 1252: cell 15, seg 0 (0.5) [0.5 on Ipop[15]] -> cell 52, seg 0 (0.5) [0.5 on Epop[52]], weight: -0.0016545403, delay 1.5
        h("Epop[52] syn_projIE_gaba[1252] = new gaba(0.5)")
        h("Ipop[15] netConn_projIE_gaba[1252] = new NetCon(&v(0.5), syn_projIE_gaba[1252], 20.0, 1.5, -0.0016545403)")  

        # Connection 1253: cell 15, seg 0 (0.5) [0.5 on Ipop[15]] -> cell 53, seg 0 (0.5) [0.5 on Epop[53]], weight: -0.0016545403, delay 1.5
        h("Epop[53] syn_projIE_gaba[1253] = new gaba(0.5)")
        h("Ipop[15] netConn_projIE_gaba[1253] = new NetCon(&v(0.5), syn_projIE_gaba[1253], 20.0, 1.5, -0.0016545403)")  

        # Connection 1254: cell 15, seg 0 (0.5) [0.5 on Ipop[15]] -> cell 54, seg 0 (0.5) [0.5 on Epop[54]], weight: -0.0016545403, delay 1.5
        h("Epop[54] syn_projIE_gaba[1254] = new gaba(0.5)")
        h("Ipop[15] netConn_projIE_gaba[1254] = new NetCon(&v(0.5), syn_projIE_gaba[1254], 20.0, 1.5, -0.0016545403)")  

        # Connection 1255: cell 15, seg 0 (0.5) [0.5 on Ipop[15]] -> cell 55, seg 0 (0.5) [0.5 on Epop[55]], weight: -0.0016545403, delay 1.5
        h("Epop[55] syn_projIE_gaba[1255] = new gaba(0.5)")
        h("Ipop[15] netConn_projIE_gaba[1255] = new NetCon(&v(0.5), syn_projIE_gaba[1255], 20.0, 1.5, -0.0016545403)")  

        # Connection 1256: cell 15, seg 0 (0.5) [0.5 on Ipop[15]] -> cell 56, seg 0 (0.5) [0.5 on Epop[56]], weight: -0.0016545403, delay 1.5
        h("Epop[56] syn_projIE_gaba[1256] = new gaba(0.5)")
        h("Ipop[15] netConn_projIE_gaba[1256] = new NetCon(&v(0.5), syn_projIE_gaba[1256], 20.0, 1.5, -0.0016545403)")  

        # Connection 1257: cell 15, seg 0 (0.5) [0.5 on Ipop[15]] -> cell 57, seg 0 (0.5) [0.5 on Epop[57]], weight: -0.0016545403, delay 1.5
        h("Epop[57] syn_projIE_gaba[1257] = new gaba(0.5)")
        h("Ipop[15] netConn_projIE_gaba[1257] = new NetCon(&v(0.5), syn_projIE_gaba[1257], 20.0, 1.5, -0.0016545403)")  

        # Connection 1258: cell 15, seg 0 (0.5) [0.5 on Ipop[15]] -> cell 58, seg 0 (0.5) [0.5 on Epop[58]], weight: -0.0016545403, delay 1.5
        h("Epop[58] syn_projIE_gaba[1258] = new gaba(0.5)")
        h("Ipop[15] netConn_projIE_gaba[1258] = new NetCon(&v(0.5), syn_projIE_gaba[1258], 20.0, 1.5, -0.0016545403)")  

        # Connection 1259: cell 15, seg 0 (0.5) [0.5 on Ipop[15]] -> cell 59, seg 0 (0.5) [0.5 on Epop[59]], weight: -0.0016545403, delay 1.5
        h("Epop[59] syn_projIE_gaba[1259] = new gaba(0.5)")
        h("Ipop[15] netConn_projIE_gaba[1259] = new NetCon(&v(0.5), syn_projIE_gaba[1259], 20.0, 1.5, -0.0016545403)")  

        # Connection 1260: cell 15, seg 0 (0.5) [0.5 on Ipop[15]] -> cell 60, seg 0 (0.5) [0.5 on Epop[60]], weight: -0.0016545403, delay 1.5
        h("Epop[60] syn_projIE_gaba[1260] = new gaba(0.5)")
        h("Ipop[15] netConn_projIE_gaba[1260] = new NetCon(&v(0.5), syn_projIE_gaba[1260], 20.0, 1.5, -0.0016545403)")  

        # Connection 1261: cell 15, seg 0 (0.5) [0.5 on Ipop[15]] -> cell 61, seg 0 (0.5) [0.5 on Epop[61]], weight: -0.0016545403, delay 1.5
        h("Epop[61] syn_projIE_gaba[1261] = new gaba(0.5)")
        h("Ipop[15] netConn_projIE_gaba[1261] = new NetCon(&v(0.5), syn_projIE_gaba[1261], 20.0, 1.5, -0.0016545403)")  

        # Connection 1262: cell 15, seg 0 (0.5) [0.5 on Ipop[15]] -> cell 62, seg 0 (0.5) [0.5 on Epop[62]], weight: -0.0016545403, delay 1.5
        h("Epop[62] syn_projIE_gaba[1262] = new gaba(0.5)")
        h("Ipop[15] netConn_projIE_gaba[1262] = new NetCon(&v(0.5), syn_projIE_gaba[1262], 20.0, 1.5, -0.0016545403)")  

        # Connection 1263: cell 15, seg 0 (0.5) [0.5 on Ipop[15]] -> cell 63, seg 0 (0.5) [0.5 on Epop[63]], weight: -0.0016545403, delay 1.5
        h("Epop[63] syn_projIE_gaba[1263] = new gaba(0.5)")
        h("Ipop[15] netConn_projIE_gaba[1263] = new NetCon(&v(0.5), syn_projIE_gaba[1263], 20.0, 1.5, -0.0016545403)")  

        # Connection 1264: cell 15, seg 0 (0.5) [0.5 on Ipop[15]] -> cell 64, seg 0 (0.5) [0.5 on Epop[64]], weight: -0.0016545403, delay 1.5
        h("Epop[64] syn_projIE_gaba[1264] = new gaba(0.5)")
        h("Ipop[15] netConn_projIE_gaba[1264] = new NetCon(&v(0.5), syn_projIE_gaba[1264], 20.0, 1.5, -0.0016545403)")  

        # Connection 1265: cell 15, seg 0 (0.5) [0.5 on Ipop[15]] -> cell 65, seg 0 (0.5) [0.5 on Epop[65]], weight: -0.0016545403, delay 1.5
        h("Epop[65] syn_projIE_gaba[1265] = new gaba(0.5)")
        h("Ipop[15] netConn_projIE_gaba[1265] = new NetCon(&v(0.5), syn_projIE_gaba[1265], 20.0, 1.5, -0.0016545403)")  

        # Connection 1266: cell 15, seg 0 (0.5) [0.5 on Ipop[15]] -> cell 66, seg 0 (0.5) [0.5 on Epop[66]], weight: -0.0016545403, delay 1.5
        h("Epop[66] syn_projIE_gaba[1266] = new gaba(0.5)")
        h("Ipop[15] netConn_projIE_gaba[1266] = new NetCon(&v(0.5), syn_projIE_gaba[1266], 20.0, 1.5, -0.0016545403)")  

        # Connection 1267: cell 15, seg 0 (0.5) [0.5 on Ipop[15]] -> cell 67, seg 0 (0.5) [0.5 on Epop[67]], weight: -0.0016545403, delay 1.5
        h("Epop[67] syn_projIE_gaba[1267] = new gaba(0.5)")
        h("Ipop[15] netConn_projIE_gaba[1267] = new NetCon(&v(0.5), syn_projIE_gaba[1267], 20.0, 1.5, -0.0016545403)")  

        # Connection 1268: cell 15, seg 0 (0.5) [0.5 on Ipop[15]] -> cell 68, seg 0 (0.5) [0.5 on Epop[68]], weight: -0.0016545403, delay 1.5
        h("Epop[68] syn_projIE_gaba[1268] = new gaba(0.5)")
        h("Ipop[15] netConn_projIE_gaba[1268] = new NetCon(&v(0.5), syn_projIE_gaba[1268], 20.0, 1.5, -0.0016545403)")  

        # Connection 1269: cell 15, seg 0 (0.5) [0.5 on Ipop[15]] -> cell 69, seg 0 (0.5) [0.5 on Epop[69]], weight: -0.0016545403, delay 1.5
        h("Epop[69] syn_projIE_gaba[1269] = new gaba(0.5)")
        h("Ipop[15] netConn_projIE_gaba[1269] = new NetCon(&v(0.5), syn_projIE_gaba[1269], 20.0, 1.5, -0.0016545403)")  

        # Connection 1270: cell 15, seg 0 (0.5) [0.5 on Ipop[15]] -> cell 70, seg 0 (0.5) [0.5 on Epop[70]], weight: -0.0016545403, delay 1.5
        h("Epop[70] syn_projIE_gaba[1270] = new gaba(0.5)")
        h("Ipop[15] netConn_projIE_gaba[1270] = new NetCon(&v(0.5), syn_projIE_gaba[1270], 20.0, 1.5, -0.0016545403)")  

        # Connection 1271: cell 15, seg 0 (0.5) [0.5 on Ipop[15]] -> cell 71, seg 0 (0.5) [0.5 on Epop[71]], weight: -0.0016545403, delay 1.5
        h("Epop[71] syn_projIE_gaba[1271] = new gaba(0.5)")
        h("Ipop[15] netConn_projIE_gaba[1271] = new NetCon(&v(0.5), syn_projIE_gaba[1271], 20.0, 1.5, -0.0016545403)")  

        # Connection 1272: cell 15, seg 0 (0.5) [0.5 on Ipop[15]] -> cell 72, seg 0 (0.5) [0.5 on Epop[72]], weight: -0.0016545403, delay 1.5
        h("Epop[72] syn_projIE_gaba[1272] = new gaba(0.5)")
        h("Ipop[15] netConn_projIE_gaba[1272] = new NetCon(&v(0.5), syn_projIE_gaba[1272], 20.0, 1.5, -0.0016545403)")  

        # Connection 1273: cell 15, seg 0 (0.5) [0.5 on Ipop[15]] -> cell 73, seg 0 (0.5) [0.5 on Epop[73]], weight: -0.0016545403, delay 1.5
        h("Epop[73] syn_projIE_gaba[1273] = new gaba(0.5)")
        h("Ipop[15] netConn_projIE_gaba[1273] = new NetCon(&v(0.5), syn_projIE_gaba[1273], 20.0, 1.5, -0.0016545403)")  

        # Connection 1274: cell 15, seg 0 (0.5) [0.5 on Ipop[15]] -> cell 74, seg 0 (0.5) [0.5 on Epop[74]], weight: -0.0016545403, delay 1.5
        h("Epop[74] syn_projIE_gaba[1274] = new gaba(0.5)")
        h("Ipop[15] netConn_projIE_gaba[1274] = new NetCon(&v(0.5), syn_projIE_gaba[1274], 20.0, 1.5, -0.0016545403)")  

        # Connection 1275: cell 15, seg 0 (0.5) [0.5 on Ipop[15]] -> cell 75, seg 0 (0.5) [0.5 on Epop[75]], weight: -0.0016545403, delay 1.5
        h("Epop[75] syn_projIE_gaba[1275] = new gaba(0.5)")
        h("Ipop[15] netConn_projIE_gaba[1275] = new NetCon(&v(0.5), syn_projIE_gaba[1275], 20.0, 1.5, -0.0016545403)")  

        # Connection 1276: cell 15, seg 0 (0.5) [0.5 on Ipop[15]] -> cell 76, seg 0 (0.5) [0.5 on Epop[76]], weight: -0.0016545403, delay 1.5
        h("Epop[76] syn_projIE_gaba[1276] = new gaba(0.5)")
        h("Ipop[15] netConn_projIE_gaba[1276] = new NetCon(&v(0.5), syn_projIE_gaba[1276], 20.0, 1.5, -0.0016545403)")  

        # Connection 1277: cell 15, seg 0 (0.5) [0.5 on Ipop[15]] -> cell 77, seg 0 (0.5) [0.5 on Epop[77]], weight: -0.0016545403, delay 1.5
        h("Epop[77] syn_projIE_gaba[1277] = new gaba(0.5)")
        h("Ipop[15] netConn_projIE_gaba[1277] = new NetCon(&v(0.5), syn_projIE_gaba[1277], 20.0, 1.5, -0.0016545403)")  

        # Connection 1278: cell 15, seg 0 (0.5) [0.5 on Ipop[15]] -> cell 78, seg 0 (0.5) [0.5 on Epop[78]], weight: -0.0016545403, delay 1.5
        h("Epop[78] syn_projIE_gaba[1278] = new gaba(0.5)")
        h("Ipop[15] netConn_projIE_gaba[1278] = new NetCon(&v(0.5), syn_projIE_gaba[1278], 20.0, 1.5, -0.0016545403)")  

        # Connection 1279: cell 15, seg 0 (0.5) [0.5 on Ipop[15]] -> cell 79, seg 0 (0.5) [0.5 on Epop[79]], weight: -0.0016545403, delay 1.5
        h("Epop[79] syn_projIE_gaba[1279] = new gaba(0.5)")
        h("Ipop[15] netConn_projIE_gaba[1279] = new NetCon(&v(0.5), syn_projIE_gaba[1279], 20.0, 1.5, -0.0016545403)")  

        # Connection 1280: cell 16, seg 0 (0.5) [0.5 on Ipop[16]] -> cell 0, seg 0 (0.5) [0.5 on Epop[0]], weight: -0.0016545403, delay 1.5
        h("Epop[0] syn_projIE_gaba[1280] = new gaba(0.5)")
        h("Ipop[16] netConn_projIE_gaba[1280] = new NetCon(&v(0.5), syn_projIE_gaba[1280], 20.0, 1.5, -0.0016545403)")  

        # Connection 1281: cell 16, seg 0 (0.5) [0.5 on Ipop[16]] -> cell 1, seg 0 (0.5) [0.5 on Epop[1]], weight: -0.0016545403, delay 1.5
        h("Epop[1] syn_projIE_gaba[1281] = new gaba(0.5)")
        h("Ipop[16] netConn_projIE_gaba[1281] = new NetCon(&v(0.5), syn_projIE_gaba[1281], 20.0, 1.5, -0.0016545403)")  

        # Connection 1282: cell 16, seg 0 (0.5) [0.5 on Ipop[16]] -> cell 2, seg 0 (0.5) [0.5 on Epop[2]], weight: -0.0016545403, delay 1.5
        h("Epop[2] syn_projIE_gaba[1282] = new gaba(0.5)")
        h("Ipop[16] netConn_projIE_gaba[1282] = new NetCon(&v(0.5), syn_projIE_gaba[1282], 20.0, 1.5, -0.0016545403)")  

        # Connection 1283: cell 16, seg 0 (0.5) [0.5 on Ipop[16]] -> cell 3, seg 0 (0.5) [0.5 on Epop[3]], weight: -0.0016545403, delay 1.5
        h("Epop[3] syn_projIE_gaba[1283] = new gaba(0.5)")
        h("Ipop[16] netConn_projIE_gaba[1283] = new NetCon(&v(0.5), syn_projIE_gaba[1283], 20.0, 1.5, -0.0016545403)")  

        # Connection 1284: cell 16, seg 0 (0.5) [0.5 on Ipop[16]] -> cell 4, seg 0 (0.5) [0.5 on Epop[4]], weight: -0.0016545403, delay 1.5
        h("Epop[4] syn_projIE_gaba[1284] = new gaba(0.5)")
        h("Ipop[16] netConn_projIE_gaba[1284] = new NetCon(&v(0.5), syn_projIE_gaba[1284], 20.0, 1.5, -0.0016545403)")  

        # Connection 1285: cell 16, seg 0 (0.5) [0.5 on Ipop[16]] -> cell 5, seg 0 (0.5) [0.5 on Epop[5]], weight: -0.0016545403, delay 1.5
        h("Epop[5] syn_projIE_gaba[1285] = new gaba(0.5)")
        h("Ipop[16] netConn_projIE_gaba[1285] = new NetCon(&v(0.5), syn_projIE_gaba[1285], 20.0, 1.5, -0.0016545403)")  

        # Connection 1286: cell 16, seg 0 (0.5) [0.5 on Ipop[16]] -> cell 6, seg 0 (0.5) [0.5 on Epop[6]], weight: -0.0016545403, delay 1.5
        h("Epop[6] syn_projIE_gaba[1286] = new gaba(0.5)")
        h("Ipop[16] netConn_projIE_gaba[1286] = new NetCon(&v(0.5), syn_projIE_gaba[1286], 20.0, 1.5, -0.0016545403)")  

        # Connection 1287: cell 16, seg 0 (0.5) [0.5 on Ipop[16]] -> cell 7, seg 0 (0.5) [0.5 on Epop[7]], weight: -0.0016545403, delay 1.5
        h("Epop[7] syn_projIE_gaba[1287] = new gaba(0.5)")
        h("Ipop[16] netConn_projIE_gaba[1287] = new NetCon(&v(0.5), syn_projIE_gaba[1287], 20.0, 1.5, -0.0016545403)")  

        # Connection 1288: cell 16, seg 0 (0.5) [0.5 on Ipop[16]] -> cell 8, seg 0 (0.5) [0.5 on Epop[8]], weight: -0.0016545403, delay 1.5
        h("Epop[8] syn_projIE_gaba[1288] = new gaba(0.5)")
        h("Ipop[16] netConn_projIE_gaba[1288] = new NetCon(&v(0.5), syn_projIE_gaba[1288], 20.0, 1.5, -0.0016545403)")  

        # Connection 1289: cell 16, seg 0 (0.5) [0.5 on Ipop[16]] -> cell 9, seg 0 (0.5) [0.5 on Epop[9]], weight: -0.0016545403, delay 1.5
        h("Epop[9] syn_projIE_gaba[1289] = new gaba(0.5)")
        h("Ipop[16] netConn_projIE_gaba[1289] = new NetCon(&v(0.5), syn_projIE_gaba[1289], 20.0, 1.5, -0.0016545403)")  

        # Connection 1290: cell 16, seg 0 (0.5) [0.5 on Ipop[16]] -> cell 10, seg 0 (0.5) [0.5 on Epop[10]], weight: -0.0016545403, delay 1.5
        h("Epop[10] syn_projIE_gaba[1290] = new gaba(0.5)")
        h("Ipop[16] netConn_projIE_gaba[1290] = new NetCon(&v(0.5), syn_projIE_gaba[1290], 20.0, 1.5, -0.0016545403)")  

        # Connection 1291: cell 16, seg 0 (0.5) [0.5 on Ipop[16]] -> cell 11, seg 0 (0.5) [0.5 on Epop[11]], weight: -0.0016545403, delay 1.5
        h("Epop[11] syn_projIE_gaba[1291] = new gaba(0.5)")
        h("Ipop[16] netConn_projIE_gaba[1291] = new NetCon(&v(0.5), syn_projIE_gaba[1291], 20.0, 1.5, -0.0016545403)")  

        # Connection 1292: cell 16, seg 0 (0.5) [0.5 on Ipop[16]] -> cell 12, seg 0 (0.5) [0.5 on Epop[12]], weight: -0.0016545403, delay 1.5
        h("Epop[12] syn_projIE_gaba[1292] = new gaba(0.5)")
        h("Ipop[16] netConn_projIE_gaba[1292] = new NetCon(&v(0.5), syn_projIE_gaba[1292], 20.0, 1.5, -0.0016545403)")  

        # Connection 1293: cell 16, seg 0 (0.5) [0.5 on Ipop[16]] -> cell 13, seg 0 (0.5) [0.5 on Epop[13]], weight: -0.0016545403, delay 1.5
        h("Epop[13] syn_projIE_gaba[1293] = new gaba(0.5)")
        h("Ipop[16] netConn_projIE_gaba[1293] = new NetCon(&v(0.5), syn_projIE_gaba[1293], 20.0, 1.5, -0.0016545403)")  

        # Connection 1294: cell 16, seg 0 (0.5) [0.5 on Ipop[16]] -> cell 14, seg 0 (0.5) [0.5 on Epop[14]], weight: -0.0016545403, delay 1.5
        h("Epop[14] syn_projIE_gaba[1294] = new gaba(0.5)")
        h("Ipop[16] netConn_projIE_gaba[1294] = new NetCon(&v(0.5), syn_projIE_gaba[1294], 20.0, 1.5, -0.0016545403)")  

        # Connection 1295: cell 16, seg 0 (0.5) [0.5 on Ipop[16]] -> cell 15, seg 0 (0.5) [0.5 on Epop[15]], weight: -0.0016545403, delay 1.5
        h("Epop[15] syn_projIE_gaba[1295] = new gaba(0.5)")
        h("Ipop[16] netConn_projIE_gaba[1295] = new NetCon(&v(0.5), syn_projIE_gaba[1295], 20.0, 1.5, -0.0016545403)")  

        # Connection 1296: cell 16, seg 0 (0.5) [0.5 on Ipop[16]] -> cell 16, seg 0 (0.5) [0.5 on Epop[16]], weight: -0.0016545403, delay 1.5
        h("Epop[16] syn_projIE_gaba[1296] = new gaba(0.5)")
        h("Ipop[16] netConn_projIE_gaba[1296] = new NetCon(&v(0.5), syn_projIE_gaba[1296], 20.0, 1.5, -0.0016545403)")  

        # Connection 1297: cell 16, seg 0 (0.5) [0.5 on Ipop[16]] -> cell 17, seg 0 (0.5) [0.5 on Epop[17]], weight: -0.0016545403, delay 1.5
        h("Epop[17] syn_projIE_gaba[1297] = new gaba(0.5)")
        h("Ipop[16] netConn_projIE_gaba[1297] = new NetCon(&v(0.5), syn_projIE_gaba[1297], 20.0, 1.5, -0.0016545403)")  

        # Connection 1298: cell 16, seg 0 (0.5) [0.5 on Ipop[16]] -> cell 18, seg 0 (0.5) [0.5 on Epop[18]], weight: -0.0016545403, delay 1.5
        h("Epop[18] syn_projIE_gaba[1298] = new gaba(0.5)")
        h("Ipop[16] netConn_projIE_gaba[1298] = new NetCon(&v(0.5), syn_projIE_gaba[1298], 20.0, 1.5, -0.0016545403)")  

        # Connection 1299: cell 16, seg 0 (0.5) [0.5 on Ipop[16]] -> cell 19, seg 0 (0.5) [0.5 on Epop[19]], weight: -0.0016545403, delay 1.5
        h("Epop[19] syn_projIE_gaba[1299] = new gaba(0.5)")
        h("Ipop[16] netConn_projIE_gaba[1299] = new NetCon(&v(0.5), syn_projIE_gaba[1299], 20.0, 1.5, -0.0016545403)")  

        # Connection 1300: cell 16, seg 0 (0.5) [0.5 on Ipop[16]] -> cell 20, seg 0 (0.5) [0.5 on Epop[20]], weight: -0.0016545403, delay 1.5
        h("Epop[20] syn_projIE_gaba[1300] = new gaba(0.5)")
        h("Ipop[16] netConn_projIE_gaba[1300] = new NetCon(&v(0.5), syn_projIE_gaba[1300], 20.0, 1.5, -0.0016545403)")  

        # Connection 1301: cell 16, seg 0 (0.5) [0.5 on Ipop[16]] -> cell 21, seg 0 (0.5) [0.5 on Epop[21]], weight: -0.0016545403, delay 1.5
        h("Epop[21] syn_projIE_gaba[1301] = new gaba(0.5)")
        h("Ipop[16] netConn_projIE_gaba[1301] = new NetCon(&v(0.5), syn_projIE_gaba[1301], 20.0, 1.5, -0.0016545403)")  

        # Connection 1302: cell 16, seg 0 (0.5) [0.5 on Ipop[16]] -> cell 22, seg 0 (0.5) [0.5 on Epop[22]], weight: -0.0016545403, delay 1.5
        h("Epop[22] syn_projIE_gaba[1302] = new gaba(0.5)")
        h("Ipop[16] netConn_projIE_gaba[1302] = new NetCon(&v(0.5), syn_projIE_gaba[1302], 20.0, 1.5, -0.0016545403)")  

        # Connection 1303: cell 16, seg 0 (0.5) [0.5 on Ipop[16]] -> cell 23, seg 0 (0.5) [0.5 on Epop[23]], weight: -0.0016545403, delay 1.5
        h("Epop[23] syn_projIE_gaba[1303] = new gaba(0.5)")
        h("Ipop[16] netConn_projIE_gaba[1303] = new NetCon(&v(0.5), syn_projIE_gaba[1303], 20.0, 1.5, -0.0016545403)")  

        # Connection 1304: cell 16, seg 0 (0.5) [0.5 on Ipop[16]] -> cell 24, seg 0 (0.5) [0.5 on Epop[24]], weight: -0.0016545403, delay 1.5
        h("Epop[24] syn_projIE_gaba[1304] = new gaba(0.5)")
        h("Ipop[16] netConn_projIE_gaba[1304] = new NetCon(&v(0.5), syn_projIE_gaba[1304], 20.0, 1.5, -0.0016545403)")  

        # Connection 1305: cell 16, seg 0 (0.5) [0.5 on Ipop[16]] -> cell 25, seg 0 (0.5) [0.5 on Epop[25]], weight: -0.0016545403, delay 1.5
        h("Epop[25] syn_projIE_gaba[1305] = new gaba(0.5)")
        h("Ipop[16] netConn_projIE_gaba[1305] = new NetCon(&v(0.5), syn_projIE_gaba[1305], 20.0, 1.5, -0.0016545403)")  

        # Connection 1306: cell 16, seg 0 (0.5) [0.5 on Ipop[16]] -> cell 26, seg 0 (0.5) [0.5 on Epop[26]], weight: -0.0016545403, delay 1.5
        h("Epop[26] syn_projIE_gaba[1306] = new gaba(0.5)")
        h("Ipop[16] netConn_projIE_gaba[1306] = new NetCon(&v(0.5), syn_projIE_gaba[1306], 20.0, 1.5, -0.0016545403)")  

        # Connection 1307: cell 16, seg 0 (0.5) [0.5 on Ipop[16]] -> cell 27, seg 0 (0.5) [0.5 on Epop[27]], weight: -0.0016545403, delay 1.5
        h("Epop[27] syn_projIE_gaba[1307] = new gaba(0.5)")
        h("Ipop[16] netConn_projIE_gaba[1307] = new NetCon(&v(0.5), syn_projIE_gaba[1307], 20.0, 1.5, -0.0016545403)")  

        # Connection 1308: cell 16, seg 0 (0.5) [0.5 on Ipop[16]] -> cell 28, seg 0 (0.5) [0.5 on Epop[28]], weight: -0.0016545403, delay 1.5
        h("Epop[28] syn_projIE_gaba[1308] = new gaba(0.5)")
        h("Ipop[16] netConn_projIE_gaba[1308] = new NetCon(&v(0.5), syn_projIE_gaba[1308], 20.0, 1.5, -0.0016545403)")  

        # Connection 1309: cell 16, seg 0 (0.5) [0.5 on Ipop[16]] -> cell 29, seg 0 (0.5) [0.5 on Epop[29]], weight: -0.0016545403, delay 1.5
        h("Epop[29] syn_projIE_gaba[1309] = new gaba(0.5)")
        h("Ipop[16] netConn_projIE_gaba[1309] = new NetCon(&v(0.5), syn_projIE_gaba[1309], 20.0, 1.5, -0.0016545403)")  

        # Connection 1310: cell 16, seg 0 (0.5) [0.5 on Ipop[16]] -> cell 30, seg 0 (0.5) [0.5 on Epop[30]], weight: -0.0016545403, delay 1.5
        h("Epop[30] syn_projIE_gaba[1310] = new gaba(0.5)")
        h("Ipop[16] netConn_projIE_gaba[1310] = new NetCon(&v(0.5), syn_projIE_gaba[1310], 20.0, 1.5, -0.0016545403)")  

        # Connection 1311: cell 16, seg 0 (0.5) [0.5 on Ipop[16]] -> cell 31, seg 0 (0.5) [0.5 on Epop[31]], weight: -0.0016545403, delay 1.5
        h("Epop[31] syn_projIE_gaba[1311] = new gaba(0.5)")
        h("Ipop[16] netConn_projIE_gaba[1311] = new NetCon(&v(0.5), syn_projIE_gaba[1311], 20.0, 1.5, -0.0016545403)")  

        # Connection 1312: cell 16, seg 0 (0.5) [0.5 on Ipop[16]] -> cell 32, seg 0 (0.5) [0.5 on Epop[32]], weight: -0.0016545403, delay 1.5
        h("Epop[32] syn_projIE_gaba[1312] = new gaba(0.5)")
        h("Ipop[16] netConn_projIE_gaba[1312] = new NetCon(&v(0.5), syn_projIE_gaba[1312], 20.0, 1.5, -0.0016545403)")  

        # Connection 1313: cell 16, seg 0 (0.5) [0.5 on Ipop[16]] -> cell 33, seg 0 (0.5) [0.5 on Epop[33]], weight: -0.0016545403, delay 1.5
        h("Epop[33] syn_projIE_gaba[1313] = new gaba(0.5)")
        h("Ipop[16] netConn_projIE_gaba[1313] = new NetCon(&v(0.5), syn_projIE_gaba[1313], 20.0, 1.5, -0.0016545403)")  

        # Connection 1314: cell 16, seg 0 (0.5) [0.5 on Ipop[16]] -> cell 34, seg 0 (0.5) [0.5 on Epop[34]], weight: -0.0016545403, delay 1.5
        h("Epop[34] syn_projIE_gaba[1314] = new gaba(0.5)")
        h("Ipop[16] netConn_projIE_gaba[1314] = new NetCon(&v(0.5), syn_projIE_gaba[1314], 20.0, 1.5, -0.0016545403)")  

        # Connection 1315: cell 16, seg 0 (0.5) [0.5 on Ipop[16]] -> cell 35, seg 0 (0.5) [0.5 on Epop[35]], weight: -0.0016545403, delay 1.5
        h("Epop[35] syn_projIE_gaba[1315] = new gaba(0.5)")
        h("Ipop[16] netConn_projIE_gaba[1315] = new NetCon(&v(0.5), syn_projIE_gaba[1315], 20.0, 1.5, -0.0016545403)")  

        # Connection 1316: cell 16, seg 0 (0.5) [0.5 on Ipop[16]] -> cell 36, seg 0 (0.5) [0.5 on Epop[36]], weight: -0.0016545403, delay 1.5
        h("Epop[36] syn_projIE_gaba[1316] = new gaba(0.5)")
        h("Ipop[16] netConn_projIE_gaba[1316] = new NetCon(&v(0.5), syn_projIE_gaba[1316], 20.0, 1.5, -0.0016545403)")  

        # Connection 1317: cell 16, seg 0 (0.5) [0.5 on Ipop[16]] -> cell 37, seg 0 (0.5) [0.5 on Epop[37]], weight: -0.0016545403, delay 1.5
        h("Epop[37] syn_projIE_gaba[1317] = new gaba(0.5)")
        h("Ipop[16] netConn_projIE_gaba[1317] = new NetCon(&v(0.5), syn_projIE_gaba[1317], 20.0, 1.5, -0.0016545403)")  

        # Connection 1318: cell 16, seg 0 (0.5) [0.5 on Ipop[16]] -> cell 38, seg 0 (0.5) [0.5 on Epop[38]], weight: -0.0016545403, delay 1.5
        h("Epop[38] syn_projIE_gaba[1318] = new gaba(0.5)")
        h("Ipop[16] netConn_projIE_gaba[1318] = new NetCon(&v(0.5), syn_projIE_gaba[1318], 20.0, 1.5, -0.0016545403)")  

        # Connection 1319: cell 16, seg 0 (0.5) [0.5 on Ipop[16]] -> cell 39, seg 0 (0.5) [0.5 on Epop[39]], weight: -0.0016545403, delay 1.5
        h("Epop[39] syn_projIE_gaba[1319] = new gaba(0.5)")
        h("Ipop[16] netConn_projIE_gaba[1319] = new NetCon(&v(0.5), syn_projIE_gaba[1319], 20.0, 1.5, -0.0016545403)")  

        # Connection 1320: cell 16, seg 0 (0.5) [0.5 on Ipop[16]] -> cell 40, seg 0 (0.5) [0.5 on Epop[40]], weight: -0.0016545403, delay 1.5
        h("Epop[40] syn_projIE_gaba[1320] = new gaba(0.5)")
        h("Ipop[16] netConn_projIE_gaba[1320] = new NetCon(&v(0.5), syn_projIE_gaba[1320], 20.0, 1.5, -0.0016545403)")  

        # Connection 1321: cell 16, seg 0 (0.5) [0.5 on Ipop[16]] -> cell 41, seg 0 (0.5) [0.5 on Epop[41]], weight: -0.0016545403, delay 1.5
        h("Epop[41] syn_projIE_gaba[1321] = new gaba(0.5)")
        h("Ipop[16] netConn_projIE_gaba[1321] = new NetCon(&v(0.5), syn_projIE_gaba[1321], 20.0, 1.5, -0.0016545403)")  

        # Connection 1322: cell 16, seg 0 (0.5) [0.5 on Ipop[16]] -> cell 42, seg 0 (0.5) [0.5 on Epop[42]], weight: -0.0016545403, delay 1.5
        h("Epop[42] syn_projIE_gaba[1322] = new gaba(0.5)")
        h("Ipop[16] netConn_projIE_gaba[1322] = new NetCon(&v(0.5), syn_projIE_gaba[1322], 20.0, 1.5, -0.0016545403)")  

        # Connection 1323: cell 16, seg 0 (0.5) [0.5 on Ipop[16]] -> cell 43, seg 0 (0.5) [0.5 on Epop[43]], weight: -0.0016545403, delay 1.5
        h("Epop[43] syn_projIE_gaba[1323] = new gaba(0.5)")
        h("Ipop[16] netConn_projIE_gaba[1323] = new NetCon(&v(0.5), syn_projIE_gaba[1323], 20.0, 1.5, -0.0016545403)")  

        # Connection 1324: cell 16, seg 0 (0.5) [0.5 on Ipop[16]] -> cell 44, seg 0 (0.5) [0.5 on Epop[44]], weight: -0.0016545403, delay 1.5
        h("Epop[44] syn_projIE_gaba[1324] = new gaba(0.5)")
        h("Ipop[16] netConn_projIE_gaba[1324] = new NetCon(&v(0.5), syn_projIE_gaba[1324], 20.0, 1.5, -0.0016545403)")  

        # Connection 1325: cell 16, seg 0 (0.5) [0.5 on Ipop[16]] -> cell 45, seg 0 (0.5) [0.5 on Epop[45]], weight: -0.0016545403, delay 1.5
        h("Epop[45] syn_projIE_gaba[1325] = new gaba(0.5)")
        h("Ipop[16] netConn_projIE_gaba[1325] = new NetCon(&v(0.5), syn_projIE_gaba[1325], 20.0, 1.5, -0.0016545403)")  

        # Connection 1326: cell 16, seg 0 (0.5) [0.5 on Ipop[16]] -> cell 46, seg 0 (0.5) [0.5 on Epop[46]], weight: -0.0016545403, delay 1.5
        h("Epop[46] syn_projIE_gaba[1326] = new gaba(0.5)")
        h("Ipop[16] netConn_projIE_gaba[1326] = new NetCon(&v(0.5), syn_projIE_gaba[1326], 20.0, 1.5, -0.0016545403)")  

        # Connection 1327: cell 16, seg 0 (0.5) [0.5 on Ipop[16]] -> cell 47, seg 0 (0.5) [0.5 on Epop[47]], weight: -0.0016545403, delay 1.5
        h("Epop[47] syn_projIE_gaba[1327] = new gaba(0.5)")
        h("Ipop[16] netConn_projIE_gaba[1327] = new NetCon(&v(0.5), syn_projIE_gaba[1327], 20.0, 1.5, -0.0016545403)")  

        # Connection 1328: cell 16, seg 0 (0.5) [0.5 on Ipop[16]] -> cell 48, seg 0 (0.5) [0.5 on Epop[48]], weight: -0.0016545403, delay 1.5
        h("Epop[48] syn_projIE_gaba[1328] = new gaba(0.5)")
        h("Ipop[16] netConn_projIE_gaba[1328] = new NetCon(&v(0.5), syn_projIE_gaba[1328], 20.0, 1.5, -0.0016545403)")  

        # Connection 1329: cell 16, seg 0 (0.5) [0.5 on Ipop[16]] -> cell 49, seg 0 (0.5) [0.5 on Epop[49]], weight: -0.0016545403, delay 1.5
        h("Epop[49] syn_projIE_gaba[1329] = new gaba(0.5)")
        h("Ipop[16] netConn_projIE_gaba[1329] = new NetCon(&v(0.5), syn_projIE_gaba[1329], 20.0, 1.5, -0.0016545403)")  

        # Connection 1330: cell 16, seg 0 (0.5) [0.5 on Ipop[16]] -> cell 50, seg 0 (0.5) [0.5 on Epop[50]], weight: -0.0016545403, delay 1.5
        h("Epop[50] syn_projIE_gaba[1330] = new gaba(0.5)")
        h("Ipop[16] netConn_projIE_gaba[1330] = new NetCon(&v(0.5), syn_projIE_gaba[1330], 20.0, 1.5, -0.0016545403)")  

        # Connection 1331: cell 16, seg 0 (0.5) [0.5 on Ipop[16]] -> cell 51, seg 0 (0.5) [0.5 on Epop[51]], weight: -0.0016545403, delay 1.5
        h("Epop[51] syn_projIE_gaba[1331] = new gaba(0.5)")
        h("Ipop[16] netConn_projIE_gaba[1331] = new NetCon(&v(0.5), syn_projIE_gaba[1331], 20.0, 1.5, -0.0016545403)")  

        # Connection 1332: cell 16, seg 0 (0.5) [0.5 on Ipop[16]] -> cell 52, seg 0 (0.5) [0.5 on Epop[52]], weight: -0.0016545403, delay 1.5
        h("Epop[52] syn_projIE_gaba[1332] = new gaba(0.5)")
        h("Ipop[16] netConn_projIE_gaba[1332] = new NetCon(&v(0.5), syn_projIE_gaba[1332], 20.0, 1.5, -0.0016545403)")  

        # Connection 1333: cell 16, seg 0 (0.5) [0.5 on Ipop[16]] -> cell 53, seg 0 (0.5) [0.5 on Epop[53]], weight: -0.0016545403, delay 1.5
        h("Epop[53] syn_projIE_gaba[1333] = new gaba(0.5)")
        h("Ipop[16] netConn_projIE_gaba[1333] = new NetCon(&v(0.5), syn_projIE_gaba[1333], 20.0, 1.5, -0.0016545403)")  

        # Connection 1334: cell 16, seg 0 (0.5) [0.5 on Ipop[16]] -> cell 54, seg 0 (0.5) [0.5 on Epop[54]], weight: -0.0016545403, delay 1.5
        h("Epop[54] syn_projIE_gaba[1334] = new gaba(0.5)")
        h("Ipop[16] netConn_projIE_gaba[1334] = new NetCon(&v(0.5), syn_projIE_gaba[1334], 20.0, 1.5, -0.0016545403)")  

        # Connection 1335: cell 16, seg 0 (0.5) [0.5 on Ipop[16]] -> cell 55, seg 0 (0.5) [0.5 on Epop[55]], weight: -0.0016545403, delay 1.5
        h("Epop[55] syn_projIE_gaba[1335] = new gaba(0.5)")
        h("Ipop[16] netConn_projIE_gaba[1335] = new NetCon(&v(0.5), syn_projIE_gaba[1335], 20.0, 1.5, -0.0016545403)")  

        # Connection 1336: cell 16, seg 0 (0.5) [0.5 on Ipop[16]] -> cell 56, seg 0 (0.5) [0.5 on Epop[56]], weight: -0.0016545403, delay 1.5
        h("Epop[56] syn_projIE_gaba[1336] = new gaba(0.5)")
        h("Ipop[16] netConn_projIE_gaba[1336] = new NetCon(&v(0.5), syn_projIE_gaba[1336], 20.0, 1.5, -0.0016545403)")  

        # Connection 1337: cell 16, seg 0 (0.5) [0.5 on Ipop[16]] -> cell 57, seg 0 (0.5) [0.5 on Epop[57]], weight: -0.0016545403, delay 1.5
        h("Epop[57] syn_projIE_gaba[1337] = new gaba(0.5)")
        h("Ipop[16] netConn_projIE_gaba[1337] = new NetCon(&v(0.5), syn_projIE_gaba[1337], 20.0, 1.5, -0.0016545403)")  

        # Connection 1338: cell 16, seg 0 (0.5) [0.5 on Ipop[16]] -> cell 58, seg 0 (0.5) [0.5 on Epop[58]], weight: -0.0016545403, delay 1.5
        h("Epop[58] syn_projIE_gaba[1338] = new gaba(0.5)")
        h("Ipop[16] netConn_projIE_gaba[1338] = new NetCon(&v(0.5), syn_projIE_gaba[1338], 20.0, 1.5, -0.0016545403)")  

        # Connection 1339: cell 16, seg 0 (0.5) [0.5 on Ipop[16]] -> cell 59, seg 0 (0.5) [0.5 on Epop[59]], weight: -0.0016545403, delay 1.5
        h("Epop[59] syn_projIE_gaba[1339] = new gaba(0.5)")
        h("Ipop[16] netConn_projIE_gaba[1339] = new NetCon(&v(0.5), syn_projIE_gaba[1339], 20.0, 1.5, -0.0016545403)")  

        # Connection 1340: cell 16, seg 0 (0.5) [0.5 on Ipop[16]] -> cell 60, seg 0 (0.5) [0.5 on Epop[60]], weight: -0.0016545403, delay 1.5
        h("Epop[60] syn_projIE_gaba[1340] = new gaba(0.5)")
        h("Ipop[16] netConn_projIE_gaba[1340] = new NetCon(&v(0.5), syn_projIE_gaba[1340], 20.0, 1.5, -0.0016545403)")  

        # Connection 1341: cell 16, seg 0 (0.5) [0.5 on Ipop[16]] -> cell 61, seg 0 (0.5) [0.5 on Epop[61]], weight: -0.0016545403, delay 1.5
        h("Epop[61] syn_projIE_gaba[1341] = new gaba(0.5)")
        h("Ipop[16] netConn_projIE_gaba[1341] = new NetCon(&v(0.5), syn_projIE_gaba[1341], 20.0, 1.5, -0.0016545403)")  

        # Connection 1342: cell 16, seg 0 (0.5) [0.5 on Ipop[16]] -> cell 62, seg 0 (0.5) [0.5 on Epop[62]], weight: -0.0016545403, delay 1.5
        h("Epop[62] syn_projIE_gaba[1342] = new gaba(0.5)")
        h("Ipop[16] netConn_projIE_gaba[1342] = new NetCon(&v(0.5), syn_projIE_gaba[1342], 20.0, 1.5, -0.0016545403)")  

        # Connection 1343: cell 16, seg 0 (0.5) [0.5 on Ipop[16]] -> cell 63, seg 0 (0.5) [0.5 on Epop[63]], weight: -0.0016545403, delay 1.5
        h("Epop[63] syn_projIE_gaba[1343] = new gaba(0.5)")
        h("Ipop[16] netConn_projIE_gaba[1343] = new NetCon(&v(0.5), syn_projIE_gaba[1343], 20.0, 1.5, -0.0016545403)")  

        # Connection 1344: cell 16, seg 0 (0.5) [0.5 on Ipop[16]] -> cell 64, seg 0 (0.5) [0.5 on Epop[64]], weight: -0.0016545403, delay 1.5
        h("Epop[64] syn_projIE_gaba[1344] = new gaba(0.5)")
        h("Ipop[16] netConn_projIE_gaba[1344] = new NetCon(&v(0.5), syn_projIE_gaba[1344], 20.0, 1.5, -0.0016545403)")  

        # Connection 1345: cell 16, seg 0 (0.5) [0.5 on Ipop[16]] -> cell 65, seg 0 (0.5) [0.5 on Epop[65]], weight: -0.0016545403, delay 1.5
        h("Epop[65] syn_projIE_gaba[1345] = new gaba(0.5)")
        h("Ipop[16] netConn_projIE_gaba[1345] = new NetCon(&v(0.5), syn_projIE_gaba[1345], 20.0, 1.5, -0.0016545403)")  

        # Connection 1346: cell 16, seg 0 (0.5) [0.5 on Ipop[16]] -> cell 66, seg 0 (0.5) [0.5 on Epop[66]], weight: -0.0016545403, delay 1.5
        h("Epop[66] syn_projIE_gaba[1346] = new gaba(0.5)")
        h("Ipop[16] netConn_projIE_gaba[1346] = new NetCon(&v(0.5), syn_projIE_gaba[1346], 20.0, 1.5, -0.0016545403)")  

        # Connection 1347: cell 16, seg 0 (0.5) [0.5 on Ipop[16]] -> cell 67, seg 0 (0.5) [0.5 on Epop[67]], weight: -0.0016545403, delay 1.5
        h("Epop[67] syn_projIE_gaba[1347] = new gaba(0.5)")
        h("Ipop[16] netConn_projIE_gaba[1347] = new NetCon(&v(0.5), syn_projIE_gaba[1347], 20.0, 1.5, -0.0016545403)")  

        # Connection 1348: cell 16, seg 0 (0.5) [0.5 on Ipop[16]] -> cell 68, seg 0 (0.5) [0.5 on Epop[68]], weight: -0.0016545403, delay 1.5
        h("Epop[68] syn_projIE_gaba[1348] = new gaba(0.5)")
        h("Ipop[16] netConn_projIE_gaba[1348] = new NetCon(&v(0.5), syn_projIE_gaba[1348], 20.0, 1.5, -0.0016545403)")  

        # Connection 1349: cell 16, seg 0 (0.5) [0.5 on Ipop[16]] -> cell 69, seg 0 (0.5) [0.5 on Epop[69]], weight: -0.0016545403, delay 1.5
        h("Epop[69] syn_projIE_gaba[1349] = new gaba(0.5)")
        h("Ipop[16] netConn_projIE_gaba[1349] = new NetCon(&v(0.5), syn_projIE_gaba[1349], 20.0, 1.5, -0.0016545403)")  

        # Connection 1350: cell 16, seg 0 (0.5) [0.5 on Ipop[16]] -> cell 70, seg 0 (0.5) [0.5 on Epop[70]], weight: -0.0016545403, delay 1.5
        h("Epop[70] syn_projIE_gaba[1350] = new gaba(0.5)")
        h("Ipop[16] netConn_projIE_gaba[1350] = new NetCon(&v(0.5), syn_projIE_gaba[1350], 20.0, 1.5, -0.0016545403)")  

        # Connection 1351: cell 16, seg 0 (0.5) [0.5 on Ipop[16]] -> cell 71, seg 0 (0.5) [0.5 on Epop[71]], weight: -0.0016545403, delay 1.5
        h("Epop[71] syn_projIE_gaba[1351] = new gaba(0.5)")
        h("Ipop[16] netConn_projIE_gaba[1351] = new NetCon(&v(0.5), syn_projIE_gaba[1351], 20.0, 1.5, -0.0016545403)")  

        # Connection 1352: cell 16, seg 0 (0.5) [0.5 on Ipop[16]] -> cell 72, seg 0 (0.5) [0.5 on Epop[72]], weight: -0.0016545403, delay 1.5
        h("Epop[72] syn_projIE_gaba[1352] = new gaba(0.5)")
        h("Ipop[16] netConn_projIE_gaba[1352] = new NetCon(&v(0.5), syn_projIE_gaba[1352], 20.0, 1.5, -0.0016545403)")  

        # Connection 1353: cell 16, seg 0 (0.5) [0.5 on Ipop[16]] -> cell 73, seg 0 (0.5) [0.5 on Epop[73]], weight: -0.0016545403, delay 1.5
        h("Epop[73] syn_projIE_gaba[1353] = new gaba(0.5)")
        h("Ipop[16] netConn_projIE_gaba[1353] = new NetCon(&v(0.5), syn_projIE_gaba[1353], 20.0, 1.5, -0.0016545403)")  

        # Connection 1354: cell 16, seg 0 (0.5) [0.5 on Ipop[16]] -> cell 74, seg 0 (0.5) [0.5 on Epop[74]], weight: -0.0016545403, delay 1.5
        h("Epop[74] syn_projIE_gaba[1354] = new gaba(0.5)")
        h("Ipop[16] netConn_projIE_gaba[1354] = new NetCon(&v(0.5), syn_projIE_gaba[1354], 20.0, 1.5, -0.0016545403)")  

        # Connection 1355: cell 16, seg 0 (0.5) [0.5 on Ipop[16]] -> cell 75, seg 0 (0.5) [0.5 on Epop[75]], weight: -0.0016545403, delay 1.5
        h("Epop[75] syn_projIE_gaba[1355] = new gaba(0.5)")
        h("Ipop[16] netConn_projIE_gaba[1355] = new NetCon(&v(0.5), syn_projIE_gaba[1355], 20.0, 1.5, -0.0016545403)")  

        # Connection 1356: cell 16, seg 0 (0.5) [0.5 on Ipop[16]] -> cell 76, seg 0 (0.5) [0.5 on Epop[76]], weight: -0.0016545403, delay 1.5
        h("Epop[76] syn_projIE_gaba[1356] = new gaba(0.5)")
        h("Ipop[16] netConn_projIE_gaba[1356] = new NetCon(&v(0.5), syn_projIE_gaba[1356], 20.0, 1.5, -0.0016545403)")  

        # Connection 1357: cell 16, seg 0 (0.5) [0.5 on Ipop[16]] -> cell 77, seg 0 (0.5) [0.5 on Epop[77]], weight: -0.0016545403, delay 1.5
        h("Epop[77] syn_projIE_gaba[1357] = new gaba(0.5)")
        h("Ipop[16] netConn_projIE_gaba[1357] = new NetCon(&v(0.5), syn_projIE_gaba[1357], 20.0, 1.5, -0.0016545403)")  

        # Connection 1358: cell 16, seg 0 (0.5) [0.5 on Ipop[16]] -> cell 78, seg 0 (0.5) [0.5 on Epop[78]], weight: -0.0016545403, delay 1.5
        h("Epop[78] syn_projIE_gaba[1358] = new gaba(0.5)")
        h("Ipop[16] netConn_projIE_gaba[1358] = new NetCon(&v(0.5), syn_projIE_gaba[1358], 20.0, 1.5, -0.0016545403)")  

        # Connection 1359: cell 16, seg 0 (0.5) [0.5 on Ipop[16]] -> cell 79, seg 0 (0.5) [0.5 on Epop[79]], weight: -0.0016545403, delay 1.5
        h("Epop[79] syn_projIE_gaba[1359] = new gaba(0.5)")
        h("Ipop[16] netConn_projIE_gaba[1359] = new NetCon(&v(0.5), syn_projIE_gaba[1359], 20.0, 1.5, -0.0016545403)")  

        # Connection 1360: cell 17, seg 0 (0.5) [0.5 on Ipop[17]] -> cell 0, seg 0 (0.5) [0.5 on Epop[0]], weight: -0.0016545403, delay 1.5
        h("Epop[0] syn_projIE_gaba[1360] = new gaba(0.5)")
        h("Ipop[17] netConn_projIE_gaba[1360] = new NetCon(&v(0.5), syn_projIE_gaba[1360], 20.0, 1.5, -0.0016545403)")  

        # Connection 1361: cell 17, seg 0 (0.5) [0.5 on Ipop[17]] -> cell 1, seg 0 (0.5) [0.5 on Epop[1]], weight: -0.0016545403, delay 1.5
        h("Epop[1] syn_projIE_gaba[1361] = new gaba(0.5)")
        h("Ipop[17] netConn_projIE_gaba[1361] = new NetCon(&v(0.5), syn_projIE_gaba[1361], 20.0, 1.5, -0.0016545403)")  

        # Connection 1362: cell 17, seg 0 (0.5) [0.5 on Ipop[17]] -> cell 2, seg 0 (0.5) [0.5 on Epop[2]], weight: -0.0016545403, delay 1.5
        h("Epop[2] syn_projIE_gaba[1362] = new gaba(0.5)")
        h("Ipop[17] netConn_projIE_gaba[1362] = new NetCon(&v(0.5), syn_projIE_gaba[1362], 20.0, 1.5, -0.0016545403)")  

        # Connection 1363: cell 17, seg 0 (0.5) [0.5 on Ipop[17]] -> cell 3, seg 0 (0.5) [0.5 on Epop[3]], weight: -0.0016545403, delay 1.5
        h("Epop[3] syn_projIE_gaba[1363] = new gaba(0.5)")
        h("Ipop[17] netConn_projIE_gaba[1363] = new NetCon(&v(0.5), syn_projIE_gaba[1363], 20.0, 1.5, -0.0016545403)")  

        # Connection 1364: cell 17, seg 0 (0.5) [0.5 on Ipop[17]] -> cell 4, seg 0 (0.5) [0.5 on Epop[4]], weight: -0.0016545403, delay 1.5
        h("Epop[4] syn_projIE_gaba[1364] = new gaba(0.5)")
        h("Ipop[17] netConn_projIE_gaba[1364] = new NetCon(&v(0.5), syn_projIE_gaba[1364], 20.0, 1.5, -0.0016545403)")  

        # Connection 1365: cell 17, seg 0 (0.5) [0.5 on Ipop[17]] -> cell 5, seg 0 (0.5) [0.5 on Epop[5]], weight: -0.0016545403, delay 1.5
        h("Epop[5] syn_projIE_gaba[1365] = new gaba(0.5)")
        h("Ipop[17] netConn_projIE_gaba[1365] = new NetCon(&v(0.5), syn_projIE_gaba[1365], 20.0, 1.5, -0.0016545403)")  

        # Connection 1366: cell 17, seg 0 (0.5) [0.5 on Ipop[17]] -> cell 6, seg 0 (0.5) [0.5 on Epop[6]], weight: -0.0016545403, delay 1.5
        h("Epop[6] syn_projIE_gaba[1366] = new gaba(0.5)")
        h("Ipop[17] netConn_projIE_gaba[1366] = new NetCon(&v(0.5), syn_projIE_gaba[1366], 20.0, 1.5, -0.0016545403)")  

        # Connection 1367: cell 17, seg 0 (0.5) [0.5 on Ipop[17]] -> cell 7, seg 0 (0.5) [0.5 on Epop[7]], weight: -0.0016545403, delay 1.5
        h("Epop[7] syn_projIE_gaba[1367] = new gaba(0.5)")
        h("Ipop[17] netConn_projIE_gaba[1367] = new NetCon(&v(0.5), syn_projIE_gaba[1367], 20.0, 1.5, -0.0016545403)")  

        # Connection 1368: cell 17, seg 0 (0.5) [0.5 on Ipop[17]] -> cell 8, seg 0 (0.5) [0.5 on Epop[8]], weight: -0.0016545403, delay 1.5
        h("Epop[8] syn_projIE_gaba[1368] = new gaba(0.5)")
        h("Ipop[17] netConn_projIE_gaba[1368] = new NetCon(&v(0.5), syn_projIE_gaba[1368], 20.0, 1.5, -0.0016545403)")  

        # Connection 1369: cell 17, seg 0 (0.5) [0.5 on Ipop[17]] -> cell 9, seg 0 (0.5) [0.5 on Epop[9]], weight: -0.0016545403, delay 1.5
        h("Epop[9] syn_projIE_gaba[1369] = new gaba(0.5)")
        h("Ipop[17] netConn_projIE_gaba[1369] = new NetCon(&v(0.5), syn_projIE_gaba[1369], 20.0, 1.5, -0.0016545403)")  

        # Connection 1370: cell 17, seg 0 (0.5) [0.5 on Ipop[17]] -> cell 10, seg 0 (0.5) [0.5 on Epop[10]], weight: -0.0016545403, delay 1.5
        h("Epop[10] syn_projIE_gaba[1370] = new gaba(0.5)")
        h("Ipop[17] netConn_projIE_gaba[1370] = new NetCon(&v(0.5), syn_projIE_gaba[1370], 20.0, 1.5, -0.0016545403)")  

        # Connection 1371: cell 17, seg 0 (0.5) [0.5 on Ipop[17]] -> cell 11, seg 0 (0.5) [0.5 on Epop[11]], weight: -0.0016545403, delay 1.5
        h("Epop[11] syn_projIE_gaba[1371] = new gaba(0.5)")
        h("Ipop[17] netConn_projIE_gaba[1371] = new NetCon(&v(0.5), syn_projIE_gaba[1371], 20.0, 1.5, -0.0016545403)")  

        # Connection 1372: cell 17, seg 0 (0.5) [0.5 on Ipop[17]] -> cell 12, seg 0 (0.5) [0.5 on Epop[12]], weight: -0.0016545403, delay 1.5
        h("Epop[12] syn_projIE_gaba[1372] = new gaba(0.5)")
        h("Ipop[17] netConn_projIE_gaba[1372] = new NetCon(&v(0.5), syn_projIE_gaba[1372], 20.0, 1.5, -0.0016545403)")  

        # Connection 1373: cell 17, seg 0 (0.5) [0.5 on Ipop[17]] -> cell 13, seg 0 (0.5) [0.5 on Epop[13]], weight: -0.0016545403, delay 1.5
        h("Epop[13] syn_projIE_gaba[1373] = new gaba(0.5)")
        h("Ipop[17] netConn_projIE_gaba[1373] = new NetCon(&v(0.5), syn_projIE_gaba[1373], 20.0, 1.5, -0.0016545403)")  

        # Connection 1374: cell 17, seg 0 (0.5) [0.5 on Ipop[17]] -> cell 14, seg 0 (0.5) [0.5 on Epop[14]], weight: -0.0016545403, delay 1.5
        h("Epop[14] syn_projIE_gaba[1374] = new gaba(0.5)")
        h("Ipop[17] netConn_projIE_gaba[1374] = new NetCon(&v(0.5), syn_projIE_gaba[1374], 20.0, 1.5, -0.0016545403)")  

        # Connection 1375: cell 17, seg 0 (0.5) [0.5 on Ipop[17]] -> cell 15, seg 0 (0.5) [0.5 on Epop[15]], weight: -0.0016545403, delay 1.5
        h("Epop[15] syn_projIE_gaba[1375] = new gaba(0.5)")
        h("Ipop[17] netConn_projIE_gaba[1375] = new NetCon(&v(0.5), syn_projIE_gaba[1375], 20.0, 1.5, -0.0016545403)")  

        # Connection 1376: cell 17, seg 0 (0.5) [0.5 on Ipop[17]] -> cell 16, seg 0 (0.5) [0.5 on Epop[16]], weight: -0.0016545403, delay 1.5
        h("Epop[16] syn_projIE_gaba[1376] = new gaba(0.5)")
        h("Ipop[17] netConn_projIE_gaba[1376] = new NetCon(&v(0.5), syn_projIE_gaba[1376], 20.0, 1.5, -0.0016545403)")  

        # Connection 1377: cell 17, seg 0 (0.5) [0.5 on Ipop[17]] -> cell 17, seg 0 (0.5) [0.5 on Epop[17]], weight: -0.0016545403, delay 1.5
        h("Epop[17] syn_projIE_gaba[1377] = new gaba(0.5)")
        h("Ipop[17] netConn_projIE_gaba[1377] = new NetCon(&v(0.5), syn_projIE_gaba[1377], 20.0, 1.5, -0.0016545403)")  

        # Connection 1378: cell 17, seg 0 (0.5) [0.5 on Ipop[17]] -> cell 18, seg 0 (0.5) [0.5 on Epop[18]], weight: -0.0016545403, delay 1.5
        h("Epop[18] syn_projIE_gaba[1378] = new gaba(0.5)")
        h("Ipop[17] netConn_projIE_gaba[1378] = new NetCon(&v(0.5), syn_projIE_gaba[1378], 20.0, 1.5, -0.0016545403)")  

        # Connection 1379: cell 17, seg 0 (0.5) [0.5 on Ipop[17]] -> cell 19, seg 0 (0.5) [0.5 on Epop[19]], weight: -0.0016545403, delay 1.5
        h("Epop[19] syn_projIE_gaba[1379] = new gaba(0.5)")
        h("Ipop[17] netConn_projIE_gaba[1379] = new NetCon(&v(0.5), syn_projIE_gaba[1379], 20.0, 1.5, -0.0016545403)")  

        # Connection 1380: cell 17, seg 0 (0.5) [0.5 on Ipop[17]] -> cell 20, seg 0 (0.5) [0.5 on Epop[20]], weight: -0.0016545403, delay 1.5
        h("Epop[20] syn_projIE_gaba[1380] = new gaba(0.5)")
        h("Ipop[17] netConn_projIE_gaba[1380] = new NetCon(&v(0.5), syn_projIE_gaba[1380], 20.0, 1.5, -0.0016545403)")  

        # Connection 1381: cell 17, seg 0 (0.5) [0.5 on Ipop[17]] -> cell 21, seg 0 (0.5) [0.5 on Epop[21]], weight: -0.0016545403, delay 1.5
        h("Epop[21] syn_projIE_gaba[1381] = new gaba(0.5)")
        h("Ipop[17] netConn_projIE_gaba[1381] = new NetCon(&v(0.5), syn_projIE_gaba[1381], 20.0, 1.5, -0.0016545403)")  

        # Connection 1382: cell 17, seg 0 (0.5) [0.5 on Ipop[17]] -> cell 22, seg 0 (0.5) [0.5 on Epop[22]], weight: -0.0016545403, delay 1.5
        h("Epop[22] syn_projIE_gaba[1382] = new gaba(0.5)")
        h("Ipop[17] netConn_projIE_gaba[1382] = new NetCon(&v(0.5), syn_projIE_gaba[1382], 20.0, 1.5, -0.0016545403)")  

        # Connection 1383: cell 17, seg 0 (0.5) [0.5 on Ipop[17]] -> cell 23, seg 0 (0.5) [0.5 on Epop[23]], weight: -0.0016545403, delay 1.5
        h("Epop[23] syn_projIE_gaba[1383] = new gaba(0.5)")
        h("Ipop[17] netConn_projIE_gaba[1383] = new NetCon(&v(0.5), syn_projIE_gaba[1383], 20.0, 1.5, -0.0016545403)")  

        # Connection 1384: cell 17, seg 0 (0.5) [0.5 on Ipop[17]] -> cell 24, seg 0 (0.5) [0.5 on Epop[24]], weight: -0.0016545403, delay 1.5
        h("Epop[24] syn_projIE_gaba[1384] = new gaba(0.5)")
        h("Ipop[17] netConn_projIE_gaba[1384] = new NetCon(&v(0.5), syn_projIE_gaba[1384], 20.0, 1.5, -0.0016545403)")  

        # Connection 1385: cell 17, seg 0 (0.5) [0.5 on Ipop[17]] -> cell 25, seg 0 (0.5) [0.5 on Epop[25]], weight: -0.0016545403, delay 1.5
        h("Epop[25] syn_projIE_gaba[1385] = new gaba(0.5)")
        h("Ipop[17] netConn_projIE_gaba[1385] = new NetCon(&v(0.5), syn_projIE_gaba[1385], 20.0, 1.5, -0.0016545403)")  

        # Connection 1386: cell 17, seg 0 (0.5) [0.5 on Ipop[17]] -> cell 26, seg 0 (0.5) [0.5 on Epop[26]], weight: -0.0016545403, delay 1.5
        h("Epop[26] syn_projIE_gaba[1386] = new gaba(0.5)")
        h("Ipop[17] netConn_projIE_gaba[1386] = new NetCon(&v(0.5), syn_projIE_gaba[1386], 20.0, 1.5, -0.0016545403)")  

        # Connection 1387: cell 17, seg 0 (0.5) [0.5 on Ipop[17]] -> cell 27, seg 0 (0.5) [0.5 on Epop[27]], weight: -0.0016545403, delay 1.5
        h("Epop[27] syn_projIE_gaba[1387] = new gaba(0.5)")
        h("Ipop[17] netConn_projIE_gaba[1387] = new NetCon(&v(0.5), syn_projIE_gaba[1387], 20.0, 1.5, -0.0016545403)")  

        # Connection 1388: cell 17, seg 0 (0.5) [0.5 on Ipop[17]] -> cell 28, seg 0 (0.5) [0.5 on Epop[28]], weight: -0.0016545403, delay 1.5
        h("Epop[28] syn_projIE_gaba[1388] = new gaba(0.5)")
        h("Ipop[17] netConn_projIE_gaba[1388] = new NetCon(&v(0.5), syn_projIE_gaba[1388], 20.0, 1.5, -0.0016545403)")  

        # Connection 1389: cell 17, seg 0 (0.5) [0.5 on Ipop[17]] -> cell 29, seg 0 (0.5) [0.5 on Epop[29]], weight: -0.0016545403, delay 1.5
        h("Epop[29] syn_projIE_gaba[1389] = new gaba(0.5)")
        h("Ipop[17] netConn_projIE_gaba[1389] = new NetCon(&v(0.5), syn_projIE_gaba[1389], 20.0, 1.5, -0.0016545403)")  

        # Connection 1390: cell 17, seg 0 (0.5) [0.5 on Ipop[17]] -> cell 30, seg 0 (0.5) [0.5 on Epop[30]], weight: -0.0016545403, delay 1.5
        h("Epop[30] syn_projIE_gaba[1390] = new gaba(0.5)")
        h("Ipop[17] netConn_projIE_gaba[1390] = new NetCon(&v(0.5), syn_projIE_gaba[1390], 20.0, 1.5, -0.0016545403)")  

        # Connection 1391: cell 17, seg 0 (0.5) [0.5 on Ipop[17]] -> cell 31, seg 0 (0.5) [0.5 on Epop[31]], weight: -0.0016545403, delay 1.5
        h("Epop[31] syn_projIE_gaba[1391] = new gaba(0.5)")
        h("Ipop[17] netConn_projIE_gaba[1391] = new NetCon(&v(0.5), syn_projIE_gaba[1391], 20.0, 1.5, -0.0016545403)")  

        # Connection 1392: cell 17, seg 0 (0.5) [0.5 on Ipop[17]] -> cell 32, seg 0 (0.5) [0.5 on Epop[32]], weight: -0.0016545403, delay 1.5
        h("Epop[32] syn_projIE_gaba[1392] = new gaba(0.5)")
        h("Ipop[17] netConn_projIE_gaba[1392] = new NetCon(&v(0.5), syn_projIE_gaba[1392], 20.0, 1.5, -0.0016545403)")  

        # Connection 1393: cell 17, seg 0 (0.5) [0.5 on Ipop[17]] -> cell 33, seg 0 (0.5) [0.5 on Epop[33]], weight: -0.0016545403, delay 1.5
        h("Epop[33] syn_projIE_gaba[1393] = new gaba(0.5)")
        h("Ipop[17] netConn_projIE_gaba[1393] = new NetCon(&v(0.5), syn_projIE_gaba[1393], 20.0, 1.5, -0.0016545403)")  

        # Connection 1394: cell 17, seg 0 (0.5) [0.5 on Ipop[17]] -> cell 34, seg 0 (0.5) [0.5 on Epop[34]], weight: -0.0016545403, delay 1.5
        h("Epop[34] syn_projIE_gaba[1394] = new gaba(0.5)")
        h("Ipop[17] netConn_projIE_gaba[1394] = new NetCon(&v(0.5), syn_projIE_gaba[1394], 20.0, 1.5, -0.0016545403)")  

        # Connection 1395: cell 17, seg 0 (0.5) [0.5 on Ipop[17]] -> cell 35, seg 0 (0.5) [0.5 on Epop[35]], weight: -0.0016545403, delay 1.5
        h("Epop[35] syn_projIE_gaba[1395] = new gaba(0.5)")
        h("Ipop[17] netConn_projIE_gaba[1395] = new NetCon(&v(0.5), syn_projIE_gaba[1395], 20.0, 1.5, -0.0016545403)")  

        # Connection 1396: cell 17, seg 0 (0.5) [0.5 on Ipop[17]] -> cell 36, seg 0 (0.5) [0.5 on Epop[36]], weight: -0.0016545403, delay 1.5
        h("Epop[36] syn_projIE_gaba[1396] = new gaba(0.5)")
        h("Ipop[17] netConn_projIE_gaba[1396] = new NetCon(&v(0.5), syn_projIE_gaba[1396], 20.0, 1.5, -0.0016545403)")  

        # Connection 1397: cell 17, seg 0 (0.5) [0.5 on Ipop[17]] -> cell 37, seg 0 (0.5) [0.5 on Epop[37]], weight: -0.0016545403, delay 1.5
        h("Epop[37] syn_projIE_gaba[1397] = new gaba(0.5)")
        h("Ipop[17] netConn_projIE_gaba[1397] = new NetCon(&v(0.5), syn_projIE_gaba[1397], 20.0, 1.5, -0.0016545403)")  

        # Connection 1398: cell 17, seg 0 (0.5) [0.5 on Ipop[17]] -> cell 38, seg 0 (0.5) [0.5 on Epop[38]], weight: -0.0016545403, delay 1.5
        h("Epop[38] syn_projIE_gaba[1398] = new gaba(0.5)")
        h("Ipop[17] netConn_projIE_gaba[1398] = new NetCon(&v(0.5), syn_projIE_gaba[1398], 20.0, 1.5, -0.0016545403)")  

        # Connection 1399: cell 17, seg 0 (0.5) [0.5 on Ipop[17]] -> cell 39, seg 0 (0.5) [0.5 on Epop[39]], weight: -0.0016545403, delay 1.5
        h("Epop[39] syn_projIE_gaba[1399] = new gaba(0.5)")
        h("Ipop[17] netConn_projIE_gaba[1399] = new NetCon(&v(0.5), syn_projIE_gaba[1399], 20.0, 1.5, -0.0016545403)")  

        # Connection 1400: cell 17, seg 0 (0.5) [0.5 on Ipop[17]] -> cell 40, seg 0 (0.5) [0.5 on Epop[40]], weight: -0.0016545403, delay 1.5
        h("Epop[40] syn_projIE_gaba[1400] = new gaba(0.5)")
        h("Ipop[17] netConn_projIE_gaba[1400] = new NetCon(&v(0.5), syn_projIE_gaba[1400], 20.0, 1.5, -0.0016545403)")  

        # Connection 1401: cell 17, seg 0 (0.5) [0.5 on Ipop[17]] -> cell 41, seg 0 (0.5) [0.5 on Epop[41]], weight: -0.0016545403, delay 1.5
        h("Epop[41] syn_projIE_gaba[1401] = new gaba(0.5)")
        h("Ipop[17] netConn_projIE_gaba[1401] = new NetCon(&v(0.5), syn_projIE_gaba[1401], 20.0, 1.5, -0.0016545403)")  

        # Connection 1402: cell 17, seg 0 (0.5) [0.5 on Ipop[17]] -> cell 42, seg 0 (0.5) [0.5 on Epop[42]], weight: -0.0016545403, delay 1.5
        h("Epop[42] syn_projIE_gaba[1402] = new gaba(0.5)")
        h("Ipop[17] netConn_projIE_gaba[1402] = new NetCon(&v(0.5), syn_projIE_gaba[1402], 20.0, 1.5, -0.0016545403)")  

        # Connection 1403: cell 17, seg 0 (0.5) [0.5 on Ipop[17]] -> cell 43, seg 0 (0.5) [0.5 on Epop[43]], weight: -0.0016545403, delay 1.5
        h("Epop[43] syn_projIE_gaba[1403] = new gaba(0.5)")
        h("Ipop[17] netConn_projIE_gaba[1403] = new NetCon(&v(0.5), syn_projIE_gaba[1403], 20.0, 1.5, -0.0016545403)")  

        # Connection 1404: cell 17, seg 0 (0.5) [0.5 on Ipop[17]] -> cell 44, seg 0 (0.5) [0.5 on Epop[44]], weight: -0.0016545403, delay 1.5
        h("Epop[44] syn_projIE_gaba[1404] = new gaba(0.5)")
        h("Ipop[17] netConn_projIE_gaba[1404] = new NetCon(&v(0.5), syn_projIE_gaba[1404], 20.0, 1.5, -0.0016545403)")  

        # Connection 1405: cell 17, seg 0 (0.5) [0.5 on Ipop[17]] -> cell 45, seg 0 (0.5) [0.5 on Epop[45]], weight: -0.0016545403, delay 1.5
        h("Epop[45] syn_projIE_gaba[1405] = new gaba(0.5)")
        h("Ipop[17] netConn_projIE_gaba[1405] = new NetCon(&v(0.5), syn_projIE_gaba[1405], 20.0, 1.5, -0.0016545403)")  

        # Connection 1406: cell 17, seg 0 (0.5) [0.5 on Ipop[17]] -> cell 46, seg 0 (0.5) [0.5 on Epop[46]], weight: -0.0016545403, delay 1.5
        h("Epop[46] syn_projIE_gaba[1406] = new gaba(0.5)")
        h("Ipop[17] netConn_projIE_gaba[1406] = new NetCon(&v(0.5), syn_projIE_gaba[1406], 20.0, 1.5, -0.0016545403)")  

        # Connection 1407: cell 17, seg 0 (0.5) [0.5 on Ipop[17]] -> cell 47, seg 0 (0.5) [0.5 on Epop[47]], weight: -0.0016545403, delay 1.5
        h("Epop[47] syn_projIE_gaba[1407] = new gaba(0.5)")
        h("Ipop[17] netConn_projIE_gaba[1407] = new NetCon(&v(0.5), syn_projIE_gaba[1407], 20.0, 1.5, -0.0016545403)")  

        # Connection 1408: cell 17, seg 0 (0.5) [0.5 on Ipop[17]] -> cell 48, seg 0 (0.5) [0.5 on Epop[48]], weight: -0.0016545403, delay 1.5
        h("Epop[48] syn_projIE_gaba[1408] = new gaba(0.5)")
        h("Ipop[17] netConn_projIE_gaba[1408] = new NetCon(&v(0.5), syn_projIE_gaba[1408], 20.0, 1.5, -0.0016545403)")  

        # Connection 1409: cell 17, seg 0 (0.5) [0.5 on Ipop[17]] -> cell 49, seg 0 (0.5) [0.5 on Epop[49]], weight: -0.0016545403, delay 1.5
        h("Epop[49] syn_projIE_gaba[1409] = new gaba(0.5)")
        h("Ipop[17] netConn_projIE_gaba[1409] = new NetCon(&v(0.5), syn_projIE_gaba[1409], 20.0, 1.5, -0.0016545403)")  

        # Connection 1410: cell 17, seg 0 (0.5) [0.5 on Ipop[17]] -> cell 50, seg 0 (0.5) [0.5 on Epop[50]], weight: -0.0016545403, delay 1.5
        h("Epop[50] syn_projIE_gaba[1410] = new gaba(0.5)")
        h("Ipop[17] netConn_projIE_gaba[1410] = new NetCon(&v(0.5), syn_projIE_gaba[1410], 20.0, 1.5, -0.0016545403)")  

        # Connection 1411: cell 17, seg 0 (0.5) [0.5 on Ipop[17]] -> cell 51, seg 0 (0.5) [0.5 on Epop[51]], weight: -0.0016545403, delay 1.5
        h("Epop[51] syn_projIE_gaba[1411] = new gaba(0.5)")
        h("Ipop[17] netConn_projIE_gaba[1411] = new NetCon(&v(0.5), syn_projIE_gaba[1411], 20.0, 1.5, -0.0016545403)")  

        # Connection 1412: cell 17, seg 0 (0.5) [0.5 on Ipop[17]] -> cell 52, seg 0 (0.5) [0.5 on Epop[52]], weight: -0.0016545403, delay 1.5
        h("Epop[52] syn_projIE_gaba[1412] = new gaba(0.5)")
        h("Ipop[17] netConn_projIE_gaba[1412] = new NetCon(&v(0.5), syn_projIE_gaba[1412], 20.0, 1.5, -0.0016545403)")  

        # Connection 1413: cell 17, seg 0 (0.5) [0.5 on Ipop[17]] -> cell 53, seg 0 (0.5) [0.5 on Epop[53]], weight: -0.0016545403, delay 1.5
        h("Epop[53] syn_projIE_gaba[1413] = new gaba(0.5)")
        h("Ipop[17] netConn_projIE_gaba[1413] = new NetCon(&v(0.5), syn_projIE_gaba[1413], 20.0, 1.5, -0.0016545403)")  

        # Connection 1414: cell 17, seg 0 (0.5) [0.5 on Ipop[17]] -> cell 54, seg 0 (0.5) [0.5 on Epop[54]], weight: -0.0016545403, delay 1.5
        h("Epop[54] syn_projIE_gaba[1414] = new gaba(0.5)")
        h("Ipop[17] netConn_projIE_gaba[1414] = new NetCon(&v(0.5), syn_projIE_gaba[1414], 20.0, 1.5, -0.0016545403)")  

        # Connection 1415: cell 17, seg 0 (0.5) [0.5 on Ipop[17]] -> cell 55, seg 0 (0.5) [0.5 on Epop[55]], weight: -0.0016545403, delay 1.5
        h("Epop[55] syn_projIE_gaba[1415] = new gaba(0.5)")
        h("Ipop[17] netConn_projIE_gaba[1415] = new NetCon(&v(0.5), syn_projIE_gaba[1415], 20.0, 1.5, -0.0016545403)")  

        # Connection 1416: cell 17, seg 0 (0.5) [0.5 on Ipop[17]] -> cell 56, seg 0 (0.5) [0.5 on Epop[56]], weight: -0.0016545403, delay 1.5
        h("Epop[56] syn_projIE_gaba[1416] = new gaba(0.5)")
        h("Ipop[17] netConn_projIE_gaba[1416] = new NetCon(&v(0.5), syn_projIE_gaba[1416], 20.0, 1.5, -0.0016545403)")  

        # Connection 1417: cell 17, seg 0 (0.5) [0.5 on Ipop[17]] -> cell 57, seg 0 (0.5) [0.5 on Epop[57]], weight: -0.0016545403, delay 1.5
        h("Epop[57] syn_projIE_gaba[1417] = new gaba(0.5)")
        h("Ipop[17] netConn_projIE_gaba[1417] = new NetCon(&v(0.5), syn_projIE_gaba[1417], 20.0, 1.5, -0.0016545403)")  

        # Connection 1418: cell 17, seg 0 (0.5) [0.5 on Ipop[17]] -> cell 58, seg 0 (0.5) [0.5 on Epop[58]], weight: -0.0016545403, delay 1.5
        h("Epop[58] syn_projIE_gaba[1418] = new gaba(0.5)")
        h("Ipop[17] netConn_projIE_gaba[1418] = new NetCon(&v(0.5), syn_projIE_gaba[1418], 20.0, 1.5, -0.0016545403)")  

        # Connection 1419: cell 17, seg 0 (0.5) [0.5 on Ipop[17]] -> cell 59, seg 0 (0.5) [0.5 on Epop[59]], weight: -0.0016545403, delay 1.5
        h("Epop[59] syn_projIE_gaba[1419] = new gaba(0.5)")
        h("Ipop[17] netConn_projIE_gaba[1419] = new NetCon(&v(0.5), syn_projIE_gaba[1419], 20.0, 1.5, -0.0016545403)")  

        # Connection 1420: cell 17, seg 0 (0.5) [0.5 on Ipop[17]] -> cell 60, seg 0 (0.5) [0.5 on Epop[60]], weight: -0.0016545403, delay 1.5
        h("Epop[60] syn_projIE_gaba[1420] = new gaba(0.5)")
        h("Ipop[17] netConn_projIE_gaba[1420] = new NetCon(&v(0.5), syn_projIE_gaba[1420], 20.0, 1.5, -0.0016545403)")  

        # Connection 1421: cell 17, seg 0 (0.5) [0.5 on Ipop[17]] -> cell 61, seg 0 (0.5) [0.5 on Epop[61]], weight: -0.0016545403, delay 1.5
        h("Epop[61] syn_projIE_gaba[1421] = new gaba(0.5)")
        h("Ipop[17] netConn_projIE_gaba[1421] = new NetCon(&v(0.5), syn_projIE_gaba[1421], 20.0, 1.5, -0.0016545403)")  

        # Connection 1422: cell 17, seg 0 (0.5) [0.5 on Ipop[17]] -> cell 62, seg 0 (0.5) [0.5 on Epop[62]], weight: -0.0016545403, delay 1.5
        h("Epop[62] syn_projIE_gaba[1422] = new gaba(0.5)")
        h("Ipop[17] netConn_projIE_gaba[1422] = new NetCon(&v(0.5), syn_projIE_gaba[1422], 20.0, 1.5, -0.0016545403)")  

        # Connection 1423: cell 17, seg 0 (0.5) [0.5 on Ipop[17]] -> cell 63, seg 0 (0.5) [0.5 on Epop[63]], weight: -0.0016545403, delay 1.5
        h("Epop[63] syn_projIE_gaba[1423] = new gaba(0.5)")
        h("Ipop[17] netConn_projIE_gaba[1423] = new NetCon(&v(0.5), syn_projIE_gaba[1423], 20.0, 1.5, -0.0016545403)")  

        # Connection 1424: cell 17, seg 0 (0.5) [0.5 on Ipop[17]] -> cell 64, seg 0 (0.5) [0.5 on Epop[64]], weight: -0.0016545403, delay 1.5
        h("Epop[64] syn_projIE_gaba[1424] = new gaba(0.5)")
        h("Ipop[17] netConn_projIE_gaba[1424] = new NetCon(&v(0.5), syn_projIE_gaba[1424], 20.0, 1.5, -0.0016545403)")  

        # Connection 1425: cell 17, seg 0 (0.5) [0.5 on Ipop[17]] -> cell 65, seg 0 (0.5) [0.5 on Epop[65]], weight: -0.0016545403, delay 1.5
        h("Epop[65] syn_projIE_gaba[1425] = new gaba(0.5)")
        h("Ipop[17] netConn_projIE_gaba[1425] = new NetCon(&v(0.5), syn_projIE_gaba[1425], 20.0, 1.5, -0.0016545403)")  

        # Connection 1426: cell 17, seg 0 (0.5) [0.5 on Ipop[17]] -> cell 66, seg 0 (0.5) [0.5 on Epop[66]], weight: -0.0016545403, delay 1.5
        h("Epop[66] syn_projIE_gaba[1426] = new gaba(0.5)")
        h("Ipop[17] netConn_projIE_gaba[1426] = new NetCon(&v(0.5), syn_projIE_gaba[1426], 20.0, 1.5, -0.0016545403)")  

        # Connection 1427: cell 17, seg 0 (0.5) [0.5 on Ipop[17]] -> cell 67, seg 0 (0.5) [0.5 on Epop[67]], weight: -0.0016545403, delay 1.5
        h("Epop[67] syn_projIE_gaba[1427] = new gaba(0.5)")
        h("Ipop[17] netConn_projIE_gaba[1427] = new NetCon(&v(0.5), syn_projIE_gaba[1427], 20.0, 1.5, -0.0016545403)")  

        # Connection 1428: cell 17, seg 0 (0.5) [0.5 on Ipop[17]] -> cell 68, seg 0 (0.5) [0.5 on Epop[68]], weight: -0.0016545403, delay 1.5
        h("Epop[68] syn_projIE_gaba[1428] = new gaba(0.5)")
        h("Ipop[17] netConn_projIE_gaba[1428] = new NetCon(&v(0.5), syn_projIE_gaba[1428], 20.0, 1.5, -0.0016545403)")  

        # Connection 1429: cell 17, seg 0 (0.5) [0.5 on Ipop[17]] -> cell 69, seg 0 (0.5) [0.5 on Epop[69]], weight: -0.0016545403, delay 1.5
        h("Epop[69] syn_projIE_gaba[1429] = new gaba(0.5)")
        h("Ipop[17] netConn_projIE_gaba[1429] = new NetCon(&v(0.5), syn_projIE_gaba[1429], 20.0, 1.5, -0.0016545403)")  

        # Connection 1430: cell 17, seg 0 (0.5) [0.5 on Ipop[17]] -> cell 70, seg 0 (0.5) [0.5 on Epop[70]], weight: -0.0016545403, delay 1.5
        h("Epop[70] syn_projIE_gaba[1430] = new gaba(0.5)")
        h("Ipop[17] netConn_projIE_gaba[1430] = new NetCon(&v(0.5), syn_projIE_gaba[1430], 20.0, 1.5, -0.0016545403)")  

        # Connection 1431: cell 17, seg 0 (0.5) [0.5 on Ipop[17]] -> cell 71, seg 0 (0.5) [0.5 on Epop[71]], weight: -0.0016545403, delay 1.5
        h("Epop[71] syn_projIE_gaba[1431] = new gaba(0.5)")
        h("Ipop[17] netConn_projIE_gaba[1431] = new NetCon(&v(0.5), syn_projIE_gaba[1431], 20.0, 1.5, -0.0016545403)")  

        # Connection 1432: cell 17, seg 0 (0.5) [0.5 on Ipop[17]] -> cell 72, seg 0 (0.5) [0.5 on Epop[72]], weight: -0.0016545403, delay 1.5
        h("Epop[72] syn_projIE_gaba[1432] = new gaba(0.5)")
        h("Ipop[17] netConn_projIE_gaba[1432] = new NetCon(&v(0.5), syn_projIE_gaba[1432], 20.0, 1.5, -0.0016545403)")  

        # Connection 1433: cell 17, seg 0 (0.5) [0.5 on Ipop[17]] -> cell 73, seg 0 (0.5) [0.5 on Epop[73]], weight: -0.0016545403, delay 1.5
        h("Epop[73] syn_projIE_gaba[1433] = new gaba(0.5)")
        h("Ipop[17] netConn_projIE_gaba[1433] = new NetCon(&v(0.5), syn_projIE_gaba[1433], 20.0, 1.5, -0.0016545403)")  

        # Connection 1434: cell 17, seg 0 (0.5) [0.5 on Ipop[17]] -> cell 74, seg 0 (0.5) [0.5 on Epop[74]], weight: -0.0016545403, delay 1.5
        h("Epop[74] syn_projIE_gaba[1434] = new gaba(0.5)")
        h("Ipop[17] netConn_projIE_gaba[1434] = new NetCon(&v(0.5), syn_projIE_gaba[1434], 20.0, 1.5, -0.0016545403)")  

        # Connection 1435: cell 17, seg 0 (0.5) [0.5 on Ipop[17]] -> cell 75, seg 0 (0.5) [0.5 on Epop[75]], weight: -0.0016545403, delay 1.5
        h("Epop[75] syn_projIE_gaba[1435] = new gaba(0.5)")
        h("Ipop[17] netConn_projIE_gaba[1435] = new NetCon(&v(0.5), syn_projIE_gaba[1435], 20.0, 1.5, -0.0016545403)")  

        # Connection 1436: cell 17, seg 0 (0.5) [0.5 on Ipop[17]] -> cell 76, seg 0 (0.5) [0.5 on Epop[76]], weight: -0.0016545403, delay 1.5
        h("Epop[76] syn_projIE_gaba[1436] = new gaba(0.5)")
        h("Ipop[17] netConn_projIE_gaba[1436] = new NetCon(&v(0.5), syn_projIE_gaba[1436], 20.0, 1.5, -0.0016545403)")  

        # Connection 1437: cell 17, seg 0 (0.5) [0.5 on Ipop[17]] -> cell 77, seg 0 (0.5) [0.5 on Epop[77]], weight: -0.0016545403, delay 1.5
        h("Epop[77] syn_projIE_gaba[1437] = new gaba(0.5)")
        h("Ipop[17] netConn_projIE_gaba[1437] = new NetCon(&v(0.5), syn_projIE_gaba[1437], 20.0, 1.5, -0.0016545403)")  

        # Connection 1438: cell 17, seg 0 (0.5) [0.5 on Ipop[17]] -> cell 78, seg 0 (0.5) [0.5 on Epop[78]], weight: -0.0016545403, delay 1.5
        h("Epop[78] syn_projIE_gaba[1438] = new gaba(0.5)")
        h("Ipop[17] netConn_projIE_gaba[1438] = new NetCon(&v(0.5), syn_projIE_gaba[1438], 20.0, 1.5, -0.0016545403)")  

        # Connection 1439: cell 17, seg 0 (0.5) [0.5 on Ipop[17]] -> cell 79, seg 0 (0.5) [0.5 on Epop[79]], weight: -0.0016545403, delay 1.5
        h("Epop[79] syn_projIE_gaba[1439] = new gaba(0.5)")
        h("Ipop[17] netConn_projIE_gaba[1439] = new NetCon(&v(0.5), syn_projIE_gaba[1439], 20.0, 1.5, -0.0016545403)")  

        # Connection 1440: cell 18, seg 0 (0.5) [0.5 on Ipop[18]] -> cell 0, seg 0 (0.5) [0.5 on Epop[0]], weight: -0.0016545403, delay 1.5
        h("Epop[0] syn_projIE_gaba[1440] = new gaba(0.5)")
        h("Ipop[18] netConn_projIE_gaba[1440] = new NetCon(&v(0.5), syn_projIE_gaba[1440], 20.0, 1.5, -0.0016545403)")  

        # Connection 1441: cell 18, seg 0 (0.5) [0.5 on Ipop[18]] -> cell 1, seg 0 (0.5) [0.5 on Epop[1]], weight: -0.0016545403, delay 1.5
        h("Epop[1] syn_projIE_gaba[1441] = new gaba(0.5)")
        h("Ipop[18] netConn_projIE_gaba[1441] = new NetCon(&v(0.5), syn_projIE_gaba[1441], 20.0, 1.5, -0.0016545403)")  

        # Connection 1442: cell 18, seg 0 (0.5) [0.5 on Ipop[18]] -> cell 2, seg 0 (0.5) [0.5 on Epop[2]], weight: -0.0016545403, delay 1.5
        h("Epop[2] syn_projIE_gaba[1442] = new gaba(0.5)")
        h("Ipop[18] netConn_projIE_gaba[1442] = new NetCon(&v(0.5), syn_projIE_gaba[1442], 20.0, 1.5, -0.0016545403)")  

        # Connection 1443: cell 18, seg 0 (0.5) [0.5 on Ipop[18]] -> cell 3, seg 0 (0.5) [0.5 on Epop[3]], weight: -0.0016545403, delay 1.5
        h("Epop[3] syn_projIE_gaba[1443] = new gaba(0.5)")
        h("Ipop[18] netConn_projIE_gaba[1443] = new NetCon(&v(0.5), syn_projIE_gaba[1443], 20.0, 1.5, -0.0016545403)")  

        # Connection 1444: cell 18, seg 0 (0.5) [0.5 on Ipop[18]] -> cell 4, seg 0 (0.5) [0.5 on Epop[4]], weight: -0.0016545403, delay 1.5
        h("Epop[4] syn_projIE_gaba[1444] = new gaba(0.5)")
        h("Ipop[18] netConn_projIE_gaba[1444] = new NetCon(&v(0.5), syn_projIE_gaba[1444], 20.0, 1.5, -0.0016545403)")  

        # Connection 1445: cell 18, seg 0 (0.5) [0.5 on Ipop[18]] -> cell 5, seg 0 (0.5) [0.5 on Epop[5]], weight: -0.0016545403, delay 1.5
        h("Epop[5] syn_projIE_gaba[1445] = new gaba(0.5)")
        h("Ipop[18] netConn_projIE_gaba[1445] = new NetCon(&v(0.5), syn_projIE_gaba[1445], 20.0, 1.5, -0.0016545403)")  

        # Connection 1446: cell 18, seg 0 (0.5) [0.5 on Ipop[18]] -> cell 6, seg 0 (0.5) [0.5 on Epop[6]], weight: -0.0016545403, delay 1.5
        h("Epop[6] syn_projIE_gaba[1446] = new gaba(0.5)")
        h("Ipop[18] netConn_projIE_gaba[1446] = new NetCon(&v(0.5), syn_projIE_gaba[1446], 20.0, 1.5, -0.0016545403)")  

        # Connection 1447: cell 18, seg 0 (0.5) [0.5 on Ipop[18]] -> cell 7, seg 0 (0.5) [0.5 on Epop[7]], weight: -0.0016545403, delay 1.5
        h("Epop[7] syn_projIE_gaba[1447] = new gaba(0.5)")
        h("Ipop[18] netConn_projIE_gaba[1447] = new NetCon(&v(0.5), syn_projIE_gaba[1447], 20.0, 1.5, -0.0016545403)")  

        # Connection 1448: cell 18, seg 0 (0.5) [0.5 on Ipop[18]] -> cell 8, seg 0 (0.5) [0.5 on Epop[8]], weight: -0.0016545403, delay 1.5
        h("Epop[8] syn_projIE_gaba[1448] = new gaba(0.5)")
        h("Ipop[18] netConn_projIE_gaba[1448] = new NetCon(&v(0.5), syn_projIE_gaba[1448], 20.0, 1.5, -0.0016545403)")  

        # Connection 1449: cell 18, seg 0 (0.5) [0.5 on Ipop[18]] -> cell 9, seg 0 (0.5) [0.5 on Epop[9]], weight: -0.0016545403, delay 1.5
        h("Epop[9] syn_projIE_gaba[1449] = new gaba(0.5)")
        h("Ipop[18] netConn_projIE_gaba[1449] = new NetCon(&v(0.5), syn_projIE_gaba[1449], 20.0, 1.5, -0.0016545403)")  

        # Connection 1450: cell 18, seg 0 (0.5) [0.5 on Ipop[18]] -> cell 10, seg 0 (0.5) [0.5 on Epop[10]], weight: -0.0016545403, delay 1.5
        h("Epop[10] syn_projIE_gaba[1450] = new gaba(0.5)")
        h("Ipop[18] netConn_projIE_gaba[1450] = new NetCon(&v(0.5), syn_projIE_gaba[1450], 20.0, 1.5, -0.0016545403)")  

        # Connection 1451: cell 18, seg 0 (0.5) [0.5 on Ipop[18]] -> cell 11, seg 0 (0.5) [0.5 on Epop[11]], weight: -0.0016545403, delay 1.5
        h("Epop[11] syn_projIE_gaba[1451] = new gaba(0.5)")
        h("Ipop[18] netConn_projIE_gaba[1451] = new NetCon(&v(0.5), syn_projIE_gaba[1451], 20.0, 1.5, -0.0016545403)")  

        # Connection 1452: cell 18, seg 0 (0.5) [0.5 on Ipop[18]] -> cell 12, seg 0 (0.5) [0.5 on Epop[12]], weight: -0.0016545403, delay 1.5
        h("Epop[12] syn_projIE_gaba[1452] = new gaba(0.5)")
        h("Ipop[18] netConn_projIE_gaba[1452] = new NetCon(&v(0.5), syn_projIE_gaba[1452], 20.0, 1.5, -0.0016545403)")  

        # Connection 1453: cell 18, seg 0 (0.5) [0.5 on Ipop[18]] -> cell 13, seg 0 (0.5) [0.5 on Epop[13]], weight: -0.0016545403, delay 1.5
        h("Epop[13] syn_projIE_gaba[1453] = new gaba(0.5)")
        h("Ipop[18] netConn_projIE_gaba[1453] = new NetCon(&v(0.5), syn_projIE_gaba[1453], 20.0, 1.5, -0.0016545403)")  

        # Connection 1454: cell 18, seg 0 (0.5) [0.5 on Ipop[18]] -> cell 14, seg 0 (0.5) [0.5 on Epop[14]], weight: -0.0016545403, delay 1.5
        h("Epop[14] syn_projIE_gaba[1454] = new gaba(0.5)")
        h("Ipop[18] netConn_projIE_gaba[1454] = new NetCon(&v(0.5), syn_projIE_gaba[1454], 20.0, 1.5, -0.0016545403)")  

        # Connection 1455: cell 18, seg 0 (0.5) [0.5 on Ipop[18]] -> cell 15, seg 0 (0.5) [0.5 on Epop[15]], weight: -0.0016545403, delay 1.5
        h("Epop[15] syn_projIE_gaba[1455] = new gaba(0.5)")
        h("Ipop[18] netConn_projIE_gaba[1455] = new NetCon(&v(0.5), syn_projIE_gaba[1455], 20.0, 1.5, -0.0016545403)")  

        # Connection 1456: cell 18, seg 0 (0.5) [0.5 on Ipop[18]] -> cell 16, seg 0 (0.5) [0.5 on Epop[16]], weight: -0.0016545403, delay 1.5
        h("Epop[16] syn_projIE_gaba[1456] = new gaba(0.5)")
        h("Ipop[18] netConn_projIE_gaba[1456] = new NetCon(&v(0.5), syn_projIE_gaba[1456], 20.0, 1.5, -0.0016545403)")  

        # Connection 1457: cell 18, seg 0 (0.5) [0.5 on Ipop[18]] -> cell 17, seg 0 (0.5) [0.5 on Epop[17]], weight: -0.0016545403, delay 1.5
        h("Epop[17] syn_projIE_gaba[1457] = new gaba(0.5)")
        h("Ipop[18] netConn_projIE_gaba[1457] = new NetCon(&v(0.5), syn_projIE_gaba[1457], 20.0, 1.5, -0.0016545403)")  

        # Connection 1458: cell 18, seg 0 (0.5) [0.5 on Ipop[18]] -> cell 18, seg 0 (0.5) [0.5 on Epop[18]], weight: -0.0016545403, delay 1.5
        h("Epop[18] syn_projIE_gaba[1458] = new gaba(0.5)")
        h("Ipop[18] netConn_projIE_gaba[1458] = new NetCon(&v(0.5), syn_projIE_gaba[1458], 20.0, 1.5, -0.0016545403)")  

        # Connection 1459: cell 18, seg 0 (0.5) [0.5 on Ipop[18]] -> cell 19, seg 0 (0.5) [0.5 on Epop[19]], weight: -0.0016545403, delay 1.5
        h("Epop[19] syn_projIE_gaba[1459] = new gaba(0.5)")
        h("Ipop[18] netConn_projIE_gaba[1459] = new NetCon(&v(0.5), syn_projIE_gaba[1459], 20.0, 1.5, -0.0016545403)")  

        # Connection 1460: cell 18, seg 0 (0.5) [0.5 on Ipop[18]] -> cell 20, seg 0 (0.5) [0.5 on Epop[20]], weight: -0.0016545403, delay 1.5
        h("Epop[20] syn_projIE_gaba[1460] = new gaba(0.5)")
        h("Ipop[18] netConn_projIE_gaba[1460] = new NetCon(&v(0.5), syn_projIE_gaba[1460], 20.0, 1.5, -0.0016545403)")  

        # Connection 1461: cell 18, seg 0 (0.5) [0.5 on Ipop[18]] -> cell 21, seg 0 (0.5) [0.5 on Epop[21]], weight: -0.0016545403, delay 1.5
        h("Epop[21] syn_projIE_gaba[1461] = new gaba(0.5)")
        h("Ipop[18] netConn_projIE_gaba[1461] = new NetCon(&v(0.5), syn_projIE_gaba[1461], 20.0, 1.5, -0.0016545403)")  

        # Connection 1462: cell 18, seg 0 (0.5) [0.5 on Ipop[18]] -> cell 22, seg 0 (0.5) [0.5 on Epop[22]], weight: -0.0016545403, delay 1.5
        h("Epop[22] syn_projIE_gaba[1462] = new gaba(0.5)")
        h("Ipop[18] netConn_projIE_gaba[1462] = new NetCon(&v(0.5), syn_projIE_gaba[1462], 20.0, 1.5, -0.0016545403)")  

        # Connection 1463: cell 18, seg 0 (0.5) [0.5 on Ipop[18]] -> cell 23, seg 0 (0.5) [0.5 on Epop[23]], weight: -0.0016545403, delay 1.5
        h("Epop[23] syn_projIE_gaba[1463] = new gaba(0.5)")
        h("Ipop[18] netConn_projIE_gaba[1463] = new NetCon(&v(0.5), syn_projIE_gaba[1463], 20.0, 1.5, -0.0016545403)")  

        # Connection 1464: cell 18, seg 0 (0.5) [0.5 on Ipop[18]] -> cell 24, seg 0 (0.5) [0.5 on Epop[24]], weight: -0.0016545403, delay 1.5
        h("Epop[24] syn_projIE_gaba[1464] = new gaba(0.5)")
        h("Ipop[18] netConn_projIE_gaba[1464] = new NetCon(&v(0.5), syn_projIE_gaba[1464], 20.0, 1.5, -0.0016545403)")  

        # Connection 1465: cell 18, seg 0 (0.5) [0.5 on Ipop[18]] -> cell 25, seg 0 (0.5) [0.5 on Epop[25]], weight: -0.0016545403, delay 1.5
        h("Epop[25] syn_projIE_gaba[1465] = new gaba(0.5)")
        h("Ipop[18] netConn_projIE_gaba[1465] = new NetCon(&v(0.5), syn_projIE_gaba[1465], 20.0, 1.5, -0.0016545403)")  

        # Connection 1466: cell 18, seg 0 (0.5) [0.5 on Ipop[18]] -> cell 26, seg 0 (0.5) [0.5 on Epop[26]], weight: -0.0016545403, delay 1.5
        h("Epop[26] syn_projIE_gaba[1466] = new gaba(0.5)")
        h("Ipop[18] netConn_projIE_gaba[1466] = new NetCon(&v(0.5), syn_projIE_gaba[1466], 20.0, 1.5, -0.0016545403)")  

        # Connection 1467: cell 18, seg 0 (0.5) [0.5 on Ipop[18]] -> cell 27, seg 0 (0.5) [0.5 on Epop[27]], weight: -0.0016545403, delay 1.5
        h("Epop[27] syn_projIE_gaba[1467] = new gaba(0.5)")
        h("Ipop[18] netConn_projIE_gaba[1467] = new NetCon(&v(0.5), syn_projIE_gaba[1467], 20.0, 1.5, -0.0016545403)")  

        # Connection 1468: cell 18, seg 0 (0.5) [0.5 on Ipop[18]] -> cell 28, seg 0 (0.5) [0.5 on Epop[28]], weight: -0.0016545403, delay 1.5
        h("Epop[28] syn_projIE_gaba[1468] = new gaba(0.5)")
        h("Ipop[18] netConn_projIE_gaba[1468] = new NetCon(&v(0.5), syn_projIE_gaba[1468], 20.0, 1.5, -0.0016545403)")  

        # Connection 1469: cell 18, seg 0 (0.5) [0.5 on Ipop[18]] -> cell 29, seg 0 (0.5) [0.5 on Epop[29]], weight: -0.0016545403, delay 1.5
        h("Epop[29] syn_projIE_gaba[1469] = new gaba(0.5)")
        h("Ipop[18] netConn_projIE_gaba[1469] = new NetCon(&v(0.5), syn_projIE_gaba[1469], 20.0, 1.5, -0.0016545403)")  

        # Connection 1470: cell 18, seg 0 (0.5) [0.5 on Ipop[18]] -> cell 30, seg 0 (0.5) [0.5 on Epop[30]], weight: -0.0016545403, delay 1.5
        h("Epop[30] syn_projIE_gaba[1470] = new gaba(0.5)")
        h("Ipop[18] netConn_projIE_gaba[1470] = new NetCon(&v(0.5), syn_projIE_gaba[1470], 20.0, 1.5, -0.0016545403)")  

        # Connection 1471: cell 18, seg 0 (0.5) [0.5 on Ipop[18]] -> cell 31, seg 0 (0.5) [0.5 on Epop[31]], weight: -0.0016545403, delay 1.5
        h("Epop[31] syn_projIE_gaba[1471] = new gaba(0.5)")
        h("Ipop[18] netConn_projIE_gaba[1471] = new NetCon(&v(0.5), syn_projIE_gaba[1471], 20.0, 1.5, -0.0016545403)")  

        # Connection 1472: cell 18, seg 0 (0.5) [0.5 on Ipop[18]] -> cell 32, seg 0 (0.5) [0.5 on Epop[32]], weight: -0.0016545403, delay 1.5
        h("Epop[32] syn_projIE_gaba[1472] = new gaba(0.5)")
        h("Ipop[18] netConn_projIE_gaba[1472] = new NetCon(&v(0.5), syn_projIE_gaba[1472], 20.0, 1.5, -0.0016545403)")  

        # Connection 1473: cell 18, seg 0 (0.5) [0.5 on Ipop[18]] -> cell 33, seg 0 (0.5) [0.5 on Epop[33]], weight: -0.0016545403, delay 1.5
        h("Epop[33] syn_projIE_gaba[1473] = new gaba(0.5)")
        h("Ipop[18] netConn_projIE_gaba[1473] = new NetCon(&v(0.5), syn_projIE_gaba[1473], 20.0, 1.5, -0.0016545403)")  

        # Connection 1474: cell 18, seg 0 (0.5) [0.5 on Ipop[18]] -> cell 34, seg 0 (0.5) [0.5 on Epop[34]], weight: -0.0016545403, delay 1.5
        h("Epop[34] syn_projIE_gaba[1474] = new gaba(0.5)")
        h("Ipop[18] netConn_projIE_gaba[1474] = new NetCon(&v(0.5), syn_projIE_gaba[1474], 20.0, 1.5, -0.0016545403)")  

        # Connection 1475: cell 18, seg 0 (0.5) [0.5 on Ipop[18]] -> cell 35, seg 0 (0.5) [0.5 on Epop[35]], weight: -0.0016545403, delay 1.5
        h("Epop[35] syn_projIE_gaba[1475] = new gaba(0.5)")
        h("Ipop[18] netConn_projIE_gaba[1475] = new NetCon(&v(0.5), syn_projIE_gaba[1475], 20.0, 1.5, -0.0016545403)")  

        # Connection 1476: cell 18, seg 0 (0.5) [0.5 on Ipop[18]] -> cell 36, seg 0 (0.5) [0.5 on Epop[36]], weight: -0.0016545403, delay 1.5
        h("Epop[36] syn_projIE_gaba[1476] = new gaba(0.5)")
        h("Ipop[18] netConn_projIE_gaba[1476] = new NetCon(&v(0.5), syn_projIE_gaba[1476], 20.0, 1.5, -0.0016545403)")  

        # Connection 1477: cell 18, seg 0 (0.5) [0.5 on Ipop[18]] -> cell 37, seg 0 (0.5) [0.5 on Epop[37]], weight: -0.0016545403, delay 1.5
        h("Epop[37] syn_projIE_gaba[1477] = new gaba(0.5)")
        h("Ipop[18] netConn_projIE_gaba[1477] = new NetCon(&v(0.5), syn_projIE_gaba[1477], 20.0, 1.5, -0.0016545403)")  

        # Connection 1478: cell 18, seg 0 (0.5) [0.5 on Ipop[18]] -> cell 38, seg 0 (0.5) [0.5 on Epop[38]], weight: -0.0016545403, delay 1.5
        h("Epop[38] syn_projIE_gaba[1478] = new gaba(0.5)")
        h("Ipop[18] netConn_projIE_gaba[1478] = new NetCon(&v(0.5), syn_projIE_gaba[1478], 20.0, 1.5, -0.0016545403)")  

        # Connection 1479: cell 18, seg 0 (0.5) [0.5 on Ipop[18]] -> cell 39, seg 0 (0.5) [0.5 on Epop[39]], weight: -0.0016545403, delay 1.5
        h("Epop[39] syn_projIE_gaba[1479] = new gaba(0.5)")
        h("Ipop[18] netConn_projIE_gaba[1479] = new NetCon(&v(0.5), syn_projIE_gaba[1479], 20.0, 1.5, -0.0016545403)")  

        # Connection 1480: cell 18, seg 0 (0.5) [0.5 on Ipop[18]] -> cell 40, seg 0 (0.5) [0.5 on Epop[40]], weight: -0.0016545403, delay 1.5
        h("Epop[40] syn_projIE_gaba[1480] = new gaba(0.5)")
        h("Ipop[18] netConn_projIE_gaba[1480] = new NetCon(&v(0.5), syn_projIE_gaba[1480], 20.0, 1.5, -0.0016545403)")  

        # Connection 1481: cell 18, seg 0 (0.5) [0.5 on Ipop[18]] -> cell 41, seg 0 (0.5) [0.5 on Epop[41]], weight: -0.0016545403, delay 1.5
        h("Epop[41] syn_projIE_gaba[1481] = new gaba(0.5)")
        h("Ipop[18] netConn_projIE_gaba[1481] = new NetCon(&v(0.5), syn_projIE_gaba[1481], 20.0, 1.5, -0.0016545403)")  

        # Connection 1482: cell 18, seg 0 (0.5) [0.5 on Ipop[18]] -> cell 42, seg 0 (0.5) [0.5 on Epop[42]], weight: -0.0016545403, delay 1.5
        h("Epop[42] syn_projIE_gaba[1482] = new gaba(0.5)")
        h("Ipop[18] netConn_projIE_gaba[1482] = new NetCon(&v(0.5), syn_projIE_gaba[1482], 20.0, 1.5, -0.0016545403)")  

        # Connection 1483: cell 18, seg 0 (0.5) [0.5 on Ipop[18]] -> cell 43, seg 0 (0.5) [0.5 on Epop[43]], weight: -0.0016545403, delay 1.5
        h("Epop[43] syn_projIE_gaba[1483] = new gaba(0.5)")
        h("Ipop[18] netConn_projIE_gaba[1483] = new NetCon(&v(0.5), syn_projIE_gaba[1483], 20.0, 1.5, -0.0016545403)")  

        # Connection 1484: cell 18, seg 0 (0.5) [0.5 on Ipop[18]] -> cell 44, seg 0 (0.5) [0.5 on Epop[44]], weight: -0.0016545403, delay 1.5
        h("Epop[44] syn_projIE_gaba[1484] = new gaba(0.5)")
        h("Ipop[18] netConn_projIE_gaba[1484] = new NetCon(&v(0.5), syn_projIE_gaba[1484], 20.0, 1.5, -0.0016545403)")  

        # Connection 1485: cell 18, seg 0 (0.5) [0.5 on Ipop[18]] -> cell 45, seg 0 (0.5) [0.5 on Epop[45]], weight: -0.0016545403, delay 1.5
        h("Epop[45] syn_projIE_gaba[1485] = new gaba(0.5)")
        h("Ipop[18] netConn_projIE_gaba[1485] = new NetCon(&v(0.5), syn_projIE_gaba[1485], 20.0, 1.5, -0.0016545403)")  

        # Connection 1486: cell 18, seg 0 (0.5) [0.5 on Ipop[18]] -> cell 46, seg 0 (0.5) [0.5 on Epop[46]], weight: -0.0016545403, delay 1.5
        h("Epop[46] syn_projIE_gaba[1486] = new gaba(0.5)")
        h("Ipop[18] netConn_projIE_gaba[1486] = new NetCon(&v(0.5), syn_projIE_gaba[1486], 20.0, 1.5, -0.0016545403)")  

        # Connection 1487: cell 18, seg 0 (0.5) [0.5 on Ipop[18]] -> cell 47, seg 0 (0.5) [0.5 on Epop[47]], weight: -0.0016545403, delay 1.5
        h("Epop[47] syn_projIE_gaba[1487] = new gaba(0.5)")
        h("Ipop[18] netConn_projIE_gaba[1487] = new NetCon(&v(0.5), syn_projIE_gaba[1487], 20.0, 1.5, -0.0016545403)")  

        # Connection 1488: cell 18, seg 0 (0.5) [0.5 on Ipop[18]] -> cell 48, seg 0 (0.5) [0.5 on Epop[48]], weight: -0.0016545403, delay 1.5
        h("Epop[48] syn_projIE_gaba[1488] = new gaba(0.5)")
        h("Ipop[18] netConn_projIE_gaba[1488] = new NetCon(&v(0.5), syn_projIE_gaba[1488], 20.0, 1.5, -0.0016545403)")  

        # Connection 1489: cell 18, seg 0 (0.5) [0.5 on Ipop[18]] -> cell 49, seg 0 (0.5) [0.5 on Epop[49]], weight: -0.0016545403, delay 1.5
        h("Epop[49] syn_projIE_gaba[1489] = new gaba(0.5)")
        h("Ipop[18] netConn_projIE_gaba[1489] = new NetCon(&v(0.5), syn_projIE_gaba[1489], 20.0, 1.5, -0.0016545403)")  

        # Connection 1490: cell 18, seg 0 (0.5) [0.5 on Ipop[18]] -> cell 50, seg 0 (0.5) [0.5 on Epop[50]], weight: -0.0016545403, delay 1.5
        h("Epop[50] syn_projIE_gaba[1490] = new gaba(0.5)")
        h("Ipop[18] netConn_projIE_gaba[1490] = new NetCon(&v(0.5), syn_projIE_gaba[1490], 20.0, 1.5, -0.0016545403)")  

        # Connection 1491: cell 18, seg 0 (0.5) [0.5 on Ipop[18]] -> cell 51, seg 0 (0.5) [0.5 on Epop[51]], weight: -0.0016545403, delay 1.5
        h("Epop[51] syn_projIE_gaba[1491] = new gaba(0.5)")
        h("Ipop[18] netConn_projIE_gaba[1491] = new NetCon(&v(0.5), syn_projIE_gaba[1491], 20.0, 1.5, -0.0016545403)")  

        # Connection 1492: cell 18, seg 0 (0.5) [0.5 on Ipop[18]] -> cell 52, seg 0 (0.5) [0.5 on Epop[52]], weight: -0.0016545403, delay 1.5
        h("Epop[52] syn_projIE_gaba[1492] = new gaba(0.5)")
        h("Ipop[18] netConn_projIE_gaba[1492] = new NetCon(&v(0.5), syn_projIE_gaba[1492], 20.0, 1.5, -0.0016545403)")  

        # Connection 1493: cell 18, seg 0 (0.5) [0.5 on Ipop[18]] -> cell 53, seg 0 (0.5) [0.5 on Epop[53]], weight: -0.0016545403, delay 1.5
        h("Epop[53] syn_projIE_gaba[1493] = new gaba(0.5)")
        h("Ipop[18] netConn_projIE_gaba[1493] = new NetCon(&v(0.5), syn_projIE_gaba[1493], 20.0, 1.5, -0.0016545403)")  

        # Connection 1494: cell 18, seg 0 (0.5) [0.5 on Ipop[18]] -> cell 54, seg 0 (0.5) [0.5 on Epop[54]], weight: -0.0016545403, delay 1.5
        h("Epop[54] syn_projIE_gaba[1494] = new gaba(0.5)")
        h("Ipop[18] netConn_projIE_gaba[1494] = new NetCon(&v(0.5), syn_projIE_gaba[1494], 20.0, 1.5, -0.0016545403)")  

        # Connection 1495: cell 18, seg 0 (0.5) [0.5 on Ipop[18]] -> cell 55, seg 0 (0.5) [0.5 on Epop[55]], weight: -0.0016545403, delay 1.5
        h("Epop[55] syn_projIE_gaba[1495] = new gaba(0.5)")
        h("Ipop[18] netConn_projIE_gaba[1495] = new NetCon(&v(0.5), syn_projIE_gaba[1495], 20.0, 1.5, -0.0016545403)")  

        # Connection 1496: cell 18, seg 0 (0.5) [0.5 on Ipop[18]] -> cell 56, seg 0 (0.5) [0.5 on Epop[56]], weight: -0.0016545403, delay 1.5
        h("Epop[56] syn_projIE_gaba[1496] = new gaba(0.5)")
        h("Ipop[18] netConn_projIE_gaba[1496] = new NetCon(&v(0.5), syn_projIE_gaba[1496], 20.0, 1.5, -0.0016545403)")  

        # Connection 1497: cell 18, seg 0 (0.5) [0.5 on Ipop[18]] -> cell 57, seg 0 (0.5) [0.5 on Epop[57]], weight: -0.0016545403, delay 1.5
        h("Epop[57] syn_projIE_gaba[1497] = new gaba(0.5)")
        h("Ipop[18] netConn_projIE_gaba[1497] = new NetCon(&v(0.5), syn_projIE_gaba[1497], 20.0, 1.5, -0.0016545403)")  

        # Connection 1498: cell 18, seg 0 (0.5) [0.5 on Ipop[18]] -> cell 58, seg 0 (0.5) [0.5 on Epop[58]], weight: -0.0016545403, delay 1.5
        h("Epop[58] syn_projIE_gaba[1498] = new gaba(0.5)")
        h("Ipop[18] netConn_projIE_gaba[1498] = new NetCon(&v(0.5), syn_projIE_gaba[1498], 20.0, 1.5, -0.0016545403)")  

        # Connection 1499: cell 18, seg 0 (0.5) [0.5 on Ipop[18]] -> cell 59, seg 0 (0.5) [0.5 on Epop[59]], weight: -0.0016545403, delay 1.5
        h("Epop[59] syn_projIE_gaba[1499] = new gaba(0.5)")
        h("Ipop[18] netConn_projIE_gaba[1499] = new NetCon(&v(0.5), syn_projIE_gaba[1499], 20.0, 1.5, -0.0016545403)")  

        # Connection 1500: cell 18, seg 0 (0.5) [0.5 on Ipop[18]] -> cell 60, seg 0 (0.5) [0.5 on Epop[60]], weight: -0.0016545403, delay 1.5
        h("Epop[60] syn_projIE_gaba[1500] = new gaba(0.5)")
        h("Ipop[18] netConn_projIE_gaba[1500] = new NetCon(&v(0.5), syn_projIE_gaba[1500], 20.0, 1.5, -0.0016545403)")  

        # Connection 1501: cell 18, seg 0 (0.5) [0.5 on Ipop[18]] -> cell 61, seg 0 (0.5) [0.5 on Epop[61]], weight: -0.0016545403, delay 1.5
        h("Epop[61] syn_projIE_gaba[1501] = new gaba(0.5)")
        h("Ipop[18] netConn_projIE_gaba[1501] = new NetCon(&v(0.5), syn_projIE_gaba[1501], 20.0, 1.5, -0.0016545403)")  

        # Connection 1502: cell 18, seg 0 (0.5) [0.5 on Ipop[18]] -> cell 62, seg 0 (0.5) [0.5 on Epop[62]], weight: -0.0016545403, delay 1.5
        h("Epop[62] syn_projIE_gaba[1502] = new gaba(0.5)")
        h("Ipop[18] netConn_projIE_gaba[1502] = new NetCon(&v(0.5), syn_projIE_gaba[1502], 20.0, 1.5, -0.0016545403)")  

        # Connection 1503: cell 18, seg 0 (0.5) [0.5 on Ipop[18]] -> cell 63, seg 0 (0.5) [0.5 on Epop[63]], weight: -0.0016545403, delay 1.5
        h("Epop[63] syn_projIE_gaba[1503] = new gaba(0.5)")
        h("Ipop[18] netConn_projIE_gaba[1503] = new NetCon(&v(0.5), syn_projIE_gaba[1503], 20.0, 1.5, -0.0016545403)")  

        # Connection 1504: cell 18, seg 0 (0.5) [0.5 on Ipop[18]] -> cell 64, seg 0 (0.5) [0.5 on Epop[64]], weight: -0.0016545403, delay 1.5
        h("Epop[64] syn_projIE_gaba[1504] = new gaba(0.5)")
        h("Ipop[18] netConn_projIE_gaba[1504] = new NetCon(&v(0.5), syn_projIE_gaba[1504], 20.0, 1.5, -0.0016545403)")  

        # Connection 1505: cell 18, seg 0 (0.5) [0.5 on Ipop[18]] -> cell 65, seg 0 (0.5) [0.5 on Epop[65]], weight: -0.0016545403, delay 1.5
        h("Epop[65] syn_projIE_gaba[1505] = new gaba(0.5)")
        h("Ipop[18] netConn_projIE_gaba[1505] = new NetCon(&v(0.5), syn_projIE_gaba[1505], 20.0, 1.5, -0.0016545403)")  

        # Connection 1506: cell 18, seg 0 (0.5) [0.5 on Ipop[18]] -> cell 66, seg 0 (0.5) [0.5 on Epop[66]], weight: -0.0016545403, delay 1.5
        h("Epop[66] syn_projIE_gaba[1506] = new gaba(0.5)")
        h("Ipop[18] netConn_projIE_gaba[1506] = new NetCon(&v(0.5), syn_projIE_gaba[1506], 20.0, 1.5, -0.0016545403)")  

        # Connection 1507: cell 18, seg 0 (0.5) [0.5 on Ipop[18]] -> cell 67, seg 0 (0.5) [0.5 on Epop[67]], weight: -0.0016545403, delay 1.5
        h("Epop[67] syn_projIE_gaba[1507] = new gaba(0.5)")
        h("Ipop[18] netConn_projIE_gaba[1507] = new NetCon(&v(0.5), syn_projIE_gaba[1507], 20.0, 1.5, -0.0016545403)")  

        # Connection 1508: cell 18, seg 0 (0.5) [0.5 on Ipop[18]] -> cell 68, seg 0 (0.5) [0.5 on Epop[68]], weight: -0.0016545403, delay 1.5
        h("Epop[68] syn_projIE_gaba[1508] = new gaba(0.5)")
        h("Ipop[18] netConn_projIE_gaba[1508] = new NetCon(&v(0.5), syn_projIE_gaba[1508], 20.0, 1.5, -0.0016545403)")  

        # Connection 1509: cell 18, seg 0 (0.5) [0.5 on Ipop[18]] -> cell 69, seg 0 (0.5) [0.5 on Epop[69]], weight: -0.0016545403, delay 1.5
        h("Epop[69] syn_projIE_gaba[1509] = new gaba(0.5)")
        h("Ipop[18] netConn_projIE_gaba[1509] = new NetCon(&v(0.5), syn_projIE_gaba[1509], 20.0, 1.5, -0.0016545403)")  

        # Connection 1510: cell 18, seg 0 (0.5) [0.5 on Ipop[18]] -> cell 70, seg 0 (0.5) [0.5 on Epop[70]], weight: -0.0016545403, delay 1.5
        h("Epop[70] syn_projIE_gaba[1510] = new gaba(0.5)")
        h("Ipop[18] netConn_projIE_gaba[1510] = new NetCon(&v(0.5), syn_projIE_gaba[1510], 20.0, 1.5, -0.0016545403)")  

        # Connection 1511: cell 18, seg 0 (0.5) [0.5 on Ipop[18]] -> cell 71, seg 0 (0.5) [0.5 on Epop[71]], weight: -0.0016545403, delay 1.5
        h("Epop[71] syn_projIE_gaba[1511] = new gaba(0.5)")
        h("Ipop[18] netConn_projIE_gaba[1511] = new NetCon(&v(0.5), syn_projIE_gaba[1511], 20.0, 1.5, -0.0016545403)")  

        # Connection 1512: cell 18, seg 0 (0.5) [0.5 on Ipop[18]] -> cell 72, seg 0 (0.5) [0.5 on Epop[72]], weight: -0.0016545403, delay 1.5
        h("Epop[72] syn_projIE_gaba[1512] = new gaba(0.5)")
        h("Ipop[18] netConn_projIE_gaba[1512] = new NetCon(&v(0.5), syn_projIE_gaba[1512], 20.0, 1.5, -0.0016545403)")  

        # Connection 1513: cell 18, seg 0 (0.5) [0.5 on Ipop[18]] -> cell 73, seg 0 (0.5) [0.5 on Epop[73]], weight: -0.0016545403, delay 1.5
        h("Epop[73] syn_projIE_gaba[1513] = new gaba(0.5)")
        h("Ipop[18] netConn_projIE_gaba[1513] = new NetCon(&v(0.5), syn_projIE_gaba[1513], 20.0, 1.5, -0.0016545403)")  

        # Connection 1514: cell 18, seg 0 (0.5) [0.5 on Ipop[18]] -> cell 74, seg 0 (0.5) [0.5 on Epop[74]], weight: -0.0016545403, delay 1.5
        h("Epop[74] syn_projIE_gaba[1514] = new gaba(0.5)")
        h("Ipop[18] netConn_projIE_gaba[1514] = new NetCon(&v(0.5), syn_projIE_gaba[1514], 20.0, 1.5, -0.0016545403)")  

        # Connection 1515: cell 18, seg 0 (0.5) [0.5 on Ipop[18]] -> cell 75, seg 0 (0.5) [0.5 on Epop[75]], weight: -0.0016545403, delay 1.5
        h("Epop[75] syn_projIE_gaba[1515] = new gaba(0.5)")
        h("Ipop[18] netConn_projIE_gaba[1515] = new NetCon(&v(0.5), syn_projIE_gaba[1515], 20.0, 1.5, -0.0016545403)")  

        # Connection 1516: cell 18, seg 0 (0.5) [0.5 on Ipop[18]] -> cell 76, seg 0 (0.5) [0.5 on Epop[76]], weight: -0.0016545403, delay 1.5
        h("Epop[76] syn_projIE_gaba[1516] = new gaba(0.5)")
        h("Ipop[18] netConn_projIE_gaba[1516] = new NetCon(&v(0.5), syn_projIE_gaba[1516], 20.0, 1.5, -0.0016545403)")  

        # Connection 1517: cell 18, seg 0 (0.5) [0.5 on Ipop[18]] -> cell 77, seg 0 (0.5) [0.5 on Epop[77]], weight: -0.0016545403, delay 1.5
        h("Epop[77] syn_projIE_gaba[1517] = new gaba(0.5)")
        h("Ipop[18] netConn_projIE_gaba[1517] = new NetCon(&v(0.5), syn_projIE_gaba[1517], 20.0, 1.5, -0.0016545403)")  

        # Connection 1518: cell 18, seg 0 (0.5) [0.5 on Ipop[18]] -> cell 78, seg 0 (0.5) [0.5 on Epop[78]], weight: -0.0016545403, delay 1.5
        h("Epop[78] syn_projIE_gaba[1518] = new gaba(0.5)")
        h("Ipop[18] netConn_projIE_gaba[1518] = new NetCon(&v(0.5), syn_projIE_gaba[1518], 20.0, 1.5, -0.0016545403)")  

        # Connection 1519: cell 18, seg 0 (0.5) [0.5 on Ipop[18]] -> cell 79, seg 0 (0.5) [0.5 on Epop[79]], weight: -0.0016545403, delay 1.5
        h("Epop[79] syn_projIE_gaba[1519] = new gaba(0.5)")
        h("Ipop[18] netConn_projIE_gaba[1519] = new NetCon(&v(0.5), syn_projIE_gaba[1519], 20.0, 1.5, -0.0016545403)")  

        # Connection 1520: cell 19, seg 0 (0.5) [0.5 on Ipop[19]] -> cell 0, seg 0 (0.5) [0.5 on Epop[0]], weight: -0.0016545403, delay 1.5
        h("Epop[0] syn_projIE_gaba[1520] = new gaba(0.5)")
        h("Ipop[19] netConn_projIE_gaba[1520] = new NetCon(&v(0.5), syn_projIE_gaba[1520], 20.0, 1.5, -0.0016545403)")  

        # Connection 1521: cell 19, seg 0 (0.5) [0.5 on Ipop[19]] -> cell 1, seg 0 (0.5) [0.5 on Epop[1]], weight: -0.0016545403, delay 1.5
        h("Epop[1] syn_projIE_gaba[1521] = new gaba(0.5)")
        h("Ipop[19] netConn_projIE_gaba[1521] = new NetCon(&v(0.5), syn_projIE_gaba[1521], 20.0, 1.5, -0.0016545403)")  

        # Connection 1522: cell 19, seg 0 (0.5) [0.5 on Ipop[19]] -> cell 2, seg 0 (0.5) [0.5 on Epop[2]], weight: -0.0016545403, delay 1.5
        h("Epop[2] syn_projIE_gaba[1522] = new gaba(0.5)")
        h("Ipop[19] netConn_projIE_gaba[1522] = new NetCon(&v(0.5), syn_projIE_gaba[1522], 20.0, 1.5, -0.0016545403)")  

        # Connection 1523: cell 19, seg 0 (0.5) [0.5 on Ipop[19]] -> cell 3, seg 0 (0.5) [0.5 on Epop[3]], weight: -0.0016545403, delay 1.5
        h("Epop[3] syn_projIE_gaba[1523] = new gaba(0.5)")
        h("Ipop[19] netConn_projIE_gaba[1523] = new NetCon(&v(0.5), syn_projIE_gaba[1523], 20.0, 1.5, -0.0016545403)")  

        # Connection 1524: cell 19, seg 0 (0.5) [0.5 on Ipop[19]] -> cell 4, seg 0 (0.5) [0.5 on Epop[4]], weight: -0.0016545403, delay 1.5
        h("Epop[4] syn_projIE_gaba[1524] = new gaba(0.5)")
        h("Ipop[19] netConn_projIE_gaba[1524] = new NetCon(&v(0.5), syn_projIE_gaba[1524], 20.0, 1.5, -0.0016545403)")  

        # Connection 1525: cell 19, seg 0 (0.5) [0.5 on Ipop[19]] -> cell 5, seg 0 (0.5) [0.5 on Epop[5]], weight: -0.0016545403, delay 1.5
        h("Epop[5] syn_projIE_gaba[1525] = new gaba(0.5)")
        h("Ipop[19] netConn_projIE_gaba[1525] = new NetCon(&v(0.5), syn_projIE_gaba[1525], 20.0, 1.5, -0.0016545403)")  

        # Connection 1526: cell 19, seg 0 (0.5) [0.5 on Ipop[19]] -> cell 6, seg 0 (0.5) [0.5 on Epop[6]], weight: -0.0016545403, delay 1.5
        h("Epop[6] syn_projIE_gaba[1526] = new gaba(0.5)")
        h("Ipop[19] netConn_projIE_gaba[1526] = new NetCon(&v(0.5), syn_projIE_gaba[1526], 20.0, 1.5, -0.0016545403)")  

        # Connection 1527: cell 19, seg 0 (0.5) [0.5 on Ipop[19]] -> cell 7, seg 0 (0.5) [0.5 on Epop[7]], weight: -0.0016545403, delay 1.5
        h("Epop[7] syn_projIE_gaba[1527] = new gaba(0.5)")
        h("Ipop[19] netConn_projIE_gaba[1527] = new NetCon(&v(0.5), syn_projIE_gaba[1527], 20.0, 1.5, -0.0016545403)")  

        # Connection 1528: cell 19, seg 0 (0.5) [0.5 on Ipop[19]] -> cell 8, seg 0 (0.5) [0.5 on Epop[8]], weight: -0.0016545403, delay 1.5
        h("Epop[8] syn_projIE_gaba[1528] = new gaba(0.5)")
        h("Ipop[19] netConn_projIE_gaba[1528] = new NetCon(&v(0.5), syn_projIE_gaba[1528], 20.0, 1.5, -0.0016545403)")  

        # Connection 1529: cell 19, seg 0 (0.5) [0.5 on Ipop[19]] -> cell 9, seg 0 (0.5) [0.5 on Epop[9]], weight: -0.0016545403, delay 1.5
        h("Epop[9] syn_projIE_gaba[1529] = new gaba(0.5)")
        h("Ipop[19] netConn_projIE_gaba[1529] = new NetCon(&v(0.5), syn_projIE_gaba[1529], 20.0, 1.5, -0.0016545403)")  

        # Connection 1530: cell 19, seg 0 (0.5) [0.5 on Ipop[19]] -> cell 10, seg 0 (0.5) [0.5 on Epop[10]], weight: -0.0016545403, delay 1.5
        h("Epop[10] syn_projIE_gaba[1530] = new gaba(0.5)")
        h("Ipop[19] netConn_projIE_gaba[1530] = new NetCon(&v(0.5), syn_projIE_gaba[1530], 20.0, 1.5, -0.0016545403)")  

        # Connection 1531: cell 19, seg 0 (0.5) [0.5 on Ipop[19]] -> cell 11, seg 0 (0.5) [0.5 on Epop[11]], weight: -0.0016545403, delay 1.5
        h("Epop[11] syn_projIE_gaba[1531] = new gaba(0.5)")
        h("Ipop[19] netConn_projIE_gaba[1531] = new NetCon(&v(0.5), syn_projIE_gaba[1531], 20.0, 1.5, -0.0016545403)")  

        # Connection 1532: cell 19, seg 0 (0.5) [0.5 on Ipop[19]] -> cell 12, seg 0 (0.5) [0.5 on Epop[12]], weight: -0.0016545403, delay 1.5
        h("Epop[12] syn_projIE_gaba[1532] = new gaba(0.5)")
        h("Ipop[19] netConn_projIE_gaba[1532] = new NetCon(&v(0.5), syn_projIE_gaba[1532], 20.0, 1.5, -0.0016545403)")  

        # Connection 1533: cell 19, seg 0 (0.5) [0.5 on Ipop[19]] -> cell 13, seg 0 (0.5) [0.5 on Epop[13]], weight: -0.0016545403, delay 1.5
        h("Epop[13] syn_projIE_gaba[1533] = new gaba(0.5)")
        h("Ipop[19] netConn_projIE_gaba[1533] = new NetCon(&v(0.5), syn_projIE_gaba[1533], 20.0, 1.5, -0.0016545403)")  

        # Connection 1534: cell 19, seg 0 (0.5) [0.5 on Ipop[19]] -> cell 14, seg 0 (0.5) [0.5 on Epop[14]], weight: -0.0016545403, delay 1.5
        h("Epop[14] syn_projIE_gaba[1534] = new gaba(0.5)")
        h("Ipop[19] netConn_projIE_gaba[1534] = new NetCon(&v(0.5), syn_projIE_gaba[1534], 20.0, 1.5, -0.0016545403)")  

        # Connection 1535: cell 19, seg 0 (0.5) [0.5 on Ipop[19]] -> cell 15, seg 0 (0.5) [0.5 on Epop[15]], weight: -0.0016545403, delay 1.5
        h("Epop[15] syn_projIE_gaba[1535] = new gaba(0.5)")
        h("Ipop[19] netConn_projIE_gaba[1535] = new NetCon(&v(0.5), syn_projIE_gaba[1535], 20.0, 1.5, -0.0016545403)")  

        # Connection 1536: cell 19, seg 0 (0.5) [0.5 on Ipop[19]] -> cell 16, seg 0 (0.5) [0.5 on Epop[16]], weight: -0.0016545403, delay 1.5
        h("Epop[16] syn_projIE_gaba[1536] = new gaba(0.5)")
        h("Ipop[19] netConn_projIE_gaba[1536] = new NetCon(&v(0.5), syn_projIE_gaba[1536], 20.0, 1.5, -0.0016545403)")  

        # Connection 1537: cell 19, seg 0 (0.5) [0.5 on Ipop[19]] -> cell 17, seg 0 (0.5) [0.5 on Epop[17]], weight: -0.0016545403, delay 1.5
        h("Epop[17] syn_projIE_gaba[1537] = new gaba(0.5)")
        h("Ipop[19] netConn_projIE_gaba[1537] = new NetCon(&v(0.5), syn_projIE_gaba[1537], 20.0, 1.5, -0.0016545403)")  

        # Connection 1538: cell 19, seg 0 (0.5) [0.5 on Ipop[19]] -> cell 18, seg 0 (0.5) [0.5 on Epop[18]], weight: -0.0016545403, delay 1.5
        h("Epop[18] syn_projIE_gaba[1538] = new gaba(0.5)")
        h("Ipop[19] netConn_projIE_gaba[1538] = new NetCon(&v(0.5), syn_projIE_gaba[1538], 20.0, 1.5, -0.0016545403)")  

        # Connection 1539: cell 19, seg 0 (0.5) [0.5 on Ipop[19]] -> cell 19, seg 0 (0.5) [0.5 on Epop[19]], weight: -0.0016545403, delay 1.5
        h("Epop[19] syn_projIE_gaba[1539] = new gaba(0.5)")
        h("Ipop[19] netConn_projIE_gaba[1539] = new NetCon(&v(0.5), syn_projIE_gaba[1539], 20.0, 1.5, -0.0016545403)")  

        # Connection 1540: cell 19, seg 0 (0.5) [0.5 on Ipop[19]] -> cell 20, seg 0 (0.5) [0.5 on Epop[20]], weight: -0.0016545403, delay 1.5
        h("Epop[20] syn_projIE_gaba[1540] = new gaba(0.5)")
        h("Ipop[19] netConn_projIE_gaba[1540] = new NetCon(&v(0.5), syn_projIE_gaba[1540], 20.0, 1.5, -0.0016545403)")  

        # Connection 1541: cell 19, seg 0 (0.5) [0.5 on Ipop[19]] -> cell 21, seg 0 (0.5) [0.5 on Epop[21]], weight: -0.0016545403, delay 1.5
        h("Epop[21] syn_projIE_gaba[1541] = new gaba(0.5)")
        h("Ipop[19] netConn_projIE_gaba[1541] = new NetCon(&v(0.5), syn_projIE_gaba[1541], 20.0, 1.5, -0.0016545403)")  

        # Connection 1542: cell 19, seg 0 (0.5) [0.5 on Ipop[19]] -> cell 22, seg 0 (0.5) [0.5 on Epop[22]], weight: -0.0016545403, delay 1.5
        h("Epop[22] syn_projIE_gaba[1542] = new gaba(0.5)")
        h("Ipop[19] netConn_projIE_gaba[1542] = new NetCon(&v(0.5), syn_projIE_gaba[1542], 20.0, 1.5, -0.0016545403)")  

        # Connection 1543: cell 19, seg 0 (0.5) [0.5 on Ipop[19]] -> cell 23, seg 0 (0.5) [0.5 on Epop[23]], weight: -0.0016545403, delay 1.5
        h("Epop[23] syn_projIE_gaba[1543] = new gaba(0.5)")
        h("Ipop[19] netConn_projIE_gaba[1543] = new NetCon(&v(0.5), syn_projIE_gaba[1543], 20.0, 1.5, -0.0016545403)")  

        # Connection 1544: cell 19, seg 0 (0.5) [0.5 on Ipop[19]] -> cell 24, seg 0 (0.5) [0.5 on Epop[24]], weight: -0.0016545403, delay 1.5
        h("Epop[24] syn_projIE_gaba[1544] = new gaba(0.5)")
        h("Ipop[19] netConn_projIE_gaba[1544] = new NetCon(&v(0.5), syn_projIE_gaba[1544], 20.0, 1.5, -0.0016545403)")  

        # Connection 1545: cell 19, seg 0 (0.5) [0.5 on Ipop[19]] -> cell 25, seg 0 (0.5) [0.5 on Epop[25]], weight: -0.0016545403, delay 1.5
        h("Epop[25] syn_projIE_gaba[1545] = new gaba(0.5)")
        h("Ipop[19] netConn_projIE_gaba[1545] = new NetCon(&v(0.5), syn_projIE_gaba[1545], 20.0, 1.5, -0.0016545403)")  

        # Connection 1546: cell 19, seg 0 (0.5) [0.5 on Ipop[19]] -> cell 26, seg 0 (0.5) [0.5 on Epop[26]], weight: -0.0016545403, delay 1.5
        h("Epop[26] syn_projIE_gaba[1546] = new gaba(0.5)")
        h("Ipop[19] netConn_projIE_gaba[1546] = new NetCon(&v(0.5), syn_projIE_gaba[1546], 20.0, 1.5, -0.0016545403)")  

        # Connection 1547: cell 19, seg 0 (0.5) [0.5 on Ipop[19]] -> cell 27, seg 0 (0.5) [0.5 on Epop[27]], weight: -0.0016545403, delay 1.5
        h("Epop[27] syn_projIE_gaba[1547] = new gaba(0.5)")
        h("Ipop[19] netConn_projIE_gaba[1547] = new NetCon(&v(0.5), syn_projIE_gaba[1547], 20.0, 1.5, -0.0016545403)")  

        # Connection 1548: cell 19, seg 0 (0.5) [0.5 on Ipop[19]] -> cell 28, seg 0 (0.5) [0.5 on Epop[28]], weight: -0.0016545403, delay 1.5
        h("Epop[28] syn_projIE_gaba[1548] = new gaba(0.5)")
        h("Ipop[19] netConn_projIE_gaba[1548] = new NetCon(&v(0.5), syn_projIE_gaba[1548], 20.0, 1.5, -0.0016545403)")  

        # Connection 1549: cell 19, seg 0 (0.5) [0.5 on Ipop[19]] -> cell 29, seg 0 (0.5) [0.5 on Epop[29]], weight: -0.0016545403, delay 1.5
        h("Epop[29] syn_projIE_gaba[1549] = new gaba(0.5)")
        h("Ipop[19] netConn_projIE_gaba[1549] = new NetCon(&v(0.5), syn_projIE_gaba[1549], 20.0, 1.5, -0.0016545403)")  

        # Connection 1550: cell 19, seg 0 (0.5) [0.5 on Ipop[19]] -> cell 30, seg 0 (0.5) [0.5 on Epop[30]], weight: -0.0016545403, delay 1.5
        h("Epop[30] syn_projIE_gaba[1550] = new gaba(0.5)")
        h("Ipop[19] netConn_projIE_gaba[1550] = new NetCon(&v(0.5), syn_projIE_gaba[1550], 20.0, 1.5, -0.0016545403)")  

        # Connection 1551: cell 19, seg 0 (0.5) [0.5 on Ipop[19]] -> cell 31, seg 0 (0.5) [0.5 on Epop[31]], weight: -0.0016545403, delay 1.5
        h("Epop[31] syn_projIE_gaba[1551] = new gaba(0.5)")
        h("Ipop[19] netConn_projIE_gaba[1551] = new NetCon(&v(0.5), syn_projIE_gaba[1551], 20.0, 1.5, -0.0016545403)")  

        # Connection 1552: cell 19, seg 0 (0.5) [0.5 on Ipop[19]] -> cell 32, seg 0 (0.5) [0.5 on Epop[32]], weight: -0.0016545403, delay 1.5
        h("Epop[32] syn_projIE_gaba[1552] = new gaba(0.5)")
        h("Ipop[19] netConn_projIE_gaba[1552] = new NetCon(&v(0.5), syn_projIE_gaba[1552], 20.0, 1.5, -0.0016545403)")  

        # Connection 1553: cell 19, seg 0 (0.5) [0.5 on Ipop[19]] -> cell 33, seg 0 (0.5) [0.5 on Epop[33]], weight: -0.0016545403, delay 1.5
        h("Epop[33] syn_projIE_gaba[1553] = new gaba(0.5)")
        h("Ipop[19] netConn_projIE_gaba[1553] = new NetCon(&v(0.5), syn_projIE_gaba[1553], 20.0, 1.5, -0.0016545403)")  

        # Connection 1554: cell 19, seg 0 (0.5) [0.5 on Ipop[19]] -> cell 34, seg 0 (0.5) [0.5 on Epop[34]], weight: -0.0016545403, delay 1.5
        h("Epop[34] syn_projIE_gaba[1554] = new gaba(0.5)")
        h("Ipop[19] netConn_projIE_gaba[1554] = new NetCon(&v(0.5), syn_projIE_gaba[1554], 20.0, 1.5, -0.0016545403)")  

        # Connection 1555: cell 19, seg 0 (0.5) [0.5 on Ipop[19]] -> cell 35, seg 0 (0.5) [0.5 on Epop[35]], weight: -0.0016545403, delay 1.5
        h("Epop[35] syn_projIE_gaba[1555] = new gaba(0.5)")
        h("Ipop[19] netConn_projIE_gaba[1555] = new NetCon(&v(0.5), syn_projIE_gaba[1555], 20.0, 1.5, -0.0016545403)")  

        # Connection 1556: cell 19, seg 0 (0.5) [0.5 on Ipop[19]] -> cell 36, seg 0 (0.5) [0.5 on Epop[36]], weight: -0.0016545403, delay 1.5
        h("Epop[36] syn_projIE_gaba[1556] = new gaba(0.5)")
        h("Ipop[19] netConn_projIE_gaba[1556] = new NetCon(&v(0.5), syn_projIE_gaba[1556], 20.0, 1.5, -0.0016545403)")  

        # Connection 1557: cell 19, seg 0 (0.5) [0.5 on Ipop[19]] -> cell 37, seg 0 (0.5) [0.5 on Epop[37]], weight: -0.0016545403, delay 1.5
        h("Epop[37] syn_projIE_gaba[1557] = new gaba(0.5)")
        h("Ipop[19] netConn_projIE_gaba[1557] = new NetCon(&v(0.5), syn_projIE_gaba[1557], 20.0, 1.5, -0.0016545403)")  

        # Connection 1558: cell 19, seg 0 (0.5) [0.5 on Ipop[19]] -> cell 38, seg 0 (0.5) [0.5 on Epop[38]], weight: -0.0016545403, delay 1.5
        h("Epop[38] syn_projIE_gaba[1558] = new gaba(0.5)")
        h("Ipop[19] netConn_projIE_gaba[1558] = new NetCon(&v(0.5), syn_projIE_gaba[1558], 20.0, 1.5, -0.0016545403)")  

        # Connection 1559: cell 19, seg 0 (0.5) [0.5 on Ipop[19]] -> cell 39, seg 0 (0.5) [0.5 on Epop[39]], weight: -0.0016545403, delay 1.5
        h("Epop[39] syn_projIE_gaba[1559] = new gaba(0.5)")
        h("Ipop[19] netConn_projIE_gaba[1559] = new NetCon(&v(0.5), syn_projIE_gaba[1559], 20.0, 1.5, -0.0016545403)")  

        # Connection 1560: cell 19, seg 0 (0.5) [0.5 on Ipop[19]] -> cell 40, seg 0 (0.5) [0.5 on Epop[40]], weight: -0.0016545403, delay 1.5
        h("Epop[40] syn_projIE_gaba[1560] = new gaba(0.5)")
        h("Ipop[19] netConn_projIE_gaba[1560] = new NetCon(&v(0.5), syn_projIE_gaba[1560], 20.0, 1.5, -0.0016545403)")  

        # Connection 1561: cell 19, seg 0 (0.5) [0.5 on Ipop[19]] -> cell 41, seg 0 (0.5) [0.5 on Epop[41]], weight: -0.0016545403, delay 1.5
        h("Epop[41] syn_projIE_gaba[1561] = new gaba(0.5)")
        h("Ipop[19] netConn_projIE_gaba[1561] = new NetCon(&v(0.5), syn_projIE_gaba[1561], 20.0, 1.5, -0.0016545403)")  

        # Connection 1562: cell 19, seg 0 (0.5) [0.5 on Ipop[19]] -> cell 42, seg 0 (0.5) [0.5 on Epop[42]], weight: -0.0016545403, delay 1.5
        h("Epop[42] syn_projIE_gaba[1562] = new gaba(0.5)")
        h("Ipop[19] netConn_projIE_gaba[1562] = new NetCon(&v(0.5), syn_projIE_gaba[1562], 20.0, 1.5, -0.0016545403)")  

        # Connection 1563: cell 19, seg 0 (0.5) [0.5 on Ipop[19]] -> cell 43, seg 0 (0.5) [0.5 on Epop[43]], weight: -0.0016545403, delay 1.5
        h("Epop[43] syn_projIE_gaba[1563] = new gaba(0.5)")
        h("Ipop[19] netConn_projIE_gaba[1563] = new NetCon(&v(0.5), syn_projIE_gaba[1563], 20.0, 1.5, -0.0016545403)")  

        # Connection 1564: cell 19, seg 0 (0.5) [0.5 on Ipop[19]] -> cell 44, seg 0 (0.5) [0.5 on Epop[44]], weight: -0.0016545403, delay 1.5
        h("Epop[44] syn_projIE_gaba[1564] = new gaba(0.5)")
        h("Ipop[19] netConn_projIE_gaba[1564] = new NetCon(&v(0.5), syn_projIE_gaba[1564], 20.0, 1.5, -0.0016545403)")  

        # Connection 1565: cell 19, seg 0 (0.5) [0.5 on Ipop[19]] -> cell 45, seg 0 (0.5) [0.5 on Epop[45]], weight: -0.0016545403, delay 1.5
        h("Epop[45] syn_projIE_gaba[1565] = new gaba(0.5)")
        h("Ipop[19] netConn_projIE_gaba[1565] = new NetCon(&v(0.5), syn_projIE_gaba[1565], 20.0, 1.5, -0.0016545403)")  

        # Connection 1566: cell 19, seg 0 (0.5) [0.5 on Ipop[19]] -> cell 46, seg 0 (0.5) [0.5 on Epop[46]], weight: -0.0016545403, delay 1.5
        h("Epop[46] syn_projIE_gaba[1566] = new gaba(0.5)")
        h("Ipop[19] netConn_projIE_gaba[1566] = new NetCon(&v(0.5), syn_projIE_gaba[1566], 20.0, 1.5, -0.0016545403)")  

        # Connection 1567: cell 19, seg 0 (0.5) [0.5 on Ipop[19]] -> cell 47, seg 0 (0.5) [0.5 on Epop[47]], weight: -0.0016545403, delay 1.5
        h("Epop[47] syn_projIE_gaba[1567] = new gaba(0.5)")
        h("Ipop[19] netConn_projIE_gaba[1567] = new NetCon(&v(0.5), syn_projIE_gaba[1567], 20.0, 1.5, -0.0016545403)")  

        # Connection 1568: cell 19, seg 0 (0.5) [0.5 on Ipop[19]] -> cell 48, seg 0 (0.5) [0.5 on Epop[48]], weight: -0.0016545403, delay 1.5
        h("Epop[48] syn_projIE_gaba[1568] = new gaba(0.5)")
        h("Ipop[19] netConn_projIE_gaba[1568] = new NetCon(&v(0.5), syn_projIE_gaba[1568], 20.0, 1.5, -0.0016545403)")  

        # Connection 1569: cell 19, seg 0 (0.5) [0.5 on Ipop[19]] -> cell 49, seg 0 (0.5) [0.5 on Epop[49]], weight: -0.0016545403, delay 1.5
        h("Epop[49] syn_projIE_gaba[1569] = new gaba(0.5)")
        h("Ipop[19] netConn_projIE_gaba[1569] = new NetCon(&v(0.5), syn_projIE_gaba[1569], 20.0, 1.5, -0.0016545403)")  

        # Connection 1570: cell 19, seg 0 (0.5) [0.5 on Ipop[19]] -> cell 50, seg 0 (0.5) [0.5 on Epop[50]], weight: -0.0016545403, delay 1.5
        h("Epop[50] syn_projIE_gaba[1570] = new gaba(0.5)")
        h("Ipop[19] netConn_projIE_gaba[1570] = new NetCon(&v(0.5), syn_projIE_gaba[1570], 20.0, 1.5, -0.0016545403)")  

        # Connection 1571: cell 19, seg 0 (0.5) [0.5 on Ipop[19]] -> cell 51, seg 0 (0.5) [0.5 on Epop[51]], weight: -0.0016545403, delay 1.5
        h("Epop[51] syn_projIE_gaba[1571] = new gaba(0.5)")
        h("Ipop[19] netConn_projIE_gaba[1571] = new NetCon(&v(0.5), syn_projIE_gaba[1571], 20.0, 1.5, -0.0016545403)")  

        # Connection 1572: cell 19, seg 0 (0.5) [0.5 on Ipop[19]] -> cell 52, seg 0 (0.5) [0.5 on Epop[52]], weight: -0.0016545403, delay 1.5
        h("Epop[52] syn_projIE_gaba[1572] = new gaba(0.5)")
        h("Ipop[19] netConn_projIE_gaba[1572] = new NetCon(&v(0.5), syn_projIE_gaba[1572], 20.0, 1.5, -0.0016545403)")  

        # Connection 1573: cell 19, seg 0 (0.5) [0.5 on Ipop[19]] -> cell 53, seg 0 (0.5) [0.5 on Epop[53]], weight: -0.0016545403, delay 1.5
        h("Epop[53] syn_projIE_gaba[1573] = new gaba(0.5)")
        h("Ipop[19] netConn_projIE_gaba[1573] = new NetCon(&v(0.5), syn_projIE_gaba[1573], 20.0, 1.5, -0.0016545403)")  

        # Connection 1574: cell 19, seg 0 (0.5) [0.5 on Ipop[19]] -> cell 54, seg 0 (0.5) [0.5 on Epop[54]], weight: -0.0016545403, delay 1.5
        h("Epop[54] syn_projIE_gaba[1574] = new gaba(0.5)")
        h("Ipop[19] netConn_projIE_gaba[1574] = new NetCon(&v(0.5), syn_projIE_gaba[1574], 20.0, 1.5, -0.0016545403)")  

        # Connection 1575: cell 19, seg 0 (0.5) [0.5 on Ipop[19]] -> cell 55, seg 0 (0.5) [0.5 on Epop[55]], weight: -0.0016545403, delay 1.5
        h("Epop[55] syn_projIE_gaba[1575] = new gaba(0.5)")
        h("Ipop[19] netConn_projIE_gaba[1575] = new NetCon(&v(0.5), syn_projIE_gaba[1575], 20.0, 1.5, -0.0016545403)")  

        # Connection 1576: cell 19, seg 0 (0.5) [0.5 on Ipop[19]] -> cell 56, seg 0 (0.5) [0.5 on Epop[56]], weight: -0.0016545403, delay 1.5
        h("Epop[56] syn_projIE_gaba[1576] = new gaba(0.5)")
        h("Ipop[19] netConn_projIE_gaba[1576] = new NetCon(&v(0.5), syn_projIE_gaba[1576], 20.0, 1.5, -0.0016545403)")  

        # Connection 1577: cell 19, seg 0 (0.5) [0.5 on Ipop[19]] -> cell 57, seg 0 (0.5) [0.5 on Epop[57]], weight: -0.0016545403, delay 1.5
        h("Epop[57] syn_projIE_gaba[1577] = new gaba(0.5)")
        h("Ipop[19] netConn_projIE_gaba[1577] = new NetCon(&v(0.5), syn_projIE_gaba[1577], 20.0, 1.5, -0.0016545403)")  

        # Connection 1578: cell 19, seg 0 (0.5) [0.5 on Ipop[19]] -> cell 58, seg 0 (0.5) [0.5 on Epop[58]], weight: -0.0016545403, delay 1.5
        h("Epop[58] syn_projIE_gaba[1578] = new gaba(0.5)")
        h("Ipop[19] netConn_projIE_gaba[1578] = new NetCon(&v(0.5), syn_projIE_gaba[1578], 20.0, 1.5, -0.0016545403)")  

        # Connection 1579: cell 19, seg 0 (0.5) [0.5 on Ipop[19]] -> cell 59, seg 0 (0.5) [0.5 on Epop[59]], weight: -0.0016545403, delay 1.5
        h("Epop[59] syn_projIE_gaba[1579] = new gaba(0.5)")
        h("Ipop[19] netConn_projIE_gaba[1579] = new NetCon(&v(0.5), syn_projIE_gaba[1579], 20.0, 1.5, -0.0016545403)")  

        # Connection 1580: cell 19, seg 0 (0.5) [0.5 on Ipop[19]] -> cell 60, seg 0 (0.5) [0.5 on Epop[60]], weight: -0.0016545403, delay 1.5
        h("Epop[60] syn_projIE_gaba[1580] = new gaba(0.5)")
        h("Ipop[19] netConn_projIE_gaba[1580] = new NetCon(&v(0.5), syn_projIE_gaba[1580], 20.0, 1.5, -0.0016545403)")  

        # Connection 1581: cell 19, seg 0 (0.5) [0.5 on Ipop[19]] -> cell 61, seg 0 (0.5) [0.5 on Epop[61]], weight: -0.0016545403, delay 1.5
        h("Epop[61] syn_projIE_gaba[1581] = new gaba(0.5)")
        h("Ipop[19] netConn_projIE_gaba[1581] = new NetCon(&v(0.5), syn_projIE_gaba[1581], 20.0, 1.5, -0.0016545403)")  

        # Connection 1582: cell 19, seg 0 (0.5) [0.5 on Ipop[19]] -> cell 62, seg 0 (0.5) [0.5 on Epop[62]], weight: -0.0016545403, delay 1.5
        h("Epop[62] syn_projIE_gaba[1582] = new gaba(0.5)")
        h("Ipop[19] netConn_projIE_gaba[1582] = new NetCon(&v(0.5), syn_projIE_gaba[1582], 20.0, 1.5, -0.0016545403)")  

        # Connection 1583: cell 19, seg 0 (0.5) [0.5 on Ipop[19]] -> cell 63, seg 0 (0.5) [0.5 on Epop[63]], weight: -0.0016545403, delay 1.5
        h("Epop[63] syn_projIE_gaba[1583] = new gaba(0.5)")
        h("Ipop[19] netConn_projIE_gaba[1583] = new NetCon(&v(0.5), syn_projIE_gaba[1583], 20.0, 1.5, -0.0016545403)")  

        # Connection 1584: cell 19, seg 0 (0.5) [0.5 on Ipop[19]] -> cell 64, seg 0 (0.5) [0.5 on Epop[64]], weight: -0.0016545403, delay 1.5
        h("Epop[64] syn_projIE_gaba[1584] = new gaba(0.5)")
        h("Ipop[19] netConn_projIE_gaba[1584] = new NetCon(&v(0.5), syn_projIE_gaba[1584], 20.0, 1.5, -0.0016545403)")  

        # Connection 1585: cell 19, seg 0 (0.5) [0.5 on Ipop[19]] -> cell 65, seg 0 (0.5) [0.5 on Epop[65]], weight: -0.0016545403, delay 1.5
        h("Epop[65] syn_projIE_gaba[1585] = new gaba(0.5)")
        h("Ipop[19] netConn_projIE_gaba[1585] = new NetCon(&v(0.5), syn_projIE_gaba[1585], 20.0, 1.5, -0.0016545403)")  

        # Connection 1586: cell 19, seg 0 (0.5) [0.5 on Ipop[19]] -> cell 66, seg 0 (0.5) [0.5 on Epop[66]], weight: -0.0016545403, delay 1.5
        h("Epop[66] syn_projIE_gaba[1586] = new gaba(0.5)")
        h("Ipop[19] netConn_projIE_gaba[1586] = new NetCon(&v(0.5), syn_projIE_gaba[1586], 20.0, 1.5, -0.0016545403)")  

        # Connection 1587: cell 19, seg 0 (0.5) [0.5 on Ipop[19]] -> cell 67, seg 0 (0.5) [0.5 on Epop[67]], weight: -0.0016545403, delay 1.5
        h("Epop[67] syn_projIE_gaba[1587] = new gaba(0.5)")
        h("Ipop[19] netConn_projIE_gaba[1587] = new NetCon(&v(0.5), syn_projIE_gaba[1587], 20.0, 1.5, -0.0016545403)")  

        # Connection 1588: cell 19, seg 0 (0.5) [0.5 on Ipop[19]] -> cell 68, seg 0 (0.5) [0.5 on Epop[68]], weight: -0.0016545403, delay 1.5
        h("Epop[68] syn_projIE_gaba[1588] = new gaba(0.5)")
        h("Ipop[19] netConn_projIE_gaba[1588] = new NetCon(&v(0.5), syn_projIE_gaba[1588], 20.0, 1.5, -0.0016545403)")  

        # Connection 1589: cell 19, seg 0 (0.5) [0.5 on Ipop[19]] -> cell 69, seg 0 (0.5) [0.5 on Epop[69]], weight: -0.0016545403, delay 1.5
        h("Epop[69] syn_projIE_gaba[1589] = new gaba(0.5)")
        h("Ipop[19] netConn_projIE_gaba[1589] = new NetCon(&v(0.5), syn_projIE_gaba[1589], 20.0, 1.5, -0.0016545403)")  

        # Connection 1590: cell 19, seg 0 (0.5) [0.5 on Ipop[19]] -> cell 70, seg 0 (0.5) [0.5 on Epop[70]], weight: -0.0016545403, delay 1.5
        h("Epop[70] syn_projIE_gaba[1590] = new gaba(0.5)")
        h("Ipop[19] netConn_projIE_gaba[1590] = new NetCon(&v(0.5), syn_projIE_gaba[1590], 20.0, 1.5, -0.0016545403)")  

        # Connection 1591: cell 19, seg 0 (0.5) [0.5 on Ipop[19]] -> cell 71, seg 0 (0.5) [0.5 on Epop[71]], weight: -0.0016545403, delay 1.5
        h("Epop[71] syn_projIE_gaba[1591] = new gaba(0.5)")
        h("Ipop[19] netConn_projIE_gaba[1591] = new NetCon(&v(0.5), syn_projIE_gaba[1591], 20.0, 1.5, -0.0016545403)")  

        # Connection 1592: cell 19, seg 0 (0.5) [0.5 on Ipop[19]] -> cell 72, seg 0 (0.5) [0.5 on Epop[72]], weight: -0.0016545403, delay 1.5
        h("Epop[72] syn_projIE_gaba[1592] = new gaba(0.5)")
        h("Ipop[19] netConn_projIE_gaba[1592] = new NetCon(&v(0.5), syn_projIE_gaba[1592], 20.0, 1.5, -0.0016545403)")  

        # Connection 1593: cell 19, seg 0 (0.5) [0.5 on Ipop[19]] -> cell 73, seg 0 (0.5) [0.5 on Epop[73]], weight: -0.0016545403, delay 1.5
        h("Epop[73] syn_projIE_gaba[1593] = new gaba(0.5)")
        h("Ipop[19] netConn_projIE_gaba[1593] = new NetCon(&v(0.5), syn_projIE_gaba[1593], 20.0, 1.5, -0.0016545403)")  

        # Connection 1594: cell 19, seg 0 (0.5) [0.5 on Ipop[19]] -> cell 74, seg 0 (0.5) [0.5 on Epop[74]], weight: -0.0016545403, delay 1.5
        h("Epop[74] syn_projIE_gaba[1594] = new gaba(0.5)")
        h("Ipop[19] netConn_projIE_gaba[1594] = new NetCon(&v(0.5), syn_projIE_gaba[1594], 20.0, 1.5, -0.0016545403)")  

        # Connection 1595: cell 19, seg 0 (0.5) [0.5 on Ipop[19]] -> cell 75, seg 0 (0.5) [0.5 on Epop[75]], weight: -0.0016545403, delay 1.5
        h("Epop[75] syn_projIE_gaba[1595] = new gaba(0.5)")
        h("Ipop[19] netConn_projIE_gaba[1595] = new NetCon(&v(0.5), syn_projIE_gaba[1595], 20.0, 1.5, -0.0016545403)")  

        # Connection 1596: cell 19, seg 0 (0.5) [0.5 on Ipop[19]] -> cell 76, seg 0 (0.5) [0.5 on Epop[76]], weight: -0.0016545403, delay 1.5
        h("Epop[76] syn_projIE_gaba[1596] = new gaba(0.5)")
        h("Ipop[19] netConn_projIE_gaba[1596] = new NetCon(&v(0.5), syn_projIE_gaba[1596], 20.0, 1.5, -0.0016545403)")  

        # Connection 1597: cell 19, seg 0 (0.5) [0.5 on Ipop[19]] -> cell 77, seg 0 (0.5) [0.5 on Epop[77]], weight: -0.0016545403, delay 1.5
        h("Epop[77] syn_projIE_gaba[1597] = new gaba(0.5)")
        h("Ipop[19] netConn_projIE_gaba[1597] = new NetCon(&v(0.5), syn_projIE_gaba[1597], 20.0, 1.5, -0.0016545403)")  

        # Connection 1598: cell 19, seg 0 (0.5) [0.5 on Ipop[19]] -> cell 78, seg 0 (0.5) [0.5 on Epop[78]], weight: -0.0016545403, delay 1.5
        h("Epop[78] syn_projIE_gaba[1598] = new gaba(0.5)")
        h("Ipop[19] netConn_projIE_gaba[1598] = new NetCon(&v(0.5), syn_projIE_gaba[1598], 20.0, 1.5, -0.0016545403)")  

        # Connection 1599: cell 19, seg 0 (0.5) [0.5 on Ipop[19]] -> cell 79, seg 0 (0.5) [0.5 on Epop[79]], weight: -0.0016545403, delay 1.5
        h("Epop[79] syn_projIE_gaba[1599] = new gaba(0.5)")
        h("Ipop[19] netConn_projIE_gaba[1599] = new NetCon(&v(0.5), syn_projIE_gaba[1599], 20.0, 1.5, -0.0016545403)")  

        # ######################   Projection: projII
        print("Adding projection: projII, from Ipop to Ipop with synapse gaba, 400 connection(s)")

        h("objectvar syn_projII_gaba[400]")

        h("objectvar netConn_projII_gaba[400]")

        # Connection 0: cell 0, seg 0 (0.5) [0.5 on Ipop[0]] -> cell 0, seg 0 (0.5) [0.5 on Ipop[0]], weight: -0.0016545403, delay 1.5
        h("Ipop[0] syn_projII_gaba[0] = new gaba(0.5)")
        h("Ipop[0] netConn_projII_gaba[0] = new NetCon(&v(0.5), syn_projII_gaba[0], 20.0, 1.5, -0.0016545403)")  

        # Connection 1: cell 0, seg 0 (0.5) [0.5 on Ipop[0]] -> cell 1, seg 0 (0.5) [0.5 on Ipop[1]], weight: -0.0016545403, delay 1.5
        h("Ipop[1] syn_projII_gaba[1] = new gaba(0.5)")
        h("Ipop[0] netConn_projII_gaba[1] = new NetCon(&v(0.5), syn_projII_gaba[1], 20.0, 1.5, -0.0016545403)")  

        # Connection 2: cell 0, seg 0 (0.5) [0.5 on Ipop[0]] -> cell 2, seg 0 (0.5) [0.5 on Ipop[2]], weight: -0.0016545403, delay 1.5
        h("Ipop[2] syn_projII_gaba[2] = new gaba(0.5)")
        h("Ipop[0] netConn_projII_gaba[2] = new NetCon(&v(0.5), syn_projII_gaba[2], 20.0, 1.5, -0.0016545403)")  

        # Connection 3: cell 0, seg 0 (0.5) [0.5 on Ipop[0]] -> cell 3, seg 0 (0.5) [0.5 on Ipop[3]], weight: -0.0016545403, delay 1.5
        h("Ipop[3] syn_projII_gaba[3] = new gaba(0.5)")
        h("Ipop[0] netConn_projII_gaba[3] = new NetCon(&v(0.5), syn_projII_gaba[3], 20.0, 1.5, -0.0016545403)")  

        # Connection 4: cell 0, seg 0 (0.5) [0.5 on Ipop[0]] -> cell 4, seg 0 (0.5) [0.5 on Ipop[4]], weight: -0.0016545403, delay 1.5
        h("Ipop[4] syn_projII_gaba[4] = new gaba(0.5)")
        h("Ipop[0] netConn_projII_gaba[4] = new NetCon(&v(0.5), syn_projII_gaba[4], 20.0, 1.5, -0.0016545403)")  

        # Connection 5: cell 0, seg 0 (0.5) [0.5 on Ipop[0]] -> cell 5, seg 0 (0.5) [0.5 on Ipop[5]], weight: -0.0016545403, delay 1.5
        h("Ipop[5] syn_projII_gaba[5] = new gaba(0.5)")
        h("Ipop[0] netConn_projII_gaba[5] = new NetCon(&v(0.5), syn_projII_gaba[5], 20.0, 1.5, -0.0016545403)")  

        # Connection 6: cell 0, seg 0 (0.5) [0.5 on Ipop[0]] -> cell 6, seg 0 (0.5) [0.5 on Ipop[6]], weight: -0.0016545403, delay 1.5
        h("Ipop[6] syn_projII_gaba[6] = new gaba(0.5)")
        h("Ipop[0] netConn_projII_gaba[6] = new NetCon(&v(0.5), syn_projII_gaba[6], 20.0, 1.5, -0.0016545403)")  

        # Connection 7: cell 0, seg 0 (0.5) [0.5 on Ipop[0]] -> cell 7, seg 0 (0.5) [0.5 on Ipop[7]], weight: -0.0016545403, delay 1.5
        h("Ipop[7] syn_projII_gaba[7] = new gaba(0.5)")
        h("Ipop[0] netConn_projII_gaba[7] = new NetCon(&v(0.5), syn_projII_gaba[7], 20.0, 1.5, -0.0016545403)")  

        # Connection 8: cell 0, seg 0 (0.5) [0.5 on Ipop[0]] -> cell 8, seg 0 (0.5) [0.5 on Ipop[8]], weight: -0.0016545403, delay 1.5
        h("Ipop[8] syn_projII_gaba[8] = new gaba(0.5)")
        h("Ipop[0] netConn_projII_gaba[8] = new NetCon(&v(0.5), syn_projII_gaba[8], 20.0, 1.5, -0.0016545403)")  

        # Connection 9: cell 0, seg 0 (0.5) [0.5 on Ipop[0]] -> cell 9, seg 0 (0.5) [0.5 on Ipop[9]], weight: -0.0016545403, delay 1.5
        h("Ipop[9] syn_projII_gaba[9] = new gaba(0.5)")
        h("Ipop[0] netConn_projII_gaba[9] = new NetCon(&v(0.5), syn_projII_gaba[9], 20.0, 1.5, -0.0016545403)")  

        # Connection 10: cell 0, seg 0 (0.5) [0.5 on Ipop[0]] -> cell 10, seg 0 (0.5) [0.5 on Ipop[10]], weight: -0.0016545403, delay 1.5
        h("Ipop[10] syn_projII_gaba[10] = new gaba(0.5)")
        h("Ipop[0] netConn_projII_gaba[10] = new NetCon(&v(0.5), syn_projII_gaba[10], 20.0, 1.5, -0.0016545403)")  

        # Connection 11: cell 0, seg 0 (0.5) [0.5 on Ipop[0]] -> cell 11, seg 0 (0.5) [0.5 on Ipop[11]], weight: -0.0016545403, delay 1.5
        h("Ipop[11] syn_projII_gaba[11] = new gaba(0.5)")
        h("Ipop[0] netConn_projII_gaba[11] = new NetCon(&v(0.5), syn_projII_gaba[11], 20.0, 1.5, -0.0016545403)")  

        # Connection 12: cell 0, seg 0 (0.5) [0.5 on Ipop[0]] -> cell 12, seg 0 (0.5) [0.5 on Ipop[12]], weight: -0.0016545403, delay 1.5
        h("Ipop[12] syn_projII_gaba[12] = new gaba(0.5)")
        h("Ipop[0] netConn_projII_gaba[12] = new NetCon(&v(0.5), syn_projII_gaba[12], 20.0, 1.5, -0.0016545403)")  

        # Connection 13: cell 0, seg 0 (0.5) [0.5 on Ipop[0]] -> cell 13, seg 0 (0.5) [0.5 on Ipop[13]], weight: -0.0016545403, delay 1.5
        h("Ipop[13] syn_projII_gaba[13] = new gaba(0.5)")
        h("Ipop[0] netConn_projII_gaba[13] = new NetCon(&v(0.5), syn_projII_gaba[13], 20.0, 1.5, -0.0016545403)")  

        # Connection 14: cell 0, seg 0 (0.5) [0.5 on Ipop[0]] -> cell 14, seg 0 (0.5) [0.5 on Ipop[14]], weight: -0.0016545403, delay 1.5
        h("Ipop[14] syn_projII_gaba[14] = new gaba(0.5)")
        h("Ipop[0] netConn_projII_gaba[14] = new NetCon(&v(0.5), syn_projII_gaba[14], 20.0, 1.5, -0.0016545403)")  

        # Connection 15: cell 0, seg 0 (0.5) [0.5 on Ipop[0]] -> cell 15, seg 0 (0.5) [0.5 on Ipop[15]], weight: -0.0016545403, delay 1.5
        h("Ipop[15] syn_projII_gaba[15] = new gaba(0.5)")
        h("Ipop[0] netConn_projII_gaba[15] = new NetCon(&v(0.5), syn_projII_gaba[15], 20.0, 1.5, -0.0016545403)")  

        # Connection 16: cell 0, seg 0 (0.5) [0.5 on Ipop[0]] -> cell 16, seg 0 (0.5) [0.5 on Ipop[16]], weight: -0.0016545403, delay 1.5
        h("Ipop[16] syn_projII_gaba[16] = new gaba(0.5)")
        h("Ipop[0] netConn_projII_gaba[16] = new NetCon(&v(0.5), syn_projII_gaba[16], 20.0, 1.5, -0.0016545403)")  

        # Connection 17: cell 0, seg 0 (0.5) [0.5 on Ipop[0]] -> cell 17, seg 0 (0.5) [0.5 on Ipop[17]], weight: -0.0016545403, delay 1.5
        h("Ipop[17] syn_projII_gaba[17] = new gaba(0.5)")
        h("Ipop[0] netConn_projII_gaba[17] = new NetCon(&v(0.5), syn_projII_gaba[17], 20.0, 1.5, -0.0016545403)")  

        # Connection 18: cell 0, seg 0 (0.5) [0.5 on Ipop[0]] -> cell 18, seg 0 (0.5) [0.5 on Ipop[18]], weight: -0.0016545403, delay 1.5
        h("Ipop[18] syn_projII_gaba[18] = new gaba(0.5)")
        h("Ipop[0] netConn_projII_gaba[18] = new NetCon(&v(0.5), syn_projII_gaba[18], 20.0, 1.5, -0.0016545403)")  

        # Connection 19: cell 0, seg 0 (0.5) [0.5 on Ipop[0]] -> cell 19, seg 0 (0.5) [0.5 on Ipop[19]], weight: -0.0016545403, delay 1.5
        h("Ipop[19] syn_projII_gaba[19] = new gaba(0.5)")
        h("Ipop[0] netConn_projII_gaba[19] = new NetCon(&v(0.5), syn_projII_gaba[19], 20.0, 1.5, -0.0016545403)")  

        # Connection 20: cell 1, seg 0 (0.5) [0.5 on Ipop[1]] -> cell 0, seg 0 (0.5) [0.5 on Ipop[0]], weight: -0.0016545403, delay 1.5
        h("Ipop[0] syn_projII_gaba[20] = new gaba(0.5)")
        h("Ipop[1] netConn_projII_gaba[20] = new NetCon(&v(0.5), syn_projII_gaba[20], 20.0, 1.5, -0.0016545403)")  

        # Connection 21: cell 1, seg 0 (0.5) [0.5 on Ipop[1]] -> cell 1, seg 0 (0.5) [0.5 on Ipop[1]], weight: -0.0016545403, delay 1.5
        h("Ipop[1] syn_projII_gaba[21] = new gaba(0.5)")
        h("Ipop[1] netConn_projII_gaba[21] = new NetCon(&v(0.5), syn_projII_gaba[21], 20.0, 1.5, -0.0016545403)")  

        # Connection 22: cell 1, seg 0 (0.5) [0.5 on Ipop[1]] -> cell 2, seg 0 (0.5) [0.5 on Ipop[2]], weight: -0.0016545403, delay 1.5
        h("Ipop[2] syn_projII_gaba[22] = new gaba(0.5)")
        h("Ipop[1] netConn_projII_gaba[22] = new NetCon(&v(0.5), syn_projII_gaba[22], 20.0, 1.5, -0.0016545403)")  

        # Connection 23: cell 1, seg 0 (0.5) [0.5 on Ipop[1]] -> cell 3, seg 0 (0.5) [0.5 on Ipop[3]], weight: -0.0016545403, delay 1.5
        h("Ipop[3] syn_projII_gaba[23] = new gaba(0.5)")
        h("Ipop[1] netConn_projII_gaba[23] = new NetCon(&v(0.5), syn_projII_gaba[23], 20.0, 1.5, -0.0016545403)")  

        # Connection 24: cell 1, seg 0 (0.5) [0.5 on Ipop[1]] -> cell 4, seg 0 (0.5) [0.5 on Ipop[4]], weight: -0.0016545403, delay 1.5
        h("Ipop[4] syn_projII_gaba[24] = new gaba(0.5)")
        h("Ipop[1] netConn_projII_gaba[24] = new NetCon(&v(0.5), syn_projII_gaba[24], 20.0, 1.5, -0.0016545403)")  

        # Connection 25: cell 1, seg 0 (0.5) [0.5 on Ipop[1]] -> cell 5, seg 0 (0.5) [0.5 on Ipop[5]], weight: -0.0016545403, delay 1.5
        h("Ipop[5] syn_projII_gaba[25] = new gaba(0.5)")
        h("Ipop[1] netConn_projII_gaba[25] = new NetCon(&v(0.5), syn_projII_gaba[25], 20.0, 1.5, -0.0016545403)")  

        # Connection 26: cell 1, seg 0 (0.5) [0.5 on Ipop[1]] -> cell 6, seg 0 (0.5) [0.5 on Ipop[6]], weight: -0.0016545403, delay 1.5
        h("Ipop[6] syn_projII_gaba[26] = new gaba(0.5)")
        h("Ipop[1] netConn_projII_gaba[26] = new NetCon(&v(0.5), syn_projII_gaba[26], 20.0, 1.5, -0.0016545403)")  

        # Connection 27: cell 1, seg 0 (0.5) [0.5 on Ipop[1]] -> cell 7, seg 0 (0.5) [0.5 on Ipop[7]], weight: -0.0016545403, delay 1.5
        h("Ipop[7] syn_projII_gaba[27] = new gaba(0.5)")
        h("Ipop[1] netConn_projII_gaba[27] = new NetCon(&v(0.5), syn_projII_gaba[27], 20.0, 1.5, -0.0016545403)")  

        # Connection 28: cell 1, seg 0 (0.5) [0.5 on Ipop[1]] -> cell 8, seg 0 (0.5) [0.5 on Ipop[8]], weight: -0.0016545403, delay 1.5
        h("Ipop[8] syn_projII_gaba[28] = new gaba(0.5)")
        h("Ipop[1] netConn_projII_gaba[28] = new NetCon(&v(0.5), syn_projII_gaba[28], 20.0, 1.5, -0.0016545403)")  

        # Connection 29: cell 1, seg 0 (0.5) [0.5 on Ipop[1]] -> cell 9, seg 0 (0.5) [0.5 on Ipop[9]], weight: -0.0016545403, delay 1.5
        h("Ipop[9] syn_projII_gaba[29] = new gaba(0.5)")
        h("Ipop[1] netConn_projII_gaba[29] = new NetCon(&v(0.5), syn_projII_gaba[29], 20.0, 1.5, -0.0016545403)")  

        # Connection 30: cell 1, seg 0 (0.5) [0.5 on Ipop[1]] -> cell 10, seg 0 (0.5) [0.5 on Ipop[10]], weight: -0.0016545403, delay 1.5
        h("Ipop[10] syn_projII_gaba[30] = new gaba(0.5)")
        h("Ipop[1] netConn_projII_gaba[30] = new NetCon(&v(0.5), syn_projII_gaba[30], 20.0, 1.5, -0.0016545403)")  

        # Connection 31: cell 1, seg 0 (0.5) [0.5 on Ipop[1]] -> cell 11, seg 0 (0.5) [0.5 on Ipop[11]], weight: -0.0016545403, delay 1.5
        h("Ipop[11] syn_projII_gaba[31] = new gaba(0.5)")
        h("Ipop[1] netConn_projII_gaba[31] = new NetCon(&v(0.5), syn_projII_gaba[31], 20.0, 1.5, -0.0016545403)")  

        # Connection 32: cell 1, seg 0 (0.5) [0.5 on Ipop[1]] -> cell 12, seg 0 (0.5) [0.5 on Ipop[12]], weight: -0.0016545403, delay 1.5
        h("Ipop[12] syn_projII_gaba[32] = new gaba(0.5)")
        h("Ipop[1] netConn_projII_gaba[32] = new NetCon(&v(0.5), syn_projII_gaba[32], 20.0, 1.5, -0.0016545403)")  

        # Connection 33: cell 1, seg 0 (0.5) [0.5 on Ipop[1]] -> cell 13, seg 0 (0.5) [0.5 on Ipop[13]], weight: -0.0016545403, delay 1.5
        h("Ipop[13] syn_projII_gaba[33] = new gaba(0.5)")
        h("Ipop[1] netConn_projII_gaba[33] = new NetCon(&v(0.5), syn_projII_gaba[33], 20.0, 1.5, -0.0016545403)")  

        # Connection 34: cell 1, seg 0 (0.5) [0.5 on Ipop[1]] -> cell 14, seg 0 (0.5) [0.5 on Ipop[14]], weight: -0.0016545403, delay 1.5
        h("Ipop[14] syn_projII_gaba[34] = new gaba(0.5)")
        h("Ipop[1] netConn_projII_gaba[34] = new NetCon(&v(0.5), syn_projII_gaba[34], 20.0, 1.5, -0.0016545403)")  

        # Connection 35: cell 1, seg 0 (0.5) [0.5 on Ipop[1]] -> cell 15, seg 0 (0.5) [0.5 on Ipop[15]], weight: -0.0016545403, delay 1.5
        h("Ipop[15] syn_projII_gaba[35] = new gaba(0.5)")
        h("Ipop[1] netConn_projII_gaba[35] = new NetCon(&v(0.5), syn_projII_gaba[35], 20.0, 1.5, -0.0016545403)")  

        # Connection 36: cell 1, seg 0 (0.5) [0.5 on Ipop[1]] -> cell 16, seg 0 (0.5) [0.5 on Ipop[16]], weight: -0.0016545403, delay 1.5
        h("Ipop[16] syn_projII_gaba[36] = new gaba(0.5)")
        h("Ipop[1] netConn_projII_gaba[36] = new NetCon(&v(0.5), syn_projII_gaba[36], 20.0, 1.5, -0.0016545403)")  

        # Connection 37: cell 1, seg 0 (0.5) [0.5 on Ipop[1]] -> cell 17, seg 0 (0.5) [0.5 on Ipop[17]], weight: -0.0016545403, delay 1.5
        h("Ipop[17] syn_projII_gaba[37] = new gaba(0.5)")
        h("Ipop[1] netConn_projII_gaba[37] = new NetCon(&v(0.5), syn_projII_gaba[37], 20.0, 1.5, -0.0016545403)")  

        # Connection 38: cell 1, seg 0 (0.5) [0.5 on Ipop[1]] -> cell 18, seg 0 (0.5) [0.5 on Ipop[18]], weight: -0.0016545403, delay 1.5
        h("Ipop[18] syn_projII_gaba[38] = new gaba(0.5)")
        h("Ipop[1] netConn_projII_gaba[38] = new NetCon(&v(0.5), syn_projII_gaba[38], 20.0, 1.5, -0.0016545403)")  

        # Connection 39: cell 1, seg 0 (0.5) [0.5 on Ipop[1]] -> cell 19, seg 0 (0.5) [0.5 on Ipop[19]], weight: -0.0016545403, delay 1.5
        h("Ipop[19] syn_projII_gaba[39] = new gaba(0.5)")
        h("Ipop[1] netConn_projII_gaba[39] = new NetCon(&v(0.5), syn_projII_gaba[39], 20.0, 1.5, -0.0016545403)")  

        # Connection 40: cell 2, seg 0 (0.5) [0.5 on Ipop[2]] -> cell 0, seg 0 (0.5) [0.5 on Ipop[0]], weight: -0.0016545403, delay 1.5
        h("Ipop[0] syn_projII_gaba[40] = new gaba(0.5)")
        h("Ipop[2] netConn_projII_gaba[40] = new NetCon(&v(0.5), syn_projII_gaba[40], 20.0, 1.5, -0.0016545403)")  

        # Connection 41: cell 2, seg 0 (0.5) [0.5 on Ipop[2]] -> cell 1, seg 0 (0.5) [0.5 on Ipop[1]], weight: -0.0016545403, delay 1.5
        h("Ipop[1] syn_projII_gaba[41] = new gaba(0.5)")
        h("Ipop[2] netConn_projII_gaba[41] = new NetCon(&v(0.5), syn_projII_gaba[41], 20.0, 1.5, -0.0016545403)")  

        # Connection 42: cell 2, seg 0 (0.5) [0.5 on Ipop[2]] -> cell 2, seg 0 (0.5) [0.5 on Ipop[2]], weight: -0.0016545403, delay 1.5
        h("Ipop[2] syn_projII_gaba[42] = new gaba(0.5)")
        h("Ipop[2] netConn_projII_gaba[42] = new NetCon(&v(0.5), syn_projII_gaba[42], 20.0, 1.5, -0.0016545403)")  

        # Connection 43: cell 2, seg 0 (0.5) [0.5 on Ipop[2]] -> cell 3, seg 0 (0.5) [0.5 on Ipop[3]], weight: -0.0016545403, delay 1.5
        h("Ipop[3] syn_projII_gaba[43] = new gaba(0.5)")
        h("Ipop[2] netConn_projII_gaba[43] = new NetCon(&v(0.5), syn_projII_gaba[43], 20.0, 1.5, -0.0016545403)")  

        # Connection 44: cell 2, seg 0 (0.5) [0.5 on Ipop[2]] -> cell 4, seg 0 (0.5) [0.5 on Ipop[4]], weight: -0.0016545403, delay 1.5
        h("Ipop[4] syn_projII_gaba[44] = new gaba(0.5)")
        h("Ipop[2] netConn_projII_gaba[44] = new NetCon(&v(0.5), syn_projII_gaba[44], 20.0, 1.5, -0.0016545403)")  

        # Connection 45: cell 2, seg 0 (0.5) [0.5 on Ipop[2]] -> cell 5, seg 0 (0.5) [0.5 on Ipop[5]], weight: -0.0016545403, delay 1.5
        h("Ipop[5] syn_projII_gaba[45] = new gaba(0.5)")
        h("Ipop[2] netConn_projII_gaba[45] = new NetCon(&v(0.5), syn_projII_gaba[45], 20.0, 1.5, -0.0016545403)")  

        # Connection 46: cell 2, seg 0 (0.5) [0.5 on Ipop[2]] -> cell 6, seg 0 (0.5) [0.5 on Ipop[6]], weight: -0.0016545403, delay 1.5
        h("Ipop[6] syn_projII_gaba[46] = new gaba(0.5)")
        h("Ipop[2] netConn_projII_gaba[46] = new NetCon(&v(0.5), syn_projII_gaba[46], 20.0, 1.5, -0.0016545403)")  

        # Connection 47: cell 2, seg 0 (0.5) [0.5 on Ipop[2]] -> cell 7, seg 0 (0.5) [0.5 on Ipop[7]], weight: -0.0016545403, delay 1.5
        h("Ipop[7] syn_projII_gaba[47] = new gaba(0.5)")
        h("Ipop[2] netConn_projII_gaba[47] = new NetCon(&v(0.5), syn_projII_gaba[47], 20.0, 1.5, -0.0016545403)")  

        # Connection 48: cell 2, seg 0 (0.5) [0.5 on Ipop[2]] -> cell 8, seg 0 (0.5) [0.5 on Ipop[8]], weight: -0.0016545403, delay 1.5
        h("Ipop[8] syn_projII_gaba[48] = new gaba(0.5)")
        h("Ipop[2] netConn_projII_gaba[48] = new NetCon(&v(0.5), syn_projII_gaba[48], 20.0, 1.5, -0.0016545403)")  

        # Connection 49: cell 2, seg 0 (0.5) [0.5 on Ipop[2]] -> cell 9, seg 0 (0.5) [0.5 on Ipop[9]], weight: -0.0016545403, delay 1.5
        h("Ipop[9] syn_projII_gaba[49] = new gaba(0.5)")
        h("Ipop[2] netConn_projII_gaba[49] = new NetCon(&v(0.5), syn_projII_gaba[49], 20.0, 1.5, -0.0016545403)")  

        # Connection 50: cell 2, seg 0 (0.5) [0.5 on Ipop[2]] -> cell 10, seg 0 (0.5) [0.5 on Ipop[10]], weight: -0.0016545403, delay 1.5
        h("Ipop[10] syn_projII_gaba[50] = new gaba(0.5)")
        h("Ipop[2] netConn_projII_gaba[50] = new NetCon(&v(0.5), syn_projII_gaba[50], 20.0, 1.5, -0.0016545403)")  

        # Connection 51: cell 2, seg 0 (0.5) [0.5 on Ipop[2]] -> cell 11, seg 0 (0.5) [0.5 on Ipop[11]], weight: -0.0016545403, delay 1.5
        h("Ipop[11] syn_projII_gaba[51] = new gaba(0.5)")
        h("Ipop[2] netConn_projII_gaba[51] = new NetCon(&v(0.5), syn_projII_gaba[51], 20.0, 1.5, -0.0016545403)")  

        # Connection 52: cell 2, seg 0 (0.5) [0.5 on Ipop[2]] -> cell 12, seg 0 (0.5) [0.5 on Ipop[12]], weight: -0.0016545403, delay 1.5
        h("Ipop[12] syn_projII_gaba[52] = new gaba(0.5)")
        h("Ipop[2] netConn_projII_gaba[52] = new NetCon(&v(0.5), syn_projII_gaba[52], 20.0, 1.5, -0.0016545403)")  

        # Connection 53: cell 2, seg 0 (0.5) [0.5 on Ipop[2]] -> cell 13, seg 0 (0.5) [0.5 on Ipop[13]], weight: -0.0016545403, delay 1.5
        h("Ipop[13] syn_projII_gaba[53] = new gaba(0.5)")
        h("Ipop[2] netConn_projII_gaba[53] = new NetCon(&v(0.5), syn_projII_gaba[53], 20.0, 1.5, -0.0016545403)")  

        # Connection 54: cell 2, seg 0 (0.5) [0.5 on Ipop[2]] -> cell 14, seg 0 (0.5) [0.5 on Ipop[14]], weight: -0.0016545403, delay 1.5
        h("Ipop[14] syn_projII_gaba[54] = new gaba(0.5)")
        h("Ipop[2] netConn_projII_gaba[54] = new NetCon(&v(0.5), syn_projII_gaba[54], 20.0, 1.5, -0.0016545403)")  

        # Connection 55: cell 2, seg 0 (0.5) [0.5 on Ipop[2]] -> cell 15, seg 0 (0.5) [0.5 on Ipop[15]], weight: -0.0016545403, delay 1.5
        h("Ipop[15] syn_projII_gaba[55] = new gaba(0.5)")
        h("Ipop[2] netConn_projII_gaba[55] = new NetCon(&v(0.5), syn_projII_gaba[55], 20.0, 1.5, -0.0016545403)")  

        # Connection 56: cell 2, seg 0 (0.5) [0.5 on Ipop[2]] -> cell 16, seg 0 (0.5) [0.5 on Ipop[16]], weight: -0.0016545403, delay 1.5
        h("Ipop[16] syn_projII_gaba[56] = new gaba(0.5)")
        h("Ipop[2] netConn_projII_gaba[56] = new NetCon(&v(0.5), syn_projII_gaba[56], 20.0, 1.5, -0.0016545403)")  

        # Connection 57: cell 2, seg 0 (0.5) [0.5 on Ipop[2]] -> cell 17, seg 0 (0.5) [0.5 on Ipop[17]], weight: -0.0016545403, delay 1.5
        h("Ipop[17] syn_projII_gaba[57] = new gaba(0.5)")
        h("Ipop[2] netConn_projII_gaba[57] = new NetCon(&v(0.5), syn_projII_gaba[57], 20.0, 1.5, -0.0016545403)")  

        # Connection 58: cell 2, seg 0 (0.5) [0.5 on Ipop[2]] -> cell 18, seg 0 (0.5) [0.5 on Ipop[18]], weight: -0.0016545403, delay 1.5
        h("Ipop[18] syn_projII_gaba[58] = new gaba(0.5)")
        h("Ipop[2] netConn_projII_gaba[58] = new NetCon(&v(0.5), syn_projII_gaba[58], 20.0, 1.5, -0.0016545403)")  

        # Connection 59: cell 2, seg 0 (0.5) [0.5 on Ipop[2]] -> cell 19, seg 0 (0.5) [0.5 on Ipop[19]], weight: -0.0016545403, delay 1.5
        h("Ipop[19] syn_projII_gaba[59] = new gaba(0.5)")
        h("Ipop[2] netConn_projII_gaba[59] = new NetCon(&v(0.5), syn_projII_gaba[59], 20.0, 1.5, -0.0016545403)")  

        # Connection 60: cell 3, seg 0 (0.5) [0.5 on Ipop[3]] -> cell 0, seg 0 (0.5) [0.5 on Ipop[0]], weight: -0.0016545403, delay 1.5
        h("Ipop[0] syn_projII_gaba[60] = new gaba(0.5)")
        h("Ipop[3] netConn_projII_gaba[60] = new NetCon(&v(0.5), syn_projII_gaba[60], 20.0, 1.5, -0.0016545403)")  

        # Connection 61: cell 3, seg 0 (0.5) [0.5 on Ipop[3]] -> cell 1, seg 0 (0.5) [0.5 on Ipop[1]], weight: -0.0016545403, delay 1.5
        h("Ipop[1] syn_projII_gaba[61] = new gaba(0.5)")
        h("Ipop[3] netConn_projII_gaba[61] = new NetCon(&v(0.5), syn_projII_gaba[61], 20.0, 1.5, -0.0016545403)")  

        # Connection 62: cell 3, seg 0 (0.5) [0.5 on Ipop[3]] -> cell 2, seg 0 (0.5) [0.5 on Ipop[2]], weight: -0.0016545403, delay 1.5
        h("Ipop[2] syn_projII_gaba[62] = new gaba(0.5)")
        h("Ipop[3] netConn_projII_gaba[62] = new NetCon(&v(0.5), syn_projII_gaba[62], 20.0, 1.5, -0.0016545403)")  

        # Connection 63: cell 3, seg 0 (0.5) [0.5 on Ipop[3]] -> cell 3, seg 0 (0.5) [0.5 on Ipop[3]], weight: -0.0016545403, delay 1.5
        h("Ipop[3] syn_projII_gaba[63] = new gaba(0.5)")
        h("Ipop[3] netConn_projII_gaba[63] = new NetCon(&v(0.5), syn_projII_gaba[63], 20.0, 1.5, -0.0016545403)")  

        # Connection 64: cell 3, seg 0 (0.5) [0.5 on Ipop[3]] -> cell 4, seg 0 (0.5) [0.5 on Ipop[4]], weight: -0.0016545403, delay 1.5
        h("Ipop[4] syn_projII_gaba[64] = new gaba(0.5)")
        h("Ipop[3] netConn_projII_gaba[64] = new NetCon(&v(0.5), syn_projII_gaba[64], 20.0, 1.5, -0.0016545403)")  

        # Connection 65: cell 3, seg 0 (0.5) [0.5 on Ipop[3]] -> cell 5, seg 0 (0.5) [0.5 on Ipop[5]], weight: -0.0016545403, delay 1.5
        h("Ipop[5] syn_projII_gaba[65] = new gaba(0.5)")
        h("Ipop[3] netConn_projII_gaba[65] = new NetCon(&v(0.5), syn_projII_gaba[65], 20.0, 1.5, -0.0016545403)")  

        # Connection 66: cell 3, seg 0 (0.5) [0.5 on Ipop[3]] -> cell 6, seg 0 (0.5) [0.5 on Ipop[6]], weight: -0.0016545403, delay 1.5
        h("Ipop[6] syn_projII_gaba[66] = new gaba(0.5)")
        h("Ipop[3] netConn_projII_gaba[66] = new NetCon(&v(0.5), syn_projII_gaba[66], 20.0, 1.5, -0.0016545403)")  

        # Connection 67: cell 3, seg 0 (0.5) [0.5 on Ipop[3]] -> cell 7, seg 0 (0.5) [0.5 on Ipop[7]], weight: -0.0016545403, delay 1.5
        h("Ipop[7] syn_projII_gaba[67] = new gaba(0.5)")
        h("Ipop[3] netConn_projII_gaba[67] = new NetCon(&v(0.5), syn_projII_gaba[67], 20.0, 1.5, -0.0016545403)")  

        # Connection 68: cell 3, seg 0 (0.5) [0.5 on Ipop[3]] -> cell 8, seg 0 (0.5) [0.5 on Ipop[8]], weight: -0.0016545403, delay 1.5
        h("Ipop[8] syn_projII_gaba[68] = new gaba(0.5)")
        h("Ipop[3] netConn_projII_gaba[68] = new NetCon(&v(0.5), syn_projII_gaba[68], 20.0, 1.5, -0.0016545403)")  

        # Connection 69: cell 3, seg 0 (0.5) [0.5 on Ipop[3]] -> cell 9, seg 0 (0.5) [0.5 on Ipop[9]], weight: -0.0016545403, delay 1.5
        h("Ipop[9] syn_projII_gaba[69] = new gaba(0.5)")
        h("Ipop[3] netConn_projII_gaba[69] = new NetCon(&v(0.5), syn_projII_gaba[69], 20.0, 1.5, -0.0016545403)")  

        # Connection 70: cell 3, seg 0 (0.5) [0.5 on Ipop[3]] -> cell 10, seg 0 (0.5) [0.5 on Ipop[10]], weight: -0.0016545403, delay 1.5
        h("Ipop[10] syn_projII_gaba[70] = new gaba(0.5)")
        h("Ipop[3] netConn_projII_gaba[70] = new NetCon(&v(0.5), syn_projII_gaba[70], 20.0, 1.5, -0.0016545403)")  

        # Connection 71: cell 3, seg 0 (0.5) [0.5 on Ipop[3]] -> cell 11, seg 0 (0.5) [0.5 on Ipop[11]], weight: -0.0016545403, delay 1.5
        h("Ipop[11] syn_projII_gaba[71] = new gaba(0.5)")
        h("Ipop[3] netConn_projII_gaba[71] = new NetCon(&v(0.5), syn_projII_gaba[71], 20.0, 1.5, -0.0016545403)")  

        # Connection 72: cell 3, seg 0 (0.5) [0.5 on Ipop[3]] -> cell 12, seg 0 (0.5) [0.5 on Ipop[12]], weight: -0.0016545403, delay 1.5
        h("Ipop[12] syn_projII_gaba[72] = new gaba(0.5)")
        h("Ipop[3] netConn_projII_gaba[72] = new NetCon(&v(0.5), syn_projII_gaba[72], 20.0, 1.5, -0.0016545403)")  

        # Connection 73: cell 3, seg 0 (0.5) [0.5 on Ipop[3]] -> cell 13, seg 0 (0.5) [0.5 on Ipop[13]], weight: -0.0016545403, delay 1.5
        h("Ipop[13] syn_projII_gaba[73] = new gaba(0.5)")
        h("Ipop[3] netConn_projII_gaba[73] = new NetCon(&v(0.5), syn_projII_gaba[73], 20.0, 1.5, -0.0016545403)")  

        # Connection 74: cell 3, seg 0 (0.5) [0.5 on Ipop[3]] -> cell 14, seg 0 (0.5) [0.5 on Ipop[14]], weight: -0.0016545403, delay 1.5
        h("Ipop[14] syn_projII_gaba[74] = new gaba(0.5)")
        h("Ipop[3] netConn_projII_gaba[74] = new NetCon(&v(0.5), syn_projII_gaba[74], 20.0, 1.5, -0.0016545403)")  

        # Connection 75: cell 3, seg 0 (0.5) [0.5 on Ipop[3]] -> cell 15, seg 0 (0.5) [0.5 on Ipop[15]], weight: -0.0016545403, delay 1.5
        h("Ipop[15] syn_projII_gaba[75] = new gaba(0.5)")
        h("Ipop[3] netConn_projII_gaba[75] = new NetCon(&v(0.5), syn_projII_gaba[75], 20.0, 1.5, -0.0016545403)")  

        # Connection 76: cell 3, seg 0 (0.5) [0.5 on Ipop[3]] -> cell 16, seg 0 (0.5) [0.5 on Ipop[16]], weight: -0.0016545403, delay 1.5
        h("Ipop[16] syn_projII_gaba[76] = new gaba(0.5)")
        h("Ipop[3] netConn_projII_gaba[76] = new NetCon(&v(0.5), syn_projII_gaba[76], 20.0, 1.5, -0.0016545403)")  

        # Connection 77: cell 3, seg 0 (0.5) [0.5 on Ipop[3]] -> cell 17, seg 0 (0.5) [0.5 on Ipop[17]], weight: -0.0016545403, delay 1.5
        h("Ipop[17] syn_projII_gaba[77] = new gaba(0.5)")
        h("Ipop[3] netConn_projII_gaba[77] = new NetCon(&v(0.5), syn_projII_gaba[77], 20.0, 1.5, -0.0016545403)")  

        # Connection 78: cell 3, seg 0 (0.5) [0.5 on Ipop[3]] -> cell 18, seg 0 (0.5) [0.5 on Ipop[18]], weight: -0.0016545403, delay 1.5
        h("Ipop[18] syn_projII_gaba[78] = new gaba(0.5)")
        h("Ipop[3] netConn_projII_gaba[78] = new NetCon(&v(0.5), syn_projII_gaba[78], 20.0, 1.5, -0.0016545403)")  

        # Connection 79: cell 3, seg 0 (0.5) [0.5 on Ipop[3]] -> cell 19, seg 0 (0.5) [0.5 on Ipop[19]], weight: -0.0016545403, delay 1.5
        h("Ipop[19] syn_projII_gaba[79] = new gaba(0.5)")
        h("Ipop[3] netConn_projII_gaba[79] = new NetCon(&v(0.5), syn_projII_gaba[79], 20.0, 1.5, -0.0016545403)")  

        # Connection 80: cell 4, seg 0 (0.5) [0.5 on Ipop[4]] -> cell 0, seg 0 (0.5) [0.5 on Ipop[0]], weight: -0.0016545403, delay 1.5
        h("Ipop[0] syn_projII_gaba[80] = new gaba(0.5)")
        h("Ipop[4] netConn_projII_gaba[80] = new NetCon(&v(0.5), syn_projII_gaba[80], 20.0, 1.5, -0.0016545403)")  

        # Connection 81: cell 4, seg 0 (0.5) [0.5 on Ipop[4]] -> cell 1, seg 0 (0.5) [0.5 on Ipop[1]], weight: -0.0016545403, delay 1.5
        h("Ipop[1] syn_projII_gaba[81] = new gaba(0.5)")
        h("Ipop[4] netConn_projII_gaba[81] = new NetCon(&v(0.5), syn_projII_gaba[81], 20.0, 1.5, -0.0016545403)")  

        # Connection 82: cell 4, seg 0 (0.5) [0.5 on Ipop[4]] -> cell 2, seg 0 (0.5) [0.5 on Ipop[2]], weight: -0.0016545403, delay 1.5
        h("Ipop[2] syn_projII_gaba[82] = new gaba(0.5)")
        h("Ipop[4] netConn_projII_gaba[82] = new NetCon(&v(0.5), syn_projII_gaba[82], 20.0, 1.5, -0.0016545403)")  

        # Connection 83: cell 4, seg 0 (0.5) [0.5 on Ipop[4]] -> cell 3, seg 0 (0.5) [0.5 on Ipop[3]], weight: -0.0016545403, delay 1.5
        h("Ipop[3] syn_projII_gaba[83] = new gaba(0.5)")
        h("Ipop[4] netConn_projII_gaba[83] = new NetCon(&v(0.5), syn_projII_gaba[83], 20.0, 1.5, -0.0016545403)")  

        # Connection 84: cell 4, seg 0 (0.5) [0.5 on Ipop[4]] -> cell 4, seg 0 (0.5) [0.5 on Ipop[4]], weight: -0.0016545403, delay 1.5
        h("Ipop[4] syn_projII_gaba[84] = new gaba(0.5)")
        h("Ipop[4] netConn_projII_gaba[84] = new NetCon(&v(0.5), syn_projII_gaba[84], 20.0, 1.5, -0.0016545403)")  

        # Connection 85: cell 4, seg 0 (0.5) [0.5 on Ipop[4]] -> cell 5, seg 0 (0.5) [0.5 on Ipop[5]], weight: -0.0016545403, delay 1.5
        h("Ipop[5] syn_projII_gaba[85] = new gaba(0.5)")
        h("Ipop[4] netConn_projII_gaba[85] = new NetCon(&v(0.5), syn_projII_gaba[85], 20.0, 1.5, -0.0016545403)")  

        # Connection 86: cell 4, seg 0 (0.5) [0.5 on Ipop[4]] -> cell 6, seg 0 (0.5) [0.5 on Ipop[6]], weight: -0.0016545403, delay 1.5
        h("Ipop[6] syn_projII_gaba[86] = new gaba(0.5)")
        h("Ipop[4] netConn_projII_gaba[86] = new NetCon(&v(0.5), syn_projII_gaba[86], 20.0, 1.5, -0.0016545403)")  

        # Connection 87: cell 4, seg 0 (0.5) [0.5 on Ipop[4]] -> cell 7, seg 0 (0.5) [0.5 on Ipop[7]], weight: -0.0016545403, delay 1.5
        h("Ipop[7] syn_projII_gaba[87] = new gaba(0.5)")
        h("Ipop[4] netConn_projII_gaba[87] = new NetCon(&v(0.5), syn_projII_gaba[87], 20.0, 1.5, -0.0016545403)")  

        # Connection 88: cell 4, seg 0 (0.5) [0.5 on Ipop[4]] -> cell 8, seg 0 (0.5) [0.5 on Ipop[8]], weight: -0.0016545403, delay 1.5
        h("Ipop[8] syn_projII_gaba[88] = new gaba(0.5)")
        h("Ipop[4] netConn_projII_gaba[88] = new NetCon(&v(0.5), syn_projII_gaba[88], 20.0, 1.5, -0.0016545403)")  

        # Connection 89: cell 4, seg 0 (0.5) [0.5 on Ipop[4]] -> cell 9, seg 0 (0.5) [0.5 on Ipop[9]], weight: -0.0016545403, delay 1.5
        h("Ipop[9] syn_projII_gaba[89] = new gaba(0.5)")
        h("Ipop[4] netConn_projII_gaba[89] = new NetCon(&v(0.5), syn_projII_gaba[89], 20.0, 1.5, -0.0016545403)")  

        # Connection 90: cell 4, seg 0 (0.5) [0.5 on Ipop[4]] -> cell 10, seg 0 (0.5) [0.5 on Ipop[10]], weight: -0.0016545403, delay 1.5
        h("Ipop[10] syn_projII_gaba[90] = new gaba(0.5)")
        h("Ipop[4] netConn_projII_gaba[90] = new NetCon(&v(0.5), syn_projII_gaba[90], 20.0, 1.5, -0.0016545403)")  

        # Connection 91: cell 4, seg 0 (0.5) [0.5 on Ipop[4]] -> cell 11, seg 0 (0.5) [0.5 on Ipop[11]], weight: -0.0016545403, delay 1.5
        h("Ipop[11] syn_projII_gaba[91] = new gaba(0.5)")
        h("Ipop[4] netConn_projII_gaba[91] = new NetCon(&v(0.5), syn_projII_gaba[91], 20.0, 1.5, -0.0016545403)")  

        # Connection 92: cell 4, seg 0 (0.5) [0.5 on Ipop[4]] -> cell 12, seg 0 (0.5) [0.5 on Ipop[12]], weight: -0.0016545403, delay 1.5
        h("Ipop[12] syn_projII_gaba[92] = new gaba(0.5)")
        h("Ipop[4] netConn_projII_gaba[92] = new NetCon(&v(0.5), syn_projII_gaba[92], 20.0, 1.5, -0.0016545403)")  

        # Connection 93: cell 4, seg 0 (0.5) [0.5 on Ipop[4]] -> cell 13, seg 0 (0.5) [0.5 on Ipop[13]], weight: -0.0016545403, delay 1.5
        h("Ipop[13] syn_projII_gaba[93] = new gaba(0.5)")
        h("Ipop[4] netConn_projII_gaba[93] = new NetCon(&v(0.5), syn_projII_gaba[93], 20.0, 1.5, -0.0016545403)")  

        # Connection 94: cell 4, seg 0 (0.5) [0.5 on Ipop[4]] -> cell 14, seg 0 (0.5) [0.5 on Ipop[14]], weight: -0.0016545403, delay 1.5
        h("Ipop[14] syn_projII_gaba[94] = new gaba(0.5)")
        h("Ipop[4] netConn_projII_gaba[94] = new NetCon(&v(0.5), syn_projII_gaba[94], 20.0, 1.5, -0.0016545403)")  

        # Connection 95: cell 4, seg 0 (0.5) [0.5 on Ipop[4]] -> cell 15, seg 0 (0.5) [0.5 on Ipop[15]], weight: -0.0016545403, delay 1.5
        h("Ipop[15] syn_projII_gaba[95] = new gaba(0.5)")
        h("Ipop[4] netConn_projII_gaba[95] = new NetCon(&v(0.5), syn_projII_gaba[95], 20.0, 1.5, -0.0016545403)")  

        # Connection 96: cell 4, seg 0 (0.5) [0.5 on Ipop[4]] -> cell 16, seg 0 (0.5) [0.5 on Ipop[16]], weight: -0.0016545403, delay 1.5
        h("Ipop[16] syn_projII_gaba[96] = new gaba(0.5)")
        h("Ipop[4] netConn_projII_gaba[96] = new NetCon(&v(0.5), syn_projII_gaba[96], 20.0, 1.5, -0.0016545403)")  

        # Connection 97: cell 4, seg 0 (0.5) [0.5 on Ipop[4]] -> cell 17, seg 0 (0.5) [0.5 on Ipop[17]], weight: -0.0016545403, delay 1.5
        h("Ipop[17] syn_projII_gaba[97] = new gaba(0.5)")
        h("Ipop[4] netConn_projII_gaba[97] = new NetCon(&v(0.5), syn_projII_gaba[97], 20.0, 1.5, -0.0016545403)")  

        # Connection 98: cell 4, seg 0 (0.5) [0.5 on Ipop[4]] -> cell 18, seg 0 (0.5) [0.5 on Ipop[18]], weight: -0.0016545403, delay 1.5
        h("Ipop[18] syn_projII_gaba[98] = new gaba(0.5)")
        h("Ipop[4] netConn_projII_gaba[98] = new NetCon(&v(0.5), syn_projII_gaba[98], 20.0, 1.5, -0.0016545403)")  

        # Connection 99: cell 4, seg 0 (0.5) [0.5 on Ipop[4]] -> cell 19, seg 0 (0.5) [0.5 on Ipop[19]], weight: -0.0016545403, delay 1.5
        h("Ipop[19] syn_projII_gaba[99] = new gaba(0.5)")
        h("Ipop[4] netConn_projII_gaba[99] = new NetCon(&v(0.5), syn_projII_gaba[99], 20.0, 1.5, -0.0016545403)")  

        # Connection 100: cell 5, seg 0 (0.5) [0.5 on Ipop[5]] -> cell 0, seg 0 (0.5) [0.5 on Ipop[0]], weight: -0.0016545403, delay 1.5
        h("Ipop[0] syn_projII_gaba[100] = new gaba(0.5)")
        h("Ipop[5] netConn_projII_gaba[100] = new NetCon(&v(0.5), syn_projII_gaba[100], 20.0, 1.5, -0.0016545403)")  

        # Connection 101: cell 5, seg 0 (0.5) [0.5 on Ipop[5]] -> cell 1, seg 0 (0.5) [0.5 on Ipop[1]], weight: -0.0016545403, delay 1.5
        h("Ipop[1] syn_projII_gaba[101] = new gaba(0.5)")
        h("Ipop[5] netConn_projII_gaba[101] = new NetCon(&v(0.5), syn_projII_gaba[101], 20.0, 1.5, -0.0016545403)")  

        # Connection 102: cell 5, seg 0 (0.5) [0.5 on Ipop[5]] -> cell 2, seg 0 (0.5) [0.5 on Ipop[2]], weight: -0.0016545403, delay 1.5
        h("Ipop[2] syn_projII_gaba[102] = new gaba(0.5)")
        h("Ipop[5] netConn_projII_gaba[102] = new NetCon(&v(0.5), syn_projII_gaba[102], 20.0, 1.5, -0.0016545403)")  

        # Connection 103: cell 5, seg 0 (0.5) [0.5 on Ipop[5]] -> cell 3, seg 0 (0.5) [0.5 on Ipop[3]], weight: -0.0016545403, delay 1.5
        h("Ipop[3] syn_projII_gaba[103] = new gaba(0.5)")
        h("Ipop[5] netConn_projII_gaba[103] = new NetCon(&v(0.5), syn_projII_gaba[103], 20.0, 1.5, -0.0016545403)")  

        # Connection 104: cell 5, seg 0 (0.5) [0.5 on Ipop[5]] -> cell 4, seg 0 (0.5) [0.5 on Ipop[4]], weight: -0.0016545403, delay 1.5
        h("Ipop[4] syn_projII_gaba[104] = new gaba(0.5)")
        h("Ipop[5] netConn_projII_gaba[104] = new NetCon(&v(0.5), syn_projII_gaba[104], 20.0, 1.5, -0.0016545403)")  

        # Connection 105: cell 5, seg 0 (0.5) [0.5 on Ipop[5]] -> cell 5, seg 0 (0.5) [0.5 on Ipop[5]], weight: -0.0016545403, delay 1.5
        h("Ipop[5] syn_projII_gaba[105] = new gaba(0.5)")
        h("Ipop[5] netConn_projII_gaba[105] = new NetCon(&v(0.5), syn_projII_gaba[105], 20.0, 1.5, -0.0016545403)")  

        # Connection 106: cell 5, seg 0 (0.5) [0.5 on Ipop[5]] -> cell 6, seg 0 (0.5) [0.5 on Ipop[6]], weight: -0.0016545403, delay 1.5
        h("Ipop[6] syn_projII_gaba[106] = new gaba(0.5)")
        h("Ipop[5] netConn_projII_gaba[106] = new NetCon(&v(0.5), syn_projII_gaba[106], 20.0, 1.5, -0.0016545403)")  

        # Connection 107: cell 5, seg 0 (0.5) [0.5 on Ipop[5]] -> cell 7, seg 0 (0.5) [0.5 on Ipop[7]], weight: -0.0016545403, delay 1.5
        h("Ipop[7] syn_projII_gaba[107] = new gaba(0.5)")
        h("Ipop[5] netConn_projII_gaba[107] = new NetCon(&v(0.5), syn_projII_gaba[107], 20.0, 1.5, -0.0016545403)")  

        # Connection 108: cell 5, seg 0 (0.5) [0.5 on Ipop[5]] -> cell 8, seg 0 (0.5) [0.5 on Ipop[8]], weight: -0.0016545403, delay 1.5
        h("Ipop[8] syn_projII_gaba[108] = new gaba(0.5)")
        h("Ipop[5] netConn_projII_gaba[108] = new NetCon(&v(0.5), syn_projII_gaba[108], 20.0, 1.5, -0.0016545403)")  

        # Connection 109: cell 5, seg 0 (0.5) [0.5 on Ipop[5]] -> cell 9, seg 0 (0.5) [0.5 on Ipop[9]], weight: -0.0016545403, delay 1.5
        h("Ipop[9] syn_projII_gaba[109] = new gaba(0.5)")
        h("Ipop[5] netConn_projII_gaba[109] = new NetCon(&v(0.5), syn_projII_gaba[109], 20.0, 1.5, -0.0016545403)")  

        # Connection 110: cell 5, seg 0 (0.5) [0.5 on Ipop[5]] -> cell 10, seg 0 (0.5) [0.5 on Ipop[10]], weight: -0.0016545403, delay 1.5
        h("Ipop[10] syn_projII_gaba[110] = new gaba(0.5)")
        h("Ipop[5] netConn_projII_gaba[110] = new NetCon(&v(0.5), syn_projII_gaba[110], 20.0, 1.5, -0.0016545403)")  

        # Connection 111: cell 5, seg 0 (0.5) [0.5 on Ipop[5]] -> cell 11, seg 0 (0.5) [0.5 on Ipop[11]], weight: -0.0016545403, delay 1.5
        h("Ipop[11] syn_projII_gaba[111] = new gaba(0.5)")
        h("Ipop[5] netConn_projII_gaba[111] = new NetCon(&v(0.5), syn_projII_gaba[111], 20.0, 1.5, -0.0016545403)")  

        # Connection 112: cell 5, seg 0 (0.5) [0.5 on Ipop[5]] -> cell 12, seg 0 (0.5) [0.5 on Ipop[12]], weight: -0.0016545403, delay 1.5
        h("Ipop[12] syn_projII_gaba[112] = new gaba(0.5)")
        h("Ipop[5] netConn_projII_gaba[112] = new NetCon(&v(0.5), syn_projII_gaba[112], 20.0, 1.5, -0.0016545403)")  

        # Connection 113: cell 5, seg 0 (0.5) [0.5 on Ipop[5]] -> cell 13, seg 0 (0.5) [0.5 on Ipop[13]], weight: -0.0016545403, delay 1.5
        h("Ipop[13] syn_projII_gaba[113] = new gaba(0.5)")
        h("Ipop[5] netConn_projII_gaba[113] = new NetCon(&v(0.5), syn_projII_gaba[113], 20.0, 1.5, -0.0016545403)")  

        # Connection 114: cell 5, seg 0 (0.5) [0.5 on Ipop[5]] -> cell 14, seg 0 (0.5) [0.5 on Ipop[14]], weight: -0.0016545403, delay 1.5
        h("Ipop[14] syn_projII_gaba[114] = new gaba(0.5)")
        h("Ipop[5] netConn_projII_gaba[114] = new NetCon(&v(0.5), syn_projII_gaba[114], 20.0, 1.5, -0.0016545403)")  

        # Connection 115: cell 5, seg 0 (0.5) [0.5 on Ipop[5]] -> cell 15, seg 0 (0.5) [0.5 on Ipop[15]], weight: -0.0016545403, delay 1.5
        h("Ipop[15] syn_projII_gaba[115] = new gaba(0.5)")
        h("Ipop[5] netConn_projII_gaba[115] = new NetCon(&v(0.5), syn_projII_gaba[115], 20.0, 1.5, -0.0016545403)")  

        # Connection 116: cell 5, seg 0 (0.5) [0.5 on Ipop[5]] -> cell 16, seg 0 (0.5) [0.5 on Ipop[16]], weight: -0.0016545403, delay 1.5
        h("Ipop[16] syn_projII_gaba[116] = new gaba(0.5)")
        h("Ipop[5] netConn_projII_gaba[116] = new NetCon(&v(0.5), syn_projII_gaba[116], 20.0, 1.5, -0.0016545403)")  

        # Connection 117: cell 5, seg 0 (0.5) [0.5 on Ipop[5]] -> cell 17, seg 0 (0.5) [0.5 on Ipop[17]], weight: -0.0016545403, delay 1.5
        h("Ipop[17] syn_projII_gaba[117] = new gaba(0.5)")
        h("Ipop[5] netConn_projII_gaba[117] = new NetCon(&v(0.5), syn_projII_gaba[117], 20.0, 1.5, -0.0016545403)")  

        # Connection 118: cell 5, seg 0 (0.5) [0.5 on Ipop[5]] -> cell 18, seg 0 (0.5) [0.5 on Ipop[18]], weight: -0.0016545403, delay 1.5
        h("Ipop[18] syn_projII_gaba[118] = new gaba(0.5)")
        h("Ipop[5] netConn_projII_gaba[118] = new NetCon(&v(0.5), syn_projII_gaba[118], 20.0, 1.5, -0.0016545403)")  

        # Connection 119: cell 5, seg 0 (0.5) [0.5 on Ipop[5]] -> cell 19, seg 0 (0.5) [0.5 on Ipop[19]], weight: -0.0016545403, delay 1.5
        h("Ipop[19] syn_projII_gaba[119] = new gaba(0.5)")
        h("Ipop[5] netConn_projII_gaba[119] = new NetCon(&v(0.5), syn_projII_gaba[119], 20.0, 1.5, -0.0016545403)")  

        # Connection 120: cell 6, seg 0 (0.5) [0.5 on Ipop[6]] -> cell 0, seg 0 (0.5) [0.5 on Ipop[0]], weight: -0.0016545403, delay 1.5
        h("Ipop[0] syn_projII_gaba[120] = new gaba(0.5)")
        h("Ipop[6] netConn_projII_gaba[120] = new NetCon(&v(0.5), syn_projII_gaba[120], 20.0, 1.5, -0.0016545403)")  

        # Connection 121: cell 6, seg 0 (0.5) [0.5 on Ipop[6]] -> cell 1, seg 0 (0.5) [0.5 on Ipop[1]], weight: -0.0016545403, delay 1.5
        h("Ipop[1] syn_projII_gaba[121] = new gaba(0.5)")
        h("Ipop[6] netConn_projII_gaba[121] = new NetCon(&v(0.5), syn_projII_gaba[121], 20.0, 1.5, -0.0016545403)")  

        # Connection 122: cell 6, seg 0 (0.5) [0.5 on Ipop[6]] -> cell 2, seg 0 (0.5) [0.5 on Ipop[2]], weight: -0.0016545403, delay 1.5
        h("Ipop[2] syn_projII_gaba[122] = new gaba(0.5)")
        h("Ipop[6] netConn_projII_gaba[122] = new NetCon(&v(0.5), syn_projII_gaba[122], 20.0, 1.5, -0.0016545403)")  

        # Connection 123: cell 6, seg 0 (0.5) [0.5 on Ipop[6]] -> cell 3, seg 0 (0.5) [0.5 on Ipop[3]], weight: -0.0016545403, delay 1.5
        h("Ipop[3] syn_projII_gaba[123] = new gaba(0.5)")
        h("Ipop[6] netConn_projII_gaba[123] = new NetCon(&v(0.5), syn_projII_gaba[123], 20.0, 1.5, -0.0016545403)")  

        # Connection 124: cell 6, seg 0 (0.5) [0.5 on Ipop[6]] -> cell 4, seg 0 (0.5) [0.5 on Ipop[4]], weight: -0.0016545403, delay 1.5
        h("Ipop[4] syn_projII_gaba[124] = new gaba(0.5)")
        h("Ipop[6] netConn_projII_gaba[124] = new NetCon(&v(0.5), syn_projII_gaba[124], 20.0, 1.5, -0.0016545403)")  

        # Connection 125: cell 6, seg 0 (0.5) [0.5 on Ipop[6]] -> cell 5, seg 0 (0.5) [0.5 on Ipop[5]], weight: -0.0016545403, delay 1.5
        h("Ipop[5] syn_projII_gaba[125] = new gaba(0.5)")
        h("Ipop[6] netConn_projII_gaba[125] = new NetCon(&v(0.5), syn_projII_gaba[125], 20.0, 1.5, -0.0016545403)")  

        # Connection 126: cell 6, seg 0 (0.5) [0.5 on Ipop[6]] -> cell 6, seg 0 (0.5) [0.5 on Ipop[6]], weight: -0.0016545403, delay 1.5
        h("Ipop[6] syn_projII_gaba[126] = new gaba(0.5)")
        h("Ipop[6] netConn_projII_gaba[126] = new NetCon(&v(0.5), syn_projII_gaba[126], 20.0, 1.5, -0.0016545403)")  

        # Connection 127: cell 6, seg 0 (0.5) [0.5 on Ipop[6]] -> cell 7, seg 0 (0.5) [0.5 on Ipop[7]], weight: -0.0016545403, delay 1.5
        h("Ipop[7] syn_projII_gaba[127] = new gaba(0.5)")
        h("Ipop[6] netConn_projII_gaba[127] = new NetCon(&v(0.5), syn_projII_gaba[127], 20.0, 1.5, -0.0016545403)")  

        # Connection 128: cell 6, seg 0 (0.5) [0.5 on Ipop[6]] -> cell 8, seg 0 (0.5) [0.5 on Ipop[8]], weight: -0.0016545403, delay 1.5
        h("Ipop[8] syn_projII_gaba[128] = new gaba(0.5)")
        h("Ipop[6] netConn_projII_gaba[128] = new NetCon(&v(0.5), syn_projII_gaba[128], 20.0, 1.5, -0.0016545403)")  

        # Connection 129: cell 6, seg 0 (0.5) [0.5 on Ipop[6]] -> cell 9, seg 0 (0.5) [0.5 on Ipop[9]], weight: -0.0016545403, delay 1.5
        h("Ipop[9] syn_projII_gaba[129] = new gaba(0.5)")
        h("Ipop[6] netConn_projII_gaba[129] = new NetCon(&v(0.5), syn_projII_gaba[129], 20.0, 1.5, -0.0016545403)")  

        # Connection 130: cell 6, seg 0 (0.5) [0.5 on Ipop[6]] -> cell 10, seg 0 (0.5) [0.5 on Ipop[10]], weight: -0.0016545403, delay 1.5
        h("Ipop[10] syn_projII_gaba[130] = new gaba(0.5)")
        h("Ipop[6] netConn_projII_gaba[130] = new NetCon(&v(0.5), syn_projII_gaba[130], 20.0, 1.5, -0.0016545403)")  

        # Connection 131: cell 6, seg 0 (0.5) [0.5 on Ipop[6]] -> cell 11, seg 0 (0.5) [0.5 on Ipop[11]], weight: -0.0016545403, delay 1.5
        h("Ipop[11] syn_projII_gaba[131] = new gaba(0.5)")
        h("Ipop[6] netConn_projII_gaba[131] = new NetCon(&v(0.5), syn_projII_gaba[131], 20.0, 1.5, -0.0016545403)")  

        # Connection 132: cell 6, seg 0 (0.5) [0.5 on Ipop[6]] -> cell 12, seg 0 (0.5) [0.5 on Ipop[12]], weight: -0.0016545403, delay 1.5
        h("Ipop[12] syn_projII_gaba[132] = new gaba(0.5)")
        h("Ipop[6] netConn_projII_gaba[132] = new NetCon(&v(0.5), syn_projII_gaba[132], 20.0, 1.5, -0.0016545403)")  

        # Connection 133: cell 6, seg 0 (0.5) [0.5 on Ipop[6]] -> cell 13, seg 0 (0.5) [0.5 on Ipop[13]], weight: -0.0016545403, delay 1.5
        h("Ipop[13] syn_projII_gaba[133] = new gaba(0.5)")
        h("Ipop[6] netConn_projII_gaba[133] = new NetCon(&v(0.5), syn_projII_gaba[133], 20.0, 1.5, -0.0016545403)")  

        # Connection 134: cell 6, seg 0 (0.5) [0.5 on Ipop[6]] -> cell 14, seg 0 (0.5) [0.5 on Ipop[14]], weight: -0.0016545403, delay 1.5
        h("Ipop[14] syn_projII_gaba[134] = new gaba(0.5)")
        h("Ipop[6] netConn_projII_gaba[134] = new NetCon(&v(0.5), syn_projII_gaba[134], 20.0, 1.5, -0.0016545403)")  

        # Connection 135: cell 6, seg 0 (0.5) [0.5 on Ipop[6]] -> cell 15, seg 0 (0.5) [0.5 on Ipop[15]], weight: -0.0016545403, delay 1.5
        h("Ipop[15] syn_projII_gaba[135] = new gaba(0.5)")
        h("Ipop[6] netConn_projII_gaba[135] = new NetCon(&v(0.5), syn_projII_gaba[135], 20.0, 1.5, -0.0016545403)")  

        # Connection 136: cell 6, seg 0 (0.5) [0.5 on Ipop[6]] -> cell 16, seg 0 (0.5) [0.5 on Ipop[16]], weight: -0.0016545403, delay 1.5
        h("Ipop[16] syn_projII_gaba[136] = new gaba(0.5)")
        h("Ipop[6] netConn_projII_gaba[136] = new NetCon(&v(0.5), syn_projII_gaba[136], 20.0, 1.5, -0.0016545403)")  

        # Connection 137: cell 6, seg 0 (0.5) [0.5 on Ipop[6]] -> cell 17, seg 0 (0.5) [0.5 on Ipop[17]], weight: -0.0016545403, delay 1.5
        h("Ipop[17] syn_projII_gaba[137] = new gaba(0.5)")
        h("Ipop[6] netConn_projII_gaba[137] = new NetCon(&v(0.5), syn_projII_gaba[137], 20.0, 1.5, -0.0016545403)")  

        # Connection 138: cell 6, seg 0 (0.5) [0.5 on Ipop[6]] -> cell 18, seg 0 (0.5) [0.5 on Ipop[18]], weight: -0.0016545403, delay 1.5
        h("Ipop[18] syn_projII_gaba[138] = new gaba(0.5)")
        h("Ipop[6] netConn_projII_gaba[138] = new NetCon(&v(0.5), syn_projII_gaba[138], 20.0, 1.5, -0.0016545403)")  

        # Connection 139: cell 6, seg 0 (0.5) [0.5 on Ipop[6]] -> cell 19, seg 0 (0.5) [0.5 on Ipop[19]], weight: -0.0016545403, delay 1.5
        h("Ipop[19] syn_projII_gaba[139] = new gaba(0.5)")
        h("Ipop[6] netConn_projII_gaba[139] = new NetCon(&v(0.5), syn_projII_gaba[139], 20.0, 1.5, -0.0016545403)")  

        # Connection 140: cell 7, seg 0 (0.5) [0.5 on Ipop[7]] -> cell 0, seg 0 (0.5) [0.5 on Ipop[0]], weight: -0.0016545403, delay 1.5
        h("Ipop[0] syn_projII_gaba[140] = new gaba(0.5)")
        h("Ipop[7] netConn_projII_gaba[140] = new NetCon(&v(0.5), syn_projII_gaba[140], 20.0, 1.5, -0.0016545403)")  

        # Connection 141: cell 7, seg 0 (0.5) [0.5 on Ipop[7]] -> cell 1, seg 0 (0.5) [0.5 on Ipop[1]], weight: -0.0016545403, delay 1.5
        h("Ipop[1] syn_projII_gaba[141] = new gaba(0.5)")
        h("Ipop[7] netConn_projII_gaba[141] = new NetCon(&v(0.5), syn_projII_gaba[141], 20.0, 1.5, -0.0016545403)")  

        # Connection 142: cell 7, seg 0 (0.5) [0.5 on Ipop[7]] -> cell 2, seg 0 (0.5) [0.5 on Ipop[2]], weight: -0.0016545403, delay 1.5
        h("Ipop[2] syn_projII_gaba[142] = new gaba(0.5)")
        h("Ipop[7] netConn_projII_gaba[142] = new NetCon(&v(0.5), syn_projII_gaba[142], 20.0, 1.5, -0.0016545403)")  

        # Connection 143: cell 7, seg 0 (0.5) [0.5 on Ipop[7]] -> cell 3, seg 0 (0.5) [0.5 on Ipop[3]], weight: -0.0016545403, delay 1.5
        h("Ipop[3] syn_projII_gaba[143] = new gaba(0.5)")
        h("Ipop[7] netConn_projII_gaba[143] = new NetCon(&v(0.5), syn_projII_gaba[143], 20.0, 1.5, -0.0016545403)")  

        # Connection 144: cell 7, seg 0 (0.5) [0.5 on Ipop[7]] -> cell 4, seg 0 (0.5) [0.5 on Ipop[4]], weight: -0.0016545403, delay 1.5
        h("Ipop[4] syn_projII_gaba[144] = new gaba(0.5)")
        h("Ipop[7] netConn_projII_gaba[144] = new NetCon(&v(0.5), syn_projII_gaba[144], 20.0, 1.5, -0.0016545403)")  

        # Connection 145: cell 7, seg 0 (0.5) [0.5 on Ipop[7]] -> cell 5, seg 0 (0.5) [0.5 on Ipop[5]], weight: -0.0016545403, delay 1.5
        h("Ipop[5] syn_projII_gaba[145] = new gaba(0.5)")
        h("Ipop[7] netConn_projII_gaba[145] = new NetCon(&v(0.5), syn_projII_gaba[145], 20.0, 1.5, -0.0016545403)")  

        # Connection 146: cell 7, seg 0 (0.5) [0.5 on Ipop[7]] -> cell 6, seg 0 (0.5) [0.5 on Ipop[6]], weight: -0.0016545403, delay 1.5
        h("Ipop[6] syn_projII_gaba[146] = new gaba(0.5)")
        h("Ipop[7] netConn_projII_gaba[146] = new NetCon(&v(0.5), syn_projII_gaba[146], 20.0, 1.5, -0.0016545403)")  

        # Connection 147: cell 7, seg 0 (0.5) [0.5 on Ipop[7]] -> cell 7, seg 0 (0.5) [0.5 on Ipop[7]], weight: -0.0016545403, delay 1.5
        h("Ipop[7] syn_projII_gaba[147] = new gaba(0.5)")
        h("Ipop[7] netConn_projII_gaba[147] = new NetCon(&v(0.5), syn_projII_gaba[147], 20.0, 1.5, -0.0016545403)")  

        # Connection 148: cell 7, seg 0 (0.5) [0.5 on Ipop[7]] -> cell 8, seg 0 (0.5) [0.5 on Ipop[8]], weight: -0.0016545403, delay 1.5
        h("Ipop[8] syn_projII_gaba[148] = new gaba(0.5)")
        h("Ipop[7] netConn_projII_gaba[148] = new NetCon(&v(0.5), syn_projII_gaba[148], 20.0, 1.5, -0.0016545403)")  

        # Connection 149: cell 7, seg 0 (0.5) [0.5 on Ipop[7]] -> cell 9, seg 0 (0.5) [0.5 on Ipop[9]], weight: -0.0016545403, delay 1.5
        h("Ipop[9] syn_projII_gaba[149] = new gaba(0.5)")
        h("Ipop[7] netConn_projII_gaba[149] = new NetCon(&v(0.5), syn_projII_gaba[149], 20.0, 1.5, -0.0016545403)")  

        # Connection 150: cell 7, seg 0 (0.5) [0.5 on Ipop[7]] -> cell 10, seg 0 (0.5) [0.5 on Ipop[10]], weight: -0.0016545403, delay 1.5
        h("Ipop[10] syn_projII_gaba[150] = new gaba(0.5)")
        h("Ipop[7] netConn_projII_gaba[150] = new NetCon(&v(0.5), syn_projII_gaba[150], 20.0, 1.5, -0.0016545403)")  

        # Connection 151: cell 7, seg 0 (0.5) [0.5 on Ipop[7]] -> cell 11, seg 0 (0.5) [0.5 on Ipop[11]], weight: -0.0016545403, delay 1.5
        h("Ipop[11] syn_projII_gaba[151] = new gaba(0.5)")
        h("Ipop[7] netConn_projII_gaba[151] = new NetCon(&v(0.5), syn_projII_gaba[151], 20.0, 1.5, -0.0016545403)")  

        # Connection 152: cell 7, seg 0 (0.5) [0.5 on Ipop[7]] -> cell 12, seg 0 (0.5) [0.5 on Ipop[12]], weight: -0.0016545403, delay 1.5
        h("Ipop[12] syn_projII_gaba[152] = new gaba(0.5)")
        h("Ipop[7] netConn_projII_gaba[152] = new NetCon(&v(0.5), syn_projII_gaba[152], 20.0, 1.5, -0.0016545403)")  

        # Connection 153: cell 7, seg 0 (0.5) [0.5 on Ipop[7]] -> cell 13, seg 0 (0.5) [0.5 on Ipop[13]], weight: -0.0016545403, delay 1.5
        h("Ipop[13] syn_projII_gaba[153] = new gaba(0.5)")
        h("Ipop[7] netConn_projII_gaba[153] = new NetCon(&v(0.5), syn_projII_gaba[153], 20.0, 1.5, -0.0016545403)")  

        # Connection 154: cell 7, seg 0 (0.5) [0.5 on Ipop[7]] -> cell 14, seg 0 (0.5) [0.5 on Ipop[14]], weight: -0.0016545403, delay 1.5
        h("Ipop[14] syn_projII_gaba[154] = new gaba(0.5)")
        h("Ipop[7] netConn_projII_gaba[154] = new NetCon(&v(0.5), syn_projII_gaba[154], 20.0, 1.5, -0.0016545403)")  

        # Connection 155: cell 7, seg 0 (0.5) [0.5 on Ipop[7]] -> cell 15, seg 0 (0.5) [0.5 on Ipop[15]], weight: -0.0016545403, delay 1.5
        h("Ipop[15] syn_projII_gaba[155] = new gaba(0.5)")
        h("Ipop[7] netConn_projII_gaba[155] = new NetCon(&v(0.5), syn_projII_gaba[155], 20.0, 1.5, -0.0016545403)")  

        # Connection 156: cell 7, seg 0 (0.5) [0.5 on Ipop[7]] -> cell 16, seg 0 (0.5) [0.5 on Ipop[16]], weight: -0.0016545403, delay 1.5
        h("Ipop[16] syn_projII_gaba[156] = new gaba(0.5)")
        h("Ipop[7] netConn_projII_gaba[156] = new NetCon(&v(0.5), syn_projII_gaba[156], 20.0, 1.5, -0.0016545403)")  

        # Connection 157: cell 7, seg 0 (0.5) [0.5 on Ipop[7]] -> cell 17, seg 0 (0.5) [0.5 on Ipop[17]], weight: -0.0016545403, delay 1.5
        h("Ipop[17] syn_projII_gaba[157] = new gaba(0.5)")
        h("Ipop[7] netConn_projII_gaba[157] = new NetCon(&v(0.5), syn_projII_gaba[157], 20.0, 1.5, -0.0016545403)")  

        # Connection 158: cell 7, seg 0 (0.5) [0.5 on Ipop[7]] -> cell 18, seg 0 (0.5) [0.5 on Ipop[18]], weight: -0.0016545403, delay 1.5
        h("Ipop[18] syn_projII_gaba[158] = new gaba(0.5)")
        h("Ipop[7] netConn_projII_gaba[158] = new NetCon(&v(0.5), syn_projII_gaba[158], 20.0, 1.5, -0.0016545403)")  

        # Connection 159: cell 7, seg 0 (0.5) [0.5 on Ipop[7]] -> cell 19, seg 0 (0.5) [0.5 on Ipop[19]], weight: -0.0016545403, delay 1.5
        h("Ipop[19] syn_projII_gaba[159] = new gaba(0.5)")
        h("Ipop[7] netConn_projII_gaba[159] = new NetCon(&v(0.5), syn_projII_gaba[159], 20.0, 1.5, -0.0016545403)")  

        # Connection 160: cell 8, seg 0 (0.5) [0.5 on Ipop[8]] -> cell 0, seg 0 (0.5) [0.5 on Ipop[0]], weight: -0.0016545403, delay 1.5
        h("Ipop[0] syn_projII_gaba[160] = new gaba(0.5)")
        h("Ipop[8] netConn_projII_gaba[160] = new NetCon(&v(0.5), syn_projII_gaba[160], 20.0, 1.5, -0.0016545403)")  

        # Connection 161: cell 8, seg 0 (0.5) [0.5 on Ipop[8]] -> cell 1, seg 0 (0.5) [0.5 on Ipop[1]], weight: -0.0016545403, delay 1.5
        h("Ipop[1] syn_projII_gaba[161] = new gaba(0.5)")
        h("Ipop[8] netConn_projII_gaba[161] = new NetCon(&v(0.5), syn_projII_gaba[161], 20.0, 1.5, -0.0016545403)")  

        # Connection 162: cell 8, seg 0 (0.5) [0.5 on Ipop[8]] -> cell 2, seg 0 (0.5) [0.5 on Ipop[2]], weight: -0.0016545403, delay 1.5
        h("Ipop[2] syn_projII_gaba[162] = new gaba(0.5)")
        h("Ipop[8] netConn_projII_gaba[162] = new NetCon(&v(0.5), syn_projII_gaba[162], 20.0, 1.5, -0.0016545403)")  

        # Connection 163: cell 8, seg 0 (0.5) [0.5 on Ipop[8]] -> cell 3, seg 0 (0.5) [0.5 on Ipop[3]], weight: -0.0016545403, delay 1.5
        h("Ipop[3] syn_projII_gaba[163] = new gaba(0.5)")
        h("Ipop[8] netConn_projII_gaba[163] = new NetCon(&v(0.5), syn_projII_gaba[163], 20.0, 1.5, -0.0016545403)")  

        # Connection 164: cell 8, seg 0 (0.5) [0.5 on Ipop[8]] -> cell 4, seg 0 (0.5) [0.5 on Ipop[4]], weight: -0.0016545403, delay 1.5
        h("Ipop[4] syn_projII_gaba[164] = new gaba(0.5)")
        h("Ipop[8] netConn_projII_gaba[164] = new NetCon(&v(0.5), syn_projII_gaba[164], 20.0, 1.5, -0.0016545403)")  

        # Connection 165: cell 8, seg 0 (0.5) [0.5 on Ipop[8]] -> cell 5, seg 0 (0.5) [0.5 on Ipop[5]], weight: -0.0016545403, delay 1.5
        h("Ipop[5] syn_projII_gaba[165] = new gaba(0.5)")
        h("Ipop[8] netConn_projII_gaba[165] = new NetCon(&v(0.5), syn_projII_gaba[165], 20.0, 1.5, -0.0016545403)")  

        # Connection 166: cell 8, seg 0 (0.5) [0.5 on Ipop[8]] -> cell 6, seg 0 (0.5) [0.5 on Ipop[6]], weight: -0.0016545403, delay 1.5
        h("Ipop[6] syn_projII_gaba[166] = new gaba(0.5)")
        h("Ipop[8] netConn_projII_gaba[166] = new NetCon(&v(0.5), syn_projII_gaba[166], 20.0, 1.5, -0.0016545403)")  

        # Connection 167: cell 8, seg 0 (0.5) [0.5 on Ipop[8]] -> cell 7, seg 0 (0.5) [0.5 on Ipop[7]], weight: -0.0016545403, delay 1.5
        h("Ipop[7] syn_projII_gaba[167] = new gaba(0.5)")
        h("Ipop[8] netConn_projII_gaba[167] = new NetCon(&v(0.5), syn_projII_gaba[167], 20.0, 1.5, -0.0016545403)")  

        # Connection 168: cell 8, seg 0 (0.5) [0.5 on Ipop[8]] -> cell 8, seg 0 (0.5) [0.5 on Ipop[8]], weight: -0.0016545403, delay 1.5
        h("Ipop[8] syn_projII_gaba[168] = new gaba(0.5)")
        h("Ipop[8] netConn_projII_gaba[168] = new NetCon(&v(0.5), syn_projII_gaba[168], 20.0, 1.5, -0.0016545403)")  

        # Connection 169: cell 8, seg 0 (0.5) [0.5 on Ipop[8]] -> cell 9, seg 0 (0.5) [0.5 on Ipop[9]], weight: -0.0016545403, delay 1.5
        h("Ipop[9] syn_projII_gaba[169] = new gaba(0.5)")
        h("Ipop[8] netConn_projII_gaba[169] = new NetCon(&v(0.5), syn_projII_gaba[169], 20.0, 1.5, -0.0016545403)")  

        # Connection 170: cell 8, seg 0 (0.5) [0.5 on Ipop[8]] -> cell 10, seg 0 (0.5) [0.5 on Ipop[10]], weight: -0.0016545403, delay 1.5
        h("Ipop[10] syn_projII_gaba[170] = new gaba(0.5)")
        h("Ipop[8] netConn_projII_gaba[170] = new NetCon(&v(0.5), syn_projII_gaba[170], 20.0, 1.5, -0.0016545403)")  

        # Connection 171: cell 8, seg 0 (0.5) [0.5 on Ipop[8]] -> cell 11, seg 0 (0.5) [0.5 on Ipop[11]], weight: -0.0016545403, delay 1.5
        h("Ipop[11] syn_projII_gaba[171] = new gaba(0.5)")
        h("Ipop[8] netConn_projII_gaba[171] = new NetCon(&v(0.5), syn_projII_gaba[171], 20.0, 1.5, -0.0016545403)")  

        # Connection 172: cell 8, seg 0 (0.5) [0.5 on Ipop[8]] -> cell 12, seg 0 (0.5) [0.5 on Ipop[12]], weight: -0.0016545403, delay 1.5
        h("Ipop[12] syn_projII_gaba[172] = new gaba(0.5)")
        h("Ipop[8] netConn_projII_gaba[172] = new NetCon(&v(0.5), syn_projII_gaba[172], 20.0, 1.5, -0.0016545403)")  

        # Connection 173: cell 8, seg 0 (0.5) [0.5 on Ipop[8]] -> cell 13, seg 0 (0.5) [0.5 on Ipop[13]], weight: -0.0016545403, delay 1.5
        h("Ipop[13] syn_projII_gaba[173] = new gaba(0.5)")
        h("Ipop[8] netConn_projII_gaba[173] = new NetCon(&v(0.5), syn_projII_gaba[173], 20.0, 1.5, -0.0016545403)")  

        # Connection 174: cell 8, seg 0 (0.5) [0.5 on Ipop[8]] -> cell 14, seg 0 (0.5) [0.5 on Ipop[14]], weight: -0.0016545403, delay 1.5
        h("Ipop[14] syn_projII_gaba[174] = new gaba(0.5)")
        h("Ipop[8] netConn_projII_gaba[174] = new NetCon(&v(0.5), syn_projII_gaba[174], 20.0, 1.5, -0.0016545403)")  

        # Connection 175: cell 8, seg 0 (0.5) [0.5 on Ipop[8]] -> cell 15, seg 0 (0.5) [0.5 on Ipop[15]], weight: -0.0016545403, delay 1.5
        h("Ipop[15] syn_projII_gaba[175] = new gaba(0.5)")
        h("Ipop[8] netConn_projII_gaba[175] = new NetCon(&v(0.5), syn_projII_gaba[175], 20.0, 1.5, -0.0016545403)")  

        # Connection 176: cell 8, seg 0 (0.5) [0.5 on Ipop[8]] -> cell 16, seg 0 (0.5) [0.5 on Ipop[16]], weight: -0.0016545403, delay 1.5
        h("Ipop[16] syn_projII_gaba[176] = new gaba(0.5)")
        h("Ipop[8] netConn_projII_gaba[176] = new NetCon(&v(0.5), syn_projII_gaba[176], 20.0, 1.5, -0.0016545403)")  

        # Connection 177: cell 8, seg 0 (0.5) [0.5 on Ipop[8]] -> cell 17, seg 0 (0.5) [0.5 on Ipop[17]], weight: -0.0016545403, delay 1.5
        h("Ipop[17] syn_projII_gaba[177] = new gaba(0.5)")
        h("Ipop[8] netConn_projII_gaba[177] = new NetCon(&v(0.5), syn_projII_gaba[177], 20.0, 1.5, -0.0016545403)")  

        # Connection 178: cell 8, seg 0 (0.5) [0.5 on Ipop[8]] -> cell 18, seg 0 (0.5) [0.5 on Ipop[18]], weight: -0.0016545403, delay 1.5
        h("Ipop[18] syn_projII_gaba[178] = new gaba(0.5)")
        h("Ipop[8] netConn_projII_gaba[178] = new NetCon(&v(0.5), syn_projII_gaba[178], 20.0, 1.5, -0.0016545403)")  

        # Connection 179: cell 8, seg 0 (0.5) [0.5 on Ipop[8]] -> cell 19, seg 0 (0.5) [0.5 on Ipop[19]], weight: -0.0016545403, delay 1.5
        h("Ipop[19] syn_projII_gaba[179] = new gaba(0.5)")
        h("Ipop[8] netConn_projII_gaba[179] = new NetCon(&v(0.5), syn_projII_gaba[179], 20.0, 1.5, -0.0016545403)")  

        # Connection 180: cell 9, seg 0 (0.5) [0.5 on Ipop[9]] -> cell 0, seg 0 (0.5) [0.5 on Ipop[0]], weight: -0.0016545403, delay 1.5
        h("Ipop[0] syn_projII_gaba[180] = new gaba(0.5)")
        h("Ipop[9] netConn_projII_gaba[180] = new NetCon(&v(0.5), syn_projII_gaba[180], 20.0, 1.5, -0.0016545403)")  

        # Connection 181: cell 9, seg 0 (0.5) [0.5 on Ipop[9]] -> cell 1, seg 0 (0.5) [0.5 on Ipop[1]], weight: -0.0016545403, delay 1.5
        h("Ipop[1] syn_projII_gaba[181] = new gaba(0.5)")
        h("Ipop[9] netConn_projII_gaba[181] = new NetCon(&v(0.5), syn_projII_gaba[181], 20.0, 1.5, -0.0016545403)")  

        # Connection 182: cell 9, seg 0 (0.5) [0.5 on Ipop[9]] -> cell 2, seg 0 (0.5) [0.5 on Ipop[2]], weight: -0.0016545403, delay 1.5
        h("Ipop[2] syn_projII_gaba[182] = new gaba(0.5)")
        h("Ipop[9] netConn_projII_gaba[182] = new NetCon(&v(0.5), syn_projII_gaba[182], 20.0, 1.5, -0.0016545403)")  

        # Connection 183: cell 9, seg 0 (0.5) [0.5 on Ipop[9]] -> cell 3, seg 0 (0.5) [0.5 on Ipop[3]], weight: -0.0016545403, delay 1.5
        h("Ipop[3] syn_projII_gaba[183] = new gaba(0.5)")
        h("Ipop[9] netConn_projII_gaba[183] = new NetCon(&v(0.5), syn_projII_gaba[183], 20.0, 1.5, -0.0016545403)")  

        # Connection 184: cell 9, seg 0 (0.5) [0.5 on Ipop[9]] -> cell 4, seg 0 (0.5) [0.5 on Ipop[4]], weight: -0.0016545403, delay 1.5
        h("Ipop[4] syn_projII_gaba[184] = new gaba(0.5)")
        h("Ipop[9] netConn_projII_gaba[184] = new NetCon(&v(0.5), syn_projII_gaba[184], 20.0, 1.5, -0.0016545403)")  

        # Connection 185: cell 9, seg 0 (0.5) [0.5 on Ipop[9]] -> cell 5, seg 0 (0.5) [0.5 on Ipop[5]], weight: -0.0016545403, delay 1.5
        h("Ipop[5] syn_projII_gaba[185] = new gaba(0.5)")
        h("Ipop[9] netConn_projII_gaba[185] = new NetCon(&v(0.5), syn_projII_gaba[185], 20.0, 1.5, -0.0016545403)")  

        # Connection 186: cell 9, seg 0 (0.5) [0.5 on Ipop[9]] -> cell 6, seg 0 (0.5) [0.5 on Ipop[6]], weight: -0.0016545403, delay 1.5
        h("Ipop[6] syn_projII_gaba[186] = new gaba(0.5)")
        h("Ipop[9] netConn_projII_gaba[186] = new NetCon(&v(0.5), syn_projII_gaba[186], 20.0, 1.5, -0.0016545403)")  

        # Connection 187: cell 9, seg 0 (0.5) [0.5 on Ipop[9]] -> cell 7, seg 0 (0.5) [0.5 on Ipop[7]], weight: -0.0016545403, delay 1.5
        h("Ipop[7] syn_projII_gaba[187] = new gaba(0.5)")
        h("Ipop[9] netConn_projII_gaba[187] = new NetCon(&v(0.5), syn_projII_gaba[187], 20.0, 1.5, -0.0016545403)")  

        # Connection 188: cell 9, seg 0 (0.5) [0.5 on Ipop[9]] -> cell 8, seg 0 (0.5) [0.5 on Ipop[8]], weight: -0.0016545403, delay 1.5
        h("Ipop[8] syn_projII_gaba[188] = new gaba(0.5)")
        h("Ipop[9] netConn_projII_gaba[188] = new NetCon(&v(0.5), syn_projII_gaba[188], 20.0, 1.5, -0.0016545403)")  

        # Connection 189: cell 9, seg 0 (0.5) [0.5 on Ipop[9]] -> cell 9, seg 0 (0.5) [0.5 on Ipop[9]], weight: -0.0016545403, delay 1.5
        h("Ipop[9] syn_projII_gaba[189] = new gaba(0.5)")
        h("Ipop[9] netConn_projII_gaba[189] = new NetCon(&v(0.5), syn_projII_gaba[189], 20.0, 1.5, -0.0016545403)")  

        # Connection 190: cell 9, seg 0 (0.5) [0.5 on Ipop[9]] -> cell 10, seg 0 (0.5) [0.5 on Ipop[10]], weight: -0.0016545403, delay 1.5
        h("Ipop[10] syn_projII_gaba[190] = new gaba(0.5)")
        h("Ipop[9] netConn_projII_gaba[190] = new NetCon(&v(0.5), syn_projII_gaba[190], 20.0, 1.5, -0.0016545403)")  

        # Connection 191: cell 9, seg 0 (0.5) [0.5 on Ipop[9]] -> cell 11, seg 0 (0.5) [0.5 on Ipop[11]], weight: -0.0016545403, delay 1.5
        h("Ipop[11] syn_projII_gaba[191] = new gaba(0.5)")
        h("Ipop[9] netConn_projII_gaba[191] = new NetCon(&v(0.5), syn_projII_gaba[191], 20.0, 1.5, -0.0016545403)")  

        # Connection 192: cell 9, seg 0 (0.5) [0.5 on Ipop[9]] -> cell 12, seg 0 (0.5) [0.5 on Ipop[12]], weight: -0.0016545403, delay 1.5
        h("Ipop[12] syn_projII_gaba[192] = new gaba(0.5)")
        h("Ipop[9] netConn_projII_gaba[192] = new NetCon(&v(0.5), syn_projII_gaba[192], 20.0, 1.5, -0.0016545403)")  

        # Connection 193: cell 9, seg 0 (0.5) [0.5 on Ipop[9]] -> cell 13, seg 0 (0.5) [0.5 on Ipop[13]], weight: -0.0016545403, delay 1.5
        h("Ipop[13] syn_projII_gaba[193] = new gaba(0.5)")
        h("Ipop[9] netConn_projII_gaba[193] = new NetCon(&v(0.5), syn_projII_gaba[193], 20.0, 1.5, -0.0016545403)")  

        # Connection 194: cell 9, seg 0 (0.5) [0.5 on Ipop[9]] -> cell 14, seg 0 (0.5) [0.5 on Ipop[14]], weight: -0.0016545403, delay 1.5
        h("Ipop[14] syn_projII_gaba[194] = new gaba(0.5)")
        h("Ipop[9] netConn_projII_gaba[194] = new NetCon(&v(0.5), syn_projII_gaba[194], 20.0, 1.5, -0.0016545403)")  

        # Connection 195: cell 9, seg 0 (0.5) [0.5 on Ipop[9]] -> cell 15, seg 0 (0.5) [0.5 on Ipop[15]], weight: -0.0016545403, delay 1.5
        h("Ipop[15] syn_projII_gaba[195] = new gaba(0.5)")
        h("Ipop[9] netConn_projII_gaba[195] = new NetCon(&v(0.5), syn_projII_gaba[195], 20.0, 1.5, -0.0016545403)")  

        # Connection 196: cell 9, seg 0 (0.5) [0.5 on Ipop[9]] -> cell 16, seg 0 (0.5) [0.5 on Ipop[16]], weight: -0.0016545403, delay 1.5
        h("Ipop[16] syn_projII_gaba[196] = new gaba(0.5)")
        h("Ipop[9] netConn_projII_gaba[196] = new NetCon(&v(0.5), syn_projII_gaba[196], 20.0, 1.5, -0.0016545403)")  

        # Connection 197: cell 9, seg 0 (0.5) [0.5 on Ipop[9]] -> cell 17, seg 0 (0.5) [0.5 on Ipop[17]], weight: -0.0016545403, delay 1.5
        h("Ipop[17] syn_projII_gaba[197] = new gaba(0.5)")
        h("Ipop[9] netConn_projII_gaba[197] = new NetCon(&v(0.5), syn_projII_gaba[197], 20.0, 1.5, -0.0016545403)")  

        # Connection 198: cell 9, seg 0 (0.5) [0.5 on Ipop[9]] -> cell 18, seg 0 (0.5) [0.5 on Ipop[18]], weight: -0.0016545403, delay 1.5
        h("Ipop[18] syn_projII_gaba[198] = new gaba(0.5)")
        h("Ipop[9] netConn_projII_gaba[198] = new NetCon(&v(0.5), syn_projII_gaba[198], 20.0, 1.5, -0.0016545403)")  

        # Connection 199: cell 9, seg 0 (0.5) [0.5 on Ipop[9]] -> cell 19, seg 0 (0.5) [0.5 on Ipop[19]], weight: -0.0016545403, delay 1.5
        h("Ipop[19] syn_projII_gaba[199] = new gaba(0.5)")
        h("Ipop[9] netConn_projII_gaba[199] = new NetCon(&v(0.5), syn_projII_gaba[199], 20.0, 1.5, -0.0016545403)")  

        # Connection 200: cell 10, seg 0 (0.5) [0.5 on Ipop[10]] -> cell 0, seg 0 (0.5) [0.5 on Ipop[0]], weight: -0.0016545403, delay 1.5
        h("Ipop[0] syn_projII_gaba[200] = new gaba(0.5)")
        h("Ipop[10] netConn_projII_gaba[200] = new NetCon(&v(0.5), syn_projII_gaba[200], 20.0, 1.5, -0.0016545403)")  

        # Connection 201: cell 10, seg 0 (0.5) [0.5 on Ipop[10]] -> cell 1, seg 0 (0.5) [0.5 on Ipop[1]], weight: -0.0016545403, delay 1.5
        h("Ipop[1] syn_projII_gaba[201] = new gaba(0.5)")
        h("Ipop[10] netConn_projII_gaba[201] = new NetCon(&v(0.5), syn_projII_gaba[201], 20.0, 1.5, -0.0016545403)")  

        # Connection 202: cell 10, seg 0 (0.5) [0.5 on Ipop[10]] -> cell 2, seg 0 (0.5) [0.5 on Ipop[2]], weight: -0.0016545403, delay 1.5
        h("Ipop[2] syn_projII_gaba[202] = new gaba(0.5)")
        h("Ipop[10] netConn_projII_gaba[202] = new NetCon(&v(0.5), syn_projII_gaba[202], 20.0, 1.5, -0.0016545403)")  

        # Connection 203: cell 10, seg 0 (0.5) [0.5 on Ipop[10]] -> cell 3, seg 0 (0.5) [0.5 on Ipop[3]], weight: -0.0016545403, delay 1.5
        h("Ipop[3] syn_projII_gaba[203] = new gaba(0.5)")
        h("Ipop[10] netConn_projII_gaba[203] = new NetCon(&v(0.5), syn_projII_gaba[203], 20.0, 1.5, -0.0016545403)")  

        # Connection 204: cell 10, seg 0 (0.5) [0.5 on Ipop[10]] -> cell 4, seg 0 (0.5) [0.5 on Ipop[4]], weight: -0.0016545403, delay 1.5
        h("Ipop[4] syn_projII_gaba[204] = new gaba(0.5)")
        h("Ipop[10] netConn_projII_gaba[204] = new NetCon(&v(0.5), syn_projII_gaba[204], 20.0, 1.5, -0.0016545403)")  

        # Connection 205: cell 10, seg 0 (0.5) [0.5 on Ipop[10]] -> cell 5, seg 0 (0.5) [0.5 on Ipop[5]], weight: -0.0016545403, delay 1.5
        h("Ipop[5] syn_projII_gaba[205] = new gaba(0.5)")
        h("Ipop[10] netConn_projII_gaba[205] = new NetCon(&v(0.5), syn_projII_gaba[205], 20.0, 1.5, -0.0016545403)")  

        # Connection 206: cell 10, seg 0 (0.5) [0.5 on Ipop[10]] -> cell 6, seg 0 (0.5) [0.5 on Ipop[6]], weight: -0.0016545403, delay 1.5
        h("Ipop[6] syn_projII_gaba[206] = new gaba(0.5)")
        h("Ipop[10] netConn_projII_gaba[206] = new NetCon(&v(0.5), syn_projII_gaba[206], 20.0, 1.5, -0.0016545403)")  

        # Connection 207: cell 10, seg 0 (0.5) [0.5 on Ipop[10]] -> cell 7, seg 0 (0.5) [0.5 on Ipop[7]], weight: -0.0016545403, delay 1.5
        h("Ipop[7] syn_projII_gaba[207] = new gaba(0.5)")
        h("Ipop[10] netConn_projII_gaba[207] = new NetCon(&v(0.5), syn_projII_gaba[207], 20.0, 1.5, -0.0016545403)")  

        # Connection 208: cell 10, seg 0 (0.5) [0.5 on Ipop[10]] -> cell 8, seg 0 (0.5) [0.5 on Ipop[8]], weight: -0.0016545403, delay 1.5
        h("Ipop[8] syn_projII_gaba[208] = new gaba(0.5)")
        h("Ipop[10] netConn_projII_gaba[208] = new NetCon(&v(0.5), syn_projII_gaba[208], 20.0, 1.5, -0.0016545403)")  

        # Connection 209: cell 10, seg 0 (0.5) [0.5 on Ipop[10]] -> cell 9, seg 0 (0.5) [0.5 on Ipop[9]], weight: -0.0016545403, delay 1.5
        h("Ipop[9] syn_projII_gaba[209] = new gaba(0.5)")
        h("Ipop[10] netConn_projII_gaba[209] = new NetCon(&v(0.5), syn_projII_gaba[209], 20.0, 1.5, -0.0016545403)")  

        # Connection 210: cell 10, seg 0 (0.5) [0.5 on Ipop[10]] -> cell 10, seg 0 (0.5) [0.5 on Ipop[10]], weight: -0.0016545403, delay 1.5
        h("Ipop[10] syn_projII_gaba[210] = new gaba(0.5)")
        h("Ipop[10] netConn_projII_gaba[210] = new NetCon(&v(0.5), syn_projII_gaba[210], 20.0, 1.5, -0.0016545403)")  

        # Connection 211: cell 10, seg 0 (0.5) [0.5 on Ipop[10]] -> cell 11, seg 0 (0.5) [0.5 on Ipop[11]], weight: -0.0016545403, delay 1.5
        h("Ipop[11] syn_projII_gaba[211] = new gaba(0.5)")
        h("Ipop[10] netConn_projII_gaba[211] = new NetCon(&v(0.5), syn_projII_gaba[211], 20.0, 1.5, -0.0016545403)")  

        # Connection 212: cell 10, seg 0 (0.5) [0.5 on Ipop[10]] -> cell 12, seg 0 (0.5) [0.5 on Ipop[12]], weight: -0.0016545403, delay 1.5
        h("Ipop[12] syn_projII_gaba[212] = new gaba(0.5)")
        h("Ipop[10] netConn_projII_gaba[212] = new NetCon(&v(0.5), syn_projII_gaba[212], 20.0, 1.5, -0.0016545403)")  

        # Connection 213: cell 10, seg 0 (0.5) [0.5 on Ipop[10]] -> cell 13, seg 0 (0.5) [0.5 on Ipop[13]], weight: -0.0016545403, delay 1.5
        h("Ipop[13] syn_projII_gaba[213] = new gaba(0.5)")
        h("Ipop[10] netConn_projII_gaba[213] = new NetCon(&v(0.5), syn_projII_gaba[213], 20.0, 1.5, -0.0016545403)")  

        # Connection 214: cell 10, seg 0 (0.5) [0.5 on Ipop[10]] -> cell 14, seg 0 (0.5) [0.5 on Ipop[14]], weight: -0.0016545403, delay 1.5
        h("Ipop[14] syn_projII_gaba[214] = new gaba(0.5)")
        h("Ipop[10] netConn_projII_gaba[214] = new NetCon(&v(0.5), syn_projII_gaba[214], 20.0, 1.5, -0.0016545403)")  

        # Connection 215: cell 10, seg 0 (0.5) [0.5 on Ipop[10]] -> cell 15, seg 0 (0.5) [0.5 on Ipop[15]], weight: -0.0016545403, delay 1.5
        h("Ipop[15] syn_projII_gaba[215] = new gaba(0.5)")
        h("Ipop[10] netConn_projII_gaba[215] = new NetCon(&v(0.5), syn_projII_gaba[215], 20.0, 1.5, -0.0016545403)")  

        # Connection 216: cell 10, seg 0 (0.5) [0.5 on Ipop[10]] -> cell 16, seg 0 (0.5) [0.5 on Ipop[16]], weight: -0.0016545403, delay 1.5
        h("Ipop[16] syn_projII_gaba[216] = new gaba(0.5)")
        h("Ipop[10] netConn_projII_gaba[216] = new NetCon(&v(0.5), syn_projII_gaba[216], 20.0, 1.5, -0.0016545403)")  

        # Connection 217: cell 10, seg 0 (0.5) [0.5 on Ipop[10]] -> cell 17, seg 0 (0.5) [0.5 on Ipop[17]], weight: -0.0016545403, delay 1.5
        h("Ipop[17] syn_projII_gaba[217] = new gaba(0.5)")
        h("Ipop[10] netConn_projII_gaba[217] = new NetCon(&v(0.5), syn_projII_gaba[217], 20.0, 1.5, -0.0016545403)")  

        # Connection 218: cell 10, seg 0 (0.5) [0.5 on Ipop[10]] -> cell 18, seg 0 (0.5) [0.5 on Ipop[18]], weight: -0.0016545403, delay 1.5
        h("Ipop[18] syn_projII_gaba[218] = new gaba(0.5)")
        h("Ipop[10] netConn_projII_gaba[218] = new NetCon(&v(0.5), syn_projII_gaba[218], 20.0, 1.5, -0.0016545403)")  

        # Connection 219: cell 10, seg 0 (0.5) [0.5 on Ipop[10]] -> cell 19, seg 0 (0.5) [0.5 on Ipop[19]], weight: -0.0016545403, delay 1.5
        h("Ipop[19] syn_projII_gaba[219] = new gaba(0.5)")
        h("Ipop[10] netConn_projII_gaba[219] = new NetCon(&v(0.5), syn_projII_gaba[219], 20.0, 1.5, -0.0016545403)")  

        # Connection 220: cell 11, seg 0 (0.5) [0.5 on Ipop[11]] -> cell 0, seg 0 (0.5) [0.5 on Ipop[0]], weight: -0.0016545403, delay 1.5
        h("Ipop[0] syn_projII_gaba[220] = new gaba(0.5)")
        h("Ipop[11] netConn_projII_gaba[220] = new NetCon(&v(0.5), syn_projII_gaba[220], 20.0, 1.5, -0.0016545403)")  

        # Connection 221: cell 11, seg 0 (0.5) [0.5 on Ipop[11]] -> cell 1, seg 0 (0.5) [0.5 on Ipop[1]], weight: -0.0016545403, delay 1.5
        h("Ipop[1] syn_projII_gaba[221] = new gaba(0.5)")
        h("Ipop[11] netConn_projII_gaba[221] = new NetCon(&v(0.5), syn_projII_gaba[221], 20.0, 1.5, -0.0016545403)")  

        # Connection 222: cell 11, seg 0 (0.5) [0.5 on Ipop[11]] -> cell 2, seg 0 (0.5) [0.5 on Ipop[2]], weight: -0.0016545403, delay 1.5
        h("Ipop[2] syn_projII_gaba[222] = new gaba(0.5)")
        h("Ipop[11] netConn_projII_gaba[222] = new NetCon(&v(0.5), syn_projII_gaba[222], 20.0, 1.5, -0.0016545403)")  

        # Connection 223: cell 11, seg 0 (0.5) [0.5 on Ipop[11]] -> cell 3, seg 0 (0.5) [0.5 on Ipop[3]], weight: -0.0016545403, delay 1.5
        h("Ipop[3] syn_projII_gaba[223] = new gaba(0.5)")
        h("Ipop[11] netConn_projII_gaba[223] = new NetCon(&v(0.5), syn_projII_gaba[223], 20.0, 1.5, -0.0016545403)")  

        # Connection 224: cell 11, seg 0 (0.5) [0.5 on Ipop[11]] -> cell 4, seg 0 (0.5) [0.5 on Ipop[4]], weight: -0.0016545403, delay 1.5
        h("Ipop[4] syn_projII_gaba[224] = new gaba(0.5)")
        h("Ipop[11] netConn_projII_gaba[224] = new NetCon(&v(0.5), syn_projII_gaba[224], 20.0, 1.5, -0.0016545403)")  

        # Connection 225: cell 11, seg 0 (0.5) [0.5 on Ipop[11]] -> cell 5, seg 0 (0.5) [0.5 on Ipop[5]], weight: -0.0016545403, delay 1.5
        h("Ipop[5] syn_projII_gaba[225] = new gaba(0.5)")
        h("Ipop[11] netConn_projII_gaba[225] = new NetCon(&v(0.5), syn_projII_gaba[225], 20.0, 1.5, -0.0016545403)")  

        # Connection 226: cell 11, seg 0 (0.5) [0.5 on Ipop[11]] -> cell 6, seg 0 (0.5) [0.5 on Ipop[6]], weight: -0.0016545403, delay 1.5
        h("Ipop[6] syn_projII_gaba[226] = new gaba(0.5)")
        h("Ipop[11] netConn_projII_gaba[226] = new NetCon(&v(0.5), syn_projII_gaba[226], 20.0, 1.5, -0.0016545403)")  

        # Connection 227: cell 11, seg 0 (0.5) [0.5 on Ipop[11]] -> cell 7, seg 0 (0.5) [0.5 on Ipop[7]], weight: -0.0016545403, delay 1.5
        h("Ipop[7] syn_projII_gaba[227] = new gaba(0.5)")
        h("Ipop[11] netConn_projII_gaba[227] = new NetCon(&v(0.5), syn_projII_gaba[227], 20.0, 1.5, -0.0016545403)")  

        # Connection 228: cell 11, seg 0 (0.5) [0.5 on Ipop[11]] -> cell 8, seg 0 (0.5) [0.5 on Ipop[8]], weight: -0.0016545403, delay 1.5
        h("Ipop[8] syn_projII_gaba[228] = new gaba(0.5)")
        h("Ipop[11] netConn_projII_gaba[228] = new NetCon(&v(0.5), syn_projII_gaba[228], 20.0, 1.5, -0.0016545403)")  

        # Connection 229: cell 11, seg 0 (0.5) [0.5 on Ipop[11]] -> cell 9, seg 0 (0.5) [0.5 on Ipop[9]], weight: -0.0016545403, delay 1.5
        h("Ipop[9] syn_projII_gaba[229] = new gaba(0.5)")
        h("Ipop[11] netConn_projII_gaba[229] = new NetCon(&v(0.5), syn_projII_gaba[229], 20.0, 1.5, -0.0016545403)")  

        # Connection 230: cell 11, seg 0 (0.5) [0.5 on Ipop[11]] -> cell 10, seg 0 (0.5) [0.5 on Ipop[10]], weight: -0.0016545403, delay 1.5
        h("Ipop[10] syn_projII_gaba[230] = new gaba(0.5)")
        h("Ipop[11] netConn_projII_gaba[230] = new NetCon(&v(0.5), syn_projII_gaba[230], 20.0, 1.5, -0.0016545403)")  

        # Connection 231: cell 11, seg 0 (0.5) [0.5 on Ipop[11]] -> cell 11, seg 0 (0.5) [0.5 on Ipop[11]], weight: -0.0016545403, delay 1.5
        h("Ipop[11] syn_projII_gaba[231] = new gaba(0.5)")
        h("Ipop[11] netConn_projII_gaba[231] = new NetCon(&v(0.5), syn_projII_gaba[231], 20.0, 1.5, -0.0016545403)")  

        # Connection 232: cell 11, seg 0 (0.5) [0.5 on Ipop[11]] -> cell 12, seg 0 (0.5) [0.5 on Ipop[12]], weight: -0.0016545403, delay 1.5
        h("Ipop[12] syn_projII_gaba[232] = new gaba(0.5)")
        h("Ipop[11] netConn_projII_gaba[232] = new NetCon(&v(0.5), syn_projII_gaba[232], 20.0, 1.5, -0.0016545403)")  

        # Connection 233: cell 11, seg 0 (0.5) [0.5 on Ipop[11]] -> cell 13, seg 0 (0.5) [0.5 on Ipop[13]], weight: -0.0016545403, delay 1.5
        h("Ipop[13] syn_projII_gaba[233] = new gaba(0.5)")
        h("Ipop[11] netConn_projII_gaba[233] = new NetCon(&v(0.5), syn_projII_gaba[233], 20.0, 1.5, -0.0016545403)")  

        # Connection 234: cell 11, seg 0 (0.5) [0.5 on Ipop[11]] -> cell 14, seg 0 (0.5) [0.5 on Ipop[14]], weight: -0.0016545403, delay 1.5
        h("Ipop[14] syn_projII_gaba[234] = new gaba(0.5)")
        h("Ipop[11] netConn_projII_gaba[234] = new NetCon(&v(0.5), syn_projII_gaba[234], 20.0, 1.5, -0.0016545403)")  

        # Connection 235: cell 11, seg 0 (0.5) [0.5 on Ipop[11]] -> cell 15, seg 0 (0.5) [0.5 on Ipop[15]], weight: -0.0016545403, delay 1.5
        h("Ipop[15] syn_projII_gaba[235] = new gaba(0.5)")
        h("Ipop[11] netConn_projII_gaba[235] = new NetCon(&v(0.5), syn_projII_gaba[235], 20.0, 1.5, -0.0016545403)")  

        # Connection 236: cell 11, seg 0 (0.5) [0.5 on Ipop[11]] -> cell 16, seg 0 (0.5) [0.5 on Ipop[16]], weight: -0.0016545403, delay 1.5
        h("Ipop[16] syn_projII_gaba[236] = new gaba(0.5)")
        h("Ipop[11] netConn_projII_gaba[236] = new NetCon(&v(0.5), syn_projII_gaba[236], 20.0, 1.5, -0.0016545403)")  

        # Connection 237: cell 11, seg 0 (0.5) [0.5 on Ipop[11]] -> cell 17, seg 0 (0.5) [0.5 on Ipop[17]], weight: -0.0016545403, delay 1.5
        h("Ipop[17] syn_projII_gaba[237] = new gaba(0.5)")
        h("Ipop[11] netConn_projII_gaba[237] = new NetCon(&v(0.5), syn_projII_gaba[237], 20.0, 1.5, -0.0016545403)")  

        # Connection 238: cell 11, seg 0 (0.5) [0.5 on Ipop[11]] -> cell 18, seg 0 (0.5) [0.5 on Ipop[18]], weight: -0.0016545403, delay 1.5
        h("Ipop[18] syn_projII_gaba[238] = new gaba(0.5)")
        h("Ipop[11] netConn_projII_gaba[238] = new NetCon(&v(0.5), syn_projII_gaba[238], 20.0, 1.5, -0.0016545403)")  

        # Connection 239: cell 11, seg 0 (0.5) [0.5 on Ipop[11]] -> cell 19, seg 0 (0.5) [0.5 on Ipop[19]], weight: -0.0016545403, delay 1.5
        h("Ipop[19] syn_projII_gaba[239] = new gaba(0.5)")
        h("Ipop[11] netConn_projII_gaba[239] = new NetCon(&v(0.5), syn_projII_gaba[239], 20.0, 1.5, -0.0016545403)")  

        # Connection 240: cell 12, seg 0 (0.5) [0.5 on Ipop[12]] -> cell 0, seg 0 (0.5) [0.5 on Ipop[0]], weight: -0.0016545403, delay 1.5
        h("Ipop[0] syn_projII_gaba[240] = new gaba(0.5)")
        h("Ipop[12] netConn_projII_gaba[240] = new NetCon(&v(0.5), syn_projII_gaba[240], 20.0, 1.5, -0.0016545403)")  

        # Connection 241: cell 12, seg 0 (0.5) [0.5 on Ipop[12]] -> cell 1, seg 0 (0.5) [0.5 on Ipop[1]], weight: -0.0016545403, delay 1.5
        h("Ipop[1] syn_projII_gaba[241] = new gaba(0.5)")
        h("Ipop[12] netConn_projII_gaba[241] = new NetCon(&v(0.5), syn_projII_gaba[241], 20.0, 1.5, -0.0016545403)")  

        # Connection 242: cell 12, seg 0 (0.5) [0.5 on Ipop[12]] -> cell 2, seg 0 (0.5) [0.5 on Ipop[2]], weight: -0.0016545403, delay 1.5
        h("Ipop[2] syn_projII_gaba[242] = new gaba(0.5)")
        h("Ipop[12] netConn_projII_gaba[242] = new NetCon(&v(0.5), syn_projII_gaba[242], 20.0, 1.5, -0.0016545403)")  

        # Connection 243: cell 12, seg 0 (0.5) [0.5 on Ipop[12]] -> cell 3, seg 0 (0.5) [0.5 on Ipop[3]], weight: -0.0016545403, delay 1.5
        h("Ipop[3] syn_projII_gaba[243] = new gaba(0.5)")
        h("Ipop[12] netConn_projII_gaba[243] = new NetCon(&v(0.5), syn_projII_gaba[243], 20.0, 1.5, -0.0016545403)")  

        # Connection 244: cell 12, seg 0 (0.5) [0.5 on Ipop[12]] -> cell 4, seg 0 (0.5) [0.5 on Ipop[4]], weight: -0.0016545403, delay 1.5
        h("Ipop[4] syn_projII_gaba[244] = new gaba(0.5)")
        h("Ipop[12] netConn_projII_gaba[244] = new NetCon(&v(0.5), syn_projII_gaba[244], 20.0, 1.5, -0.0016545403)")  

        # Connection 245: cell 12, seg 0 (0.5) [0.5 on Ipop[12]] -> cell 5, seg 0 (0.5) [0.5 on Ipop[5]], weight: -0.0016545403, delay 1.5
        h("Ipop[5] syn_projII_gaba[245] = new gaba(0.5)")
        h("Ipop[12] netConn_projII_gaba[245] = new NetCon(&v(0.5), syn_projII_gaba[245], 20.0, 1.5, -0.0016545403)")  

        # Connection 246: cell 12, seg 0 (0.5) [0.5 on Ipop[12]] -> cell 6, seg 0 (0.5) [0.5 on Ipop[6]], weight: -0.0016545403, delay 1.5
        h("Ipop[6] syn_projII_gaba[246] = new gaba(0.5)")
        h("Ipop[12] netConn_projII_gaba[246] = new NetCon(&v(0.5), syn_projII_gaba[246], 20.0, 1.5, -0.0016545403)")  

        # Connection 247: cell 12, seg 0 (0.5) [0.5 on Ipop[12]] -> cell 7, seg 0 (0.5) [0.5 on Ipop[7]], weight: -0.0016545403, delay 1.5
        h("Ipop[7] syn_projII_gaba[247] = new gaba(0.5)")
        h("Ipop[12] netConn_projII_gaba[247] = new NetCon(&v(0.5), syn_projII_gaba[247], 20.0, 1.5, -0.0016545403)")  

        # Connection 248: cell 12, seg 0 (0.5) [0.5 on Ipop[12]] -> cell 8, seg 0 (0.5) [0.5 on Ipop[8]], weight: -0.0016545403, delay 1.5
        h("Ipop[8] syn_projII_gaba[248] = new gaba(0.5)")
        h("Ipop[12] netConn_projII_gaba[248] = new NetCon(&v(0.5), syn_projII_gaba[248], 20.0, 1.5, -0.0016545403)")  

        # Connection 249: cell 12, seg 0 (0.5) [0.5 on Ipop[12]] -> cell 9, seg 0 (0.5) [0.5 on Ipop[9]], weight: -0.0016545403, delay 1.5
        h("Ipop[9] syn_projII_gaba[249] = new gaba(0.5)")
        h("Ipop[12] netConn_projII_gaba[249] = new NetCon(&v(0.5), syn_projII_gaba[249], 20.0, 1.5, -0.0016545403)")  

        # Connection 250: cell 12, seg 0 (0.5) [0.5 on Ipop[12]] -> cell 10, seg 0 (0.5) [0.5 on Ipop[10]], weight: -0.0016545403, delay 1.5
        h("Ipop[10] syn_projII_gaba[250] = new gaba(0.5)")
        h("Ipop[12] netConn_projII_gaba[250] = new NetCon(&v(0.5), syn_projII_gaba[250], 20.0, 1.5, -0.0016545403)")  

        # Connection 251: cell 12, seg 0 (0.5) [0.5 on Ipop[12]] -> cell 11, seg 0 (0.5) [0.5 on Ipop[11]], weight: -0.0016545403, delay 1.5
        h("Ipop[11] syn_projII_gaba[251] = new gaba(0.5)")
        h("Ipop[12] netConn_projII_gaba[251] = new NetCon(&v(0.5), syn_projII_gaba[251], 20.0, 1.5, -0.0016545403)")  

        # Connection 252: cell 12, seg 0 (0.5) [0.5 on Ipop[12]] -> cell 12, seg 0 (0.5) [0.5 on Ipop[12]], weight: -0.0016545403, delay 1.5
        h("Ipop[12] syn_projII_gaba[252] = new gaba(0.5)")
        h("Ipop[12] netConn_projII_gaba[252] = new NetCon(&v(0.5), syn_projII_gaba[252], 20.0, 1.5, -0.0016545403)")  

        # Connection 253: cell 12, seg 0 (0.5) [0.5 on Ipop[12]] -> cell 13, seg 0 (0.5) [0.5 on Ipop[13]], weight: -0.0016545403, delay 1.5
        h("Ipop[13] syn_projII_gaba[253] = new gaba(0.5)")
        h("Ipop[12] netConn_projII_gaba[253] = new NetCon(&v(0.5), syn_projII_gaba[253], 20.0, 1.5, -0.0016545403)")  

        # Connection 254: cell 12, seg 0 (0.5) [0.5 on Ipop[12]] -> cell 14, seg 0 (0.5) [0.5 on Ipop[14]], weight: -0.0016545403, delay 1.5
        h("Ipop[14] syn_projII_gaba[254] = new gaba(0.5)")
        h("Ipop[12] netConn_projII_gaba[254] = new NetCon(&v(0.5), syn_projII_gaba[254], 20.0, 1.5, -0.0016545403)")  

        # Connection 255: cell 12, seg 0 (0.5) [0.5 on Ipop[12]] -> cell 15, seg 0 (0.5) [0.5 on Ipop[15]], weight: -0.0016545403, delay 1.5
        h("Ipop[15] syn_projII_gaba[255] = new gaba(0.5)")
        h("Ipop[12] netConn_projII_gaba[255] = new NetCon(&v(0.5), syn_projII_gaba[255], 20.0, 1.5, -0.0016545403)")  

        # Connection 256: cell 12, seg 0 (0.5) [0.5 on Ipop[12]] -> cell 16, seg 0 (0.5) [0.5 on Ipop[16]], weight: -0.0016545403, delay 1.5
        h("Ipop[16] syn_projII_gaba[256] = new gaba(0.5)")
        h("Ipop[12] netConn_projII_gaba[256] = new NetCon(&v(0.5), syn_projII_gaba[256], 20.0, 1.5, -0.0016545403)")  

        # Connection 257: cell 12, seg 0 (0.5) [0.5 on Ipop[12]] -> cell 17, seg 0 (0.5) [0.5 on Ipop[17]], weight: -0.0016545403, delay 1.5
        h("Ipop[17] syn_projII_gaba[257] = new gaba(0.5)")
        h("Ipop[12] netConn_projII_gaba[257] = new NetCon(&v(0.5), syn_projII_gaba[257], 20.0, 1.5, -0.0016545403)")  

        # Connection 258: cell 12, seg 0 (0.5) [0.5 on Ipop[12]] -> cell 18, seg 0 (0.5) [0.5 on Ipop[18]], weight: -0.0016545403, delay 1.5
        h("Ipop[18] syn_projII_gaba[258] = new gaba(0.5)")
        h("Ipop[12] netConn_projII_gaba[258] = new NetCon(&v(0.5), syn_projII_gaba[258], 20.0, 1.5, -0.0016545403)")  

        # Connection 259: cell 12, seg 0 (0.5) [0.5 on Ipop[12]] -> cell 19, seg 0 (0.5) [0.5 on Ipop[19]], weight: -0.0016545403, delay 1.5
        h("Ipop[19] syn_projII_gaba[259] = new gaba(0.5)")
        h("Ipop[12] netConn_projII_gaba[259] = new NetCon(&v(0.5), syn_projII_gaba[259], 20.0, 1.5, -0.0016545403)")  

        # Connection 260: cell 13, seg 0 (0.5) [0.5 on Ipop[13]] -> cell 0, seg 0 (0.5) [0.5 on Ipop[0]], weight: -0.0016545403, delay 1.5
        h("Ipop[0] syn_projII_gaba[260] = new gaba(0.5)")
        h("Ipop[13] netConn_projII_gaba[260] = new NetCon(&v(0.5), syn_projII_gaba[260], 20.0, 1.5, -0.0016545403)")  

        # Connection 261: cell 13, seg 0 (0.5) [0.5 on Ipop[13]] -> cell 1, seg 0 (0.5) [0.5 on Ipop[1]], weight: -0.0016545403, delay 1.5
        h("Ipop[1] syn_projII_gaba[261] = new gaba(0.5)")
        h("Ipop[13] netConn_projII_gaba[261] = new NetCon(&v(0.5), syn_projII_gaba[261], 20.0, 1.5, -0.0016545403)")  

        # Connection 262: cell 13, seg 0 (0.5) [0.5 on Ipop[13]] -> cell 2, seg 0 (0.5) [0.5 on Ipop[2]], weight: -0.0016545403, delay 1.5
        h("Ipop[2] syn_projII_gaba[262] = new gaba(0.5)")
        h("Ipop[13] netConn_projII_gaba[262] = new NetCon(&v(0.5), syn_projII_gaba[262], 20.0, 1.5, -0.0016545403)")  

        # Connection 263: cell 13, seg 0 (0.5) [0.5 on Ipop[13]] -> cell 3, seg 0 (0.5) [0.5 on Ipop[3]], weight: -0.0016545403, delay 1.5
        h("Ipop[3] syn_projII_gaba[263] = new gaba(0.5)")
        h("Ipop[13] netConn_projII_gaba[263] = new NetCon(&v(0.5), syn_projII_gaba[263], 20.0, 1.5, -0.0016545403)")  

        # Connection 264: cell 13, seg 0 (0.5) [0.5 on Ipop[13]] -> cell 4, seg 0 (0.5) [0.5 on Ipop[4]], weight: -0.0016545403, delay 1.5
        h("Ipop[4] syn_projII_gaba[264] = new gaba(0.5)")
        h("Ipop[13] netConn_projII_gaba[264] = new NetCon(&v(0.5), syn_projII_gaba[264], 20.0, 1.5, -0.0016545403)")  

        # Connection 265: cell 13, seg 0 (0.5) [0.5 on Ipop[13]] -> cell 5, seg 0 (0.5) [0.5 on Ipop[5]], weight: -0.0016545403, delay 1.5
        h("Ipop[5] syn_projII_gaba[265] = new gaba(0.5)")
        h("Ipop[13] netConn_projII_gaba[265] = new NetCon(&v(0.5), syn_projII_gaba[265], 20.0, 1.5, -0.0016545403)")  

        # Connection 266: cell 13, seg 0 (0.5) [0.5 on Ipop[13]] -> cell 6, seg 0 (0.5) [0.5 on Ipop[6]], weight: -0.0016545403, delay 1.5
        h("Ipop[6] syn_projII_gaba[266] = new gaba(0.5)")
        h("Ipop[13] netConn_projII_gaba[266] = new NetCon(&v(0.5), syn_projII_gaba[266], 20.0, 1.5, -0.0016545403)")  

        # Connection 267: cell 13, seg 0 (0.5) [0.5 on Ipop[13]] -> cell 7, seg 0 (0.5) [0.5 on Ipop[7]], weight: -0.0016545403, delay 1.5
        h("Ipop[7] syn_projII_gaba[267] = new gaba(0.5)")
        h("Ipop[13] netConn_projII_gaba[267] = new NetCon(&v(0.5), syn_projII_gaba[267], 20.0, 1.5, -0.0016545403)")  

        # Connection 268: cell 13, seg 0 (0.5) [0.5 on Ipop[13]] -> cell 8, seg 0 (0.5) [0.5 on Ipop[8]], weight: -0.0016545403, delay 1.5
        h("Ipop[8] syn_projII_gaba[268] = new gaba(0.5)")
        h("Ipop[13] netConn_projII_gaba[268] = new NetCon(&v(0.5), syn_projII_gaba[268], 20.0, 1.5, -0.0016545403)")  

        # Connection 269: cell 13, seg 0 (0.5) [0.5 on Ipop[13]] -> cell 9, seg 0 (0.5) [0.5 on Ipop[9]], weight: -0.0016545403, delay 1.5
        h("Ipop[9] syn_projII_gaba[269] = new gaba(0.5)")
        h("Ipop[13] netConn_projII_gaba[269] = new NetCon(&v(0.5), syn_projII_gaba[269], 20.0, 1.5, -0.0016545403)")  

        # Connection 270: cell 13, seg 0 (0.5) [0.5 on Ipop[13]] -> cell 10, seg 0 (0.5) [0.5 on Ipop[10]], weight: -0.0016545403, delay 1.5
        h("Ipop[10] syn_projII_gaba[270] = new gaba(0.5)")
        h("Ipop[13] netConn_projII_gaba[270] = new NetCon(&v(0.5), syn_projII_gaba[270], 20.0, 1.5, -0.0016545403)")  

        # Connection 271: cell 13, seg 0 (0.5) [0.5 on Ipop[13]] -> cell 11, seg 0 (0.5) [0.5 on Ipop[11]], weight: -0.0016545403, delay 1.5
        h("Ipop[11] syn_projII_gaba[271] = new gaba(0.5)")
        h("Ipop[13] netConn_projII_gaba[271] = new NetCon(&v(0.5), syn_projII_gaba[271], 20.0, 1.5, -0.0016545403)")  

        # Connection 272: cell 13, seg 0 (0.5) [0.5 on Ipop[13]] -> cell 12, seg 0 (0.5) [0.5 on Ipop[12]], weight: -0.0016545403, delay 1.5
        h("Ipop[12] syn_projII_gaba[272] = new gaba(0.5)")
        h("Ipop[13] netConn_projII_gaba[272] = new NetCon(&v(0.5), syn_projII_gaba[272], 20.0, 1.5, -0.0016545403)")  

        # Connection 273: cell 13, seg 0 (0.5) [0.5 on Ipop[13]] -> cell 13, seg 0 (0.5) [0.5 on Ipop[13]], weight: -0.0016545403, delay 1.5
        h("Ipop[13] syn_projII_gaba[273] = new gaba(0.5)")
        h("Ipop[13] netConn_projII_gaba[273] = new NetCon(&v(0.5), syn_projII_gaba[273], 20.0, 1.5, -0.0016545403)")  

        # Connection 274: cell 13, seg 0 (0.5) [0.5 on Ipop[13]] -> cell 14, seg 0 (0.5) [0.5 on Ipop[14]], weight: -0.0016545403, delay 1.5
        h("Ipop[14] syn_projII_gaba[274] = new gaba(0.5)")
        h("Ipop[13] netConn_projII_gaba[274] = new NetCon(&v(0.5), syn_projII_gaba[274], 20.0, 1.5, -0.0016545403)")  

        # Connection 275: cell 13, seg 0 (0.5) [0.5 on Ipop[13]] -> cell 15, seg 0 (0.5) [0.5 on Ipop[15]], weight: -0.0016545403, delay 1.5
        h("Ipop[15] syn_projII_gaba[275] = new gaba(0.5)")
        h("Ipop[13] netConn_projII_gaba[275] = new NetCon(&v(0.5), syn_projII_gaba[275], 20.0, 1.5, -0.0016545403)")  

        # Connection 276: cell 13, seg 0 (0.5) [0.5 on Ipop[13]] -> cell 16, seg 0 (0.5) [0.5 on Ipop[16]], weight: -0.0016545403, delay 1.5
        h("Ipop[16] syn_projII_gaba[276] = new gaba(0.5)")
        h("Ipop[13] netConn_projII_gaba[276] = new NetCon(&v(0.5), syn_projII_gaba[276], 20.0, 1.5, -0.0016545403)")  

        # Connection 277: cell 13, seg 0 (0.5) [0.5 on Ipop[13]] -> cell 17, seg 0 (0.5) [0.5 on Ipop[17]], weight: -0.0016545403, delay 1.5
        h("Ipop[17] syn_projII_gaba[277] = new gaba(0.5)")
        h("Ipop[13] netConn_projII_gaba[277] = new NetCon(&v(0.5), syn_projII_gaba[277], 20.0, 1.5, -0.0016545403)")  

        # Connection 278: cell 13, seg 0 (0.5) [0.5 on Ipop[13]] -> cell 18, seg 0 (0.5) [0.5 on Ipop[18]], weight: -0.0016545403, delay 1.5
        h("Ipop[18] syn_projII_gaba[278] = new gaba(0.5)")
        h("Ipop[13] netConn_projII_gaba[278] = new NetCon(&v(0.5), syn_projII_gaba[278], 20.0, 1.5, -0.0016545403)")  

        # Connection 279: cell 13, seg 0 (0.5) [0.5 on Ipop[13]] -> cell 19, seg 0 (0.5) [0.5 on Ipop[19]], weight: -0.0016545403, delay 1.5
        h("Ipop[19] syn_projII_gaba[279] = new gaba(0.5)")
        h("Ipop[13] netConn_projII_gaba[279] = new NetCon(&v(0.5), syn_projII_gaba[279], 20.0, 1.5, -0.0016545403)")  

        # Connection 280: cell 14, seg 0 (0.5) [0.5 on Ipop[14]] -> cell 0, seg 0 (0.5) [0.5 on Ipop[0]], weight: -0.0016545403, delay 1.5
        h("Ipop[0] syn_projII_gaba[280] = new gaba(0.5)")
        h("Ipop[14] netConn_projII_gaba[280] = new NetCon(&v(0.5), syn_projII_gaba[280], 20.0, 1.5, -0.0016545403)")  

        # Connection 281: cell 14, seg 0 (0.5) [0.5 on Ipop[14]] -> cell 1, seg 0 (0.5) [0.5 on Ipop[1]], weight: -0.0016545403, delay 1.5
        h("Ipop[1] syn_projII_gaba[281] = new gaba(0.5)")
        h("Ipop[14] netConn_projII_gaba[281] = new NetCon(&v(0.5), syn_projII_gaba[281], 20.0, 1.5, -0.0016545403)")  

        # Connection 282: cell 14, seg 0 (0.5) [0.5 on Ipop[14]] -> cell 2, seg 0 (0.5) [0.5 on Ipop[2]], weight: -0.0016545403, delay 1.5
        h("Ipop[2] syn_projII_gaba[282] = new gaba(0.5)")
        h("Ipop[14] netConn_projII_gaba[282] = new NetCon(&v(0.5), syn_projII_gaba[282], 20.0, 1.5, -0.0016545403)")  

        # Connection 283: cell 14, seg 0 (0.5) [0.5 on Ipop[14]] -> cell 3, seg 0 (0.5) [0.5 on Ipop[3]], weight: -0.0016545403, delay 1.5
        h("Ipop[3] syn_projII_gaba[283] = new gaba(0.5)")
        h("Ipop[14] netConn_projII_gaba[283] = new NetCon(&v(0.5), syn_projII_gaba[283], 20.0, 1.5, -0.0016545403)")  

        # Connection 284: cell 14, seg 0 (0.5) [0.5 on Ipop[14]] -> cell 4, seg 0 (0.5) [0.5 on Ipop[4]], weight: -0.0016545403, delay 1.5
        h("Ipop[4] syn_projII_gaba[284] = new gaba(0.5)")
        h("Ipop[14] netConn_projII_gaba[284] = new NetCon(&v(0.5), syn_projII_gaba[284], 20.0, 1.5, -0.0016545403)")  

        # Connection 285: cell 14, seg 0 (0.5) [0.5 on Ipop[14]] -> cell 5, seg 0 (0.5) [0.5 on Ipop[5]], weight: -0.0016545403, delay 1.5
        h("Ipop[5] syn_projII_gaba[285] = new gaba(0.5)")
        h("Ipop[14] netConn_projII_gaba[285] = new NetCon(&v(0.5), syn_projII_gaba[285], 20.0, 1.5, -0.0016545403)")  

        # Connection 286: cell 14, seg 0 (0.5) [0.5 on Ipop[14]] -> cell 6, seg 0 (0.5) [0.5 on Ipop[6]], weight: -0.0016545403, delay 1.5
        h("Ipop[6] syn_projII_gaba[286] = new gaba(0.5)")
        h("Ipop[14] netConn_projII_gaba[286] = new NetCon(&v(0.5), syn_projII_gaba[286], 20.0, 1.5, -0.0016545403)")  

        # Connection 287: cell 14, seg 0 (0.5) [0.5 on Ipop[14]] -> cell 7, seg 0 (0.5) [0.5 on Ipop[7]], weight: -0.0016545403, delay 1.5
        h("Ipop[7] syn_projII_gaba[287] = new gaba(0.5)")
        h("Ipop[14] netConn_projII_gaba[287] = new NetCon(&v(0.5), syn_projII_gaba[287], 20.0, 1.5, -0.0016545403)")  

        # Connection 288: cell 14, seg 0 (0.5) [0.5 on Ipop[14]] -> cell 8, seg 0 (0.5) [0.5 on Ipop[8]], weight: -0.0016545403, delay 1.5
        h("Ipop[8] syn_projII_gaba[288] = new gaba(0.5)")
        h("Ipop[14] netConn_projII_gaba[288] = new NetCon(&v(0.5), syn_projII_gaba[288], 20.0, 1.5, -0.0016545403)")  

        # Connection 289: cell 14, seg 0 (0.5) [0.5 on Ipop[14]] -> cell 9, seg 0 (0.5) [0.5 on Ipop[9]], weight: -0.0016545403, delay 1.5
        h("Ipop[9] syn_projII_gaba[289] = new gaba(0.5)")
        h("Ipop[14] netConn_projII_gaba[289] = new NetCon(&v(0.5), syn_projII_gaba[289], 20.0, 1.5, -0.0016545403)")  

        # Connection 290: cell 14, seg 0 (0.5) [0.5 on Ipop[14]] -> cell 10, seg 0 (0.5) [0.5 on Ipop[10]], weight: -0.0016545403, delay 1.5
        h("Ipop[10] syn_projII_gaba[290] = new gaba(0.5)")
        h("Ipop[14] netConn_projII_gaba[290] = new NetCon(&v(0.5), syn_projII_gaba[290], 20.0, 1.5, -0.0016545403)")  

        # Connection 291: cell 14, seg 0 (0.5) [0.5 on Ipop[14]] -> cell 11, seg 0 (0.5) [0.5 on Ipop[11]], weight: -0.0016545403, delay 1.5
        h("Ipop[11] syn_projII_gaba[291] = new gaba(0.5)")
        h("Ipop[14] netConn_projII_gaba[291] = new NetCon(&v(0.5), syn_projII_gaba[291], 20.0, 1.5, -0.0016545403)")  

        # Connection 292: cell 14, seg 0 (0.5) [0.5 on Ipop[14]] -> cell 12, seg 0 (0.5) [0.5 on Ipop[12]], weight: -0.0016545403, delay 1.5
        h("Ipop[12] syn_projII_gaba[292] = new gaba(0.5)")
        h("Ipop[14] netConn_projII_gaba[292] = new NetCon(&v(0.5), syn_projII_gaba[292], 20.0, 1.5, -0.0016545403)")  

        # Connection 293: cell 14, seg 0 (0.5) [0.5 on Ipop[14]] -> cell 13, seg 0 (0.5) [0.5 on Ipop[13]], weight: -0.0016545403, delay 1.5
        h("Ipop[13] syn_projII_gaba[293] = new gaba(0.5)")
        h("Ipop[14] netConn_projII_gaba[293] = new NetCon(&v(0.5), syn_projII_gaba[293], 20.0, 1.5, -0.0016545403)")  

        # Connection 294: cell 14, seg 0 (0.5) [0.5 on Ipop[14]] -> cell 14, seg 0 (0.5) [0.5 on Ipop[14]], weight: -0.0016545403, delay 1.5
        h("Ipop[14] syn_projII_gaba[294] = new gaba(0.5)")
        h("Ipop[14] netConn_projII_gaba[294] = new NetCon(&v(0.5), syn_projII_gaba[294], 20.0, 1.5, -0.0016545403)")  

        # Connection 295: cell 14, seg 0 (0.5) [0.5 on Ipop[14]] -> cell 15, seg 0 (0.5) [0.5 on Ipop[15]], weight: -0.0016545403, delay 1.5
        h("Ipop[15] syn_projII_gaba[295] = new gaba(0.5)")
        h("Ipop[14] netConn_projII_gaba[295] = new NetCon(&v(0.5), syn_projII_gaba[295], 20.0, 1.5, -0.0016545403)")  

        # Connection 296: cell 14, seg 0 (0.5) [0.5 on Ipop[14]] -> cell 16, seg 0 (0.5) [0.5 on Ipop[16]], weight: -0.0016545403, delay 1.5
        h("Ipop[16] syn_projII_gaba[296] = new gaba(0.5)")
        h("Ipop[14] netConn_projII_gaba[296] = new NetCon(&v(0.5), syn_projII_gaba[296], 20.0, 1.5, -0.0016545403)")  

        # Connection 297: cell 14, seg 0 (0.5) [0.5 on Ipop[14]] -> cell 17, seg 0 (0.5) [0.5 on Ipop[17]], weight: -0.0016545403, delay 1.5
        h("Ipop[17] syn_projII_gaba[297] = new gaba(0.5)")
        h("Ipop[14] netConn_projII_gaba[297] = new NetCon(&v(0.5), syn_projII_gaba[297], 20.0, 1.5, -0.0016545403)")  

        # Connection 298: cell 14, seg 0 (0.5) [0.5 on Ipop[14]] -> cell 18, seg 0 (0.5) [0.5 on Ipop[18]], weight: -0.0016545403, delay 1.5
        h("Ipop[18] syn_projII_gaba[298] = new gaba(0.5)")
        h("Ipop[14] netConn_projII_gaba[298] = new NetCon(&v(0.5), syn_projII_gaba[298], 20.0, 1.5, -0.0016545403)")  

        # Connection 299: cell 14, seg 0 (0.5) [0.5 on Ipop[14]] -> cell 19, seg 0 (0.5) [0.5 on Ipop[19]], weight: -0.0016545403, delay 1.5
        h("Ipop[19] syn_projII_gaba[299] = new gaba(0.5)")
        h("Ipop[14] netConn_projII_gaba[299] = new NetCon(&v(0.5), syn_projII_gaba[299], 20.0, 1.5, -0.0016545403)")  

        # Connection 300: cell 15, seg 0 (0.5) [0.5 on Ipop[15]] -> cell 0, seg 0 (0.5) [0.5 on Ipop[0]], weight: -0.0016545403, delay 1.5
        h("Ipop[0] syn_projII_gaba[300] = new gaba(0.5)")
        h("Ipop[15] netConn_projII_gaba[300] = new NetCon(&v(0.5), syn_projII_gaba[300], 20.0, 1.5, -0.0016545403)")  

        # Connection 301: cell 15, seg 0 (0.5) [0.5 on Ipop[15]] -> cell 1, seg 0 (0.5) [0.5 on Ipop[1]], weight: -0.0016545403, delay 1.5
        h("Ipop[1] syn_projII_gaba[301] = new gaba(0.5)")
        h("Ipop[15] netConn_projII_gaba[301] = new NetCon(&v(0.5), syn_projII_gaba[301], 20.0, 1.5, -0.0016545403)")  

        # Connection 302: cell 15, seg 0 (0.5) [0.5 on Ipop[15]] -> cell 2, seg 0 (0.5) [0.5 on Ipop[2]], weight: -0.0016545403, delay 1.5
        h("Ipop[2] syn_projII_gaba[302] = new gaba(0.5)")
        h("Ipop[15] netConn_projII_gaba[302] = new NetCon(&v(0.5), syn_projII_gaba[302], 20.0, 1.5, -0.0016545403)")  

        # Connection 303: cell 15, seg 0 (0.5) [0.5 on Ipop[15]] -> cell 3, seg 0 (0.5) [0.5 on Ipop[3]], weight: -0.0016545403, delay 1.5
        h("Ipop[3] syn_projII_gaba[303] = new gaba(0.5)")
        h("Ipop[15] netConn_projII_gaba[303] = new NetCon(&v(0.5), syn_projII_gaba[303], 20.0, 1.5, -0.0016545403)")  

        # Connection 304: cell 15, seg 0 (0.5) [0.5 on Ipop[15]] -> cell 4, seg 0 (0.5) [0.5 on Ipop[4]], weight: -0.0016545403, delay 1.5
        h("Ipop[4] syn_projII_gaba[304] = new gaba(0.5)")
        h("Ipop[15] netConn_projII_gaba[304] = new NetCon(&v(0.5), syn_projII_gaba[304], 20.0, 1.5, -0.0016545403)")  

        # Connection 305: cell 15, seg 0 (0.5) [0.5 on Ipop[15]] -> cell 5, seg 0 (0.5) [0.5 on Ipop[5]], weight: -0.0016545403, delay 1.5
        h("Ipop[5] syn_projII_gaba[305] = new gaba(0.5)")
        h("Ipop[15] netConn_projII_gaba[305] = new NetCon(&v(0.5), syn_projII_gaba[305], 20.0, 1.5, -0.0016545403)")  

        # Connection 306: cell 15, seg 0 (0.5) [0.5 on Ipop[15]] -> cell 6, seg 0 (0.5) [0.5 on Ipop[6]], weight: -0.0016545403, delay 1.5
        h("Ipop[6] syn_projII_gaba[306] = new gaba(0.5)")
        h("Ipop[15] netConn_projII_gaba[306] = new NetCon(&v(0.5), syn_projII_gaba[306], 20.0, 1.5, -0.0016545403)")  

        # Connection 307: cell 15, seg 0 (0.5) [0.5 on Ipop[15]] -> cell 7, seg 0 (0.5) [0.5 on Ipop[7]], weight: -0.0016545403, delay 1.5
        h("Ipop[7] syn_projII_gaba[307] = new gaba(0.5)")
        h("Ipop[15] netConn_projII_gaba[307] = new NetCon(&v(0.5), syn_projII_gaba[307], 20.0, 1.5, -0.0016545403)")  

        # Connection 308: cell 15, seg 0 (0.5) [0.5 on Ipop[15]] -> cell 8, seg 0 (0.5) [0.5 on Ipop[8]], weight: -0.0016545403, delay 1.5
        h("Ipop[8] syn_projII_gaba[308] = new gaba(0.5)")
        h("Ipop[15] netConn_projII_gaba[308] = new NetCon(&v(0.5), syn_projII_gaba[308], 20.0, 1.5, -0.0016545403)")  

        # Connection 309: cell 15, seg 0 (0.5) [0.5 on Ipop[15]] -> cell 9, seg 0 (0.5) [0.5 on Ipop[9]], weight: -0.0016545403, delay 1.5
        h("Ipop[9] syn_projII_gaba[309] = new gaba(0.5)")
        h("Ipop[15] netConn_projII_gaba[309] = new NetCon(&v(0.5), syn_projII_gaba[309], 20.0, 1.5, -0.0016545403)")  

        # Connection 310: cell 15, seg 0 (0.5) [0.5 on Ipop[15]] -> cell 10, seg 0 (0.5) [0.5 on Ipop[10]], weight: -0.0016545403, delay 1.5
        h("Ipop[10] syn_projII_gaba[310] = new gaba(0.5)")
        h("Ipop[15] netConn_projII_gaba[310] = new NetCon(&v(0.5), syn_projII_gaba[310], 20.0, 1.5, -0.0016545403)")  

        # Connection 311: cell 15, seg 0 (0.5) [0.5 on Ipop[15]] -> cell 11, seg 0 (0.5) [0.5 on Ipop[11]], weight: -0.0016545403, delay 1.5
        h("Ipop[11] syn_projII_gaba[311] = new gaba(0.5)")
        h("Ipop[15] netConn_projII_gaba[311] = new NetCon(&v(0.5), syn_projII_gaba[311], 20.0, 1.5, -0.0016545403)")  

        # Connection 312: cell 15, seg 0 (0.5) [0.5 on Ipop[15]] -> cell 12, seg 0 (0.5) [0.5 on Ipop[12]], weight: -0.0016545403, delay 1.5
        h("Ipop[12] syn_projII_gaba[312] = new gaba(0.5)")
        h("Ipop[15] netConn_projII_gaba[312] = new NetCon(&v(0.5), syn_projII_gaba[312], 20.0, 1.5, -0.0016545403)")  

        # Connection 313: cell 15, seg 0 (0.5) [0.5 on Ipop[15]] -> cell 13, seg 0 (0.5) [0.5 on Ipop[13]], weight: -0.0016545403, delay 1.5
        h("Ipop[13] syn_projII_gaba[313] = new gaba(0.5)")
        h("Ipop[15] netConn_projII_gaba[313] = new NetCon(&v(0.5), syn_projII_gaba[313], 20.0, 1.5, -0.0016545403)")  

        # Connection 314: cell 15, seg 0 (0.5) [0.5 on Ipop[15]] -> cell 14, seg 0 (0.5) [0.5 on Ipop[14]], weight: -0.0016545403, delay 1.5
        h("Ipop[14] syn_projII_gaba[314] = new gaba(0.5)")
        h("Ipop[15] netConn_projII_gaba[314] = new NetCon(&v(0.5), syn_projII_gaba[314], 20.0, 1.5, -0.0016545403)")  

        # Connection 315: cell 15, seg 0 (0.5) [0.5 on Ipop[15]] -> cell 15, seg 0 (0.5) [0.5 on Ipop[15]], weight: -0.0016545403, delay 1.5
        h("Ipop[15] syn_projII_gaba[315] = new gaba(0.5)")
        h("Ipop[15] netConn_projII_gaba[315] = new NetCon(&v(0.5), syn_projII_gaba[315], 20.0, 1.5, -0.0016545403)")  

        # Connection 316: cell 15, seg 0 (0.5) [0.5 on Ipop[15]] -> cell 16, seg 0 (0.5) [0.5 on Ipop[16]], weight: -0.0016545403, delay 1.5
        h("Ipop[16] syn_projII_gaba[316] = new gaba(0.5)")
        h("Ipop[15] netConn_projII_gaba[316] = new NetCon(&v(0.5), syn_projII_gaba[316], 20.0, 1.5, -0.0016545403)")  

        # Connection 317: cell 15, seg 0 (0.5) [0.5 on Ipop[15]] -> cell 17, seg 0 (0.5) [0.5 on Ipop[17]], weight: -0.0016545403, delay 1.5
        h("Ipop[17] syn_projII_gaba[317] = new gaba(0.5)")
        h("Ipop[15] netConn_projII_gaba[317] = new NetCon(&v(0.5), syn_projII_gaba[317], 20.0, 1.5, -0.0016545403)")  

        # Connection 318: cell 15, seg 0 (0.5) [0.5 on Ipop[15]] -> cell 18, seg 0 (0.5) [0.5 on Ipop[18]], weight: -0.0016545403, delay 1.5
        h("Ipop[18] syn_projII_gaba[318] = new gaba(0.5)")
        h("Ipop[15] netConn_projII_gaba[318] = new NetCon(&v(0.5), syn_projII_gaba[318], 20.0, 1.5, -0.0016545403)")  

        # Connection 319: cell 15, seg 0 (0.5) [0.5 on Ipop[15]] -> cell 19, seg 0 (0.5) [0.5 on Ipop[19]], weight: -0.0016545403, delay 1.5
        h("Ipop[19] syn_projII_gaba[319] = new gaba(0.5)")
        h("Ipop[15] netConn_projII_gaba[319] = new NetCon(&v(0.5), syn_projII_gaba[319], 20.0, 1.5, -0.0016545403)")  

        # Connection 320: cell 16, seg 0 (0.5) [0.5 on Ipop[16]] -> cell 0, seg 0 (0.5) [0.5 on Ipop[0]], weight: -0.0016545403, delay 1.5
        h("Ipop[0] syn_projII_gaba[320] = new gaba(0.5)")
        h("Ipop[16] netConn_projII_gaba[320] = new NetCon(&v(0.5), syn_projII_gaba[320], 20.0, 1.5, -0.0016545403)")  

        # Connection 321: cell 16, seg 0 (0.5) [0.5 on Ipop[16]] -> cell 1, seg 0 (0.5) [0.5 on Ipop[1]], weight: -0.0016545403, delay 1.5
        h("Ipop[1] syn_projII_gaba[321] = new gaba(0.5)")
        h("Ipop[16] netConn_projII_gaba[321] = new NetCon(&v(0.5), syn_projII_gaba[321], 20.0, 1.5, -0.0016545403)")  

        # Connection 322: cell 16, seg 0 (0.5) [0.5 on Ipop[16]] -> cell 2, seg 0 (0.5) [0.5 on Ipop[2]], weight: -0.0016545403, delay 1.5
        h("Ipop[2] syn_projII_gaba[322] = new gaba(0.5)")
        h("Ipop[16] netConn_projII_gaba[322] = new NetCon(&v(0.5), syn_projII_gaba[322], 20.0, 1.5, -0.0016545403)")  

        # Connection 323: cell 16, seg 0 (0.5) [0.5 on Ipop[16]] -> cell 3, seg 0 (0.5) [0.5 on Ipop[3]], weight: -0.0016545403, delay 1.5
        h("Ipop[3] syn_projII_gaba[323] = new gaba(0.5)")
        h("Ipop[16] netConn_projII_gaba[323] = new NetCon(&v(0.5), syn_projII_gaba[323], 20.0, 1.5, -0.0016545403)")  

        # Connection 324: cell 16, seg 0 (0.5) [0.5 on Ipop[16]] -> cell 4, seg 0 (0.5) [0.5 on Ipop[4]], weight: -0.0016545403, delay 1.5
        h("Ipop[4] syn_projII_gaba[324] = new gaba(0.5)")
        h("Ipop[16] netConn_projII_gaba[324] = new NetCon(&v(0.5), syn_projII_gaba[324], 20.0, 1.5, -0.0016545403)")  

        # Connection 325: cell 16, seg 0 (0.5) [0.5 on Ipop[16]] -> cell 5, seg 0 (0.5) [0.5 on Ipop[5]], weight: -0.0016545403, delay 1.5
        h("Ipop[5] syn_projII_gaba[325] = new gaba(0.5)")
        h("Ipop[16] netConn_projII_gaba[325] = new NetCon(&v(0.5), syn_projII_gaba[325], 20.0, 1.5, -0.0016545403)")  

        # Connection 326: cell 16, seg 0 (0.5) [0.5 on Ipop[16]] -> cell 6, seg 0 (0.5) [0.5 on Ipop[6]], weight: -0.0016545403, delay 1.5
        h("Ipop[6] syn_projII_gaba[326] = new gaba(0.5)")
        h("Ipop[16] netConn_projII_gaba[326] = new NetCon(&v(0.5), syn_projII_gaba[326], 20.0, 1.5, -0.0016545403)")  

        # Connection 327: cell 16, seg 0 (0.5) [0.5 on Ipop[16]] -> cell 7, seg 0 (0.5) [0.5 on Ipop[7]], weight: -0.0016545403, delay 1.5
        h("Ipop[7] syn_projII_gaba[327] = new gaba(0.5)")
        h("Ipop[16] netConn_projII_gaba[327] = new NetCon(&v(0.5), syn_projII_gaba[327], 20.0, 1.5, -0.0016545403)")  

        # Connection 328: cell 16, seg 0 (0.5) [0.5 on Ipop[16]] -> cell 8, seg 0 (0.5) [0.5 on Ipop[8]], weight: -0.0016545403, delay 1.5
        h("Ipop[8] syn_projII_gaba[328] = new gaba(0.5)")
        h("Ipop[16] netConn_projII_gaba[328] = new NetCon(&v(0.5), syn_projII_gaba[328], 20.0, 1.5, -0.0016545403)")  

        # Connection 329: cell 16, seg 0 (0.5) [0.5 on Ipop[16]] -> cell 9, seg 0 (0.5) [0.5 on Ipop[9]], weight: -0.0016545403, delay 1.5
        h("Ipop[9] syn_projII_gaba[329] = new gaba(0.5)")
        h("Ipop[16] netConn_projII_gaba[329] = new NetCon(&v(0.5), syn_projII_gaba[329], 20.0, 1.5, -0.0016545403)")  

        # Connection 330: cell 16, seg 0 (0.5) [0.5 on Ipop[16]] -> cell 10, seg 0 (0.5) [0.5 on Ipop[10]], weight: -0.0016545403, delay 1.5
        h("Ipop[10] syn_projII_gaba[330] = new gaba(0.5)")
        h("Ipop[16] netConn_projII_gaba[330] = new NetCon(&v(0.5), syn_projII_gaba[330], 20.0, 1.5, -0.0016545403)")  

        # Connection 331: cell 16, seg 0 (0.5) [0.5 on Ipop[16]] -> cell 11, seg 0 (0.5) [0.5 on Ipop[11]], weight: -0.0016545403, delay 1.5
        h("Ipop[11] syn_projII_gaba[331] = new gaba(0.5)")
        h("Ipop[16] netConn_projII_gaba[331] = new NetCon(&v(0.5), syn_projII_gaba[331], 20.0, 1.5, -0.0016545403)")  

        # Connection 332: cell 16, seg 0 (0.5) [0.5 on Ipop[16]] -> cell 12, seg 0 (0.5) [0.5 on Ipop[12]], weight: -0.0016545403, delay 1.5
        h("Ipop[12] syn_projII_gaba[332] = new gaba(0.5)")
        h("Ipop[16] netConn_projII_gaba[332] = new NetCon(&v(0.5), syn_projII_gaba[332], 20.0, 1.5, -0.0016545403)")  

        # Connection 333: cell 16, seg 0 (0.5) [0.5 on Ipop[16]] -> cell 13, seg 0 (0.5) [0.5 on Ipop[13]], weight: -0.0016545403, delay 1.5
        h("Ipop[13] syn_projII_gaba[333] = new gaba(0.5)")
        h("Ipop[16] netConn_projII_gaba[333] = new NetCon(&v(0.5), syn_projII_gaba[333], 20.0, 1.5, -0.0016545403)")  

        # Connection 334: cell 16, seg 0 (0.5) [0.5 on Ipop[16]] -> cell 14, seg 0 (0.5) [0.5 on Ipop[14]], weight: -0.0016545403, delay 1.5
        h("Ipop[14] syn_projII_gaba[334] = new gaba(0.5)")
        h("Ipop[16] netConn_projII_gaba[334] = new NetCon(&v(0.5), syn_projII_gaba[334], 20.0, 1.5, -0.0016545403)")  

        # Connection 335: cell 16, seg 0 (0.5) [0.5 on Ipop[16]] -> cell 15, seg 0 (0.5) [0.5 on Ipop[15]], weight: -0.0016545403, delay 1.5
        h("Ipop[15] syn_projII_gaba[335] = new gaba(0.5)")
        h("Ipop[16] netConn_projII_gaba[335] = new NetCon(&v(0.5), syn_projII_gaba[335], 20.0, 1.5, -0.0016545403)")  

        # Connection 336: cell 16, seg 0 (0.5) [0.5 on Ipop[16]] -> cell 16, seg 0 (0.5) [0.5 on Ipop[16]], weight: -0.0016545403, delay 1.5
        h("Ipop[16] syn_projII_gaba[336] = new gaba(0.5)")
        h("Ipop[16] netConn_projII_gaba[336] = new NetCon(&v(0.5), syn_projII_gaba[336], 20.0, 1.5, -0.0016545403)")  

        # Connection 337: cell 16, seg 0 (0.5) [0.5 on Ipop[16]] -> cell 17, seg 0 (0.5) [0.5 on Ipop[17]], weight: -0.0016545403, delay 1.5
        h("Ipop[17] syn_projII_gaba[337] = new gaba(0.5)")
        h("Ipop[16] netConn_projII_gaba[337] = new NetCon(&v(0.5), syn_projII_gaba[337], 20.0, 1.5, -0.0016545403)")  

        # Connection 338: cell 16, seg 0 (0.5) [0.5 on Ipop[16]] -> cell 18, seg 0 (0.5) [0.5 on Ipop[18]], weight: -0.0016545403, delay 1.5
        h("Ipop[18] syn_projII_gaba[338] = new gaba(0.5)")
        h("Ipop[16] netConn_projII_gaba[338] = new NetCon(&v(0.5), syn_projII_gaba[338], 20.0, 1.5, -0.0016545403)")  

        # Connection 339: cell 16, seg 0 (0.5) [0.5 on Ipop[16]] -> cell 19, seg 0 (0.5) [0.5 on Ipop[19]], weight: -0.0016545403, delay 1.5
        h("Ipop[19] syn_projII_gaba[339] = new gaba(0.5)")
        h("Ipop[16] netConn_projII_gaba[339] = new NetCon(&v(0.5), syn_projII_gaba[339], 20.0, 1.5, -0.0016545403)")  

        # Connection 340: cell 17, seg 0 (0.5) [0.5 on Ipop[17]] -> cell 0, seg 0 (0.5) [0.5 on Ipop[0]], weight: -0.0016545403, delay 1.5
        h("Ipop[0] syn_projII_gaba[340] = new gaba(0.5)")
        h("Ipop[17] netConn_projII_gaba[340] = new NetCon(&v(0.5), syn_projII_gaba[340], 20.0, 1.5, -0.0016545403)")  

        # Connection 341: cell 17, seg 0 (0.5) [0.5 on Ipop[17]] -> cell 1, seg 0 (0.5) [0.5 on Ipop[1]], weight: -0.0016545403, delay 1.5
        h("Ipop[1] syn_projII_gaba[341] = new gaba(0.5)")
        h("Ipop[17] netConn_projII_gaba[341] = new NetCon(&v(0.5), syn_projII_gaba[341], 20.0, 1.5, -0.0016545403)")  

        # Connection 342: cell 17, seg 0 (0.5) [0.5 on Ipop[17]] -> cell 2, seg 0 (0.5) [0.5 on Ipop[2]], weight: -0.0016545403, delay 1.5
        h("Ipop[2] syn_projII_gaba[342] = new gaba(0.5)")
        h("Ipop[17] netConn_projII_gaba[342] = new NetCon(&v(0.5), syn_projII_gaba[342], 20.0, 1.5, -0.0016545403)")  

        # Connection 343: cell 17, seg 0 (0.5) [0.5 on Ipop[17]] -> cell 3, seg 0 (0.5) [0.5 on Ipop[3]], weight: -0.0016545403, delay 1.5
        h("Ipop[3] syn_projII_gaba[343] = new gaba(0.5)")
        h("Ipop[17] netConn_projII_gaba[343] = new NetCon(&v(0.5), syn_projII_gaba[343], 20.0, 1.5, -0.0016545403)")  

        # Connection 344: cell 17, seg 0 (0.5) [0.5 on Ipop[17]] -> cell 4, seg 0 (0.5) [0.5 on Ipop[4]], weight: -0.0016545403, delay 1.5
        h("Ipop[4] syn_projII_gaba[344] = new gaba(0.5)")
        h("Ipop[17] netConn_projII_gaba[344] = new NetCon(&v(0.5), syn_projII_gaba[344], 20.0, 1.5, -0.0016545403)")  

        # Connection 345: cell 17, seg 0 (0.5) [0.5 on Ipop[17]] -> cell 5, seg 0 (0.5) [0.5 on Ipop[5]], weight: -0.0016545403, delay 1.5
        h("Ipop[5] syn_projII_gaba[345] = new gaba(0.5)")
        h("Ipop[17] netConn_projII_gaba[345] = new NetCon(&v(0.5), syn_projII_gaba[345], 20.0, 1.5, -0.0016545403)")  

        # Connection 346: cell 17, seg 0 (0.5) [0.5 on Ipop[17]] -> cell 6, seg 0 (0.5) [0.5 on Ipop[6]], weight: -0.0016545403, delay 1.5
        h("Ipop[6] syn_projII_gaba[346] = new gaba(0.5)")
        h("Ipop[17] netConn_projII_gaba[346] = new NetCon(&v(0.5), syn_projII_gaba[346], 20.0, 1.5, -0.0016545403)")  

        # Connection 347: cell 17, seg 0 (0.5) [0.5 on Ipop[17]] -> cell 7, seg 0 (0.5) [0.5 on Ipop[7]], weight: -0.0016545403, delay 1.5
        h("Ipop[7] syn_projII_gaba[347] = new gaba(0.5)")
        h("Ipop[17] netConn_projII_gaba[347] = new NetCon(&v(0.5), syn_projII_gaba[347], 20.0, 1.5, -0.0016545403)")  

        # Connection 348: cell 17, seg 0 (0.5) [0.5 on Ipop[17]] -> cell 8, seg 0 (0.5) [0.5 on Ipop[8]], weight: -0.0016545403, delay 1.5
        h("Ipop[8] syn_projII_gaba[348] = new gaba(0.5)")
        h("Ipop[17] netConn_projII_gaba[348] = new NetCon(&v(0.5), syn_projII_gaba[348], 20.0, 1.5, -0.0016545403)")  

        # Connection 349: cell 17, seg 0 (0.5) [0.5 on Ipop[17]] -> cell 9, seg 0 (0.5) [0.5 on Ipop[9]], weight: -0.0016545403, delay 1.5
        h("Ipop[9] syn_projII_gaba[349] = new gaba(0.5)")
        h("Ipop[17] netConn_projII_gaba[349] = new NetCon(&v(0.5), syn_projII_gaba[349], 20.0, 1.5, -0.0016545403)")  

        # Connection 350: cell 17, seg 0 (0.5) [0.5 on Ipop[17]] -> cell 10, seg 0 (0.5) [0.5 on Ipop[10]], weight: -0.0016545403, delay 1.5
        h("Ipop[10] syn_projII_gaba[350] = new gaba(0.5)")
        h("Ipop[17] netConn_projII_gaba[350] = new NetCon(&v(0.5), syn_projII_gaba[350], 20.0, 1.5, -0.0016545403)")  

        # Connection 351: cell 17, seg 0 (0.5) [0.5 on Ipop[17]] -> cell 11, seg 0 (0.5) [0.5 on Ipop[11]], weight: -0.0016545403, delay 1.5
        h("Ipop[11] syn_projII_gaba[351] = new gaba(0.5)")
        h("Ipop[17] netConn_projII_gaba[351] = new NetCon(&v(0.5), syn_projII_gaba[351], 20.0, 1.5, -0.0016545403)")  

        # Connection 352: cell 17, seg 0 (0.5) [0.5 on Ipop[17]] -> cell 12, seg 0 (0.5) [0.5 on Ipop[12]], weight: -0.0016545403, delay 1.5
        h("Ipop[12] syn_projII_gaba[352] = new gaba(0.5)")
        h("Ipop[17] netConn_projII_gaba[352] = new NetCon(&v(0.5), syn_projII_gaba[352], 20.0, 1.5, -0.0016545403)")  

        # Connection 353: cell 17, seg 0 (0.5) [0.5 on Ipop[17]] -> cell 13, seg 0 (0.5) [0.5 on Ipop[13]], weight: -0.0016545403, delay 1.5
        h("Ipop[13] syn_projII_gaba[353] = new gaba(0.5)")
        h("Ipop[17] netConn_projII_gaba[353] = new NetCon(&v(0.5), syn_projII_gaba[353], 20.0, 1.5, -0.0016545403)")  

        # Connection 354: cell 17, seg 0 (0.5) [0.5 on Ipop[17]] -> cell 14, seg 0 (0.5) [0.5 on Ipop[14]], weight: -0.0016545403, delay 1.5
        h("Ipop[14] syn_projII_gaba[354] = new gaba(0.5)")
        h("Ipop[17] netConn_projII_gaba[354] = new NetCon(&v(0.5), syn_projII_gaba[354], 20.0, 1.5, -0.0016545403)")  

        # Connection 355: cell 17, seg 0 (0.5) [0.5 on Ipop[17]] -> cell 15, seg 0 (0.5) [0.5 on Ipop[15]], weight: -0.0016545403, delay 1.5
        h("Ipop[15] syn_projII_gaba[355] = new gaba(0.5)")
        h("Ipop[17] netConn_projII_gaba[355] = new NetCon(&v(0.5), syn_projII_gaba[355], 20.0, 1.5, -0.0016545403)")  

        # Connection 356: cell 17, seg 0 (0.5) [0.5 on Ipop[17]] -> cell 16, seg 0 (0.5) [0.5 on Ipop[16]], weight: -0.0016545403, delay 1.5
        h("Ipop[16] syn_projII_gaba[356] = new gaba(0.5)")
        h("Ipop[17] netConn_projII_gaba[356] = new NetCon(&v(0.5), syn_projII_gaba[356], 20.0, 1.5, -0.0016545403)")  

        # Connection 357: cell 17, seg 0 (0.5) [0.5 on Ipop[17]] -> cell 17, seg 0 (0.5) [0.5 on Ipop[17]], weight: -0.0016545403, delay 1.5
        h("Ipop[17] syn_projII_gaba[357] = new gaba(0.5)")
        h("Ipop[17] netConn_projII_gaba[357] = new NetCon(&v(0.5), syn_projII_gaba[357], 20.0, 1.5, -0.0016545403)")  

        # Connection 358: cell 17, seg 0 (0.5) [0.5 on Ipop[17]] -> cell 18, seg 0 (0.5) [0.5 on Ipop[18]], weight: -0.0016545403, delay 1.5
        h("Ipop[18] syn_projII_gaba[358] = new gaba(0.5)")
        h("Ipop[17] netConn_projII_gaba[358] = new NetCon(&v(0.5), syn_projII_gaba[358], 20.0, 1.5, -0.0016545403)")  

        # Connection 359: cell 17, seg 0 (0.5) [0.5 on Ipop[17]] -> cell 19, seg 0 (0.5) [0.5 on Ipop[19]], weight: -0.0016545403, delay 1.5
        h("Ipop[19] syn_projII_gaba[359] = new gaba(0.5)")
        h("Ipop[17] netConn_projII_gaba[359] = new NetCon(&v(0.5), syn_projII_gaba[359], 20.0, 1.5, -0.0016545403)")  

        # Connection 360: cell 18, seg 0 (0.5) [0.5 on Ipop[18]] -> cell 0, seg 0 (0.5) [0.5 on Ipop[0]], weight: -0.0016545403, delay 1.5
        h("Ipop[0] syn_projII_gaba[360] = new gaba(0.5)")
        h("Ipop[18] netConn_projII_gaba[360] = new NetCon(&v(0.5), syn_projII_gaba[360], 20.0, 1.5, -0.0016545403)")  

        # Connection 361: cell 18, seg 0 (0.5) [0.5 on Ipop[18]] -> cell 1, seg 0 (0.5) [0.5 on Ipop[1]], weight: -0.0016545403, delay 1.5
        h("Ipop[1] syn_projII_gaba[361] = new gaba(0.5)")
        h("Ipop[18] netConn_projII_gaba[361] = new NetCon(&v(0.5), syn_projII_gaba[361], 20.0, 1.5, -0.0016545403)")  

        # Connection 362: cell 18, seg 0 (0.5) [0.5 on Ipop[18]] -> cell 2, seg 0 (0.5) [0.5 on Ipop[2]], weight: -0.0016545403, delay 1.5
        h("Ipop[2] syn_projII_gaba[362] = new gaba(0.5)")
        h("Ipop[18] netConn_projII_gaba[362] = new NetCon(&v(0.5), syn_projII_gaba[362], 20.0, 1.5, -0.0016545403)")  

        # Connection 363: cell 18, seg 0 (0.5) [0.5 on Ipop[18]] -> cell 3, seg 0 (0.5) [0.5 on Ipop[3]], weight: -0.0016545403, delay 1.5
        h("Ipop[3] syn_projII_gaba[363] = new gaba(0.5)")
        h("Ipop[18] netConn_projII_gaba[363] = new NetCon(&v(0.5), syn_projII_gaba[363], 20.0, 1.5, -0.0016545403)")  

        # Connection 364: cell 18, seg 0 (0.5) [0.5 on Ipop[18]] -> cell 4, seg 0 (0.5) [0.5 on Ipop[4]], weight: -0.0016545403, delay 1.5
        h("Ipop[4] syn_projII_gaba[364] = new gaba(0.5)")
        h("Ipop[18] netConn_projII_gaba[364] = new NetCon(&v(0.5), syn_projII_gaba[364], 20.0, 1.5, -0.0016545403)")  

        # Connection 365: cell 18, seg 0 (0.5) [0.5 on Ipop[18]] -> cell 5, seg 0 (0.5) [0.5 on Ipop[5]], weight: -0.0016545403, delay 1.5
        h("Ipop[5] syn_projII_gaba[365] = new gaba(0.5)")
        h("Ipop[18] netConn_projII_gaba[365] = new NetCon(&v(0.5), syn_projII_gaba[365], 20.0, 1.5, -0.0016545403)")  

        # Connection 366: cell 18, seg 0 (0.5) [0.5 on Ipop[18]] -> cell 6, seg 0 (0.5) [0.5 on Ipop[6]], weight: -0.0016545403, delay 1.5
        h("Ipop[6] syn_projII_gaba[366] = new gaba(0.5)")
        h("Ipop[18] netConn_projII_gaba[366] = new NetCon(&v(0.5), syn_projII_gaba[366], 20.0, 1.5, -0.0016545403)")  

        # Connection 367: cell 18, seg 0 (0.5) [0.5 on Ipop[18]] -> cell 7, seg 0 (0.5) [0.5 on Ipop[7]], weight: -0.0016545403, delay 1.5
        h("Ipop[7] syn_projII_gaba[367] = new gaba(0.5)")
        h("Ipop[18] netConn_projII_gaba[367] = new NetCon(&v(0.5), syn_projII_gaba[367], 20.0, 1.5, -0.0016545403)")  

        # Connection 368: cell 18, seg 0 (0.5) [0.5 on Ipop[18]] -> cell 8, seg 0 (0.5) [0.5 on Ipop[8]], weight: -0.0016545403, delay 1.5
        h("Ipop[8] syn_projII_gaba[368] = new gaba(0.5)")
        h("Ipop[18] netConn_projII_gaba[368] = new NetCon(&v(0.5), syn_projII_gaba[368], 20.0, 1.5, -0.0016545403)")  

        # Connection 369: cell 18, seg 0 (0.5) [0.5 on Ipop[18]] -> cell 9, seg 0 (0.5) [0.5 on Ipop[9]], weight: -0.0016545403, delay 1.5
        h("Ipop[9] syn_projII_gaba[369] = new gaba(0.5)")
        h("Ipop[18] netConn_projII_gaba[369] = new NetCon(&v(0.5), syn_projII_gaba[369], 20.0, 1.5, -0.0016545403)")  

        # Connection 370: cell 18, seg 0 (0.5) [0.5 on Ipop[18]] -> cell 10, seg 0 (0.5) [0.5 on Ipop[10]], weight: -0.0016545403, delay 1.5
        h("Ipop[10] syn_projII_gaba[370] = new gaba(0.5)")
        h("Ipop[18] netConn_projII_gaba[370] = new NetCon(&v(0.5), syn_projII_gaba[370], 20.0, 1.5, -0.0016545403)")  

        # Connection 371: cell 18, seg 0 (0.5) [0.5 on Ipop[18]] -> cell 11, seg 0 (0.5) [0.5 on Ipop[11]], weight: -0.0016545403, delay 1.5
        h("Ipop[11] syn_projII_gaba[371] = new gaba(0.5)")
        h("Ipop[18] netConn_projII_gaba[371] = new NetCon(&v(0.5), syn_projII_gaba[371], 20.0, 1.5, -0.0016545403)")  

        # Connection 372: cell 18, seg 0 (0.5) [0.5 on Ipop[18]] -> cell 12, seg 0 (0.5) [0.5 on Ipop[12]], weight: -0.0016545403, delay 1.5
        h("Ipop[12] syn_projII_gaba[372] = new gaba(0.5)")
        h("Ipop[18] netConn_projII_gaba[372] = new NetCon(&v(0.5), syn_projII_gaba[372], 20.0, 1.5, -0.0016545403)")  

        # Connection 373: cell 18, seg 0 (0.5) [0.5 on Ipop[18]] -> cell 13, seg 0 (0.5) [0.5 on Ipop[13]], weight: -0.0016545403, delay 1.5
        h("Ipop[13] syn_projII_gaba[373] = new gaba(0.5)")
        h("Ipop[18] netConn_projII_gaba[373] = new NetCon(&v(0.5), syn_projII_gaba[373], 20.0, 1.5, -0.0016545403)")  

        # Connection 374: cell 18, seg 0 (0.5) [0.5 on Ipop[18]] -> cell 14, seg 0 (0.5) [0.5 on Ipop[14]], weight: -0.0016545403, delay 1.5
        h("Ipop[14] syn_projII_gaba[374] = new gaba(0.5)")
        h("Ipop[18] netConn_projII_gaba[374] = new NetCon(&v(0.5), syn_projII_gaba[374], 20.0, 1.5, -0.0016545403)")  

        # Connection 375: cell 18, seg 0 (0.5) [0.5 on Ipop[18]] -> cell 15, seg 0 (0.5) [0.5 on Ipop[15]], weight: -0.0016545403, delay 1.5
        h("Ipop[15] syn_projII_gaba[375] = new gaba(0.5)")
        h("Ipop[18] netConn_projII_gaba[375] = new NetCon(&v(0.5), syn_projII_gaba[375], 20.0, 1.5, -0.0016545403)")  

        # Connection 376: cell 18, seg 0 (0.5) [0.5 on Ipop[18]] -> cell 16, seg 0 (0.5) [0.5 on Ipop[16]], weight: -0.0016545403, delay 1.5
        h("Ipop[16] syn_projII_gaba[376] = new gaba(0.5)")
        h("Ipop[18] netConn_projII_gaba[376] = new NetCon(&v(0.5), syn_projII_gaba[376], 20.0, 1.5, -0.0016545403)")  

        # Connection 377: cell 18, seg 0 (0.5) [0.5 on Ipop[18]] -> cell 17, seg 0 (0.5) [0.5 on Ipop[17]], weight: -0.0016545403, delay 1.5
        h("Ipop[17] syn_projII_gaba[377] = new gaba(0.5)")
        h("Ipop[18] netConn_projII_gaba[377] = new NetCon(&v(0.5), syn_projII_gaba[377], 20.0, 1.5, -0.0016545403)")  

        # Connection 378: cell 18, seg 0 (0.5) [0.5 on Ipop[18]] -> cell 18, seg 0 (0.5) [0.5 on Ipop[18]], weight: -0.0016545403, delay 1.5
        h("Ipop[18] syn_projII_gaba[378] = new gaba(0.5)")
        h("Ipop[18] netConn_projII_gaba[378] = new NetCon(&v(0.5), syn_projII_gaba[378], 20.0, 1.5, -0.0016545403)")  

        # Connection 379: cell 18, seg 0 (0.5) [0.5 on Ipop[18]] -> cell 19, seg 0 (0.5) [0.5 on Ipop[19]], weight: -0.0016545403, delay 1.5
        h("Ipop[19] syn_projII_gaba[379] = new gaba(0.5)")
        h("Ipop[18] netConn_projII_gaba[379] = new NetCon(&v(0.5), syn_projII_gaba[379], 20.0, 1.5, -0.0016545403)")  

        # Connection 380: cell 19, seg 0 (0.5) [0.5 on Ipop[19]] -> cell 0, seg 0 (0.5) [0.5 on Ipop[0]], weight: -0.0016545403, delay 1.5
        h("Ipop[0] syn_projII_gaba[380] = new gaba(0.5)")
        h("Ipop[19] netConn_projII_gaba[380] = new NetCon(&v(0.5), syn_projII_gaba[380], 20.0, 1.5, -0.0016545403)")  

        # Connection 381: cell 19, seg 0 (0.5) [0.5 on Ipop[19]] -> cell 1, seg 0 (0.5) [0.5 on Ipop[1]], weight: -0.0016545403, delay 1.5
        h("Ipop[1] syn_projII_gaba[381] = new gaba(0.5)")
        h("Ipop[19] netConn_projII_gaba[381] = new NetCon(&v(0.5), syn_projII_gaba[381], 20.0, 1.5, -0.0016545403)")  

        # Connection 382: cell 19, seg 0 (0.5) [0.5 on Ipop[19]] -> cell 2, seg 0 (0.5) [0.5 on Ipop[2]], weight: -0.0016545403, delay 1.5
        h("Ipop[2] syn_projII_gaba[382] = new gaba(0.5)")
        h("Ipop[19] netConn_projII_gaba[382] = new NetCon(&v(0.5), syn_projII_gaba[382], 20.0, 1.5, -0.0016545403)")  

        # Connection 383: cell 19, seg 0 (0.5) [0.5 on Ipop[19]] -> cell 3, seg 0 (0.5) [0.5 on Ipop[3]], weight: -0.0016545403, delay 1.5
        h("Ipop[3] syn_projII_gaba[383] = new gaba(0.5)")
        h("Ipop[19] netConn_projII_gaba[383] = new NetCon(&v(0.5), syn_projII_gaba[383], 20.0, 1.5, -0.0016545403)")  

        # Connection 384: cell 19, seg 0 (0.5) [0.5 on Ipop[19]] -> cell 4, seg 0 (0.5) [0.5 on Ipop[4]], weight: -0.0016545403, delay 1.5
        h("Ipop[4] syn_projII_gaba[384] = new gaba(0.5)")
        h("Ipop[19] netConn_projII_gaba[384] = new NetCon(&v(0.5), syn_projII_gaba[384], 20.0, 1.5, -0.0016545403)")  

        # Connection 385: cell 19, seg 0 (0.5) [0.5 on Ipop[19]] -> cell 5, seg 0 (0.5) [0.5 on Ipop[5]], weight: -0.0016545403, delay 1.5
        h("Ipop[5] syn_projII_gaba[385] = new gaba(0.5)")
        h("Ipop[19] netConn_projII_gaba[385] = new NetCon(&v(0.5), syn_projII_gaba[385], 20.0, 1.5, -0.0016545403)")  

        # Connection 386: cell 19, seg 0 (0.5) [0.5 on Ipop[19]] -> cell 6, seg 0 (0.5) [0.5 on Ipop[6]], weight: -0.0016545403, delay 1.5
        h("Ipop[6] syn_projII_gaba[386] = new gaba(0.5)")
        h("Ipop[19] netConn_projII_gaba[386] = new NetCon(&v(0.5), syn_projII_gaba[386], 20.0, 1.5, -0.0016545403)")  

        # Connection 387: cell 19, seg 0 (0.5) [0.5 on Ipop[19]] -> cell 7, seg 0 (0.5) [0.5 on Ipop[7]], weight: -0.0016545403, delay 1.5
        h("Ipop[7] syn_projII_gaba[387] = new gaba(0.5)")
        h("Ipop[19] netConn_projII_gaba[387] = new NetCon(&v(0.5), syn_projII_gaba[387], 20.0, 1.5, -0.0016545403)")  

        # Connection 388: cell 19, seg 0 (0.5) [0.5 on Ipop[19]] -> cell 8, seg 0 (0.5) [0.5 on Ipop[8]], weight: -0.0016545403, delay 1.5
        h("Ipop[8] syn_projII_gaba[388] = new gaba(0.5)")
        h("Ipop[19] netConn_projII_gaba[388] = new NetCon(&v(0.5), syn_projII_gaba[388], 20.0, 1.5, -0.0016545403)")  

        # Connection 389: cell 19, seg 0 (0.5) [0.5 on Ipop[19]] -> cell 9, seg 0 (0.5) [0.5 on Ipop[9]], weight: -0.0016545403, delay 1.5
        h("Ipop[9] syn_projII_gaba[389] = new gaba(0.5)")
        h("Ipop[19] netConn_projII_gaba[389] = new NetCon(&v(0.5), syn_projII_gaba[389], 20.0, 1.5, -0.0016545403)")  

        # Connection 390: cell 19, seg 0 (0.5) [0.5 on Ipop[19]] -> cell 10, seg 0 (0.5) [0.5 on Ipop[10]], weight: -0.0016545403, delay 1.5
        h("Ipop[10] syn_projII_gaba[390] = new gaba(0.5)")
        h("Ipop[19] netConn_projII_gaba[390] = new NetCon(&v(0.5), syn_projII_gaba[390], 20.0, 1.5, -0.0016545403)")  

        # Connection 391: cell 19, seg 0 (0.5) [0.5 on Ipop[19]] -> cell 11, seg 0 (0.5) [0.5 on Ipop[11]], weight: -0.0016545403, delay 1.5
        h("Ipop[11] syn_projII_gaba[391] = new gaba(0.5)")
        h("Ipop[19] netConn_projII_gaba[391] = new NetCon(&v(0.5), syn_projII_gaba[391], 20.0, 1.5, -0.0016545403)")  

        # Connection 392: cell 19, seg 0 (0.5) [0.5 on Ipop[19]] -> cell 12, seg 0 (0.5) [0.5 on Ipop[12]], weight: -0.0016545403, delay 1.5
        h("Ipop[12] syn_projII_gaba[392] = new gaba(0.5)")
        h("Ipop[19] netConn_projII_gaba[392] = new NetCon(&v(0.5), syn_projII_gaba[392], 20.0, 1.5, -0.0016545403)")  

        # Connection 393: cell 19, seg 0 (0.5) [0.5 on Ipop[19]] -> cell 13, seg 0 (0.5) [0.5 on Ipop[13]], weight: -0.0016545403, delay 1.5
        h("Ipop[13] syn_projII_gaba[393] = new gaba(0.5)")
        h("Ipop[19] netConn_projII_gaba[393] = new NetCon(&v(0.5), syn_projII_gaba[393], 20.0, 1.5, -0.0016545403)")  

        # Connection 394: cell 19, seg 0 (0.5) [0.5 on Ipop[19]] -> cell 14, seg 0 (0.5) [0.5 on Ipop[14]], weight: -0.0016545403, delay 1.5
        h("Ipop[14] syn_projII_gaba[394] = new gaba(0.5)")
        h("Ipop[19] netConn_projII_gaba[394] = new NetCon(&v(0.5), syn_projII_gaba[394], 20.0, 1.5, -0.0016545403)")  

        # Connection 395: cell 19, seg 0 (0.5) [0.5 on Ipop[19]] -> cell 15, seg 0 (0.5) [0.5 on Ipop[15]], weight: -0.0016545403, delay 1.5
        h("Ipop[15] syn_projII_gaba[395] = new gaba(0.5)")
        h("Ipop[19] netConn_projII_gaba[395] = new NetCon(&v(0.5), syn_projII_gaba[395], 20.0, 1.5, -0.0016545403)")  

        # Connection 396: cell 19, seg 0 (0.5) [0.5 on Ipop[19]] -> cell 16, seg 0 (0.5) [0.5 on Ipop[16]], weight: -0.0016545403, delay 1.5
        h("Ipop[16] syn_projII_gaba[396] = new gaba(0.5)")
        h("Ipop[19] netConn_projII_gaba[396] = new NetCon(&v(0.5), syn_projII_gaba[396], 20.0, 1.5, -0.0016545403)")  

        # Connection 397: cell 19, seg 0 (0.5) [0.5 on Ipop[19]] -> cell 17, seg 0 (0.5) [0.5 on Ipop[17]], weight: -0.0016545403, delay 1.5
        h("Ipop[17] syn_projII_gaba[397] = new gaba(0.5)")
        h("Ipop[19] netConn_projII_gaba[397] = new NetCon(&v(0.5), syn_projII_gaba[397], 20.0, 1.5, -0.0016545403)")  

        # Connection 398: cell 19, seg 0 (0.5) [0.5 on Ipop[19]] -> cell 18, seg 0 (0.5) [0.5 on Ipop[18]], weight: -0.0016545403, delay 1.5
        h("Ipop[18] syn_projII_gaba[398] = new gaba(0.5)")
        h("Ipop[19] netConn_projII_gaba[398] = new NetCon(&v(0.5), syn_projII_gaba[398], 20.0, 1.5, -0.0016545403)")  

        # Connection 399: cell 19, seg 0 (0.5) [0.5 on Ipop[19]] -> cell 19, seg 0 (0.5) [0.5 on Ipop[19]], weight: -0.0016545403, delay 1.5
        h("Ipop[19] syn_projII_gaba[399] = new gaba(0.5)")
        h("Ipop[19] netConn_projII_gaba[399] = new NetCon(&v(0.5), syn_projII_gaba[399], 20.0, 1.5, -0.0016545403)")  

        trec = h.Vector()
        trec.record(h._ref_t)

        h.tstop = tstop

        h.dt = dt

        h.steps_per_ms = 1/h.dt



        # ######################   File to save: SimExample7.expoisson.spikes (Spikes_file__expoisson)
        h(' objectvar spiketimes_Spikes_file__expoisson, t_spiketimes_Spikes_file__expoisson ')
        h(' { spiketimes_Spikes_file__expoisson = new Vector() } ')
        h(' { t_spiketimes_Spikes_file__expoisson = new Vector() } ')
        h(' objref netConnSpike_Spikes_file__expoisson, nil ')
        # It's a spike source, will listen to m_poisson_input_expoisson...
        h(' netConnSpike_Spikes_file__expoisson = new NetCon(m_poisson_input_expoisson[0], nil) ')
        h(' { netConnSpike_Spikes_file__expoisson.record(t_spiketimes_Spikes_file__expoisson, spiketimes_Spikes_file__expoisson, 0) } ')
        # It's a spike source, will listen to m_poisson_input_expoisson...
        h(' netConnSpike_Spikes_file__expoisson = new NetCon(m_poisson_input_expoisson[1], nil) ')
        h(' { netConnSpike_Spikes_file__expoisson.record(t_spiketimes_Spikes_file__expoisson, spiketimes_Spikes_file__expoisson, 1) } ')
        # It's a spike source, will listen to m_poisson_input_expoisson...
        h(' netConnSpike_Spikes_file__expoisson = new NetCon(m_poisson_input_expoisson[2], nil) ')
        h(' { netConnSpike_Spikes_file__expoisson.record(t_spiketimes_Spikes_file__expoisson, spiketimes_Spikes_file__expoisson, 2) } ')
        # It's a spike source, will listen to m_poisson_input_expoisson...
        h(' netConnSpike_Spikes_file__expoisson = new NetCon(m_poisson_input_expoisson[3], nil) ')
        h(' { netConnSpike_Spikes_file__expoisson.record(t_spiketimes_Spikes_file__expoisson, spiketimes_Spikes_file__expoisson, 3) } ')
        # It's a spike source, will listen to m_poisson_input_expoisson...
        h(' netConnSpike_Spikes_file__expoisson = new NetCon(m_poisson_input_expoisson[4], nil) ')
        h(' { netConnSpike_Spikes_file__expoisson.record(t_spiketimes_Spikes_file__expoisson, spiketimes_Spikes_file__expoisson, 4) } ')
        # It's a spike source, will listen to m_poisson_input_expoisson...
        h(' netConnSpike_Spikes_file__expoisson = new NetCon(m_poisson_input_expoisson[5], nil) ')
        h(' { netConnSpike_Spikes_file__expoisson.record(t_spiketimes_Spikes_file__expoisson, spiketimes_Spikes_file__expoisson, 5) } ')
        # It's a spike source, will listen to m_poisson_input_expoisson...
        h(' netConnSpike_Spikes_file__expoisson = new NetCon(m_poisson_input_expoisson[6], nil) ')
        h(' { netConnSpike_Spikes_file__expoisson.record(t_spiketimes_Spikes_file__expoisson, spiketimes_Spikes_file__expoisson, 6) } ')
        # It's a spike source, will listen to m_poisson_input_expoisson...
        h(' netConnSpike_Spikes_file__expoisson = new NetCon(m_poisson_input_expoisson[7], nil) ')
        h(' { netConnSpike_Spikes_file__expoisson.record(t_spiketimes_Spikes_file__expoisson, spiketimes_Spikes_file__expoisson, 7) } ')
        # It's a spike source, will listen to m_poisson_input_expoisson...
        h(' netConnSpike_Spikes_file__expoisson = new NetCon(m_poisson_input_expoisson[8], nil) ')
        h(' { netConnSpike_Spikes_file__expoisson.record(t_spiketimes_Spikes_file__expoisson, spiketimes_Spikes_file__expoisson, 8) } ')
        # It's a spike source, will listen to m_poisson_input_expoisson...
        h(' netConnSpike_Spikes_file__expoisson = new NetCon(m_poisson_input_expoisson[9], nil) ')
        h(' { netConnSpike_Spikes_file__expoisson.record(t_spiketimes_Spikes_file__expoisson, spiketimes_Spikes_file__expoisson, 9) } ')
        # It's a spike source, will listen to m_poisson_input_expoisson...
        h(' netConnSpike_Spikes_file__expoisson = new NetCon(m_poisson_input_expoisson[10], nil) ')
        h(' { netConnSpike_Spikes_file__expoisson.record(t_spiketimes_Spikes_file__expoisson, spiketimes_Spikes_file__expoisson, 10) } ')
        # It's a spike source, will listen to m_poisson_input_expoisson...
        h(' netConnSpike_Spikes_file__expoisson = new NetCon(m_poisson_input_expoisson[11], nil) ')
        h(' { netConnSpike_Spikes_file__expoisson.record(t_spiketimes_Spikes_file__expoisson, spiketimes_Spikes_file__expoisson, 11) } ')
        # It's a spike source, will listen to m_poisson_input_expoisson...
        h(' netConnSpike_Spikes_file__expoisson = new NetCon(m_poisson_input_expoisson[12], nil) ')
        h(' { netConnSpike_Spikes_file__expoisson.record(t_spiketimes_Spikes_file__expoisson, spiketimes_Spikes_file__expoisson, 12) } ')
        # It's a spike source, will listen to m_poisson_input_expoisson...
        h(' netConnSpike_Spikes_file__expoisson = new NetCon(m_poisson_input_expoisson[13], nil) ')
        h(' { netConnSpike_Spikes_file__expoisson.record(t_spiketimes_Spikes_file__expoisson, spiketimes_Spikes_file__expoisson, 13) } ')
        # It's a spike source, will listen to m_poisson_input_expoisson...
        h(' netConnSpike_Spikes_file__expoisson = new NetCon(m_poisson_input_expoisson[14], nil) ')
        h(' { netConnSpike_Spikes_file__expoisson.record(t_spiketimes_Spikes_file__expoisson, spiketimes_Spikes_file__expoisson, 14) } ')
        # It's a spike source, will listen to m_poisson_input_expoisson...
        h(' netConnSpike_Spikes_file__expoisson = new NetCon(m_poisson_input_expoisson[15], nil) ')
        h(' { netConnSpike_Spikes_file__expoisson.record(t_spiketimes_Spikes_file__expoisson, spiketimes_Spikes_file__expoisson, 15) } ')
        # It's a spike source, will listen to m_poisson_input_expoisson...
        h(' netConnSpike_Spikes_file__expoisson = new NetCon(m_poisson_input_expoisson[16], nil) ')
        h(' { netConnSpike_Spikes_file__expoisson.record(t_spiketimes_Spikes_file__expoisson, spiketimes_Spikes_file__expoisson, 16) } ')
        # It's a spike source, will listen to m_poisson_input_expoisson...
        h(' netConnSpike_Spikes_file__expoisson = new NetCon(m_poisson_input_expoisson[17], nil) ')
        h(' { netConnSpike_Spikes_file__expoisson.record(t_spiketimes_Spikes_file__expoisson, spiketimes_Spikes_file__expoisson, 17) } ')
        # It's a spike source, will listen to m_poisson_input_expoisson...
        h(' netConnSpike_Spikes_file__expoisson = new NetCon(m_poisson_input_expoisson[18], nil) ')
        h(' { netConnSpike_Spikes_file__expoisson.record(t_spiketimes_Spikes_file__expoisson, spiketimes_Spikes_file__expoisson, 18) } ')
        # It's a spike source, will listen to m_poisson_input_expoisson...
        h(' netConnSpike_Spikes_file__expoisson = new NetCon(m_poisson_input_expoisson[19], nil) ')
        h(' { netConnSpike_Spikes_file__expoisson.record(t_spiketimes_Spikes_file__expoisson, spiketimes_Spikes_file__expoisson, 19) } ')
        # It's a spike source, will listen to m_poisson_input_expoisson...
        h(' netConnSpike_Spikes_file__expoisson = new NetCon(m_poisson_input_expoisson[20], nil) ')
        h(' { netConnSpike_Spikes_file__expoisson.record(t_spiketimes_Spikes_file__expoisson, spiketimes_Spikes_file__expoisson, 20) } ')
        # It's a spike source, will listen to m_poisson_input_expoisson...
        h(' netConnSpike_Spikes_file__expoisson = new NetCon(m_poisson_input_expoisson[21], nil) ')
        h(' { netConnSpike_Spikes_file__expoisson.record(t_spiketimes_Spikes_file__expoisson, spiketimes_Spikes_file__expoisson, 21) } ')
        # It's a spike source, will listen to m_poisson_input_expoisson...
        h(' netConnSpike_Spikes_file__expoisson = new NetCon(m_poisson_input_expoisson[22], nil) ')
        h(' { netConnSpike_Spikes_file__expoisson.record(t_spiketimes_Spikes_file__expoisson, spiketimes_Spikes_file__expoisson, 22) } ')
        # It's a spike source, will listen to m_poisson_input_expoisson...
        h(' netConnSpike_Spikes_file__expoisson = new NetCon(m_poisson_input_expoisson[23], nil) ')
        h(' { netConnSpike_Spikes_file__expoisson.record(t_spiketimes_Spikes_file__expoisson, spiketimes_Spikes_file__expoisson, 23) } ')
        # It's a spike source, will listen to m_poisson_input_expoisson...
        h(' netConnSpike_Spikes_file__expoisson = new NetCon(m_poisson_input_expoisson[24], nil) ')
        h(' { netConnSpike_Spikes_file__expoisson.record(t_spiketimes_Spikes_file__expoisson, spiketimes_Spikes_file__expoisson, 24) } ')
        # It's a spike source, will listen to m_poisson_input_expoisson...
        h(' netConnSpike_Spikes_file__expoisson = new NetCon(m_poisson_input_expoisson[25], nil) ')
        h(' { netConnSpike_Spikes_file__expoisson.record(t_spiketimes_Spikes_file__expoisson, spiketimes_Spikes_file__expoisson, 25) } ')
        # It's a spike source, will listen to m_poisson_input_expoisson...
        h(' netConnSpike_Spikes_file__expoisson = new NetCon(m_poisson_input_expoisson[26], nil) ')
        h(' { netConnSpike_Spikes_file__expoisson.record(t_spiketimes_Spikes_file__expoisson, spiketimes_Spikes_file__expoisson, 26) } ')
        # It's a spike source, will listen to m_poisson_input_expoisson...
        h(' netConnSpike_Spikes_file__expoisson = new NetCon(m_poisson_input_expoisson[27], nil) ')
        h(' { netConnSpike_Spikes_file__expoisson.record(t_spiketimes_Spikes_file__expoisson, spiketimes_Spikes_file__expoisson, 27) } ')
        # It's a spike source, will listen to m_poisson_input_expoisson...
        h(' netConnSpike_Spikes_file__expoisson = new NetCon(m_poisson_input_expoisson[28], nil) ')
        h(' { netConnSpike_Spikes_file__expoisson.record(t_spiketimes_Spikes_file__expoisson, spiketimes_Spikes_file__expoisson, 28) } ')
        # It's a spike source, will listen to m_poisson_input_expoisson...
        h(' netConnSpike_Spikes_file__expoisson = new NetCon(m_poisson_input_expoisson[29], nil) ')
        h(' { netConnSpike_Spikes_file__expoisson.record(t_spiketimes_Spikes_file__expoisson, spiketimes_Spikes_file__expoisson, 29) } ')
        # It's a spike source, will listen to m_poisson_input_expoisson...
        h(' netConnSpike_Spikes_file__expoisson = new NetCon(m_poisson_input_expoisson[30], nil) ')
        h(' { netConnSpike_Spikes_file__expoisson.record(t_spiketimes_Spikes_file__expoisson, spiketimes_Spikes_file__expoisson, 30) } ')
        # It's a spike source, will listen to m_poisson_input_expoisson...
        h(' netConnSpike_Spikes_file__expoisson = new NetCon(m_poisson_input_expoisson[31], nil) ')
        h(' { netConnSpike_Spikes_file__expoisson.record(t_spiketimes_Spikes_file__expoisson, spiketimes_Spikes_file__expoisson, 31) } ')
        # It's a spike source, will listen to m_poisson_input_expoisson...
        h(' netConnSpike_Spikes_file__expoisson = new NetCon(m_poisson_input_expoisson[32], nil) ')
        h(' { netConnSpike_Spikes_file__expoisson.record(t_spiketimes_Spikes_file__expoisson, spiketimes_Spikes_file__expoisson, 32) } ')
        # It's a spike source, will listen to m_poisson_input_expoisson...
        h(' netConnSpike_Spikes_file__expoisson = new NetCon(m_poisson_input_expoisson[33], nil) ')
        h(' { netConnSpike_Spikes_file__expoisson.record(t_spiketimes_Spikes_file__expoisson, spiketimes_Spikes_file__expoisson, 33) } ')
        # It's a spike source, will listen to m_poisson_input_expoisson...
        h(' netConnSpike_Spikes_file__expoisson = new NetCon(m_poisson_input_expoisson[34], nil) ')
        h(' { netConnSpike_Spikes_file__expoisson.record(t_spiketimes_Spikes_file__expoisson, spiketimes_Spikes_file__expoisson, 34) } ')
        # It's a spike source, will listen to m_poisson_input_expoisson...
        h(' netConnSpike_Spikes_file__expoisson = new NetCon(m_poisson_input_expoisson[35], nil) ')
        h(' { netConnSpike_Spikes_file__expoisson.record(t_spiketimes_Spikes_file__expoisson, spiketimes_Spikes_file__expoisson, 35) } ')
        # It's a spike source, will listen to m_poisson_input_expoisson...
        h(' netConnSpike_Spikes_file__expoisson = new NetCon(m_poisson_input_expoisson[36], nil) ')
        h(' { netConnSpike_Spikes_file__expoisson.record(t_spiketimes_Spikes_file__expoisson, spiketimes_Spikes_file__expoisson, 36) } ')
        # It's a spike source, will listen to m_poisson_input_expoisson...
        h(' netConnSpike_Spikes_file__expoisson = new NetCon(m_poisson_input_expoisson[37], nil) ')
        h(' { netConnSpike_Spikes_file__expoisson.record(t_spiketimes_Spikes_file__expoisson, spiketimes_Spikes_file__expoisson, 37) } ')
        # It's a spike source, will listen to m_poisson_input_expoisson...
        h(' netConnSpike_Spikes_file__expoisson = new NetCon(m_poisson_input_expoisson[38], nil) ')
        h(' { netConnSpike_Spikes_file__expoisson.record(t_spiketimes_Spikes_file__expoisson, spiketimes_Spikes_file__expoisson, 38) } ')
        # It's a spike source, will listen to m_poisson_input_expoisson...
        h(' netConnSpike_Spikes_file__expoisson = new NetCon(m_poisson_input_expoisson[39], nil) ')
        h(' { netConnSpike_Spikes_file__expoisson.record(t_spiketimes_Spikes_file__expoisson, spiketimes_Spikes_file__expoisson, 39) } ')
        # It's a spike source, will listen to m_poisson_input_expoisson...
        h(' netConnSpike_Spikes_file__expoisson = new NetCon(m_poisson_input_expoisson[40], nil) ')
        h(' { netConnSpike_Spikes_file__expoisson.record(t_spiketimes_Spikes_file__expoisson, spiketimes_Spikes_file__expoisson, 40) } ')
        # It's a spike source, will listen to m_poisson_input_expoisson...
        h(' netConnSpike_Spikes_file__expoisson = new NetCon(m_poisson_input_expoisson[41], nil) ')
        h(' { netConnSpike_Spikes_file__expoisson.record(t_spiketimes_Spikes_file__expoisson, spiketimes_Spikes_file__expoisson, 41) } ')
        # It's a spike source, will listen to m_poisson_input_expoisson...
        h(' netConnSpike_Spikes_file__expoisson = new NetCon(m_poisson_input_expoisson[42], nil) ')
        h(' { netConnSpike_Spikes_file__expoisson.record(t_spiketimes_Spikes_file__expoisson, spiketimes_Spikes_file__expoisson, 42) } ')
        # It's a spike source, will listen to m_poisson_input_expoisson...
        h(' netConnSpike_Spikes_file__expoisson = new NetCon(m_poisson_input_expoisson[43], nil) ')
        h(' { netConnSpike_Spikes_file__expoisson.record(t_spiketimes_Spikes_file__expoisson, spiketimes_Spikes_file__expoisson, 43) } ')
        # It's a spike source, will listen to m_poisson_input_expoisson...
        h(' netConnSpike_Spikes_file__expoisson = new NetCon(m_poisson_input_expoisson[44], nil) ')
        h(' { netConnSpike_Spikes_file__expoisson.record(t_spiketimes_Spikes_file__expoisson, spiketimes_Spikes_file__expoisson, 44) } ')
        # It's a spike source, will listen to m_poisson_input_expoisson...
        h(' netConnSpike_Spikes_file__expoisson = new NetCon(m_poisson_input_expoisson[45], nil) ')
        h(' { netConnSpike_Spikes_file__expoisson.record(t_spiketimes_Spikes_file__expoisson, spiketimes_Spikes_file__expoisson, 45) } ')
        # It's a spike source, will listen to m_poisson_input_expoisson...
        h(' netConnSpike_Spikes_file__expoisson = new NetCon(m_poisson_input_expoisson[46], nil) ')
        h(' { netConnSpike_Spikes_file__expoisson.record(t_spiketimes_Spikes_file__expoisson, spiketimes_Spikes_file__expoisson, 46) } ')
        # It's a spike source, will listen to m_poisson_input_expoisson...
        h(' netConnSpike_Spikes_file__expoisson = new NetCon(m_poisson_input_expoisson[47], nil) ')
        h(' { netConnSpike_Spikes_file__expoisson.record(t_spiketimes_Spikes_file__expoisson, spiketimes_Spikes_file__expoisson, 47) } ')
        # It's a spike source, will listen to m_poisson_input_expoisson...
        h(' netConnSpike_Spikes_file__expoisson = new NetCon(m_poisson_input_expoisson[48], nil) ')
        h(' { netConnSpike_Spikes_file__expoisson.record(t_spiketimes_Spikes_file__expoisson, spiketimes_Spikes_file__expoisson, 48) } ')
        # It's a spike source, will listen to m_poisson_input_expoisson...
        h(' netConnSpike_Spikes_file__expoisson = new NetCon(m_poisson_input_expoisson[49], nil) ')
        h(' { netConnSpike_Spikes_file__expoisson.record(t_spiketimes_Spikes_file__expoisson, spiketimes_Spikes_file__expoisson, 49) } ')
        # It's a spike source, will listen to m_poisson_input_expoisson...
        h(' netConnSpike_Spikes_file__expoisson = new NetCon(m_poisson_input_expoisson[50], nil) ')
        h(' { netConnSpike_Spikes_file__expoisson.record(t_spiketimes_Spikes_file__expoisson, spiketimes_Spikes_file__expoisson, 50) } ')
        # It's a spike source, will listen to m_poisson_input_expoisson...
        h(' netConnSpike_Spikes_file__expoisson = new NetCon(m_poisson_input_expoisson[51], nil) ')
        h(' { netConnSpike_Spikes_file__expoisson.record(t_spiketimes_Spikes_file__expoisson, spiketimes_Spikes_file__expoisson, 51) } ')
        # It's a spike source, will listen to m_poisson_input_expoisson...
        h(' netConnSpike_Spikes_file__expoisson = new NetCon(m_poisson_input_expoisson[52], nil) ')
        h(' { netConnSpike_Spikes_file__expoisson.record(t_spiketimes_Spikes_file__expoisson, spiketimes_Spikes_file__expoisson, 52) } ')
        # It's a spike source, will listen to m_poisson_input_expoisson...
        h(' netConnSpike_Spikes_file__expoisson = new NetCon(m_poisson_input_expoisson[53], nil) ')
        h(' { netConnSpike_Spikes_file__expoisson.record(t_spiketimes_Spikes_file__expoisson, spiketimes_Spikes_file__expoisson, 53) } ')
        # It's a spike source, will listen to m_poisson_input_expoisson...
        h(' netConnSpike_Spikes_file__expoisson = new NetCon(m_poisson_input_expoisson[54], nil) ')
        h(' { netConnSpike_Spikes_file__expoisson.record(t_spiketimes_Spikes_file__expoisson, spiketimes_Spikes_file__expoisson, 54) } ')
        # It's a spike source, will listen to m_poisson_input_expoisson...
        h(' netConnSpike_Spikes_file__expoisson = new NetCon(m_poisson_input_expoisson[55], nil) ')
        h(' { netConnSpike_Spikes_file__expoisson.record(t_spiketimes_Spikes_file__expoisson, spiketimes_Spikes_file__expoisson, 55) } ')
        # It's a spike source, will listen to m_poisson_input_expoisson...
        h(' netConnSpike_Spikes_file__expoisson = new NetCon(m_poisson_input_expoisson[56], nil) ')
        h(' { netConnSpike_Spikes_file__expoisson.record(t_spiketimes_Spikes_file__expoisson, spiketimes_Spikes_file__expoisson, 56) } ')
        # It's a spike source, will listen to m_poisson_input_expoisson...
        h(' netConnSpike_Spikes_file__expoisson = new NetCon(m_poisson_input_expoisson[57], nil) ')
        h(' { netConnSpike_Spikes_file__expoisson.record(t_spiketimes_Spikes_file__expoisson, spiketimes_Spikes_file__expoisson, 57) } ')
        # It's a spike source, will listen to m_poisson_input_expoisson...
        h(' netConnSpike_Spikes_file__expoisson = new NetCon(m_poisson_input_expoisson[58], nil) ')
        h(' { netConnSpike_Spikes_file__expoisson.record(t_spiketimes_Spikes_file__expoisson, spiketimes_Spikes_file__expoisson, 58) } ')
        # It's a spike source, will listen to m_poisson_input_expoisson...
        h(' netConnSpike_Spikes_file__expoisson = new NetCon(m_poisson_input_expoisson[59], nil) ')
        h(' { netConnSpike_Spikes_file__expoisson.record(t_spiketimes_Spikes_file__expoisson, spiketimes_Spikes_file__expoisson, 59) } ')
        # It's a spike source, will listen to m_poisson_input_expoisson...
        h(' netConnSpike_Spikes_file__expoisson = new NetCon(m_poisson_input_expoisson[60], nil) ')
        h(' { netConnSpike_Spikes_file__expoisson.record(t_spiketimes_Spikes_file__expoisson, spiketimes_Spikes_file__expoisson, 60) } ')
        # It's a spike source, will listen to m_poisson_input_expoisson...
        h(' netConnSpike_Spikes_file__expoisson = new NetCon(m_poisson_input_expoisson[61], nil) ')
        h(' { netConnSpike_Spikes_file__expoisson.record(t_spiketimes_Spikes_file__expoisson, spiketimes_Spikes_file__expoisson, 61) } ')
        # It's a spike source, will listen to m_poisson_input_expoisson...
        h(' netConnSpike_Spikes_file__expoisson = new NetCon(m_poisson_input_expoisson[62], nil) ')
        h(' { netConnSpike_Spikes_file__expoisson.record(t_spiketimes_Spikes_file__expoisson, spiketimes_Spikes_file__expoisson, 62) } ')
        # It's a spike source, will listen to m_poisson_input_expoisson...
        h(' netConnSpike_Spikes_file__expoisson = new NetCon(m_poisson_input_expoisson[63], nil) ')
        h(' { netConnSpike_Spikes_file__expoisson.record(t_spiketimes_Spikes_file__expoisson, spiketimes_Spikes_file__expoisson, 63) } ')
        # It's a spike source, will listen to m_poisson_input_expoisson...
        h(' netConnSpike_Spikes_file__expoisson = new NetCon(m_poisson_input_expoisson[64], nil) ')
        h(' { netConnSpike_Spikes_file__expoisson.record(t_spiketimes_Spikes_file__expoisson, spiketimes_Spikes_file__expoisson, 64) } ')
        # It's a spike source, will listen to m_poisson_input_expoisson...
        h(' netConnSpike_Spikes_file__expoisson = new NetCon(m_poisson_input_expoisson[65], nil) ')
        h(' { netConnSpike_Spikes_file__expoisson.record(t_spiketimes_Spikes_file__expoisson, spiketimes_Spikes_file__expoisson, 65) } ')
        # It's a spike source, will listen to m_poisson_input_expoisson...
        h(' netConnSpike_Spikes_file__expoisson = new NetCon(m_poisson_input_expoisson[66], nil) ')
        h(' { netConnSpike_Spikes_file__expoisson.record(t_spiketimes_Spikes_file__expoisson, spiketimes_Spikes_file__expoisson, 66) } ')
        # It's a spike source, will listen to m_poisson_input_expoisson...
        h(' netConnSpike_Spikes_file__expoisson = new NetCon(m_poisson_input_expoisson[67], nil) ')
        h(' { netConnSpike_Spikes_file__expoisson.record(t_spiketimes_Spikes_file__expoisson, spiketimes_Spikes_file__expoisson, 67) } ')
        # It's a spike source, will listen to m_poisson_input_expoisson...
        h(' netConnSpike_Spikes_file__expoisson = new NetCon(m_poisson_input_expoisson[68], nil) ')
        h(' { netConnSpike_Spikes_file__expoisson.record(t_spiketimes_Spikes_file__expoisson, spiketimes_Spikes_file__expoisson, 68) } ')
        # It's a spike source, will listen to m_poisson_input_expoisson...
        h(' netConnSpike_Spikes_file__expoisson = new NetCon(m_poisson_input_expoisson[69], nil) ')
        h(' { netConnSpike_Spikes_file__expoisson.record(t_spiketimes_Spikes_file__expoisson, spiketimes_Spikes_file__expoisson, 69) } ')
        # It's a spike source, will listen to m_poisson_input_expoisson...
        h(' netConnSpike_Spikes_file__expoisson = new NetCon(m_poisson_input_expoisson[70], nil) ')
        h(' { netConnSpike_Spikes_file__expoisson.record(t_spiketimes_Spikes_file__expoisson, spiketimes_Spikes_file__expoisson, 70) } ')
        # It's a spike source, will listen to m_poisson_input_expoisson...
        h(' netConnSpike_Spikes_file__expoisson = new NetCon(m_poisson_input_expoisson[71], nil) ')
        h(' { netConnSpike_Spikes_file__expoisson.record(t_spiketimes_Spikes_file__expoisson, spiketimes_Spikes_file__expoisson, 71) } ')
        # It's a spike source, will listen to m_poisson_input_expoisson...
        h(' netConnSpike_Spikes_file__expoisson = new NetCon(m_poisson_input_expoisson[72], nil) ')
        h(' { netConnSpike_Spikes_file__expoisson.record(t_spiketimes_Spikes_file__expoisson, spiketimes_Spikes_file__expoisson, 72) } ')
        # It's a spike source, will listen to m_poisson_input_expoisson...
        h(' netConnSpike_Spikes_file__expoisson = new NetCon(m_poisson_input_expoisson[73], nil) ')
        h(' { netConnSpike_Spikes_file__expoisson.record(t_spiketimes_Spikes_file__expoisson, spiketimes_Spikes_file__expoisson, 73) } ')
        # It's a spike source, will listen to m_poisson_input_expoisson...
        h(' netConnSpike_Spikes_file__expoisson = new NetCon(m_poisson_input_expoisson[74], nil) ')
        h(' { netConnSpike_Spikes_file__expoisson.record(t_spiketimes_Spikes_file__expoisson, spiketimes_Spikes_file__expoisson, 74) } ')
        # It's a spike source, will listen to m_poisson_input_expoisson...
        h(' netConnSpike_Spikes_file__expoisson = new NetCon(m_poisson_input_expoisson[75], nil) ')
        h(' { netConnSpike_Spikes_file__expoisson.record(t_spiketimes_Spikes_file__expoisson, spiketimes_Spikes_file__expoisson, 75) } ')
        # It's a spike source, will listen to m_poisson_input_expoisson...
        h(' netConnSpike_Spikes_file__expoisson = new NetCon(m_poisson_input_expoisson[76], nil) ')
        h(' { netConnSpike_Spikes_file__expoisson.record(t_spiketimes_Spikes_file__expoisson, spiketimes_Spikes_file__expoisson, 76) } ')
        # It's a spike source, will listen to m_poisson_input_expoisson...
        h(' netConnSpike_Spikes_file__expoisson = new NetCon(m_poisson_input_expoisson[77], nil) ')
        h(' { netConnSpike_Spikes_file__expoisson.record(t_spiketimes_Spikes_file__expoisson, spiketimes_Spikes_file__expoisson, 77) } ')
        # It's a spike source, will listen to m_poisson_input_expoisson...
        h(' netConnSpike_Spikes_file__expoisson = new NetCon(m_poisson_input_expoisson[78], nil) ')
        h(' { netConnSpike_Spikes_file__expoisson.record(t_spiketimes_Spikes_file__expoisson, spiketimes_Spikes_file__expoisson, 78) } ')
        # It's a spike source, will listen to m_poisson_input_expoisson...
        h(' netConnSpike_Spikes_file__expoisson = new NetCon(m_poisson_input_expoisson[79], nil) ')
        h(' { netConnSpike_Spikes_file__expoisson.record(t_spiketimes_Spikes_file__expoisson, spiketimes_Spikes_file__expoisson, 79) } ')

        # ######################   File to save: SimExample7.Ipop.spikes (Spikes_file__Ipop)
        h(' objectvar spiketimes_Spikes_file__Ipop, t_spiketimes_Spikes_file__Ipop ')
        h(' { spiketimes_Spikes_file__Ipop = new Vector() } ')
        h(' { t_spiketimes_Spikes_file__Ipop = new Vector() } ')
        h(' objref netConnSpike_Spikes_file__Ipop, nil ')
        # Column: Ipop/0/ifcell (0) Ipop[0]
        h(' Ipop[0] { netConnSpike_Spikes_file__Ipop = new NetCon(&v(0.5), nil, 20.0, 0, 1) } ')
        h(' { netConnSpike_Spikes_file__Ipop.record(t_spiketimes_Spikes_file__Ipop, spiketimes_Spikes_file__Ipop, 0) } ')
        # Column: Ipop/1/ifcell (1) Ipop[1]
        h(' Ipop[1] { netConnSpike_Spikes_file__Ipop = new NetCon(&v(0.5), nil, 20.0, 0, 1) } ')
        h(' { netConnSpike_Spikes_file__Ipop.record(t_spiketimes_Spikes_file__Ipop, spiketimes_Spikes_file__Ipop, 1) } ')
        # Column: Ipop/2/ifcell (2) Ipop[2]
        h(' Ipop[2] { netConnSpike_Spikes_file__Ipop = new NetCon(&v(0.5), nil, 20.0, 0, 1) } ')
        h(' { netConnSpike_Spikes_file__Ipop.record(t_spiketimes_Spikes_file__Ipop, spiketimes_Spikes_file__Ipop, 2) } ')
        # Column: Ipop/3/ifcell (3) Ipop[3]
        h(' Ipop[3] { netConnSpike_Spikes_file__Ipop = new NetCon(&v(0.5), nil, 20.0, 0, 1) } ')
        h(' { netConnSpike_Spikes_file__Ipop.record(t_spiketimes_Spikes_file__Ipop, spiketimes_Spikes_file__Ipop, 3) } ')
        # Column: Ipop/4/ifcell (4) Ipop[4]
        h(' Ipop[4] { netConnSpike_Spikes_file__Ipop = new NetCon(&v(0.5), nil, 20.0, 0, 1) } ')
        h(' { netConnSpike_Spikes_file__Ipop.record(t_spiketimes_Spikes_file__Ipop, spiketimes_Spikes_file__Ipop, 4) } ')
        # Column: Ipop/5/ifcell (5) Ipop[5]
        h(' Ipop[5] { netConnSpike_Spikes_file__Ipop = new NetCon(&v(0.5), nil, 20.0, 0, 1) } ')
        h(' { netConnSpike_Spikes_file__Ipop.record(t_spiketimes_Spikes_file__Ipop, spiketimes_Spikes_file__Ipop, 5) } ')
        # Column: Ipop/6/ifcell (6) Ipop[6]
        h(' Ipop[6] { netConnSpike_Spikes_file__Ipop = new NetCon(&v(0.5), nil, 20.0, 0, 1) } ')
        h(' { netConnSpike_Spikes_file__Ipop.record(t_spiketimes_Spikes_file__Ipop, spiketimes_Spikes_file__Ipop, 6) } ')
        # Column: Ipop/7/ifcell (7) Ipop[7]
        h(' Ipop[7] { netConnSpike_Spikes_file__Ipop = new NetCon(&v(0.5), nil, 20.0, 0, 1) } ')
        h(' { netConnSpike_Spikes_file__Ipop.record(t_spiketimes_Spikes_file__Ipop, spiketimes_Spikes_file__Ipop, 7) } ')
        # Column: Ipop/8/ifcell (8) Ipop[8]
        h(' Ipop[8] { netConnSpike_Spikes_file__Ipop = new NetCon(&v(0.5), nil, 20.0, 0, 1) } ')
        h(' { netConnSpike_Spikes_file__Ipop.record(t_spiketimes_Spikes_file__Ipop, spiketimes_Spikes_file__Ipop, 8) } ')
        # Column: Ipop/9/ifcell (9) Ipop[9]
        h(' Ipop[9] { netConnSpike_Spikes_file__Ipop = new NetCon(&v(0.5), nil, 20.0, 0, 1) } ')
        h(' { netConnSpike_Spikes_file__Ipop.record(t_spiketimes_Spikes_file__Ipop, spiketimes_Spikes_file__Ipop, 9) } ')
        # Column: Ipop/10/ifcell (10) Ipop[10]
        h(' Ipop[10] { netConnSpike_Spikes_file__Ipop = new NetCon(&v(0.5), nil, 20.0, 0, 1) } ')
        h(' { netConnSpike_Spikes_file__Ipop.record(t_spiketimes_Spikes_file__Ipop, spiketimes_Spikes_file__Ipop, 10) } ')
        # Column: Ipop/11/ifcell (11) Ipop[11]
        h(' Ipop[11] { netConnSpike_Spikes_file__Ipop = new NetCon(&v(0.5), nil, 20.0, 0, 1) } ')
        h(' { netConnSpike_Spikes_file__Ipop.record(t_spiketimes_Spikes_file__Ipop, spiketimes_Spikes_file__Ipop, 11) } ')
        # Column: Ipop/12/ifcell (12) Ipop[12]
        h(' Ipop[12] { netConnSpike_Spikes_file__Ipop = new NetCon(&v(0.5), nil, 20.0, 0, 1) } ')
        h(' { netConnSpike_Spikes_file__Ipop.record(t_spiketimes_Spikes_file__Ipop, spiketimes_Spikes_file__Ipop, 12) } ')
        # Column: Ipop/13/ifcell (13) Ipop[13]
        h(' Ipop[13] { netConnSpike_Spikes_file__Ipop = new NetCon(&v(0.5), nil, 20.0, 0, 1) } ')
        h(' { netConnSpike_Spikes_file__Ipop.record(t_spiketimes_Spikes_file__Ipop, spiketimes_Spikes_file__Ipop, 13) } ')
        # Column: Ipop/14/ifcell (14) Ipop[14]
        h(' Ipop[14] { netConnSpike_Spikes_file__Ipop = new NetCon(&v(0.5), nil, 20.0, 0, 1) } ')
        h(' { netConnSpike_Spikes_file__Ipop.record(t_spiketimes_Spikes_file__Ipop, spiketimes_Spikes_file__Ipop, 14) } ')
        # Column: Ipop/15/ifcell (15) Ipop[15]
        h(' Ipop[15] { netConnSpike_Spikes_file__Ipop = new NetCon(&v(0.5), nil, 20.0, 0, 1) } ')
        h(' { netConnSpike_Spikes_file__Ipop.record(t_spiketimes_Spikes_file__Ipop, spiketimes_Spikes_file__Ipop, 15) } ')
        # Column: Ipop/16/ifcell (16) Ipop[16]
        h(' Ipop[16] { netConnSpike_Spikes_file__Ipop = new NetCon(&v(0.5), nil, 20.0, 0, 1) } ')
        h(' { netConnSpike_Spikes_file__Ipop.record(t_spiketimes_Spikes_file__Ipop, spiketimes_Spikes_file__Ipop, 16) } ')
        # Column: Ipop/17/ifcell (17) Ipop[17]
        h(' Ipop[17] { netConnSpike_Spikes_file__Ipop = new NetCon(&v(0.5), nil, 20.0, 0, 1) } ')
        h(' { netConnSpike_Spikes_file__Ipop.record(t_spiketimes_Spikes_file__Ipop, spiketimes_Spikes_file__Ipop, 17) } ')
        # Column: Ipop/18/ifcell (18) Ipop[18]
        h(' Ipop[18] { netConnSpike_Spikes_file__Ipop = new NetCon(&v(0.5), nil, 20.0, 0, 1) } ')
        h(' { netConnSpike_Spikes_file__Ipop.record(t_spiketimes_Spikes_file__Ipop, spiketimes_Spikes_file__Ipop, 18) } ')
        # Column: Ipop/19/ifcell (19) Ipop[19]
        h(' Ipop[19] { netConnSpike_Spikes_file__Ipop = new NetCon(&v(0.5), nil, 20.0, 0, 1) } ')
        h(' { netConnSpike_Spikes_file__Ipop.record(t_spiketimes_Spikes_file__Ipop, spiketimes_Spikes_file__Ipop, 19) } ')

        # ######################   File to save: SimExample7.Ipop.v.dat (SimExample7_Ipop_v_dat)
        # Column: Ipop/0/ifcell/v
        h(' objectvar v_Ipop_0_ifcell_v_SimExample7_Ipop_v_dat ')
        h(' { v_Ipop_0_ifcell_v_SimExample7_Ipop_v_dat = new Vector() } ')
        h(' { v_Ipop_0_ifcell_v_SimExample7_Ipop_v_dat.record(&Ipop[0].v(0.5)) } ')
        h.v_Ipop_0_ifcell_v_SimExample7_Ipop_v_dat.resize((h.tstop * h.steps_per_ms) + 1)
        # Column: Ipop/1/ifcell/v
        h(' objectvar v_Ipop_1_ifcell_v_SimExample7_Ipop_v_dat ')
        h(' { v_Ipop_1_ifcell_v_SimExample7_Ipop_v_dat = new Vector() } ')
        h(' { v_Ipop_1_ifcell_v_SimExample7_Ipop_v_dat.record(&Ipop[1].v(0.5)) } ')
        h.v_Ipop_1_ifcell_v_SimExample7_Ipop_v_dat.resize((h.tstop * h.steps_per_ms) + 1)

        # ######################   File to save: SimExample7.Epop.v.dat (SimExample7_Epop_v_dat)
        # Column: Epop/0/ifcell/v
        h(' objectvar v_Epop_0_ifcell_v_SimExample7_Epop_v_dat ')
        h(' { v_Epop_0_ifcell_v_SimExample7_Epop_v_dat = new Vector() } ')
        h(' { v_Epop_0_ifcell_v_SimExample7_Epop_v_dat.record(&Epop[0].v(0.5)) } ')
        h.v_Epop_0_ifcell_v_SimExample7_Epop_v_dat.resize((h.tstop * h.steps_per_ms) + 1)
        # Column: Epop/1/ifcell/v
        h(' objectvar v_Epop_1_ifcell_v_SimExample7_Epop_v_dat ')
        h(' { v_Epop_1_ifcell_v_SimExample7_Epop_v_dat = new Vector() } ')
        h(' { v_Epop_1_ifcell_v_SimExample7_Epop_v_dat.record(&Epop[1].v(0.5)) } ')
        h.v_Epop_1_ifcell_v_SimExample7_Epop_v_dat.resize((h.tstop * h.steps_per_ms) + 1)

        # ######################   File to save: SimExample7.inpoisson.spikes (Spikes_file__inpoisson)
        h(' objectvar spiketimes_Spikes_file__inpoisson, t_spiketimes_Spikes_file__inpoisson ')
        h(' { spiketimes_Spikes_file__inpoisson = new Vector() } ')
        h(' { t_spiketimes_Spikes_file__inpoisson = new Vector() } ')
        h(' objref netConnSpike_Spikes_file__inpoisson, nil ')
        # It's a spike source, will listen to m_poisson_input_inpoisson...
        h(' netConnSpike_Spikes_file__inpoisson = new NetCon(m_poisson_input_inpoisson[0], nil) ')
        h(' { netConnSpike_Spikes_file__inpoisson.record(t_spiketimes_Spikes_file__inpoisson, spiketimes_Spikes_file__inpoisson, 0) } ')
        # It's a spike source, will listen to m_poisson_input_inpoisson...
        h(' netConnSpike_Spikes_file__inpoisson = new NetCon(m_poisson_input_inpoisson[1], nil) ')
        h(' { netConnSpike_Spikes_file__inpoisson.record(t_spiketimes_Spikes_file__inpoisson, spiketimes_Spikes_file__inpoisson, 1) } ')
        # It's a spike source, will listen to m_poisson_input_inpoisson...
        h(' netConnSpike_Spikes_file__inpoisson = new NetCon(m_poisson_input_inpoisson[2], nil) ')
        h(' { netConnSpike_Spikes_file__inpoisson.record(t_spiketimes_Spikes_file__inpoisson, spiketimes_Spikes_file__inpoisson, 2) } ')
        # It's a spike source, will listen to m_poisson_input_inpoisson...
        h(' netConnSpike_Spikes_file__inpoisson = new NetCon(m_poisson_input_inpoisson[3], nil) ')
        h(' { netConnSpike_Spikes_file__inpoisson.record(t_spiketimes_Spikes_file__inpoisson, spiketimes_Spikes_file__inpoisson, 3) } ')
        # It's a spike source, will listen to m_poisson_input_inpoisson...
        h(' netConnSpike_Spikes_file__inpoisson = new NetCon(m_poisson_input_inpoisson[4], nil) ')
        h(' { netConnSpike_Spikes_file__inpoisson.record(t_spiketimes_Spikes_file__inpoisson, spiketimes_Spikes_file__inpoisson, 4) } ')
        # It's a spike source, will listen to m_poisson_input_inpoisson...
        h(' netConnSpike_Spikes_file__inpoisson = new NetCon(m_poisson_input_inpoisson[5], nil) ')
        h(' { netConnSpike_Spikes_file__inpoisson.record(t_spiketimes_Spikes_file__inpoisson, spiketimes_Spikes_file__inpoisson, 5) } ')
        # It's a spike source, will listen to m_poisson_input_inpoisson...
        h(' netConnSpike_Spikes_file__inpoisson = new NetCon(m_poisson_input_inpoisson[6], nil) ')
        h(' { netConnSpike_Spikes_file__inpoisson.record(t_spiketimes_Spikes_file__inpoisson, spiketimes_Spikes_file__inpoisson, 6) } ')
        # It's a spike source, will listen to m_poisson_input_inpoisson...
        h(' netConnSpike_Spikes_file__inpoisson = new NetCon(m_poisson_input_inpoisson[7], nil) ')
        h(' { netConnSpike_Spikes_file__inpoisson.record(t_spiketimes_Spikes_file__inpoisson, spiketimes_Spikes_file__inpoisson, 7) } ')
        # It's a spike source, will listen to m_poisson_input_inpoisson...
        h(' netConnSpike_Spikes_file__inpoisson = new NetCon(m_poisson_input_inpoisson[8], nil) ')
        h(' { netConnSpike_Spikes_file__inpoisson.record(t_spiketimes_Spikes_file__inpoisson, spiketimes_Spikes_file__inpoisson, 8) } ')
        # It's a spike source, will listen to m_poisson_input_inpoisson...
        h(' netConnSpike_Spikes_file__inpoisson = new NetCon(m_poisson_input_inpoisson[9], nil) ')
        h(' { netConnSpike_Spikes_file__inpoisson.record(t_spiketimes_Spikes_file__inpoisson, spiketimes_Spikes_file__inpoisson, 9) } ')
        # It's a spike source, will listen to m_poisson_input_inpoisson...
        h(' netConnSpike_Spikes_file__inpoisson = new NetCon(m_poisson_input_inpoisson[10], nil) ')
        h(' { netConnSpike_Spikes_file__inpoisson.record(t_spiketimes_Spikes_file__inpoisson, spiketimes_Spikes_file__inpoisson, 10) } ')
        # It's a spike source, will listen to m_poisson_input_inpoisson...
        h(' netConnSpike_Spikes_file__inpoisson = new NetCon(m_poisson_input_inpoisson[11], nil) ')
        h(' { netConnSpike_Spikes_file__inpoisson.record(t_spiketimes_Spikes_file__inpoisson, spiketimes_Spikes_file__inpoisson, 11) } ')
        # It's a spike source, will listen to m_poisson_input_inpoisson...
        h(' netConnSpike_Spikes_file__inpoisson = new NetCon(m_poisson_input_inpoisson[12], nil) ')
        h(' { netConnSpike_Spikes_file__inpoisson.record(t_spiketimes_Spikes_file__inpoisson, spiketimes_Spikes_file__inpoisson, 12) } ')
        # It's a spike source, will listen to m_poisson_input_inpoisson...
        h(' netConnSpike_Spikes_file__inpoisson = new NetCon(m_poisson_input_inpoisson[13], nil) ')
        h(' { netConnSpike_Spikes_file__inpoisson.record(t_spiketimes_Spikes_file__inpoisson, spiketimes_Spikes_file__inpoisson, 13) } ')
        # It's a spike source, will listen to m_poisson_input_inpoisson...
        h(' netConnSpike_Spikes_file__inpoisson = new NetCon(m_poisson_input_inpoisson[14], nil) ')
        h(' { netConnSpike_Spikes_file__inpoisson.record(t_spiketimes_Spikes_file__inpoisson, spiketimes_Spikes_file__inpoisson, 14) } ')
        # It's a spike source, will listen to m_poisson_input_inpoisson...
        h(' netConnSpike_Spikes_file__inpoisson = new NetCon(m_poisson_input_inpoisson[15], nil) ')
        h(' { netConnSpike_Spikes_file__inpoisson.record(t_spiketimes_Spikes_file__inpoisson, spiketimes_Spikes_file__inpoisson, 15) } ')
        # It's a spike source, will listen to m_poisson_input_inpoisson...
        h(' netConnSpike_Spikes_file__inpoisson = new NetCon(m_poisson_input_inpoisson[16], nil) ')
        h(' { netConnSpike_Spikes_file__inpoisson.record(t_spiketimes_Spikes_file__inpoisson, spiketimes_Spikes_file__inpoisson, 16) } ')
        # It's a spike source, will listen to m_poisson_input_inpoisson...
        h(' netConnSpike_Spikes_file__inpoisson = new NetCon(m_poisson_input_inpoisson[17], nil) ')
        h(' { netConnSpike_Spikes_file__inpoisson.record(t_spiketimes_Spikes_file__inpoisson, spiketimes_Spikes_file__inpoisson, 17) } ')
        # It's a spike source, will listen to m_poisson_input_inpoisson...
        h(' netConnSpike_Spikes_file__inpoisson = new NetCon(m_poisson_input_inpoisson[18], nil) ')
        h(' { netConnSpike_Spikes_file__inpoisson.record(t_spiketimes_Spikes_file__inpoisson, spiketimes_Spikes_file__inpoisson, 18) } ')
        # It's a spike source, will listen to m_poisson_input_inpoisson...
        h(' netConnSpike_Spikes_file__inpoisson = new NetCon(m_poisson_input_inpoisson[19], nil) ')
        h(' { netConnSpike_Spikes_file__inpoisson.record(t_spiketimes_Spikes_file__inpoisson, spiketimes_Spikes_file__inpoisson, 19) } ')

        # ######################   File to save: time.dat (time)
        # Column: time
        h(' objectvar v_time ')
        h(' { v_time = new Vector() } ')
        h(' { v_time.record(&t) } ')
        h.v_time.resize((h.tstop * h.steps_per_ms) + 1)

        # ######################   File to save: SimExample7.Epop.spikes (Spikes_file__Epop)
        h(' objectvar spiketimes_Spikes_file__Epop, t_spiketimes_Spikes_file__Epop ')
        h(' { spiketimes_Spikes_file__Epop = new Vector() } ')
        h(' { t_spiketimes_Spikes_file__Epop = new Vector() } ')
        h(' objref netConnSpike_Spikes_file__Epop, nil ')
        # Column: Epop/0/ifcell (0) Epop[0]
        h(' Epop[0] { netConnSpike_Spikes_file__Epop = new NetCon(&v(0.5), nil, 20.0, 0, 1) } ')
        h(' { netConnSpike_Spikes_file__Epop.record(t_spiketimes_Spikes_file__Epop, spiketimes_Spikes_file__Epop, 0) } ')
        # Column: Epop/1/ifcell (1) Epop[1]
        h(' Epop[1] { netConnSpike_Spikes_file__Epop = new NetCon(&v(0.5), nil, 20.0, 0, 1) } ')
        h(' { netConnSpike_Spikes_file__Epop.record(t_spiketimes_Spikes_file__Epop, spiketimes_Spikes_file__Epop, 1) } ')
        # Column: Epop/2/ifcell (2) Epop[2]
        h(' Epop[2] { netConnSpike_Spikes_file__Epop = new NetCon(&v(0.5), nil, 20.0, 0, 1) } ')
        h(' { netConnSpike_Spikes_file__Epop.record(t_spiketimes_Spikes_file__Epop, spiketimes_Spikes_file__Epop, 2) } ')
        # Column: Epop/3/ifcell (3) Epop[3]
        h(' Epop[3] { netConnSpike_Spikes_file__Epop = new NetCon(&v(0.5), nil, 20.0, 0, 1) } ')
        h(' { netConnSpike_Spikes_file__Epop.record(t_spiketimes_Spikes_file__Epop, spiketimes_Spikes_file__Epop, 3) } ')
        # Column: Epop/4/ifcell (4) Epop[4]
        h(' Epop[4] { netConnSpike_Spikes_file__Epop = new NetCon(&v(0.5), nil, 20.0, 0, 1) } ')
        h(' { netConnSpike_Spikes_file__Epop.record(t_spiketimes_Spikes_file__Epop, spiketimes_Spikes_file__Epop, 4) } ')
        # Column: Epop/5/ifcell (5) Epop[5]
        h(' Epop[5] { netConnSpike_Spikes_file__Epop = new NetCon(&v(0.5), nil, 20.0, 0, 1) } ')
        h(' { netConnSpike_Spikes_file__Epop.record(t_spiketimes_Spikes_file__Epop, spiketimes_Spikes_file__Epop, 5) } ')
        # Column: Epop/6/ifcell (6) Epop[6]
        h(' Epop[6] { netConnSpike_Spikes_file__Epop = new NetCon(&v(0.5), nil, 20.0, 0, 1) } ')
        h(' { netConnSpike_Spikes_file__Epop.record(t_spiketimes_Spikes_file__Epop, spiketimes_Spikes_file__Epop, 6) } ')
        # Column: Epop/7/ifcell (7) Epop[7]
        h(' Epop[7] { netConnSpike_Spikes_file__Epop = new NetCon(&v(0.5), nil, 20.0, 0, 1) } ')
        h(' { netConnSpike_Spikes_file__Epop.record(t_spiketimes_Spikes_file__Epop, spiketimes_Spikes_file__Epop, 7) } ')
        # Column: Epop/8/ifcell (8) Epop[8]
        h(' Epop[8] { netConnSpike_Spikes_file__Epop = new NetCon(&v(0.5), nil, 20.0, 0, 1) } ')
        h(' { netConnSpike_Spikes_file__Epop.record(t_spiketimes_Spikes_file__Epop, spiketimes_Spikes_file__Epop, 8) } ')
        # Column: Epop/9/ifcell (9) Epop[9]
        h(' Epop[9] { netConnSpike_Spikes_file__Epop = new NetCon(&v(0.5), nil, 20.0, 0, 1) } ')
        h(' { netConnSpike_Spikes_file__Epop.record(t_spiketimes_Spikes_file__Epop, spiketimes_Spikes_file__Epop, 9) } ')
        # Column: Epop/10/ifcell (10) Epop[10]
        h(' Epop[10] { netConnSpike_Spikes_file__Epop = new NetCon(&v(0.5), nil, 20.0, 0, 1) } ')
        h(' { netConnSpike_Spikes_file__Epop.record(t_spiketimes_Spikes_file__Epop, spiketimes_Spikes_file__Epop, 10) } ')
        # Column: Epop/11/ifcell (11) Epop[11]
        h(' Epop[11] { netConnSpike_Spikes_file__Epop = new NetCon(&v(0.5), nil, 20.0, 0, 1) } ')
        h(' { netConnSpike_Spikes_file__Epop.record(t_spiketimes_Spikes_file__Epop, spiketimes_Spikes_file__Epop, 11) } ')
        # Column: Epop/12/ifcell (12) Epop[12]
        h(' Epop[12] { netConnSpike_Spikes_file__Epop = new NetCon(&v(0.5), nil, 20.0, 0, 1) } ')
        h(' { netConnSpike_Spikes_file__Epop.record(t_spiketimes_Spikes_file__Epop, spiketimes_Spikes_file__Epop, 12) } ')
        # Column: Epop/13/ifcell (13) Epop[13]
        h(' Epop[13] { netConnSpike_Spikes_file__Epop = new NetCon(&v(0.5), nil, 20.0, 0, 1) } ')
        h(' { netConnSpike_Spikes_file__Epop.record(t_spiketimes_Spikes_file__Epop, spiketimes_Spikes_file__Epop, 13) } ')
        # Column: Epop/14/ifcell (14) Epop[14]
        h(' Epop[14] { netConnSpike_Spikes_file__Epop = new NetCon(&v(0.5), nil, 20.0, 0, 1) } ')
        h(' { netConnSpike_Spikes_file__Epop.record(t_spiketimes_Spikes_file__Epop, spiketimes_Spikes_file__Epop, 14) } ')
        # Column: Epop/15/ifcell (15) Epop[15]
        h(' Epop[15] { netConnSpike_Spikes_file__Epop = new NetCon(&v(0.5), nil, 20.0, 0, 1) } ')
        h(' { netConnSpike_Spikes_file__Epop.record(t_spiketimes_Spikes_file__Epop, spiketimes_Spikes_file__Epop, 15) } ')
        # Column: Epop/16/ifcell (16) Epop[16]
        h(' Epop[16] { netConnSpike_Spikes_file__Epop = new NetCon(&v(0.5), nil, 20.0, 0, 1) } ')
        h(' { netConnSpike_Spikes_file__Epop.record(t_spiketimes_Spikes_file__Epop, spiketimes_Spikes_file__Epop, 16) } ')
        # Column: Epop/17/ifcell (17) Epop[17]
        h(' Epop[17] { netConnSpike_Spikes_file__Epop = new NetCon(&v(0.5), nil, 20.0, 0, 1) } ')
        h(' { netConnSpike_Spikes_file__Epop.record(t_spiketimes_Spikes_file__Epop, spiketimes_Spikes_file__Epop, 17) } ')
        # Column: Epop/18/ifcell (18) Epop[18]
        h(' Epop[18] { netConnSpike_Spikes_file__Epop = new NetCon(&v(0.5), nil, 20.0, 0, 1) } ')
        h(' { netConnSpike_Spikes_file__Epop.record(t_spiketimes_Spikes_file__Epop, spiketimes_Spikes_file__Epop, 18) } ')
        # Column: Epop/19/ifcell (19) Epop[19]
        h(' Epop[19] { netConnSpike_Spikes_file__Epop = new NetCon(&v(0.5), nil, 20.0, 0, 1) } ')
        h(' { netConnSpike_Spikes_file__Epop.record(t_spiketimes_Spikes_file__Epop, spiketimes_Spikes_file__Epop, 19) } ')
        # Column: Epop/20/ifcell (20) Epop[20]
        h(' Epop[20] { netConnSpike_Spikes_file__Epop = new NetCon(&v(0.5), nil, 20.0, 0, 1) } ')
        h(' { netConnSpike_Spikes_file__Epop.record(t_spiketimes_Spikes_file__Epop, spiketimes_Spikes_file__Epop, 20) } ')
        # Column: Epop/21/ifcell (21) Epop[21]
        h(' Epop[21] { netConnSpike_Spikes_file__Epop = new NetCon(&v(0.5), nil, 20.0, 0, 1) } ')
        h(' { netConnSpike_Spikes_file__Epop.record(t_spiketimes_Spikes_file__Epop, spiketimes_Spikes_file__Epop, 21) } ')
        # Column: Epop/22/ifcell (22) Epop[22]
        h(' Epop[22] { netConnSpike_Spikes_file__Epop = new NetCon(&v(0.5), nil, 20.0, 0, 1) } ')
        h(' { netConnSpike_Spikes_file__Epop.record(t_spiketimes_Spikes_file__Epop, spiketimes_Spikes_file__Epop, 22) } ')
        # Column: Epop/23/ifcell (23) Epop[23]
        h(' Epop[23] { netConnSpike_Spikes_file__Epop = new NetCon(&v(0.5), nil, 20.0, 0, 1) } ')
        h(' { netConnSpike_Spikes_file__Epop.record(t_spiketimes_Spikes_file__Epop, spiketimes_Spikes_file__Epop, 23) } ')
        # Column: Epop/24/ifcell (24) Epop[24]
        h(' Epop[24] { netConnSpike_Spikes_file__Epop = new NetCon(&v(0.5), nil, 20.0, 0, 1) } ')
        h(' { netConnSpike_Spikes_file__Epop.record(t_spiketimes_Spikes_file__Epop, spiketimes_Spikes_file__Epop, 24) } ')
        # Column: Epop/25/ifcell (25) Epop[25]
        h(' Epop[25] { netConnSpike_Spikes_file__Epop = new NetCon(&v(0.5), nil, 20.0, 0, 1) } ')
        h(' { netConnSpike_Spikes_file__Epop.record(t_spiketimes_Spikes_file__Epop, spiketimes_Spikes_file__Epop, 25) } ')
        # Column: Epop/26/ifcell (26) Epop[26]
        h(' Epop[26] { netConnSpike_Spikes_file__Epop = new NetCon(&v(0.5), nil, 20.0, 0, 1) } ')
        h(' { netConnSpike_Spikes_file__Epop.record(t_spiketimes_Spikes_file__Epop, spiketimes_Spikes_file__Epop, 26) } ')
        # Column: Epop/27/ifcell (27) Epop[27]
        h(' Epop[27] { netConnSpike_Spikes_file__Epop = new NetCon(&v(0.5), nil, 20.0, 0, 1) } ')
        h(' { netConnSpike_Spikes_file__Epop.record(t_spiketimes_Spikes_file__Epop, spiketimes_Spikes_file__Epop, 27) } ')
        # Column: Epop/28/ifcell (28) Epop[28]
        h(' Epop[28] { netConnSpike_Spikes_file__Epop = new NetCon(&v(0.5), nil, 20.0, 0, 1) } ')
        h(' { netConnSpike_Spikes_file__Epop.record(t_spiketimes_Spikes_file__Epop, spiketimes_Spikes_file__Epop, 28) } ')
        # Column: Epop/29/ifcell (29) Epop[29]
        h(' Epop[29] { netConnSpike_Spikes_file__Epop = new NetCon(&v(0.5), nil, 20.0, 0, 1) } ')
        h(' { netConnSpike_Spikes_file__Epop.record(t_spiketimes_Spikes_file__Epop, spiketimes_Spikes_file__Epop, 29) } ')
        # Column: Epop/30/ifcell (30) Epop[30]
        h(' Epop[30] { netConnSpike_Spikes_file__Epop = new NetCon(&v(0.5), nil, 20.0, 0, 1) } ')
        h(' { netConnSpike_Spikes_file__Epop.record(t_spiketimes_Spikes_file__Epop, spiketimes_Spikes_file__Epop, 30) } ')
        # Column: Epop/31/ifcell (31) Epop[31]
        h(' Epop[31] { netConnSpike_Spikes_file__Epop = new NetCon(&v(0.5), nil, 20.0, 0, 1) } ')
        h(' { netConnSpike_Spikes_file__Epop.record(t_spiketimes_Spikes_file__Epop, spiketimes_Spikes_file__Epop, 31) } ')
        # Column: Epop/32/ifcell (32) Epop[32]
        h(' Epop[32] { netConnSpike_Spikes_file__Epop = new NetCon(&v(0.5), nil, 20.0, 0, 1) } ')
        h(' { netConnSpike_Spikes_file__Epop.record(t_spiketimes_Spikes_file__Epop, spiketimes_Spikes_file__Epop, 32) } ')
        # Column: Epop/33/ifcell (33) Epop[33]
        h(' Epop[33] { netConnSpike_Spikes_file__Epop = new NetCon(&v(0.5), nil, 20.0, 0, 1) } ')
        h(' { netConnSpike_Spikes_file__Epop.record(t_spiketimes_Spikes_file__Epop, spiketimes_Spikes_file__Epop, 33) } ')
        # Column: Epop/34/ifcell (34) Epop[34]
        h(' Epop[34] { netConnSpike_Spikes_file__Epop = new NetCon(&v(0.5), nil, 20.0, 0, 1) } ')
        h(' { netConnSpike_Spikes_file__Epop.record(t_spiketimes_Spikes_file__Epop, spiketimes_Spikes_file__Epop, 34) } ')
        # Column: Epop/35/ifcell (35) Epop[35]
        h(' Epop[35] { netConnSpike_Spikes_file__Epop = new NetCon(&v(0.5), nil, 20.0, 0, 1) } ')
        h(' { netConnSpike_Spikes_file__Epop.record(t_spiketimes_Spikes_file__Epop, spiketimes_Spikes_file__Epop, 35) } ')
        # Column: Epop/36/ifcell (36) Epop[36]
        h(' Epop[36] { netConnSpike_Spikes_file__Epop = new NetCon(&v(0.5), nil, 20.0, 0, 1) } ')
        h(' { netConnSpike_Spikes_file__Epop.record(t_spiketimes_Spikes_file__Epop, spiketimes_Spikes_file__Epop, 36) } ')
        # Column: Epop/37/ifcell (37) Epop[37]
        h(' Epop[37] { netConnSpike_Spikes_file__Epop = new NetCon(&v(0.5), nil, 20.0, 0, 1) } ')
        h(' { netConnSpike_Spikes_file__Epop.record(t_spiketimes_Spikes_file__Epop, spiketimes_Spikes_file__Epop, 37) } ')
        # Column: Epop/38/ifcell (38) Epop[38]
        h(' Epop[38] { netConnSpike_Spikes_file__Epop = new NetCon(&v(0.5), nil, 20.0, 0, 1) } ')
        h(' { netConnSpike_Spikes_file__Epop.record(t_spiketimes_Spikes_file__Epop, spiketimes_Spikes_file__Epop, 38) } ')
        # Column: Epop/39/ifcell (39) Epop[39]
        h(' Epop[39] { netConnSpike_Spikes_file__Epop = new NetCon(&v(0.5), nil, 20.0, 0, 1) } ')
        h(' { netConnSpike_Spikes_file__Epop.record(t_spiketimes_Spikes_file__Epop, spiketimes_Spikes_file__Epop, 39) } ')
        # Column: Epop/40/ifcell (40) Epop[40]
        h(' Epop[40] { netConnSpike_Spikes_file__Epop = new NetCon(&v(0.5), nil, 20.0, 0, 1) } ')
        h(' { netConnSpike_Spikes_file__Epop.record(t_spiketimes_Spikes_file__Epop, spiketimes_Spikes_file__Epop, 40) } ')
        # Column: Epop/41/ifcell (41) Epop[41]
        h(' Epop[41] { netConnSpike_Spikes_file__Epop = new NetCon(&v(0.5), nil, 20.0, 0, 1) } ')
        h(' { netConnSpike_Spikes_file__Epop.record(t_spiketimes_Spikes_file__Epop, spiketimes_Spikes_file__Epop, 41) } ')
        # Column: Epop/42/ifcell (42) Epop[42]
        h(' Epop[42] { netConnSpike_Spikes_file__Epop = new NetCon(&v(0.5), nil, 20.0, 0, 1) } ')
        h(' { netConnSpike_Spikes_file__Epop.record(t_spiketimes_Spikes_file__Epop, spiketimes_Spikes_file__Epop, 42) } ')
        # Column: Epop/43/ifcell (43) Epop[43]
        h(' Epop[43] { netConnSpike_Spikes_file__Epop = new NetCon(&v(0.5), nil, 20.0, 0, 1) } ')
        h(' { netConnSpike_Spikes_file__Epop.record(t_spiketimes_Spikes_file__Epop, spiketimes_Spikes_file__Epop, 43) } ')
        # Column: Epop/44/ifcell (44) Epop[44]
        h(' Epop[44] { netConnSpike_Spikes_file__Epop = new NetCon(&v(0.5), nil, 20.0, 0, 1) } ')
        h(' { netConnSpike_Spikes_file__Epop.record(t_spiketimes_Spikes_file__Epop, spiketimes_Spikes_file__Epop, 44) } ')
        # Column: Epop/45/ifcell (45) Epop[45]
        h(' Epop[45] { netConnSpike_Spikes_file__Epop = new NetCon(&v(0.5), nil, 20.0, 0, 1) } ')
        h(' { netConnSpike_Spikes_file__Epop.record(t_spiketimes_Spikes_file__Epop, spiketimes_Spikes_file__Epop, 45) } ')
        # Column: Epop/46/ifcell (46) Epop[46]
        h(' Epop[46] { netConnSpike_Spikes_file__Epop = new NetCon(&v(0.5), nil, 20.0, 0, 1) } ')
        h(' { netConnSpike_Spikes_file__Epop.record(t_spiketimes_Spikes_file__Epop, spiketimes_Spikes_file__Epop, 46) } ')
        # Column: Epop/47/ifcell (47) Epop[47]
        h(' Epop[47] { netConnSpike_Spikes_file__Epop = new NetCon(&v(0.5), nil, 20.0, 0, 1) } ')
        h(' { netConnSpike_Spikes_file__Epop.record(t_spiketimes_Spikes_file__Epop, spiketimes_Spikes_file__Epop, 47) } ')
        # Column: Epop/48/ifcell (48) Epop[48]
        h(' Epop[48] { netConnSpike_Spikes_file__Epop = new NetCon(&v(0.5), nil, 20.0, 0, 1) } ')
        h(' { netConnSpike_Spikes_file__Epop.record(t_spiketimes_Spikes_file__Epop, spiketimes_Spikes_file__Epop, 48) } ')
        # Column: Epop/49/ifcell (49) Epop[49]
        h(' Epop[49] { netConnSpike_Spikes_file__Epop = new NetCon(&v(0.5), nil, 20.0, 0, 1) } ')
        h(' { netConnSpike_Spikes_file__Epop.record(t_spiketimes_Spikes_file__Epop, spiketimes_Spikes_file__Epop, 49) } ')
        # Column: Epop/50/ifcell (50) Epop[50]
        h(' Epop[50] { netConnSpike_Spikes_file__Epop = new NetCon(&v(0.5), nil, 20.0, 0, 1) } ')
        h(' { netConnSpike_Spikes_file__Epop.record(t_spiketimes_Spikes_file__Epop, spiketimes_Spikes_file__Epop, 50) } ')
        # Column: Epop/51/ifcell (51) Epop[51]
        h(' Epop[51] { netConnSpike_Spikes_file__Epop = new NetCon(&v(0.5), nil, 20.0, 0, 1) } ')
        h(' { netConnSpike_Spikes_file__Epop.record(t_spiketimes_Spikes_file__Epop, spiketimes_Spikes_file__Epop, 51) } ')
        # Column: Epop/52/ifcell (52) Epop[52]
        h(' Epop[52] { netConnSpike_Spikes_file__Epop = new NetCon(&v(0.5), nil, 20.0, 0, 1) } ')
        h(' { netConnSpike_Spikes_file__Epop.record(t_spiketimes_Spikes_file__Epop, spiketimes_Spikes_file__Epop, 52) } ')
        # Column: Epop/53/ifcell (53) Epop[53]
        h(' Epop[53] { netConnSpike_Spikes_file__Epop = new NetCon(&v(0.5), nil, 20.0, 0, 1) } ')
        h(' { netConnSpike_Spikes_file__Epop.record(t_spiketimes_Spikes_file__Epop, spiketimes_Spikes_file__Epop, 53) } ')
        # Column: Epop/54/ifcell (54) Epop[54]
        h(' Epop[54] { netConnSpike_Spikes_file__Epop = new NetCon(&v(0.5), nil, 20.0, 0, 1) } ')
        h(' { netConnSpike_Spikes_file__Epop.record(t_spiketimes_Spikes_file__Epop, spiketimes_Spikes_file__Epop, 54) } ')
        # Column: Epop/55/ifcell (55) Epop[55]
        h(' Epop[55] { netConnSpike_Spikes_file__Epop = new NetCon(&v(0.5), nil, 20.0, 0, 1) } ')
        h(' { netConnSpike_Spikes_file__Epop.record(t_spiketimes_Spikes_file__Epop, spiketimes_Spikes_file__Epop, 55) } ')
        # Column: Epop/56/ifcell (56) Epop[56]
        h(' Epop[56] { netConnSpike_Spikes_file__Epop = new NetCon(&v(0.5), nil, 20.0, 0, 1) } ')
        h(' { netConnSpike_Spikes_file__Epop.record(t_spiketimes_Spikes_file__Epop, spiketimes_Spikes_file__Epop, 56) } ')
        # Column: Epop/57/ifcell (57) Epop[57]
        h(' Epop[57] { netConnSpike_Spikes_file__Epop = new NetCon(&v(0.5), nil, 20.0, 0, 1) } ')
        h(' { netConnSpike_Spikes_file__Epop.record(t_spiketimes_Spikes_file__Epop, spiketimes_Spikes_file__Epop, 57) } ')
        # Column: Epop/58/ifcell (58) Epop[58]
        h(' Epop[58] { netConnSpike_Spikes_file__Epop = new NetCon(&v(0.5), nil, 20.0, 0, 1) } ')
        h(' { netConnSpike_Spikes_file__Epop.record(t_spiketimes_Spikes_file__Epop, spiketimes_Spikes_file__Epop, 58) } ')
        # Column: Epop/59/ifcell (59) Epop[59]
        h(' Epop[59] { netConnSpike_Spikes_file__Epop = new NetCon(&v(0.5), nil, 20.0, 0, 1) } ')
        h(' { netConnSpike_Spikes_file__Epop.record(t_spiketimes_Spikes_file__Epop, spiketimes_Spikes_file__Epop, 59) } ')
        # Column: Epop/60/ifcell (60) Epop[60]
        h(' Epop[60] { netConnSpike_Spikes_file__Epop = new NetCon(&v(0.5), nil, 20.0, 0, 1) } ')
        h(' { netConnSpike_Spikes_file__Epop.record(t_spiketimes_Spikes_file__Epop, spiketimes_Spikes_file__Epop, 60) } ')
        # Column: Epop/61/ifcell (61) Epop[61]
        h(' Epop[61] { netConnSpike_Spikes_file__Epop = new NetCon(&v(0.5), nil, 20.0, 0, 1) } ')
        h(' { netConnSpike_Spikes_file__Epop.record(t_spiketimes_Spikes_file__Epop, spiketimes_Spikes_file__Epop, 61) } ')
        # Column: Epop/62/ifcell (62) Epop[62]
        h(' Epop[62] { netConnSpike_Spikes_file__Epop = new NetCon(&v(0.5), nil, 20.0, 0, 1) } ')
        h(' { netConnSpike_Spikes_file__Epop.record(t_spiketimes_Spikes_file__Epop, spiketimes_Spikes_file__Epop, 62) } ')
        # Column: Epop/63/ifcell (63) Epop[63]
        h(' Epop[63] { netConnSpike_Spikes_file__Epop = new NetCon(&v(0.5), nil, 20.0, 0, 1) } ')
        h(' { netConnSpike_Spikes_file__Epop.record(t_spiketimes_Spikes_file__Epop, spiketimes_Spikes_file__Epop, 63) } ')
        # Column: Epop/64/ifcell (64) Epop[64]
        h(' Epop[64] { netConnSpike_Spikes_file__Epop = new NetCon(&v(0.5), nil, 20.0, 0, 1) } ')
        h(' { netConnSpike_Spikes_file__Epop.record(t_spiketimes_Spikes_file__Epop, spiketimes_Spikes_file__Epop, 64) } ')
        # Column: Epop/65/ifcell (65) Epop[65]
        h(' Epop[65] { netConnSpike_Spikes_file__Epop = new NetCon(&v(0.5), nil, 20.0, 0, 1) } ')
        h(' { netConnSpike_Spikes_file__Epop.record(t_spiketimes_Spikes_file__Epop, spiketimes_Spikes_file__Epop, 65) } ')
        # Column: Epop/66/ifcell (66) Epop[66]
        h(' Epop[66] { netConnSpike_Spikes_file__Epop = new NetCon(&v(0.5), nil, 20.0, 0, 1) } ')
        h(' { netConnSpike_Spikes_file__Epop.record(t_spiketimes_Spikes_file__Epop, spiketimes_Spikes_file__Epop, 66) } ')
        # Column: Epop/67/ifcell (67) Epop[67]
        h(' Epop[67] { netConnSpike_Spikes_file__Epop = new NetCon(&v(0.5), nil, 20.0, 0, 1) } ')
        h(' { netConnSpike_Spikes_file__Epop.record(t_spiketimes_Spikes_file__Epop, spiketimes_Spikes_file__Epop, 67) } ')
        # Column: Epop/68/ifcell (68) Epop[68]
        h(' Epop[68] { netConnSpike_Spikes_file__Epop = new NetCon(&v(0.5), nil, 20.0, 0, 1) } ')
        h(' { netConnSpike_Spikes_file__Epop.record(t_spiketimes_Spikes_file__Epop, spiketimes_Spikes_file__Epop, 68) } ')
        # Column: Epop/69/ifcell (69) Epop[69]
        h(' Epop[69] { netConnSpike_Spikes_file__Epop = new NetCon(&v(0.5), nil, 20.0, 0, 1) } ')
        h(' { netConnSpike_Spikes_file__Epop.record(t_spiketimes_Spikes_file__Epop, spiketimes_Spikes_file__Epop, 69) } ')
        # Column: Epop/70/ifcell (70) Epop[70]
        h(' Epop[70] { netConnSpike_Spikes_file__Epop = new NetCon(&v(0.5), nil, 20.0, 0, 1) } ')
        h(' { netConnSpike_Spikes_file__Epop.record(t_spiketimes_Spikes_file__Epop, spiketimes_Spikes_file__Epop, 70) } ')
        # Column: Epop/71/ifcell (71) Epop[71]
        h(' Epop[71] { netConnSpike_Spikes_file__Epop = new NetCon(&v(0.5), nil, 20.0, 0, 1) } ')
        h(' { netConnSpike_Spikes_file__Epop.record(t_spiketimes_Spikes_file__Epop, spiketimes_Spikes_file__Epop, 71) } ')
        # Column: Epop/72/ifcell (72) Epop[72]
        h(' Epop[72] { netConnSpike_Spikes_file__Epop = new NetCon(&v(0.5), nil, 20.0, 0, 1) } ')
        h(' { netConnSpike_Spikes_file__Epop.record(t_spiketimes_Spikes_file__Epop, spiketimes_Spikes_file__Epop, 72) } ')
        # Column: Epop/73/ifcell (73) Epop[73]
        h(' Epop[73] { netConnSpike_Spikes_file__Epop = new NetCon(&v(0.5), nil, 20.0, 0, 1) } ')
        h(' { netConnSpike_Spikes_file__Epop.record(t_spiketimes_Spikes_file__Epop, spiketimes_Spikes_file__Epop, 73) } ')
        # Column: Epop/74/ifcell (74) Epop[74]
        h(' Epop[74] { netConnSpike_Spikes_file__Epop = new NetCon(&v(0.5), nil, 20.0, 0, 1) } ')
        h(' { netConnSpike_Spikes_file__Epop.record(t_spiketimes_Spikes_file__Epop, spiketimes_Spikes_file__Epop, 74) } ')
        # Column: Epop/75/ifcell (75) Epop[75]
        h(' Epop[75] { netConnSpike_Spikes_file__Epop = new NetCon(&v(0.5), nil, 20.0, 0, 1) } ')
        h(' { netConnSpike_Spikes_file__Epop.record(t_spiketimes_Spikes_file__Epop, spiketimes_Spikes_file__Epop, 75) } ')
        # Column: Epop/76/ifcell (76) Epop[76]
        h(' Epop[76] { netConnSpike_Spikes_file__Epop = new NetCon(&v(0.5), nil, 20.0, 0, 1) } ')
        h(' { netConnSpike_Spikes_file__Epop.record(t_spiketimes_Spikes_file__Epop, spiketimes_Spikes_file__Epop, 76) } ')
        # Column: Epop/77/ifcell (77) Epop[77]
        h(' Epop[77] { netConnSpike_Spikes_file__Epop = new NetCon(&v(0.5), nil, 20.0, 0, 1) } ')
        h(' { netConnSpike_Spikes_file__Epop.record(t_spiketimes_Spikes_file__Epop, spiketimes_Spikes_file__Epop, 77) } ')
        # Column: Epop/78/ifcell (78) Epop[78]
        h(' Epop[78] { netConnSpike_Spikes_file__Epop = new NetCon(&v(0.5), nil, 20.0, 0, 1) } ')
        h(' { netConnSpike_Spikes_file__Epop.record(t_spiketimes_Spikes_file__Epop, spiketimes_Spikes_file__Epop, 78) } ')
        # Column: Epop/79/ifcell (79) Epop[79]
        h(' Epop[79] { netConnSpike_Spikes_file__Epop = new NetCon(&v(0.5), nil, 20.0, 0, 1) } ')
        h(' { netConnSpike_Spikes_file__Epop.record(t_spiketimes_Spikes_file__Epop, spiketimes_Spikes_file__Epop, 79) } ')

        self.initialized = False

        self.sim_end = -1 # will be overwritten

        setup_end = time.time()
        self.setup_time = setup_end - self.setup_start
        print("Setting up the network to simulate took %f seconds"%(self.setup_time))

    def run(self):

        self.initialized = True
        sim_start = time.time()
        print("Running a simulation of %sms (dt = %sms; seed=%s)" % (h.tstop, h.dt, self.seed))

        try:
            h.run()
        except Exception as e:
            print("Exception running NEURON: %s" % (e))
            quit()


        self.sim_end = time.time()
        self.sim_time = self.sim_end - sim_start
        print("Finished NEURON simulation in %f seconds (%f mins)..."%(self.sim_time, self.sim_time/60.0))

        try:
            self.save_results()
        except Exception as e:
            print("Exception saving results of NEURON simulation: %s" % (e))
            quit()


    def advance(self):

        if not self.initialized:
            h.finitialize()
            self.initialized = True

        h.fadvance()


    ###############################################################################
    # Hash function to use in generation of random value
    # This is copied from NetPyNE: https://github.com/Neurosim-lab/netpyne/blob/master/netpyne/simFuncs.py
    ###############################################################################
    def _id32 (self,obj): 
        return int(hashlib.md5(obj).hexdigest()[0:8],16)  # convert 8 first chars of md5 hash in base 16 to int


    ###############################################################################
    # Initialize the stim randomizer
    # This is copied from NetPyNE: https://github.com/Neurosim-lab/netpyne/blob/master/netpyne/simFuncs.py
    ###############################################################################
    def _init_stim_randomizer(self,rand, stimType, gid, seed): 
        #print("INIT STIM  %s; %s; %s; %s"%(rand, stimType, gid, seed))
        rand.Random123(self._id32(stimType), gid, seed)


    def save_results(self):

        print("Saving results at t=%s..."%h.t)

        if self.sim_end < 0: self.sim_end = time.time()


        # ######################   File to save: time.dat (time)
        py_v_time = [ t/1000 for t in h.v_time.to_python() ]  # Convert to Python list for speed...

        f_time_f2 = open('time.dat', 'w')
        num_points = len(py_v_time)  # Simulation may have been stopped before tstop...

        for i in range(num_points):
            f_time_f2.write('%f'% py_v_time[i])  # Save in SI units...
        f_time_f2.close()
        print("Saved data to: time.dat")

        # ######################   File to save: SimExample7.expoisson.spikes (Spikes_file__expoisson)

        f_Spikes_file__expoisson_f2 = open('SimExample7.expoisson.spikes', 'w')
        h(' objref netConnSpike_Spikes_file__expoisson ')
        spike_ids = h.spiketimes_Spikes_file__expoisson.to_python()  
        spike_times = h.t_spiketimes_Spikes_file__expoisson.to_python()
        for i, id in enumerate(spike_ids):
            # Saving in format: ID_TIME
            f_Spikes_file__expoisson_f2.write("%i\t%s\n"%(id,spike_times[i]/1000.0))
        f_Spikes_file__expoisson_f2.close()
        print("Saved data to: SimExample7.expoisson.spikes")

        # ######################   File to save: SimExample7.Ipop.spikes (Spikes_file__Ipop)

        f_Spikes_file__Ipop_f2 = open('SimExample7.Ipop.spikes', 'w')
        h(' objref netConnSpike_Spikes_file__Ipop ')
        spike_ids = h.spiketimes_Spikes_file__Ipop.to_python()  
        spike_times = h.t_spiketimes_Spikes_file__Ipop.to_python()
        for i, id in enumerate(spike_ids):
            # Saving in format: ID_TIME
            f_Spikes_file__Ipop_f2.write("%i\t%s\n"%(id,spike_times[i]/1000.0))
        f_Spikes_file__Ipop_f2.close()
        print("Saved data to: SimExample7.Ipop.spikes")

        # ######################   File to save: SimExample7.Ipop.v.dat (SimExample7_Ipop_v_dat)
        py_v_Ipop_0_ifcell_v_SimExample7_Ipop_v_dat = [ float(x  / 1000.0) for x in h.v_Ipop_0_ifcell_v_SimExample7_Ipop_v_dat.to_python() ]  # Convert to Python list for speed, variable has dim: voltage
        py_v_Ipop_1_ifcell_v_SimExample7_Ipop_v_dat = [ float(x  / 1000.0) for x in h.v_Ipop_1_ifcell_v_SimExample7_Ipop_v_dat.to_python() ]  # Convert to Python list for speed, variable has dim: voltage

        f_SimExample7_Ipop_v_dat_f2 = open('SimExample7.Ipop.v.dat', 'w')
        num_points = len(py_v_time)  # Simulation may have been stopped before tstop...

        for i in range(num_points):
            f_SimExample7_Ipop_v_dat_f2.write('%e\t%e\t%e\t\n' % (py_v_time[i], py_v_Ipop_0_ifcell_v_SimExample7_Ipop_v_dat[i], py_v_Ipop_1_ifcell_v_SimExample7_Ipop_v_dat[i], ))
        f_SimExample7_Ipop_v_dat_f2.close()
        print("Saved data to: SimExample7.Ipop.v.dat")

        # ######################   File to save: SimExample7.Epop.v.dat (SimExample7_Epop_v_dat)
        py_v_Epop_0_ifcell_v_SimExample7_Epop_v_dat = [ float(x  / 1000.0) for x in h.v_Epop_0_ifcell_v_SimExample7_Epop_v_dat.to_python() ]  # Convert to Python list for speed, variable has dim: voltage
        py_v_Epop_1_ifcell_v_SimExample7_Epop_v_dat = [ float(x  / 1000.0) for x in h.v_Epop_1_ifcell_v_SimExample7_Epop_v_dat.to_python() ]  # Convert to Python list for speed, variable has dim: voltage

        f_SimExample7_Epop_v_dat_f2 = open('SimExample7.Epop.v.dat', 'w')
        num_points = len(py_v_time)  # Simulation may have been stopped before tstop...

        for i in range(num_points):
            f_SimExample7_Epop_v_dat_f2.write('%e\t%e\t%e\t\n' % (py_v_time[i], py_v_Epop_0_ifcell_v_SimExample7_Epop_v_dat[i], py_v_Epop_1_ifcell_v_SimExample7_Epop_v_dat[i], ))
        f_SimExample7_Epop_v_dat_f2.close()
        print("Saved data to: SimExample7.Epop.v.dat")

        # ######################   File to save: SimExample7.inpoisson.spikes (Spikes_file__inpoisson)

        f_Spikes_file__inpoisson_f2 = open('SimExample7.inpoisson.spikes', 'w')
        h(' objref netConnSpike_Spikes_file__inpoisson ')
        spike_ids = h.spiketimes_Spikes_file__inpoisson.to_python()  
        spike_times = h.t_spiketimes_Spikes_file__inpoisson.to_python()
        for i, id in enumerate(spike_ids):
            # Saving in format: ID_TIME
            f_Spikes_file__inpoisson_f2.write("%i\t%s\n"%(id,spike_times[i]/1000.0))
        f_Spikes_file__inpoisson_f2.close()
        print("Saved data to: SimExample7.inpoisson.spikes")

        # ######################   File to save: SimExample7.Epop.spikes (Spikes_file__Epop)

        f_Spikes_file__Epop_f2 = open('SimExample7.Epop.spikes', 'w')
        h(' objref netConnSpike_Spikes_file__Epop ')
        spike_ids = h.spiketimes_Spikes_file__Epop.to_python()  
        spike_times = h.t_spiketimes_Spikes_file__Epop.to_python()
        for i, id in enumerate(spike_ids):
            # Saving in format: ID_TIME
            f_Spikes_file__Epop_f2.write("%i\t%s\n"%(id,spike_times[i]/1000.0))
        f_Spikes_file__Epop_f2.close()
        print("Saved data to: SimExample7.Epop.spikes")

        save_end = time.time()
        save_time = save_end - self.sim_end
        print("Finished saving results in %f seconds"%(save_time))

        self.report_file.write('StartTime=%s\n'%datetime.datetime.fromtimestamp(self.setup_start).strftime('%Y-%m-%d %H:%M:%S'))
        self.report_file.write('SetupTime=%s\n'%self.setup_time)
        self.report_file.write('RealSimulationTime=%s\n'%self.sim_time)
        self.report_file.write('SimulationSaveTime=%s\n'%save_time)
        self.report_file.close()

        print("Saving report of simulation to %s"%('report.SimExample7.txt'))

        print("Done")

        quit()


if __name__ == '__main__':

    ns = NeuronSimulation(tstop=1000.0, dt=0.025, seed=123)

    ns.run()

